use lazy_static::lazy_static;
use std::collections::HashMap;

type Colormap = [[u8; 3]; 256];

pub fn load_cmap(cmap_name: &str) -> &[[u8; 3]; 256] {
    CMAPS
        .get(cmap_name)
        .unwrap_or_else(|| panic!("Invalid colormap name: {}", cmap_name))
}

lazy_static! {
    pub static ref CMAPS: HashMap<&'static str, Colormap> = {
        let mut m = HashMap::new();
        m.insert(
            "16_colors",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 171],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [1, 1, 224],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [0, 110, 255],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 171, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 224, 254],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [1, 254, 1],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [190, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 224, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [255, 141, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [250, 94, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 0],
                [245, 0, 135],
                [245, 0, 141],
                [245, 0, 147],
                [245, 0, 153],
                [245, 0, 160],
                [245, 0, 166],
                [245, 0, 172],
                [245, 0, 178],
                [245, 0, 185],
                [245, 0, 191],
                [245, 0, 197],
                [245, 0, 203],
                [245, 0, 210],
                [245, 0, 216],
                [245, 0, 222],
                [245, 0, 228],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [222, 180, 222],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "3-3-2 RGB",
            [
                [0, 0, 0],
                [0, 0, 64],
                [0, 0, 128],
                [0, 0, 192],
                [0, 32, 0],
                [0, 32, 64],
                [0, 32, 128],
                [0, 32, 192],
                [0, 64, 0],
                [0, 64, 64],
                [0, 64, 128],
                [0, 64, 192],
                [0, 96, 0],
                [0, 96, 64],
                [0, 96, 128],
                [0, 96, 192],
                [0, 128, 0],
                [0, 128, 64],
                [0, 128, 128],
                [0, 128, 192],
                [0, 160, 0],
                [0, 160, 64],
                [0, 160, 128],
                [0, 160, 192],
                [0, 192, 0],
                [0, 192, 64],
                [0, 192, 128],
                [0, 192, 192],
                [0, 224, 0],
                [0, 224, 64],
                [0, 224, 128],
                [0, 224, 192],
                [32, 0, 0],
                [32, 0, 64],
                [32, 0, 128],
                [32, 0, 192],
                [32, 32, 0],
                [32, 32, 64],
                [32, 32, 128],
                [32, 32, 192],
                [32, 64, 0],
                [32, 64, 64],
                [32, 64, 128],
                [32, 64, 192],
                [32, 96, 0],
                [32, 96, 64],
                [32, 96, 128],
                [32, 96, 192],
                [32, 128, 0],
                [32, 128, 64],
                [32, 128, 128],
                [32, 128, 192],
                [32, 160, 0],
                [32, 160, 64],
                [32, 160, 128],
                [32, 160, 192],
                [32, 192, 0],
                [32, 192, 64],
                [32, 192, 128],
                [32, 192, 192],
                [32, 224, 0],
                [32, 224, 64],
                [32, 224, 128],
                [32, 224, 192],
                [64, 0, 0],
                [64, 0, 64],
                [64, 0, 128],
                [64, 0, 192],
                [64, 32, 0],
                [64, 32, 64],
                [64, 32, 128],
                [64, 32, 192],
                [64, 64, 0],
                [64, 64, 64],
                [64, 64, 128],
                [64, 64, 192],
                [64, 96, 0],
                [64, 96, 64],
                [64, 96, 128],
                [64, 96, 192],
                [64, 128, 0],
                [64, 128, 64],
                [64, 128, 128],
                [64, 128, 192],
                [64, 160, 0],
                [64, 160, 64],
                [64, 160, 128],
                [64, 160, 192],
                [64, 192, 0],
                [64, 192, 64],
                [64, 192, 128],
                [64, 192, 192],
                [64, 224, 0],
                [64, 224, 64],
                [64, 224, 128],
                [64, 224, 192],
                [96, 0, 0],
                [96, 0, 64],
                [96, 0, 128],
                [96, 0, 192],
                [96, 32, 0],
                [96, 32, 64],
                [96, 32, 128],
                [96, 32, 192],
                [96, 64, 0],
                [96, 64, 64],
                [96, 64, 128],
                [96, 64, 192],
                [96, 96, 0],
                [96, 96, 64],
                [96, 96, 128],
                [96, 96, 192],
                [96, 128, 0],
                [96, 128, 64],
                [96, 128, 128],
                [96, 128, 192],
                [96, 160, 0],
                [96, 160, 64],
                [96, 160, 128],
                [96, 160, 192],
                [96, 192, 0],
                [96, 192, 64],
                [96, 192, 128],
                [96, 192, 192],
                [96, 224, 0],
                [96, 224, 64],
                [96, 224, 128],
                [96, 224, 192],
                [128, 0, 0],
                [128, 0, 64],
                [128, 0, 128],
                [128, 0, 192],
                [128, 32, 0],
                [128, 32, 64],
                [128, 32, 128],
                [128, 32, 192],
                [128, 64, 0],
                [128, 64, 64],
                [128, 64, 128],
                [128, 64, 192],
                [128, 96, 0],
                [128, 96, 64],
                [128, 96, 128],
                [128, 96, 192],
                [128, 128, 0],
                [128, 128, 64],
                [128, 128, 128],
                [128, 128, 192],
                [128, 160, 0],
                [128, 160, 64],
                [128, 160, 128],
                [128, 160, 192],
                [128, 192, 0],
                [128, 192, 64],
                [128, 192, 128],
                [128, 192, 192],
                [128, 224, 0],
                [128, 224, 64],
                [128, 224, 128],
                [128, 224, 192],
                [160, 0, 0],
                [160, 0, 64],
                [160, 0, 128],
                [160, 0, 192],
                [160, 32, 0],
                [160, 32, 64],
                [160, 32, 128],
                [160, 32, 192],
                [160, 64, 0],
                [160, 64, 64],
                [160, 64, 128],
                [160, 64, 192],
                [160, 96, 0],
                [160, 96, 64],
                [160, 96, 128],
                [160, 96, 192],
                [160, 128, 0],
                [160, 128, 64],
                [160, 128, 128],
                [160, 128, 192],
                [160, 160, 0],
                [160, 160, 64],
                [160, 160, 128],
                [160, 160, 192],
                [160, 192, 0],
                [160, 192, 64],
                [160, 192, 128],
                [160, 192, 192],
                [160, 224, 0],
                [160, 224, 64],
                [160, 224, 128],
                [160, 224, 192],
                [192, 0, 0],
                [192, 0, 64],
                [192, 0, 128],
                [192, 0, 192],
                [192, 32, 0],
                [192, 32, 64],
                [192, 32, 128],
                [192, 32, 192],
                [192, 64, 0],
                [192, 64, 64],
                [192, 64, 128],
                [192, 64, 192],
                [192, 96, 0],
                [192, 96, 64],
                [192, 96, 128],
                [192, 96, 192],
                [192, 128, 0],
                [192, 128, 64],
                [192, 128, 128],
                [192, 128, 192],
                [192, 160, 0],
                [192, 160, 64],
                [192, 160, 128],
                [192, 160, 192],
                [192, 192, 0],
                [192, 192, 64],
                [192, 192, 128],
                [192, 192, 192],
                [192, 224, 0],
                [192, 224, 64],
                [192, 224, 128],
                [192, 224, 192],
                [224, 0, 0],
                [224, 0, 64],
                [224, 0, 128],
                [224, 0, 192],
                [224, 32, 0],
                [224, 32, 64],
                [224, 32, 128],
                [224, 32, 192],
                [224, 64, 0],
                [224, 64, 64],
                [224, 64, 128],
                [224, 64, 192],
                [224, 96, 0],
                [224, 96, 64],
                [224, 96, 128],
                [224, 96, 192],
                [224, 128, 0],
                [224, 128, 64],
                [224, 128, 128],
                [224, 128, 192],
                [224, 160, 0],
                [224, 160, 64],
                [224, 160, 128],
                [224, 160, 192],
                [224, 192, 0],
                [224, 192, 64],
                [224, 192, 128],
                [224, 192, 192],
                [224, 224, 0],
                [224, 224, 64],
                [224, 224, 128],
                [224, 224, 192],
            ],
        );

        m.insert(
            "3color-BMR",
            [
                [0, 0, 255],
                [1, 0, 255],
                [3, 0, 255],
                [5, 0, 255],
                [7, 0, 255],
                [9, 0, 255],
                [11, 0, 255],
                [13, 0, 255],
                [15, 0, 255],
                [17, 0, 255],
                [19, 0, 255],
                [21, 0, 255],
                [23, 0, 255],
                [25, 0, 255],
                [27, 0, 255],
                [29, 0, 255],
                [31, 0, 255],
                [33, 0, 255],
                [35, 0, 255],
                [37, 0, 255],
                [39, 0, 255],
                [41, 0, 255],
                [43, 0, 255],
                [45, 0, 255],
                [47, 0, 255],
                [49, 0, 255],
                [51, 0, 255],
                [53, 0, 255],
                [55, 0, 255],
                [57, 0, 255],
                [59, 0, 255],
                [61, 0, 255],
                [63, 0, 255],
                [65, 0, 255],
                [67, 0, 255],
                [69, 0, 255],
                [71, 0, 255],
                [73, 0, 255],
                [75, 0, 255],
                [77, 0, 255],
                [79, 0, 255],
                [81, 0, 255],
                [83, 0, 255],
                [85, 0, 255],
                [87, 0, 255],
                [89, 0, 255],
                [91, 0, 255],
                [93, 0, 255],
                [95, 0, 255],
                [97, 0, 255],
                [99, 0, 255],
                [101, 0, 255],
                [103, 0, 255],
                [105, 0, 255],
                [107, 0, 255],
                [109, 0, 255],
                [111, 0, 255],
                [113, 0, 255],
                [115, 0, 255],
                [117, 0, 255],
                [119, 0, 255],
                [121, 0, 255],
                [123, 0, 255],
                [125, 0, 255],
                [127, 0, 255],
                [129, 0, 255],
                [131, 0, 255],
                [133, 0, 255],
                [135, 0, 255],
                [137, 0, 255],
                [139, 0, 255],
                [141, 0, 255],
                [143, 0, 255],
                [145, 0, 255],
                [147, 0, 255],
                [149, 0, 255],
                [151, 0, 255],
                [153, 0, 255],
                [155, 0, 255],
                [157, 0, 255],
                [159, 0, 255],
                [161, 0, 255],
                [163, 0, 255],
                [165, 0, 255],
                [167, 0, 255],
                [169, 0, 255],
                [171, 0, 255],
                [173, 0, 255],
                [175, 0, 255],
                [177, 0, 255],
                [179, 0, 255],
                [181, 0, 255],
                [183, 0, 255],
                [185, 0, 255],
                [187, 0, 255],
                [189, 0, 255],
                [191, 0, 255],
                [193, 0, 255],
                [195, 0, 255],
                [197, 0, 255],
                [199, 0, 255],
                [201, 0, 255],
                [203, 0, 255],
                [205, 0, 255],
                [207, 0, 255],
                [209, 0, 255],
                [211, 0, 255],
                [213, 0, 255],
                [215, 0, 255],
                [217, 0, 255],
                [219, 0, 255],
                [221, 0, 255],
                [223, 0, 255],
                [225, 0, 255],
                [227, 0, 255],
                [229, 0, 255],
                [231, 0, 255],
                [233, 0, 255],
                [235, 0, 255],
                [237, 0, 255],
                [239, 0, 255],
                [241, 0, 255],
                [243, 0, 255],
                [245, 0, 255],
                [247, 0, 255],
                [249, 0, 255],
                [251, 0, 255],
                [255, 0, 255],
                [255, 0, 255],
                [255, 0, 253],
                [255, 0, 251],
                [255, 0, 249],
                [255, 0, 247],
                [255, 0, 245],
                [255, 0, 243],
                [255, 0, 241],
                [255, 0, 239],
                [255, 0, 237],
                [255, 0, 235],
                [255, 0, 233],
                [255, 0, 231],
                [255, 0, 229],
                [255, 0, 227],
                [255, 0, 225],
                [255, 0, 223],
                [255, 0, 221],
                [255, 0, 219],
                [255, 0, 217],
                [255, 0, 215],
                [255, 0, 213],
                [255, 0, 211],
                [255, 0, 209],
                [255, 0, 207],
                [255, 0, 205],
                [255, 0, 203],
                [255, 0, 201],
                [255, 0, 199],
                [255, 0, 197],
                [255, 0, 195],
                [255, 0, 193],
                [255, 0, 191],
                [255, 0, 189],
                [255, 0, 187],
                [255, 0, 185],
                [255, 0, 183],
                [255, 0, 181],
                [255, 0, 179],
                [255, 0, 177],
                [255, 0, 175],
                [255, 0, 173],
                [255, 0, 171],
                [255, 0, 169],
                [255, 0, 167],
                [255, 0, 165],
                [255, 0, 163],
                [255, 0, 161],
                [255, 0, 159],
                [255, 0, 157],
                [255, 0, 155],
                [255, 0, 153],
                [255, 0, 151],
                [255, 0, 149],
                [255, 0, 147],
                [255, 0, 145],
                [255, 0, 143],
                [255, 0, 141],
                [255, 0, 139],
                [255, 0, 137],
                [255, 0, 135],
                [255, 0, 133],
                [255, 0, 131],
                [255, 0, 129],
                [255, 0, 127],
                [255, 0, 125],
                [255, 0, 123],
                [255, 0, 121],
                [255, 0, 119],
                [255, 0, 117],
                [255, 0, 115],
                [255, 0, 113],
                [255, 0, 111],
                [255, 0, 109],
                [255, 0, 107],
                [255, 0, 105],
                [255, 0, 103],
                [255, 0, 101],
                [255, 0, 99],
                [255, 0, 97],
                [255, 0, 95],
                [255, 0, 93],
                [255, 0, 91],
                [255, 0, 89],
                [255, 0, 87],
                [255, 0, 85],
                [255, 0, 83],
                [255, 0, 81],
                [255, 0, 79],
                [255, 0, 77],
                [255, 0, 75],
                [255, 0, 73],
                [255, 0, 71],
                [255, 0, 69],
                [255, 0, 67],
                [255, 0, 65],
                [255, 0, 63],
                [255, 0, 61],
                [255, 0, 59],
                [255, 0, 57],
                [255, 0, 55],
                [255, 0, 53],
                [255, 0, 51],
                [255, 0, 49],
                [255, 0, 47],
                [255, 0, 45],
                [255, 0, 43],
                [255, 0, 41],
                [255, 0, 39],
                [255, 0, 37],
                [255, 0, 35],
                [255, 0, 33],
                [255, 0, 31],
                [255, 0, 29],
                [255, 0, 27],
                [255, 0, 25],
                [255, 0, 23],
                [255, 0, 21],
                [255, 0, 19],
                [255, 0, 17],
                [255, 0, 15],
                [255, 0, 13],
                [255, 0, 11],
                [255, 0, 9],
                [255, 0, 7],
                [255, 0, 5],
                [255, 0, 3],
                [255, 0, 0],
            ],
        );

        m.insert(
            "3color-CGY",
            [
                [0, 255, 255],
                [0, 255, 253],
                [0, 255, 251],
                [0, 255, 249],
                [0, 255, 247],
                [0, 255, 245],
                [0, 255, 243],
                [0, 255, 241],
                [0, 255, 239],
                [0, 255, 237],
                [0, 255, 235],
                [0, 255, 233],
                [0, 255, 231],
                [0, 255, 229],
                [0, 255, 227],
                [0, 255, 225],
                [0, 255, 223],
                [0, 255, 221],
                [0, 255, 219],
                [0, 255, 217],
                [0, 255, 215],
                [0, 255, 213],
                [0, 255, 211],
                [0, 255, 209],
                [0, 255, 207],
                [0, 255, 205],
                [0, 255, 203],
                [0, 255, 201],
                [0, 255, 199],
                [0, 255, 197],
                [0, 255, 195],
                [0, 255, 193],
                [0, 255, 191],
                [0, 255, 189],
                [0, 255, 187],
                [0, 255, 185],
                [0, 255, 183],
                [0, 255, 181],
                [0, 255, 179],
                [0, 255, 177],
                [0, 255, 175],
                [0, 255, 173],
                [0, 255, 171],
                [0, 255, 169],
                [0, 255, 167],
                [0, 255, 165],
                [0, 255, 163],
                [0, 255, 161],
                [0, 255, 159],
                [0, 255, 157],
                [0, 255, 155],
                [0, 255, 153],
                [0, 255, 151],
                [0, 255, 149],
                [0, 255, 147],
                [0, 255, 145],
                [0, 255, 143],
                [0, 255, 141],
                [0, 255, 139],
                [0, 255, 137],
                [0, 255, 135],
                [0, 255, 133],
                [0, 255, 131],
                [0, 255, 129],
                [0, 255, 127],
                [0, 255, 125],
                [0, 255, 123],
                [0, 255, 121],
                [0, 255, 119],
                [0, 255, 117],
                [0, 255, 115],
                [0, 255, 113],
                [0, 255, 111],
                [0, 255, 109],
                [0, 255, 107],
                [0, 255, 105],
                [0, 255, 103],
                [0, 255, 101],
                [0, 255, 99],
                [0, 255, 97],
                [0, 255, 95],
                [0, 255, 93],
                [0, 255, 91],
                [0, 255, 89],
                [0, 255, 87],
                [0, 255, 85],
                [0, 255, 83],
                [0, 255, 81],
                [0, 255, 79],
                [0, 255, 77],
                [0, 255, 75],
                [0, 255, 73],
                [0, 255, 71],
                [0, 255, 69],
                [0, 255, 67],
                [0, 255, 65],
                [0, 255, 63],
                [0, 255, 61],
                [0, 255, 59],
                [0, 255, 57],
                [0, 255, 55],
                [0, 255, 53],
                [0, 255, 51],
                [0, 255, 49],
                [0, 255, 47],
                [0, 255, 45],
                [0, 255, 43],
                [0, 255, 41],
                [0, 255, 39],
                [0, 255, 37],
                [0, 255, 35],
                [0, 255, 33],
                [0, 255, 31],
                [0, 255, 29],
                [0, 255, 27],
                [0, 255, 25],
                [0, 255, 23],
                [0, 255, 21],
                [0, 255, 19],
                [0, 255, 17],
                [0, 255, 15],
                [0, 255, 13],
                [0, 255, 11],
                [0, 255, 9],
                [0, 255, 7],
                [0, 255, 5],
                [0, 255, 3],
                [0, 255, 0],
                [0, 255, 0],
                [1, 255, 0],
                [3, 255, 0],
                [5, 255, 0],
                [7, 255, 0],
                [9, 255, 0],
                [11, 255, 0],
                [13, 255, 0],
                [15, 255, 0],
                [17, 255, 0],
                [19, 255, 0],
                [21, 255, 0],
                [23, 255, 0],
                [25, 255, 0],
                [27, 255, 0],
                [29, 255, 0],
                [31, 255, 0],
                [33, 255, 0],
                [35, 255, 0],
                [37, 255, 0],
                [39, 255, 0],
                [41, 255, 0],
                [43, 255, 0],
                [45, 255, 0],
                [47, 255, 0],
                [49, 255, 0],
                [51, 255, 0],
                [53, 255, 0],
                [55, 255, 0],
                [57, 255, 0],
                [59, 255, 0],
                [61, 255, 0],
                [63, 255, 0],
                [65, 255, 0],
                [67, 255, 0],
                [69, 255, 0],
                [71, 255, 0],
                [73, 255, 0],
                [75, 255, 0],
                [77, 255, 0],
                [79, 255, 0],
                [81, 255, 0],
                [83, 255, 0],
                [85, 255, 0],
                [87, 255, 0],
                [89, 255, 0],
                [91, 255, 0],
                [93, 255, 0],
                [95, 255, 0],
                [97, 255, 0],
                [99, 255, 0],
                [101, 255, 0],
                [103, 255, 0],
                [105, 255, 0],
                [107, 255, 0],
                [109, 255, 0],
                [111, 255, 0],
                [113, 255, 0],
                [115, 255, 0],
                [117, 255, 0],
                [119, 255, 0],
                [121, 255, 0],
                [123, 255, 0],
                [125, 255, 0],
                [127, 255, 0],
                [129, 255, 0],
                [131, 255, 0],
                [133, 255, 0],
                [135, 255, 0],
                [137, 255, 0],
                [139, 255, 0],
                [141, 255, 0],
                [143, 255, 0],
                [145, 255, 0],
                [147, 255, 0],
                [149, 255, 0],
                [151, 255, 0],
                [153, 255, 0],
                [155, 255, 0],
                [157, 255, 0],
                [159, 255, 0],
                [161, 255, 0],
                [163, 255, 0],
                [165, 255, 0],
                [167, 255, 0],
                [169, 255, 0],
                [171, 255, 0],
                [173, 255, 0],
                [175, 255, 0],
                [177, 255, 0],
                [179, 255, 0],
                [181, 255, 0],
                [183, 255, 0],
                [185, 255, 0],
                [187, 255, 0],
                [189, 255, 0],
                [191, 255, 0],
                [193, 255, 0],
                [195, 255, 0],
                [197, 255, 0],
                [199, 255, 0],
                [201, 255, 0],
                [203, 255, 0],
                [205, 255, 0],
                [207, 255, 0],
                [209, 255, 0],
                [211, 255, 0],
                [213, 255, 0],
                [215, 255, 0],
                [217, 255, 0],
                [219, 255, 0],
                [221, 255, 0],
                [223, 255, 0],
                [225, 255, 0],
                [227, 255, 0],
                [229, 255, 0],
                [231, 255, 0],
                [233, 255, 0],
                [235, 255, 0],
                [237, 255, 0],
                [239, 255, 0],
                [241, 255, 0],
                [243, 255, 0],
                [245, 255, 0],
                [247, 255, 0],
                [249, 255, 0],
                [251, 255, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "3color-RMB",
            [
                [255, 0, 0],
                [255, 0, 1],
                [255, 0, 3],
                [255, 0, 5],
                [255, 0, 7],
                [255, 0, 9],
                [255, 0, 11],
                [255, 0, 13],
                [255, 0, 15],
                [255, 0, 17],
                [255, 0, 19],
                [255, 0, 21],
                [255, 0, 23],
                [255, 0, 25],
                [255, 0, 27],
                [255, 0, 29],
                [255, 0, 31],
                [255, 0, 33],
                [255, 0, 35],
                [255, 0, 37],
                [255, 0, 39],
                [255, 0, 41],
                [255, 0, 43],
                [255, 0, 45],
                [255, 0, 47],
                [255, 0, 49],
                [255, 0, 51],
                [255, 0, 53],
                [255, 0, 55],
                [255, 0, 57],
                [255, 0, 59],
                [255, 0, 61],
                [255, 0, 63],
                [255, 0, 65],
                [255, 0, 67],
                [255, 0, 69],
                [255, 0, 71],
                [255, 0, 73],
                [255, 0, 75],
                [255, 0, 77],
                [255, 0, 79],
                [255, 0, 81],
                [255, 0, 83],
                [255, 0, 85],
                [255, 0, 87],
                [255, 0, 89],
                [255, 0, 91],
                [255, 0, 93],
                [255, 0, 95],
                [255, 0, 97],
                [255, 0, 99],
                [255, 0, 101],
                [255, 0, 103],
                [255, 0, 105],
                [255, 0, 107],
                [255, 0, 109],
                [255, 0, 111],
                [255, 0, 113],
                [255, 0, 115],
                [255, 0, 117],
                [255, 0, 119],
                [255, 0, 121],
                [255, 0, 123],
                [255, 0, 125],
                [255, 0, 127],
                [255, 0, 129],
                [255, 0, 131],
                [255, 0, 133],
                [255, 0, 135],
                [255, 0, 137],
                [255, 0, 139],
                [255, 0, 141],
                [255, 0, 143],
                [255, 0, 145],
                [255, 0, 147],
                [255, 0, 149],
                [255, 0, 151],
                [255, 0, 153],
                [255, 0, 155],
                [255, 0, 157],
                [255, 0, 159],
                [255, 0, 161],
                [255, 0, 163],
                [255, 0, 165],
                [255, 0, 167],
                [255, 0, 169],
                [255, 0, 171],
                [255, 0, 173],
                [255, 0, 175],
                [255, 0, 177],
                [255, 0, 179],
                [255, 0, 181],
                [255, 0, 183],
                [255, 0, 185],
                [255, 0, 187],
                [255, 0, 189],
                [255, 0, 191],
                [255, 0, 193],
                [255, 0, 195],
                [255, 0, 197],
                [255, 0, 199],
                [255, 0, 201],
                [255, 0, 203],
                [255, 0, 205],
                [255, 0, 207],
                [255, 0, 209],
                [255, 0, 211],
                [255, 0, 213],
                [255, 0, 215],
                [255, 0, 217],
                [255, 0, 219],
                [255, 0, 221],
                [255, 0, 223],
                [255, 0, 225],
                [255, 0, 227],
                [255, 0, 229],
                [255, 0, 231],
                [255, 0, 233],
                [255, 0, 235],
                [255, 0, 237],
                [255, 0, 239],
                [255, 0, 241],
                [255, 0, 243],
                [255, 0, 245],
                [255, 0, 247],
                [255, 0, 249],
                [255, 0, 251],
                [255, 0, 255],
                [255, 0, 255],
                [253, 0, 255],
                [251, 0, 255],
                [249, 0, 255],
                [247, 0, 255],
                [245, 0, 255],
                [243, 0, 255],
                [241, 0, 255],
                [239, 0, 255],
                [237, 0, 255],
                [235, 0, 255],
                [233, 0, 255],
                [231, 0, 255],
                [229, 0, 255],
                [227, 0, 255],
                [225, 0, 255],
                [223, 0, 255],
                [221, 0, 255],
                [219, 0, 255],
                [217, 0, 255],
                [215, 0, 255],
                [213, 0, 255],
                [211, 0, 255],
                [209, 0, 255],
                [207, 0, 255],
                [205, 0, 255],
                [203, 0, 255],
                [201, 0, 255],
                [199, 0, 255],
                [197, 0, 255],
                [195, 0, 255],
                [193, 0, 255],
                [191, 0, 255],
                [189, 0, 255],
                [187, 0, 255],
                [185, 0, 255],
                [183, 0, 255],
                [181, 0, 255],
                [179, 0, 255],
                [177, 0, 255],
                [175, 0, 255],
                [173, 0, 255],
                [171, 0, 255],
                [169, 0, 255],
                [167, 0, 255],
                [165, 0, 255],
                [163, 0, 255],
                [161, 0, 255],
                [159, 0, 255],
                [157, 0, 255],
                [155, 0, 255],
                [153, 0, 255],
                [151, 0, 255],
                [149, 0, 255],
                [147, 0, 255],
                [145, 0, 255],
                [143, 0, 255],
                [141, 0, 255],
                [139, 0, 255],
                [137, 0, 255],
                [135, 0, 255],
                [133, 0, 255],
                [131, 0, 255],
                [129, 0, 255],
                [127, 0, 255],
                [125, 0, 255],
                [123, 0, 255],
                [121, 0, 255],
                [119, 0, 255],
                [117, 0, 255],
                [115, 0, 255],
                [113, 0, 255],
                [111, 0, 255],
                [109, 0, 255],
                [107, 0, 255],
                [105, 0, 255],
                [103, 0, 255],
                [101, 0, 255],
                [99, 0, 255],
                [97, 0, 255],
                [95, 0, 255],
                [93, 0, 255],
                [91, 0, 255],
                [89, 0, 255],
                [87, 0, 255],
                [85, 0, 255],
                [83, 0, 255],
                [81, 0, 255],
                [79, 0, 255],
                [77, 0, 255],
                [75, 0, 255],
                [73, 0, 255],
                [71, 0, 255],
                [69, 0, 255],
                [67, 0, 255],
                [65, 0, 255],
                [63, 0, 255],
                [61, 0, 255],
                [59, 0, 255],
                [57, 0, 255],
                [55, 0, 255],
                [53, 0, 255],
                [51, 0, 255],
                [49, 0, 255],
                [47, 0, 255],
                [45, 0, 255],
                [43, 0, 255],
                [41, 0, 255],
                [39, 0, 255],
                [37, 0, 255],
                [35, 0, 255],
                [33, 0, 255],
                [31, 0, 255],
                [29, 0, 255],
                [27, 0, 255],
                [25, 0, 255],
                [23, 0, 255],
                [21, 0, 255],
                [19, 0, 255],
                [17, 0, 255],
                [15, 0, 255],
                [13, 0, 255],
                [11, 0, 255],
                [9, 0, 255],
                [7, 0, 255],
                [5, 0, 255],
                [3, 0, 255],
                [0, 0, 255],
            ],
        );

        m.insert(
            "3color-YGC",
            [
                [255, 255, 0],
                [253, 255, 0],
                [251, 255, 0],
                [249, 255, 0],
                [247, 255, 0],
                [245, 255, 0],
                [243, 255, 0],
                [241, 255, 0],
                [239, 255, 0],
                [237, 255, 0],
                [235, 255, 0],
                [233, 255, 0],
                [231, 255, 0],
                [229, 255, 0],
                [227, 255, 0],
                [225, 255, 0],
                [223, 255, 0],
                [221, 255, 0],
                [219, 255, 0],
                [217, 255, 0],
                [215, 255, 0],
                [213, 255, 0],
                [211, 255, 0],
                [209, 255, 0],
                [207, 255, 0],
                [205, 255, 0],
                [203, 255, 0],
                [201, 255, 0],
                [199, 255, 0],
                [197, 255, 0],
                [195, 255, 0],
                [193, 255, 0],
                [191, 255, 0],
                [189, 255, 0],
                [187, 255, 0],
                [185, 255, 0],
                [183, 255, 0],
                [181, 255, 0],
                [179, 255, 0],
                [177, 255, 0],
                [175, 255, 0],
                [173, 255, 0],
                [171, 255, 0],
                [169, 255, 0],
                [167, 255, 0],
                [165, 255, 0],
                [163, 255, 0],
                [161, 255, 0],
                [159, 255, 0],
                [157, 255, 0],
                [155, 255, 0],
                [153, 255, 0],
                [151, 255, 0],
                [149, 255, 0],
                [147, 255, 0],
                [145, 255, 0],
                [143, 255, 0],
                [141, 255, 0],
                [139, 255, 0],
                [137, 255, 0],
                [135, 255, 0],
                [133, 255, 0],
                [131, 255, 0],
                [129, 255, 0],
                [127, 255, 0],
                [125, 255, 0],
                [123, 255, 0],
                [121, 255, 0],
                [119, 255, 0],
                [117, 255, 0],
                [115, 255, 0],
                [113, 255, 0],
                [111, 255, 0],
                [109, 255, 0],
                [107, 255, 0],
                [105, 255, 0],
                [103, 255, 0],
                [101, 255, 0],
                [99, 255, 0],
                [97, 255, 0],
                [95, 255, 0],
                [93, 255, 0],
                [91, 255, 0],
                [89, 255, 0],
                [87, 255, 0],
                [85, 255, 0],
                [83, 255, 0],
                [81, 255, 0],
                [79, 255, 0],
                [77, 255, 0],
                [75, 255, 0],
                [73, 255, 0],
                [71, 255, 0],
                [69, 255, 0],
                [67, 255, 0],
                [65, 255, 0],
                [63, 255, 0],
                [61, 255, 0],
                [59, 255, 0],
                [57, 255, 0],
                [55, 255, 0],
                [53, 255, 0],
                [51, 255, 0],
                [49, 255, 0],
                [47, 255, 0],
                [45, 255, 0],
                [43, 255, 0],
                [41, 255, 0],
                [39, 255, 0],
                [37, 255, 0],
                [35, 255, 0],
                [33, 255, 0],
                [31, 255, 0],
                [29, 255, 0],
                [27, 255, 0],
                [25, 255, 0],
                [23, 255, 0],
                [21, 255, 0],
                [19, 255, 0],
                [17, 255, 0],
                [15, 255, 0],
                [13, 255, 0],
                [11, 255, 0],
                [9, 255, 0],
                [7, 255, 0],
                [5, 255, 0],
                [3, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 1],
                [0, 255, 3],
                [0, 255, 5],
                [0, 255, 7],
                [0, 255, 9],
                [0, 255, 11],
                [0, 255, 13],
                [0, 255, 15],
                [0, 255, 17],
                [0, 255, 19],
                [0, 255, 21],
                [0, 255, 23],
                [0, 255, 25],
                [0, 255, 27],
                [0, 255, 29],
                [0, 255, 31],
                [0, 255, 33],
                [0, 255, 35],
                [0, 255, 37],
                [0, 255, 39],
                [0, 255, 41],
                [0, 255, 43],
                [0, 255, 45],
                [0, 255, 47],
                [0, 255, 49],
                [0, 255, 51],
                [0, 255, 53],
                [0, 255, 55],
                [0, 255, 57],
                [0, 255, 59],
                [0, 255, 61],
                [0, 255, 63],
                [0, 255, 65],
                [0, 255, 67],
                [0, 255, 69],
                [0, 255, 71],
                [0, 255, 73],
                [0, 255, 75],
                [0, 255, 77],
                [0, 255, 79],
                [0, 255, 81],
                [0, 255, 83],
                [0, 255, 85],
                [0, 255, 87],
                [0, 255, 89],
                [0, 255, 91],
                [0, 255, 93],
                [0, 255, 95],
                [0, 255, 97],
                [0, 255, 99],
                [0, 255, 101],
                [0, 255, 103],
                [0, 255, 105],
                [0, 255, 107],
                [0, 255, 109],
                [0, 255, 111],
                [0, 255, 113],
                [0, 255, 115],
                [0, 255, 117],
                [0, 255, 119],
                [0, 255, 121],
                [0, 255, 123],
                [0, 255, 125],
                [0, 255, 127],
                [0, 255, 129],
                [0, 255, 131],
                [0, 255, 133],
                [0, 255, 135],
                [0, 255, 137],
                [0, 255, 139],
                [0, 255, 141],
                [0, 255, 143],
                [0, 255, 145],
                [0, 255, 147],
                [0, 255, 149],
                [0, 255, 151],
                [0, 255, 153],
                [0, 255, 155],
                [0, 255, 157],
                [0, 255, 159],
                [0, 255, 161],
                [0, 255, 163],
                [0, 255, 165],
                [0, 255, 167],
                [0, 255, 169],
                [0, 255, 171],
                [0, 255, 173],
                [0, 255, 175],
                [0, 255, 177],
                [0, 255, 179],
                [0, 255, 181],
                [0, 255, 183],
                [0, 255, 185],
                [0, 255, 187],
                [0, 255, 189],
                [0, 255, 191],
                [0, 255, 193],
                [0, 255, 195],
                [0, 255, 197],
                [0, 255, 199],
                [0, 255, 201],
                [0, 255, 203],
                [0, 255, 205],
                [0, 255, 207],
                [0, 255, 209],
                [0, 255, 211],
                [0, 255, 213],
                [0, 255, 215],
                [0, 255, 217],
                [0, 255, 219],
                [0, 255, 221],
                [0, 255, 223],
                [0, 255, 225],
                [0, 255, 227],
                [0, 255, 229],
                [0, 255, 231],
                [0, 255, 233],
                [0, 255, 235],
                [0, 255, 237],
                [0, 255, 239],
                [0, 255, 241],
                [0, 255, 243],
                [0, 255, 245],
                [0, 255, 247],
                [0, 255, 249],
                [0, 255, 251],
                [0, 255, 255],
            ],
        );

        m.insert(
            "5_ramps",
            [
                [0, 0, 1],
                [0, 0, 5],
                [0, 0, 10],
                [0, 0, 15],
                [0, 0, 20],
                [0, 0, 25],
                [0, 0, 30],
                [0, 0, 35],
                [0, 0, 40],
                [0, 0, 45],
                [0, 0, 50],
                [0, 0, 55],
                [0, 0, 60],
                [0, 0, 65],
                [0, 0, 70],
                [0, 0, 75],
                [0, 0, 80],
                [0, 0, 85],
                [0, 0, 90],
                [0, 0, 95],
                [0, 0, 100],
                [0, 0, 105],
                [0, 0, 110],
                [0, 0, 115],
                [0, 0, 120],
                [0, 0, 125],
                [0, 0, 130],
                [0, 0, 135],
                [0, 0, 140],
                [0, 0, 145],
                [0, 0, 150],
                [0, 0, 155],
                [0, 0, 160],
                [0, 0, 165],
                [0, 0, 170],
                [0, 0, 175],
                [0, 0, 180],
                [0, 0, 185],
                [0, 0, 190],
                [0, 0, 195],
                [0, 0, 200],
                [0, 0, 205],
                [0, 0, 210],
                [0, 0, 215],
                [0, 0, 220],
                [0, 0, 225],
                [0, 0, 230],
                [0, 0, 235],
                [0, 0, 240],
                [0, 0, 245],
                [0, 0, 250],
                [0, 1, 0],
                [0, 5, 0],
                [0, 10, 0],
                [0, 15, 0],
                [0, 20, 0],
                [0, 25, 0],
                [0, 30, 0],
                [0, 35, 0],
                [0, 40, 0],
                [0, 45, 0],
                [0, 50, 0],
                [0, 55, 0],
                [0, 60, 0],
                [0, 65, 0],
                [0, 70, 0],
                [0, 75, 0],
                [0, 80, 0],
                [0, 85, 0],
                [0, 90, 0],
                [0, 95, 0],
                [0, 100, 0],
                [0, 105, 0],
                [0, 110, 0],
                [0, 115, 0],
                [0, 120, 0],
                [0, 125, 0],
                [0, 130, 0],
                [0, 135, 0],
                [0, 140, 0],
                [0, 145, 0],
                [0, 150, 0],
                [0, 155, 0],
                [0, 160, 0],
                [0, 165, 0],
                [0, 170, 0],
                [0, 175, 0],
                [0, 180, 0],
                [0, 185, 0],
                [0, 190, 0],
                [0, 195, 0],
                [0, 200, 0],
                [0, 205, 0],
                [0, 210, 0],
                [0, 215, 0],
                [0, 220, 0],
                [0, 225, 0],
                [0, 230, 0],
                [0, 235, 0],
                [0, 240, 0],
                [0, 245, 0],
                [0, 250, 0],
                [1, 1, 0],
                [5, 5, 0],
                [10, 10, 0],
                [15, 15, 0],
                [20, 20, 0],
                [25, 25, 0],
                [30, 30, 0],
                [35, 35, 0],
                [40, 40, 0],
                [45, 45, 0],
                [50, 50, 0],
                [55, 55, 0],
                [60, 60, 0],
                [65, 65, 0],
                [70, 70, 0],
                [75, 75, 0],
                [80, 80, 0],
                [85, 85, 0],
                [90, 90, 0],
                [95, 95, 0],
                [100, 100, 0],
                [105, 105, 0],
                [110, 110, 0],
                [115, 115, 0],
                [120, 120, 0],
                [125, 125, 0],
                [130, 130, 0],
                [135, 135, 0],
                [140, 140, 0],
                [145, 145, 0],
                [150, 150, 0],
                [155, 155, 0],
                [160, 160, 0],
                [165, 165, 0],
                [170, 170, 0],
                [175, 175, 0],
                [180, 180, 0],
                [185, 185, 0],
                [190, 190, 0],
                [195, 195, 0],
                [200, 200, 0],
                [205, 205, 0],
                [210, 210, 0],
                [215, 215, 0],
                [220, 220, 0],
                [225, 225, 0],
                [230, 230, 0],
                [235, 235, 0],
                [240, 240, 0],
                [245, 245, 0],
                [250, 250, 0],
                [1, 0, 0],
                [5, 0, 0],
                [10, 0, 0],
                [15, 0, 0],
                [20, 0, 0],
                [25, 0, 0],
                [30, 0, 0],
                [35, 0, 0],
                [40, 0, 0],
                [45, 0, 0],
                [50, 0, 0],
                [55, 0, 0],
                [60, 0, 0],
                [65, 0, 0],
                [70, 0, 0],
                [75, 0, 0],
                [80, 0, 0],
                [85, 0, 0],
                [90, 0, 0],
                [95, 0, 0],
                [100, 0, 0],
                [105, 0, 0],
                [110, 0, 0],
                [115, 0, 0],
                [120, 0, 0],
                [125, 0, 0],
                [130, 0, 0],
                [135, 0, 0],
                [140, 0, 0],
                [145, 0, 0],
                [150, 0, 0],
                [155, 0, 0],
                [160, 0, 0],
                [165, 0, 0],
                [170, 0, 0],
                [175, 0, 0],
                [180, 0, 0],
                [185, 0, 0],
                [190, 0, 0],
                [195, 0, 0],
                [200, 0, 0],
                [205, 0, 0],
                [210, 0, 0],
                [215, 0, 0],
                [220, 0, 0],
                [225, 0, 0],
                [230, 0, 0],
                [235, 0, 0],
                [240, 0, 0],
                [245, 0, 0],
                [250, 0, 0],
                [1, 1, 1],
                [5, 5, 5],
                [10, 10, 10],
                [15, 15, 15],
                [20, 20, 20],
                [25, 25, 25],
                [30, 30, 30],
                [35, 35, 35],
                [40, 40, 40],
                [45, 45, 45],
                [50, 50, 50],
                [55, 55, 55],
                [60, 60, 60],
                [65, 65, 65],
                [70, 70, 70],
                [75, 75, 75],
                [80, 80, 80],
                [85, 85, 85],
                [90, 90, 90],
                [95, 95, 95],
                [100, 100, 100],
                [105, 105, 105],
                [110, 110, 110],
                [115, 115, 115],
                [120, 120, 120],
                [125, 125, 125],
                [130, 130, 130],
                [135, 135, 135],
                [140, 140, 140],
                [145, 145, 145],
                [150, 150, 150],
                [155, 155, 155],
                [160, 160, 160],
                [165, 165, 165],
                [170, 170, 170],
                [175, 175, 175],
                [180, 180, 180],
                [185, 185, 185],
                [190, 190, 190],
                [195, 195, 195],
                [200, 200, 200],
                [205, 205, 205],
                [210, 210, 210],
                [215, 215, 215],
                [220, 220, 220],
                [225, 225, 225],
                [230, 230, 230],
                [235, 235, 235],
                [240, 240, 240],
                [245, 245, 245],
                [250, 250, 250],
                [255, 255, 255],
            ],
        );

        m.insert(
            "6_shades",
            [
                [0, 0, 0],
                [3, 0, 0],
                [7, 0, 0],
                [11, 0, 0],
                [15, 0, 0],
                [19, 0, 0],
                [23, 0, 0],
                [27, 0, 0],
                [31, 0, 0],
                [35, 0, 0],
                [39, 0, 0],
                [43, 0, 0],
                [47, 0, 0],
                [51, 0, 0],
                [55, 0, 0],
                [59, 0, 0],
                [63, 0, 0],
                [67, 0, 0],
                [71, 0, 0],
                [75, 0, 0],
                [79, 0, 0],
                [83, 0, 0],
                [87, 0, 0],
                [91, 0, 0],
                [95, 0, 0],
                [99, 0, 0],
                [103, 0, 0],
                [107, 0, 0],
                [111, 0, 0],
                [115, 0, 0],
                [119, 0, 0],
                [123, 0, 0],
                [127, 0, 0],
                [131, 0, 0],
                [135, 0, 0],
                [139, 0, 0],
                [143, 0, 0],
                [147, 0, 0],
                [151, 0, 0],
                [155, 0, 0],
                [159, 0, 0],
                [163, 0, 0],
                [167, 0, 0],
                [171, 0, 0],
                [175, 0, 0],
                [179, 0, 0],
                [183, 0, 0],
                [187, 0, 0],
                [191, 0, 0],
                [195, 0, 0],
                [199, 0, 0],
                [203, 0, 0],
                [207, 0, 0],
                [211, 0, 0],
                [215, 0, 0],
                [219, 0, 0],
                [223, 0, 0],
                [227, 0, 0],
                [231, 0, 0],
                [235, 0, 0],
                [239, 0, 0],
                [243, 0, 0],
                [247, 0, 0],
                [251, 0, 0],
                [255, 0, 0],
                [247, 7, 0],
                [239, 15, 0],
                [231, 23, 0],
                [223, 31, 0],
                [215, 39, 0],
                [207, 47, 0],
                [199, 55, 0],
                [191, 63, 0],
                [183, 71, 0],
                [175, 79, 0],
                [167, 87, 0],
                [159, 95, 0],
                [151, 103, 0],
                [143, 111, 0],
                [135, 119, 0],
                [127, 127, 0],
                [119, 135, 0],
                [111, 143, 0],
                [103, 151, 0],
                [95, 159, 0],
                [87, 167, 0],
                [79, 175, 0],
                [71, 183, 0],
                [63, 191, 0],
                [55, 199, 0],
                [47, 207, 0],
                [39, 215, 0],
                [31, 223, 0],
                [23, 231, 0],
                [15, 239, 0],
                [7, 247, 0],
                [0, 255, 0],
                [0, 247, 7],
                [0, 239, 15],
                [0, 231, 23],
                [0, 223, 31],
                [0, 215, 39],
                [0, 207, 47],
                [0, 199, 55],
                [0, 191, 63],
                [0, 183, 71],
                [0, 175, 79],
                [0, 167, 87],
                [0, 159, 95],
                [0, 151, 103],
                [0, 143, 111],
                [0, 135, 119],
                [0, 127, 127],
                [0, 119, 135],
                [0, 111, 143],
                [0, 103, 151],
                [0, 95, 159],
                [0, 87, 167],
                [0, 79, 175],
                [0, 71, 183],
                [0, 63, 191],
                [0, 55, 199],
                [0, 47, 207],
                [0, 39, 215],
                [0, 31, 223],
                [0, 23, 231],
                [0, 15, 239],
                [0, 7, 247],
                [0, 0, 255],
                [0, 7, 255],
                [0, 15, 255],
                [0, 23, 255],
                [0, 31, 255],
                [0, 39, 255],
                [0, 47, 255],
                [0, 55, 255],
                [0, 63, 255],
                [0, 71, 255],
                [0, 79, 255],
                [0, 87, 255],
                [0, 95, 255],
                [0, 103, 255],
                [0, 111, 255],
                [0, 119, 255],
                [0, 127, 255],
                [0, 135, 255],
                [0, 143, 255],
                [0, 151, 255],
                [0, 159, 255],
                [0, 167, 255],
                [0, 175, 255],
                [0, 183, 255],
                [0, 191, 255],
                [0, 199, 255],
                [0, 207, 255],
                [0, 215, 255],
                [0, 223, 255],
                [0, 231, 255],
                [0, 239, 255],
                [0, 247, 255],
                [0, 255, 255],
                [7, 247, 255],
                [15, 239, 255],
                [23, 231, 255],
                [31, 223, 255],
                [39, 215, 255],
                [47, 207, 255],
                [55, 199, 255],
                [63, 191, 255],
                [71, 183, 255],
                [79, 175, 255],
                [87, 167, 255],
                [95, 159, 255],
                [103, 151, 255],
                [111, 143, 255],
                [119, 135, 255],
                [127, 127, 255],
                [135, 119, 255],
                [143, 111, 255],
                [151, 103, 255],
                [159, 95, 255],
                [167, 87, 255],
                [175, 79, 255],
                [183, 71, 255],
                [191, 63, 255],
                [199, 55, 255],
                [207, 47, 255],
                [215, 39, 255],
                [223, 31, 255],
                [231, 23, 255],
                [239, 15, 255],
                [247, 7, 255],
                [255, 0, 255],
                [255, 7, 247],
                [255, 15, 239],
                [255, 23, 231],
                [255, 31, 223],
                [255, 39, 215],
                [255, 47, 207],
                [255, 55, 199],
                [255, 63, 191],
                [255, 71, 183],
                [255, 79, 175],
                [255, 87, 167],
                [255, 95, 159],
                [255, 103, 151],
                [255, 111, 143],
                [255, 119, 135],
                [255, 127, 127],
                [255, 135, 119],
                [255, 143, 111],
                [255, 151, 103],
                [255, 159, 95],
                [255, 167, 87],
                [255, 175, 79],
                [255, 183, 71],
                [255, 191, 63],
                [255, 199, 55],
                [255, 207, 47],
                [255, 215, 39],
                [255, 223, 31],
                [255, 231, 23],
                [255, 239, 15],
                [255, 247, 7],
                [255, 255, 0],
                [255, 255, 7],
                [255, 255, 15],
                [255, 255, 23],
                [255, 255, 31],
                [255, 255, 39],
                [255, 255, 47],
                [255, 255, 55],
                [255, 255, 63],
                [255, 255, 71],
                [255, 255, 79],
                [255, 255, 87],
                [255, 255, 95],
                [255, 255, 103],
                [255, 255, 111],
                [255, 255, 119],
                [255, 255, 127],
                [255, 255, 135],
                [255, 255, 143],
                [255, 255, 151],
                [255, 255, 159],
                [255, 255, 167],
                [255, 255, 175],
                [255, 255, 183],
                [255, 255, 191],
                [255, 255, 199],
                [255, 255, 207],
                [255, 255, 215],
                [255, 255, 223],
                [255, 255, 231],
                [255, 255, 239],
                [255, 255, 247],
            ],
        );

        m.insert(
            "BOP blue",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 1, 1],
                [0, 2, 2],
                [0, 2, 3],
                [0, 3, 4],
                [0, 4, 5],
                [0, 4, 6],
                [1, 5, 7],
                [1, 6, 8],
                [1, 6, 9],
                [1, 7, 10],
                [1, 8, 11],
                [1, 8, 12],
                [1, 9, 13],
                [1, 10, 14],
                [2, 10, 15],
                [2, 11, 16],
                [2, 12, 17],
                [2, 12, 18],
                [2, 13, 19],
                [2, 14, 20],
                [2, 14, 21],
                [2, 15, 22],
                [3, 16, 23],
                [3, 16, 24],
                [3, 17, 25],
                [3, 18, 26],
                [3, 18, 27],
                [3, 19, 28],
                [3, 20, 29],
                [3, 20, 30],
                [4, 21, 31],
                [4, 22, 31],
                [4, 22, 32],
                [4, 23, 33],
                [4, 24, 34],
                [4, 25, 35],
                [4, 25, 36],
                [4, 26, 37],
                [5, 27, 38],
                [5, 27, 39],
                [5, 28, 40],
                [5, 29, 41],
                [5, 29, 42],
                [5, 30, 43],
                [5, 31, 44],
                [5, 31, 45],
                [6, 32, 46],
                [6, 33, 47],
                [6, 33, 48],
                [6, 34, 49],
                [6, 35, 50],
                [6, 35, 51],
                [6, 36, 52],
                [6, 37, 53],
                [7, 37, 54],
                [7, 38, 55],
                [7, 39, 56],
                [7, 39, 57],
                [7, 40, 58],
                [7, 41, 59],
                [7, 41, 60],
                [7, 42, 61],
                [8, 43, 62],
                [8, 43, 62],
                [8, 44, 63],
                [8, 45, 64],
                [8, 45, 65],
                [8, 46, 66],
                [8, 47, 67],
                [8, 47, 68],
                [9, 48, 69],
                [9, 49, 70],
                [9, 50, 71],
                [9, 50, 72],
                [9, 51, 73],
                [9, 52, 74],
                [9, 52, 75],
                [9, 53, 76],
                [10, 54, 77],
                [10, 54, 78],
                [10, 55, 79],
                [10, 56, 80],
                [10, 56, 81],
                [10, 57, 82],
                [10, 58, 83],
                [10, 58, 84],
                [11, 59, 85],
                [11, 60, 86],
                [11, 60, 87],
                [11, 61, 88],
                [11, 62, 89],
                [11, 62, 90],
                [11, 63, 91],
                [11, 64, 92],
                [12, 64, 93],
                [12, 65, 93],
                [12, 66, 94],
                [12, 66, 95],
                [12, 67, 96],
                [12, 68, 97],
                [12, 68, 98],
                [12, 69, 99],
                [13, 70, 100],
                [13, 70, 101],
                [13, 71, 102],
                [13, 72, 103],
                [13, 72, 104],
                [13, 73, 105],
                [13, 74, 106],
                [13, 75, 107],
                [14, 75, 108],
                [14, 76, 109],
                [14, 77, 110],
                [14, 77, 111],
                [14, 78, 112],
                [14, 79, 113],
                [14, 79, 114],
                [14, 80, 115],
                [15, 81, 116],
                [15, 81, 117],
                [15, 82, 118],
                [15, 83, 119],
                [15, 83, 120],
                [15, 84, 121],
                [15, 85, 122],
                [15, 85, 123],
                [16, 86, 124],
                [16, 87, 124],
                [16, 87, 125],
                [16, 88, 126],
                [16, 89, 127],
                [16, 89, 128],
                [16, 90, 129],
                [16, 91, 130],
                [17, 91, 131],
                [17, 92, 132],
                [17, 93, 133],
                [17, 93, 134],
                [17, 94, 135],
                [17, 95, 136],
                [17, 95, 137],
                [17, 96, 138],
                [18, 97, 139],
                [18, 97, 140],
                [18, 98, 141],
                [18, 99, 142],
                [18, 100, 143],
                [18, 100, 144],
                [18, 101, 145],
                [18, 102, 146],
                [19, 102, 147],
                [19, 103, 148],
                [19, 104, 149],
                [19, 104, 150],
                [19, 105, 151],
                [19, 106, 152],
                [19, 106, 153],
                [19, 107, 154],
                [20, 108, 155],
                [20, 108, 155],
                [20, 109, 156],
                [20, 110, 157],
                [20, 110, 158],
                [20, 111, 159],
                [20, 112, 160],
                [20, 112, 161],
                [21, 113, 162],
                [21, 114, 163],
                [21, 114, 164],
                [21, 115, 165],
                [21, 116, 166],
                [21, 116, 167],
                [21, 117, 168],
                [21, 118, 169],
                [22, 118, 170],
                [22, 119, 171],
                [22, 120, 172],
                [22, 120, 173],
                [22, 121, 174],
                [22, 122, 175],
                [22, 122, 176],
                [22, 123, 177],
                [23, 124, 178],
                [23, 125, 179],
                [23, 125, 180],
                [23, 126, 181],
                [23, 127, 182],
                [23, 127, 183],
                [23, 128, 184],
                [23, 129, 185],
                [24, 129, 186],
                [24, 130, 186],
                [24, 131, 187],
                [24, 131, 188],
                [24, 132, 189],
                [24, 133, 190],
                [24, 133, 191],
                [24, 134, 192],
                [25, 135, 193],
                [25, 135, 194],
                [25, 136, 195],
                [25, 137, 196],
                [25, 137, 197],
                [25, 138, 198],
                [25, 139, 199],
                [25, 139, 200],
                [26, 140, 201],
                [26, 141, 202],
                [26, 141, 203],
                [26, 142, 204],
                [26, 143, 205],
                [26, 143, 206],
                [26, 144, 207],
                [26, 145, 208],
                [27, 145, 209],
                [27, 146, 210],
                [27, 147, 211],
                [27, 147, 212],
                [27, 148, 213],
                [27, 149, 214],
                [27, 150, 215],
                [27, 150, 216],
                [28, 151, 217],
                [28, 152, 217],
                [28, 152, 218],
                [28, 153, 219],
                [28, 154, 220],
                [28, 154, 221],
                [28, 155, 222],
                [28, 156, 223],
                [29, 156, 224],
                [29, 157, 225],
                [29, 158, 226],
                [29, 158, 227],
                [29, 159, 228],
                [29, 160, 229],
                [29, 160, 230],
                [29, 161, 231],
                [30, 162, 232],
                [30, 162, 233],
                [30, 163, 234],
                [30, 164, 235],
                [30, 164, 236],
                [30, 165, 237],
                [30, 166, 238],
                [30, 166, 239],
                [31, 167, 240],
                [31, 168, 241],
                [31, 168, 242],
                [31, 169, 243],
                [31, 170, 244],
                [31, 170, 245],
                [31, 171, 246],
                [32, 173, 248],
            ],
        );

        m.insert(
            "BOP orange",
            [
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 0],
                [2, 2, 0],
                [3, 2, 0],
                [4, 3, 0],
                [5, 4, 0],
                [6, 4, 0],
                [7, 5, 1],
                [8, 6, 1],
                [9, 6, 1],
                [10, 7, 1],
                [11, 8, 1],
                [12, 8, 1],
                [13, 9, 1],
                [14, 10, 1],
                [15, 10, 2],
                [16, 11, 2],
                [17, 12, 2],
                [18, 12, 2],
                [19, 13, 2],
                [20, 14, 2],
                [21, 14, 2],
                [22, 15, 2],
                [23, 16, 3],
                [24, 16, 3],
                [25, 17, 3],
                [26, 18, 3],
                [27, 18, 3],
                [28, 19, 3],
                [29, 20, 3],
                [30, 20, 3],
                [31, 21, 4],
                [31, 22, 4],
                [32, 22, 4],
                [33, 23, 4],
                [34, 24, 4],
                [35, 25, 4],
                [36, 25, 4],
                [37, 26, 4],
                [38, 27, 5],
                [39, 27, 5],
                [40, 28, 5],
                [41, 29, 5],
                [42, 29, 5],
                [43, 30, 5],
                [44, 31, 5],
                [45, 31, 5],
                [46, 32, 6],
                [47, 33, 6],
                [48, 33, 6],
                [49, 34, 6],
                [50, 35, 6],
                [51, 35, 6],
                [52, 36, 6],
                [53, 37, 6],
                [54, 37, 7],
                [55, 38, 7],
                [56, 39, 7],
                [57, 39, 7],
                [58, 40, 7],
                [59, 41, 7],
                [60, 41, 7],
                [61, 42, 7],
                [62, 43, 8],
                [62, 43, 8],
                [63, 44, 8],
                [64, 45, 8],
                [65, 45, 8],
                [66, 46, 8],
                [67, 47, 8],
                [68, 47, 8],
                [69, 48, 9],
                [70, 49, 9],
                [71, 50, 9],
                [72, 50, 9],
                [73, 51, 9],
                [74, 52, 9],
                [75, 52, 9],
                [76, 53, 9],
                [77, 54, 10],
                [78, 54, 10],
                [79, 55, 10],
                [80, 56, 10],
                [81, 56, 10],
                [82, 57, 10],
                [83, 58, 10],
                [84, 58, 10],
                [85, 59, 11],
                [86, 60, 11],
                [87, 60, 11],
                [88, 61, 11],
                [89, 62, 11],
                [90, 62, 11],
                [91, 63, 11],
                [92, 64, 11],
                [93, 64, 12],
                [93, 65, 12],
                [94, 66, 12],
                [95, 66, 12],
                [96, 67, 12],
                [97, 68, 12],
                [98, 68, 12],
                [99, 69, 12],
                [100, 70, 13],
                [101, 70, 13],
                [102, 71, 13],
                [103, 72, 13],
                [104, 72, 13],
                [105, 73, 13],
                [106, 74, 13],
                [107, 75, 13],
                [108, 75, 14],
                [109, 76, 14],
                [110, 77, 14],
                [111, 77, 14],
                [112, 78, 14],
                [113, 79, 14],
                [114, 79, 14],
                [115, 80, 14],
                [116, 81, 15],
                [117, 81, 15],
                [118, 82, 15],
                [119, 83, 15],
                [120, 83, 15],
                [121, 84, 15],
                [122, 85, 15],
                [123, 85, 15],
                [124, 86, 16],
                [124, 87, 16],
                [125, 87, 16],
                [126, 88, 16],
                [127, 89, 16],
                [128, 89, 16],
                [129, 90, 16],
                [130, 91, 16],
                [131, 91, 17],
                [132, 92, 17],
                [133, 93, 17],
                [134, 93, 17],
                [135, 94, 17],
                [136, 95, 17],
                [137, 95, 17],
                [138, 96, 17],
                [139, 97, 18],
                [140, 97, 18],
                [141, 98, 18],
                [142, 99, 18],
                [143, 100, 18],
                [144, 100, 18],
                [145, 101, 18],
                [146, 102, 18],
                [147, 102, 19],
                [148, 103, 19],
                [149, 104, 19],
                [150, 104, 19],
                [151, 105, 19],
                [152, 106, 19],
                [153, 106, 19],
                [154, 107, 19],
                [155, 108, 20],
                [155, 108, 20],
                [156, 109, 20],
                [157, 110, 20],
                [158, 110, 20],
                [159, 111, 20],
                [160, 112, 20],
                [161, 112, 20],
                [162, 113, 21],
                [163, 114, 21],
                [164, 114, 21],
                [165, 115, 21],
                [166, 116, 21],
                [167, 116, 21],
                [168, 117, 21],
                [169, 118, 21],
                [170, 118, 22],
                [171, 119, 22],
                [172, 120, 22],
                [173, 120, 22],
                [174, 121, 22],
                [175, 122, 22],
                [176, 122, 22],
                [177, 123, 22],
                [178, 124, 23],
                [179, 125, 23],
                [180, 125, 23],
                [181, 126, 23],
                [182, 127, 23],
                [183, 127, 23],
                [184, 128, 23],
                [185, 129, 23],
                [186, 129, 24],
                [186, 130, 24],
                [187, 131, 24],
                [188, 131, 24],
                [189, 132, 24],
                [190, 133, 24],
                [191, 133, 24],
                [192, 134, 24],
                [193, 135, 25],
                [194, 135, 25],
                [195, 136, 25],
                [196, 137, 25],
                [197, 137, 25],
                [198, 138, 25],
                [199, 139, 25],
                [200, 139, 25],
                [201, 140, 26],
                [202, 141, 26],
                [203, 141, 26],
                [204, 142, 26],
                [205, 143, 26],
                [206, 143, 26],
                [207, 144, 26],
                [208, 145, 26],
                [209, 145, 27],
                [210, 146, 27],
                [211, 147, 27],
                [212, 147, 27],
                [213, 148, 27],
                [214, 149, 27],
                [215, 150, 27],
                [216, 150, 27],
                [217, 151, 28],
                [217, 152, 28],
                [218, 152, 28],
                [219, 153, 28],
                [220, 154, 28],
                [221, 154, 28],
                [222, 155, 28],
                [223, 156, 28],
                [224, 156, 29],
                [225, 157, 29],
                [226, 158, 29],
                [227, 158, 29],
                [228, 159, 29],
                [229, 160, 29],
                [230, 160, 29],
                [231, 161, 29],
                [232, 162, 30],
                [233, 162, 30],
                [234, 163, 30],
                [235, 164, 30],
                [236, 164, 30],
                [237, 165, 30],
                [238, 166, 30],
                [239, 166, 30],
                [240, 167, 31],
                [241, 168, 31],
                [242, 168, 31],
                [243, 169, 31],
                [244, 170, 31],
                [245, 170, 31],
                [246, 171, 31],
                [248, 173, 32],
            ],
        );

        m.insert(
            "BOP purple",
            [
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 1],
                [1, 0, 1],
                [2, 0, 2],
                [2, 0, 2],
                [3, 0, 3],
                [4, 0, 4],
                [4, 1, 4],
                [5, 1, 5],
                [5, 1, 5],
                [6, 1, 6],
                [6, 1, 6],
                [7, 1, 7],
                [8, 1, 8],
                [8, 1, 8],
                [9, 2, 9],
                [9, 2, 9],
                [10, 2, 10],
                [10, 2, 10],
                [11, 2, 11],
                [12, 2, 12],
                [12, 2, 12],
                [13, 2, 13],
                [13, 3, 13],
                [14, 3, 14],
                [15, 3, 15],
                [15, 3, 15],
                [16, 3, 16],
                [16, 3, 16],
                [17, 3, 17],
                [17, 3, 17],
                [18, 4, 18],
                [19, 4, 19],
                [19, 4, 19],
                [20, 4, 20],
                [20, 4, 20],
                [21, 4, 21],
                [21, 4, 21],
                [22, 4, 22],
                [23, 5, 23],
                [23, 5, 23],
                [24, 5, 24],
                [24, 5, 24],
                [25, 5, 25],
                [26, 5, 26],
                [26, 5, 26],
                [27, 5, 27],
                [27, 6, 27],
                [28, 6, 28],
                [28, 6, 28],
                [29, 6, 29],
                [30, 6, 30],
                [30, 6, 30],
                [31, 6, 31],
                [31, 6, 31],
                [32, 7, 32],
                [32, 7, 32],
                [33, 7, 33],
                [34, 7, 34],
                [34, 7, 34],
                [35, 7, 35],
                [35, 7, 35],
                [36, 7, 36],
                [37, 8, 37],
                [37, 8, 37],
                [38, 8, 38],
                [38, 8, 38],
                [39, 8, 39],
                [39, 8, 39],
                [40, 8, 40],
                [41, 8, 41],
                [41, 9, 41],
                [42, 9, 42],
                [42, 9, 42],
                [43, 9, 43],
                [43, 9, 43],
                [44, 9, 44],
                [45, 9, 45],
                [45, 9, 45],
                [46, 10, 46],
                [46, 10, 46],
                [47, 10, 47],
                [47, 10, 47],
                [48, 10, 48],
                [49, 10, 49],
                [49, 10, 49],
                [50, 10, 50],
                [50, 11, 50],
                [51, 11, 51],
                [52, 11, 52],
                [52, 11, 52],
                [53, 11, 53],
                [53, 11, 53],
                [54, 11, 54],
                [54, 11, 54],
                [55, 12, 55],
                [56, 12, 56],
                [56, 12, 56],
                [57, 12, 57],
                [57, 12, 57],
                [58, 12, 58],
                [58, 12, 58],
                [59, 12, 59],
                [60, 13, 60],
                [60, 13, 60],
                [61, 13, 61],
                [61, 13, 61],
                [62, 13, 62],
                [63, 13, 63],
                [63, 13, 63],
                [64, 13, 64],
                [64, 14, 64],
                [65, 14, 65],
                [65, 14, 65],
                [66, 14, 66],
                [67, 14, 67],
                [67, 14, 67],
                [68, 14, 68],
                [68, 14, 68],
                [69, 15, 69],
                [69, 15, 69],
                [70, 15, 70],
                [71, 15, 71],
                [71, 15, 71],
                [72, 15, 72],
                [72, 15, 72],
                [73, 15, 73],
                [74, 16, 74],
                [74, 16, 74],
                [75, 16, 75],
                [75, 16, 75],
                [76, 16, 76],
                [76, 16, 76],
                [77, 16, 77],
                [78, 16, 78],
                [78, 17, 78],
                [79, 17, 79],
                [79, 17, 79],
                [80, 17, 80],
                [80, 17, 80],
                [81, 17, 81],
                [82, 17, 82],
                [82, 17, 82],
                [83, 18, 83],
                [83, 18, 83],
                [84, 18, 84],
                [84, 18, 84],
                [85, 18, 85],
                [86, 18, 86],
                [86, 18, 86],
                [87, 18, 87],
                [87, 19, 87],
                [88, 19, 88],
                [89, 19, 89],
                [89, 19, 89],
                [90, 19, 90],
                [90, 19, 90],
                [91, 19, 91],
                [91, 19, 91],
                [92, 20, 92],
                [93, 20, 93],
                [93, 20, 93],
                [94, 20, 94],
                [94, 20, 94],
                [95, 20, 95],
                [95, 20, 95],
                [96, 20, 96],
                [97, 21, 97],
                [97, 21, 97],
                [98, 21, 98],
                [98, 21, 98],
                [99, 21, 99],
                [100, 21, 100],
                [100, 21, 100],
                [101, 21, 101],
                [101, 22, 101],
                [102, 22, 102],
                [102, 22, 102],
                [103, 22, 103],
                [104, 22, 104],
                [104, 22, 104],
                [105, 22, 105],
                [105, 22, 105],
                [106, 23, 106],
                [106, 23, 106],
                [107, 23, 107],
                [108, 23, 108],
                [108, 23, 108],
                [109, 23, 109],
                [109, 23, 109],
                [110, 23, 110],
                [111, 24, 111],
                [111, 24, 111],
                [112, 24, 112],
                [112, 24, 112],
                [113, 24, 113],
                [113, 24, 113],
                [114, 24, 114],
                [115, 24, 115],
                [115, 25, 115],
                [116, 25, 116],
                [116, 25, 116],
                [117, 25, 117],
                [117, 25, 117],
                [118, 25, 118],
                [119, 25, 119],
                [119, 25, 119],
                [120, 26, 120],
                [120, 26, 120],
                [121, 26, 121],
                [121, 26, 121],
                [122, 26, 122],
                [123, 26, 123],
                [123, 26, 123],
                [124, 26, 124],
                [124, 27, 124],
                [125, 27, 125],
                [126, 27, 126],
                [126, 27, 126],
                [127, 27, 127],
                [127, 27, 127],
                [128, 27, 128],
                [128, 27, 128],
                [129, 28, 129],
                [130, 28, 130],
                [130, 28, 130],
                [131, 28, 131],
                [131, 28, 131],
                [132, 28, 132],
                [132, 28, 132],
                [133, 28, 133],
                [134, 29, 134],
                [134, 29, 134],
                [135, 29, 135],
                [135, 29, 135],
                [136, 29, 136],
                [137, 29, 137],
                [137, 29, 137],
                [138, 29, 138],
                [138, 30, 138],
                [139, 30, 139],
                [139, 30, 139],
                [140, 30, 140],
                [141, 30, 141],
                [141, 30, 141],
                [142, 30, 142],
                [142, 30, 142],
                [143, 31, 143],
                [143, 31, 143],
                [144, 31, 144],
                [145, 31, 145],
                [145, 31, 145],
                [146, 31, 146],
                [146, 31, 146],
                [148, 32, 148],
            ],
        );

        m.insert(
            "Blue",
            [
                [0, 0, 0],
                [0, 0, 1],
                [0, 0, 2],
                [0, 0, 3],
                [0, 0, 4],
                [0, 0, 5],
                [0, 0, 6],
                [0, 0, 7],
                [0, 0, 8],
                [0, 0, 9],
                [0, 0, 10],
                [0, 0, 11],
                [0, 0, 12],
                [0, 0, 13],
                [0, 0, 14],
                [0, 0, 15],
                [0, 0, 16],
                [0, 0, 17],
                [0, 0, 18],
                [0, 0, 19],
                [0, 0, 20],
                [0, 0, 21],
                [0, 0, 22],
                [0, 0, 23],
                [0, 0, 24],
                [0, 0, 25],
                [0, 0, 26],
                [0, 0, 27],
                [0, 0, 28],
                [0, 0, 29],
                [0, 0, 30],
                [0, 0, 31],
                [0, 0, 32],
                [0, 0, 33],
                [0, 0, 34],
                [0, 0, 35],
                [0, 0, 36],
                [0, 0, 37],
                [0, 0, 38],
                [0, 0, 39],
                [0, 0, 40],
                [0, 0, 41],
                [0, 0, 42],
                [0, 0, 43],
                [0, 0, 44],
                [0, 0, 45],
                [0, 0, 46],
                [0, 0, 47],
                [0, 0, 48],
                [0, 0, 49],
                [0, 0, 50],
                [0, 0, 51],
                [0, 0, 52],
                [0, 0, 53],
                [0, 0, 54],
                [0, 0, 55],
                [0, 0, 56],
                [0, 0, 57],
                [0, 0, 58],
                [0, 0, 59],
                [0, 0, 60],
                [0, 0, 61],
                [0, 0, 62],
                [0, 0, 63],
                [0, 0, 64],
                [0, 0, 65],
                [0, 0, 66],
                [0, 0, 67],
                [0, 0, 68],
                [0, 0, 69],
                [0, 0, 70],
                [0, 0, 71],
                [0, 0, 72],
                [0, 0, 73],
                [0, 0, 74],
                [0, 0, 75],
                [0, 0, 76],
                [0, 0, 77],
                [0, 0, 78],
                [0, 0, 79],
                [0, 0, 80],
                [0, 0, 81],
                [0, 0, 82],
                [0, 0, 83],
                [0, 0, 84],
                [0, 0, 85],
                [0, 0, 86],
                [0, 0, 87],
                [0, 0, 88],
                [0, 0, 89],
                [0, 0, 90],
                [0, 0, 91],
                [0, 0, 92],
                [0, 0, 93],
                [0, 0, 94],
                [0, 0, 95],
                [0, 0, 96],
                [0, 0, 97],
                [0, 0, 98],
                [0, 0, 99],
                [0, 0, 100],
                [0, 0, 101],
                [0, 0, 102],
                [0, 0, 103],
                [0, 0, 104],
                [0, 0, 105],
                [0, 0, 106],
                [0, 0, 107],
                [0, 0, 108],
                [0, 0, 109],
                [0, 0, 110],
                [0, 0, 111],
                [0, 0, 112],
                [0, 0, 113],
                [0, 0, 114],
                [0, 0, 115],
                [0, 0, 116],
                [0, 0, 117],
                [0, 0, 118],
                [0, 0, 119],
                [0, 0, 120],
                [0, 0, 121],
                [0, 0, 122],
                [0, 0, 123],
                [0, 0, 124],
                [0, 0, 125],
                [0, 0, 126],
                [0, 0, 127],
                [0, 0, 128],
                [0, 0, 129],
                [0, 0, 130],
                [0, 0, 131],
                [0, 0, 132],
                [0, 0, 133],
                [0, 0, 134],
                [0, 0, 135],
                [0, 0, 136],
                [0, 0, 137],
                [0, 0, 138],
                [0, 0, 139],
                [0, 0, 140],
                [0, 0, 141],
                [0, 0, 142],
                [0, 0, 143],
                [0, 0, 144],
                [0, 0, 145],
                [0, 0, 146],
                [0, 0, 147],
                [0, 0, 148],
                [0, 0, 149],
                [0, 0, 150],
                [0, 0, 151],
                [0, 0, 152],
                [0, 0, 153],
                [0, 0, 154],
                [0, 0, 155],
                [0, 0, 156],
                [0, 0, 157],
                [0, 0, 158],
                [0, 0, 159],
                [0, 0, 160],
                [0, 0, 161],
                [0, 0, 162],
                [0, 0, 163],
                [0, 0, 164],
                [0, 0, 165],
                [0, 0, 166],
                [0, 0, 167],
                [0, 0, 168],
                [0, 0, 169],
                [0, 0, 170],
                [0, 0, 171],
                [0, 0, 172],
                [0, 0, 173],
                [0, 0, 174],
                [0, 0, 175],
                [0, 0, 176],
                [0, 0, 177],
                [0, 0, 178],
                [0, 0, 179],
                [0, 0, 180],
                [0, 0, 181],
                [0, 0, 182],
                [0, 0, 183],
                [0, 0, 184],
                [0, 0, 185],
                [0, 0, 186],
                [0, 0, 187],
                [0, 0, 188],
                [0, 0, 189],
                [0, 0, 190],
                [0, 0, 191],
                [0, 0, 192],
                [0, 0, 193],
                [0, 0, 194],
                [0, 0, 195],
                [0, 0, 196],
                [0, 0, 197],
                [0, 0, 198],
                [0, 0, 199],
                [0, 0, 200],
                [0, 0, 201],
                [0, 0, 202],
                [0, 0, 203],
                [0, 0, 204],
                [0, 0, 205],
                [0, 0, 206],
                [0, 0, 207],
                [0, 0, 208],
                [0, 0, 209],
                [0, 0, 210],
                [0, 0, 211],
                [0, 0, 212],
                [0, 0, 213],
                [0, 0, 214],
                [0, 0, 215],
                [0, 0, 216],
                [0, 0, 217],
                [0, 0, 218],
                [0, 0, 219],
                [0, 0, 220],
                [0, 0, 221],
                [0, 0, 222],
                [0, 0, 223],
                [0, 0, 224],
                [0, 0, 225],
                [0, 0, 226],
                [0, 0, 227],
                [0, 0, 228],
                [0, 0, 229],
                [0, 0, 230],
                [0, 0, 231],
                [0, 0, 232],
                [0, 0, 233],
                [0, 0, 234],
                [0, 0, 235],
                [0, 0, 236],
                [0, 0, 237],
                [0, 0, 238],
                [0, 0, 239],
                [0, 0, 240],
                [0, 0, 241],
                [0, 0, 242],
                [0, 0, 243],
                [0, 0, 244],
                [0, 0, 245],
                [0, 0, 246],
                [0, 0, 247],
                [0, 0, 248],
                [0, 0, 249],
                [0, 0, 250],
                [0, 0, 251],
                [0, 0, 252],
                [0, 0, 253],
                [0, 0, 254],
                [0, 0, 255],
            ],
        );

        m.insert(
            "Circus Cherry",
            [
                [0, 0, 0],
                [3, 0, 0],
                [5, 1, 0],
                [8, 1, 0],
                [10, 1, 0],
                [13, 2, 1],
                [15, 2, 1],
                [17, 2, 1],
                [20, 3, 2],
                [22, 3, 2],
                [24, 3, 2],
                [26, 4, 3],
                [28, 4, 3],
                [30, 5, 4],
                [33, 5, 5],
                [35, 5, 5],
                [37, 6, 6],
                [39, 6, 6],
                [41, 6, 7],
                [43, 7, 8],
                [44, 7, 8],
                [46, 8, 9],
                [48, 8, 10],
                [50, 8, 10],
                [52, 9, 11],
                [54, 9, 12],
                [56, 10, 13],
                [57, 10, 14],
                [59, 11, 14],
                [61, 11, 15],
                [63, 11, 16],
                [64, 12, 17],
                [66, 12, 18],
                [68, 13, 19],
                [69, 13, 20],
                [71, 14, 20],
                [73, 14, 21],
                [74, 15, 22],
                [76, 15, 23],
                [77, 16, 24],
                [79, 16, 25],
                [80, 17, 26],
                [82, 17, 27],
                [84, 17, 28],
                [85, 18, 29],
                [87, 18, 30],
                [88, 19, 31],
                [90, 19, 32],
                [91, 20, 33],
                [92, 20, 34],
                [94, 21, 35],
                [95, 22, 36],
                [97, 22, 37],
                [98, 23, 38],
                [100, 23, 39],
                [101, 24, 40],
                [102, 24, 41],
                [104, 25, 43],
                [105, 25, 44],
                [106, 26, 45],
                [108, 26, 46],
                [109, 27, 47],
                [110, 27, 48],
                [112, 28, 49],
                [113, 29, 50],
                [114, 29, 51],
                [116, 30, 53],
                [117, 30, 54],
                [118, 31, 55],
                [120, 32, 56],
                [121, 32, 57],
                [122, 33, 58],
                [123, 33, 59],
                [124, 34, 61],
                [126, 35, 62],
                [127, 35, 63],
                [128, 36, 64],
                [129, 36, 65],
                [131, 37, 66],
                [132, 38, 68],
                [133, 38, 69],
                [134, 39, 70],
                [135, 40, 71],
                [136, 40, 72],
                [137, 41, 74],
                [139, 42, 75],
                [140, 42, 76],
                [141, 43, 77],
                [142, 44, 78],
                [143, 44, 80],
                [144, 45, 81],
                [145, 46, 82],
                [146, 46, 83],
                [147, 47, 84],
                [149, 48, 86],
                [150, 48, 87],
                [151, 49, 88],
                [152, 50, 89],
                [153, 51, 91],
                [154, 51, 92],
                [155, 52, 93],
                [156, 53, 94],
                [157, 54, 96],
                [158, 54, 97],
                [159, 55, 98],
                [160, 56, 99],
                [161, 57, 101],
                [162, 57, 102],
                [163, 58, 103],
                [164, 59, 104],
                [165, 60, 106],
                [166, 60, 107],
                [167, 61, 108],
                [168, 62, 109],
                [169, 63, 111],
                [170, 64, 112],
                [171, 64, 113],
                [171, 65, 114],
                [172, 66, 116],
                [173, 67, 117],
                [174, 68, 118],
                [175, 69, 119],
                [176, 69, 121],
                [177, 70, 122],
                [178, 71, 123],
                [179, 72, 124],
                [180, 73, 126],
                [180, 74, 127],
                [181, 75, 128],
                [182, 75, 129],
                [183, 76, 131],
                [184, 77, 132],
                [185, 78, 133],
                [186, 79, 134],
                [186, 80, 136],
                [187, 81, 137],
                [188, 82, 138],
                [189, 83, 139],
                [190, 84, 141],
                [191, 84, 142],
                [191, 85, 143],
                [192, 86, 144],
                [193, 87, 146],
                [194, 88, 147],
                [195, 89, 148],
                [195, 90, 149],
                [196, 91, 151],
                [197, 92, 152],
                [198, 93, 153],
                [198, 94, 154],
                [199, 95, 156],
                [200, 96, 157],
                [201, 97, 158],
                [201, 98, 159],
                [202, 99, 161],
                [203, 100, 162],
                [204, 101, 163],
                [204, 102, 164],
                [205, 103, 166],
                [206, 104, 167],
                [207, 105, 168],
                [207, 106, 169],
                [208, 108, 171],
                [209, 109, 172],
                [209, 110, 173],
                [210, 111, 174],
                [211, 112, 175],
                [211, 113, 177],
                [212, 114, 178],
                [213, 115, 179],
                [213, 116, 180],
                [214, 118, 181],
                [215, 119, 183],
                [215, 120, 184],
                [216, 121, 185],
                [217, 122, 186],
                [217, 123, 187],
                [218, 124, 189],
                [219, 126, 190],
                [219, 127, 191],
                [220, 128, 192],
                [220, 129, 193],
                [221, 131, 194],
                [222, 132, 196],
                [222, 133, 197],
                [223, 134, 198],
                [223, 135, 199],
                [224, 137, 200],
                [225, 138, 201],
                [225, 139, 202],
                [226, 141, 204],
                [226, 142, 205],
                [227, 143, 206],
                [228, 145, 207],
                [228, 146, 208],
                [229, 147, 209],
                [229, 149, 210],
                [230, 150, 211],
                [230, 151, 212],
                [231, 153, 214],
                [231, 154, 215],
                [232, 155, 216],
                [232, 157, 217],
                [233, 158, 218],
                [233, 160, 219],
                [234, 161, 220],
                [235, 163, 221],
                [235, 164, 222],
                [236, 165, 223],
                [236, 167, 224],
                [237, 168, 225],
                [237, 170, 226],
                [238, 171, 227],
                [238, 173, 228],
                [238, 175, 229],
                [239, 176, 230],
                [239, 178, 231],
                [240, 179, 232],
                [240, 181, 233],
                [241, 182, 234],
                [241, 184, 235],
                [242, 186, 235],
                [242, 187, 236],
                [243, 189, 237],
                [243, 191, 238],
                [244, 192, 239],
                [244, 194, 240],
                [244, 196, 241],
                [245, 198, 241],
                [245, 199, 242],
                [246, 201, 243],
                [246, 203, 244],
                [247, 205, 245],
                [247, 207, 245],
                [247, 209, 246],
                [248, 211, 247],
                [248, 212, 247],
                [249, 214, 248],
                [249, 216, 249],
                [249, 218, 249],
                [250, 220, 250],
                [250, 222, 250],
                [250, 225, 251],
                [251, 227, 252],
                [251, 229, 252],
                [252, 231, 253],
                [252, 233, 253],
                [252, 235, 253],
                [253, 238, 254],
                [253, 240, 254],
                [253, 242, 254],
                [254, 245, 255],
                [254, 247, 255],
                [254, 250, 255],
                [255, 252, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Circus Cyan",
            [
                [0, 0, 0],
                [0, 0, 3],
                [1, 0, 5],
                [1, 0, 8],
                [1, 0, 10],
                [2, 1, 13],
                [2, 1, 15],
                [2, 1, 17],
                [3, 2, 20],
                [3, 2, 22],
                [3, 2, 24],
                [4, 3, 26],
                [4, 3, 28],
                [5, 4, 30],
                [5, 5, 33],
                [5, 5, 35],
                [6, 6, 37],
                [6, 6, 39],
                [6, 7, 41],
                [7, 8, 43],
                [7, 8, 44],
                [8, 9, 46],
                [8, 10, 48],
                [8, 10, 50],
                [9, 11, 52],
                [9, 12, 54],
                [10, 13, 56],
                [10, 14, 57],
                [11, 14, 59],
                [11, 15, 61],
                [11, 16, 63],
                [12, 17, 64],
                [12, 18, 66],
                [13, 19, 68],
                [13, 20, 69],
                [14, 20, 71],
                [14, 21, 73],
                [15, 22, 74],
                [15, 23, 76],
                [16, 24, 77],
                [16, 25, 79],
                [17, 26, 80],
                [17, 27, 82],
                [17, 28, 84],
                [18, 29, 85],
                [18, 30, 87],
                [19, 31, 88],
                [19, 32, 90],
                [20, 33, 91],
                [20, 34, 92],
                [21, 35, 94],
                [22, 36, 95],
                [22, 37, 97],
                [23, 38, 98],
                [23, 39, 100],
                [24, 40, 101],
                [24, 41, 102],
                [25, 43, 104],
                [25, 44, 105],
                [26, 45, 106],
                [26, 46, 108],
                [27, 47, 109],
                [27, 48, 110],
                [28, 49, 112],
                [29, 50, 113],
                [29, 51, 114],
                [30, 53, 116],
                [30, 54, 117],
                [31, 55, 118],
                [32, 56, 120],
                [32, 57, 121],
                [33, 58, 122],
                [33, 59, 123],
                [34, 61, 124],
                [35, 62, 126],
                [35, 63, 127],
                [36, 64, 128],
                [36, 65, 129],
                [37, 66, 131],
                [38, 68, 132],
                [38, 69, 133],
                [39, 70, 134],
                [40, 71, 135],
                [40, 72, 136],
                [41, 74, 137],
                [42, 75, 139],
                [42, 76, 140],
                [43, 77, 141],
                [44, 78, 142],
                [44, 80, 143],
                [45, 81, 144],
                [46, 82, 145],
                [46, 83, 146],
                [47, 84, 147],
                [48, 86, 149],
                [48, 87, 150],
                [49, 88, 151],
                [50, 89, 152],
                [51, 91, 153],
                [51, 92, 154],
                [52, 93, 155],
                [53, 94, 156],
                [54, 96, 157],
                [54, 97, 158],
                [55, 98, 159],
                [56, 99, 160],
                [57, 101, 161],
                [57, 102, 162],
                [58, 103, 163],
                [59, 104, 164],
                [60, 106, 165],
                [60, 107, 166],
                [61, 108, 167],
                [62, 109, 168],
                [63, 111, 169],
                [64, 112, 170],
                [64, 113, 171],
                [65, 114, 171],
                [66, 116, 172],
                [67, 117, 173],
                [68, 118, 174],
                [69, 119, 175],
                [69, 121, 176],
                [70, 122, 177],
                [71, 123, 178],
                [72, 124, 179],
                [73, 126, 180],
                [74, 127, 180],
                [75, 128, 181],
                [75, 129, 182],
                [76, 131, 183],
                [77, 132, 184],
                [78, 133, 185],
                [79, 134, 186],
                [80, 136, 186],
                [81, 137, 187],
                [82, 138, 188],
                [83, 139, 189],
                [84, 141, 190],
                [84, 142, 191],
                [85, 143, 191],
                [86, 144, 192],
                [87, 146, 193],
                [88, 147, 194],
                [89, 148, 195],
                [90, 149, 195],
                [91, 151, 196],
                [92, 152, 197],
                [93, 153, 198],
                [94, 154, 198],
                [95, 156, 199],
                [96, 157, 200],
                [97, 158, 201],
                [98, 159, 201],
                [99, 161, 202],
                [100, 162, 203],
                [101, 163, 204],
                [102, 164, 204],
                [103, 166, 205],
                [104, 167, 206],
                [105, 168, 207],
                [106, 169, 207],
                [108, 171, 208],
                [109, 172, 209],
                [110, 173, 209],
                [111, 174, 210],
                [112, 175, 211],
                [113, 177, 211],
                [114, 178, 212],
                [115, 179, 213],
                [116, 180, 213],
                [118, 181, 214],
                [119, 183, 215],
                [120, 184, 215],
                [121, 185, 216],
                [122, 186, 217],
                [123, 187, 217],
                [124, 189, 218],
                [126, 190, 219],
                [127, 191, 219],
                [128, 192, 220],
                [129, 193, 220],
                [131, 194, 221],
                [132, 196, 222],
                [133, 197, 222],
                [134, 198, 223],
                [135, 199, 223],
                [137, 200, 224],
                [138, 201, 225],
                [139, 202, 225],
                [141, 204, 226],
                [142, 205, 226],
                [143, 206, 227],
                [145, 207, 228],
                [146, 208, 228],
                [147, 209, 229],
                [149, 210, 229],
                [150, 211, 230],
                [151, 212, 230],
                [153, 214, 231],
                [154, 215, 231],
                [155, 216, 232],
                [157, 217, 232],
                [158, 218, 233],
                [160, 219, 233],
                [161, 220, 234],
                [163, 221, 235],
                [164, 222, 235],
                [165, 223, 236],
                [167, 224, 236],
                [168, 225, 237],
                [170, 226, 237],
                [171, 227, 238],
                [173, 228, 238],
                [175, 229, 238],
                [176, 230, 239],
                [178, 231, 239],
                [179, 232, 240],
                [181, 233, 240],
                [182, 234, 241],
                [184, 235, 241],
                [186, 235, 242],
                [187, 236, 242],
                [189, 237, 243],
                [191, 238, 243],
                [192, 239, 244],
                [194, 240, 244],
                [196, 241, 244],
                [198, 241, 245],
                [199, 242, 245],
                [201, 243, 246],
                [203, 244, 246],
                [205, 245, 247],
                [207, 245, 247],
                [209, 246, 247],
                [211, 247, 248],
                [212, 247, 248],
                [214, 248, 249],
                [216, 249, 249],
                [218, 249, 249],
                [220, 250, 250],
                [222, 250, 250],
                [225, 251, 250],
                [227, 252, 251],
                [229, 252, 251],
                [231, 253, 252],
                [233, 253, 252],
                [235, 253, 252],
                [238, 254, 253],
                [240, 254, 253],
                [242, 254, 253],
                [245, 255, 254],
                [247, 255, 254],
                [250, 255, 254],
                [252, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Circus Green",
            [
                [0, 0, 0],
                [0, 3, 0],
                [0, 5, 1],
                [0, 8, 1],
                [0, 10, 1],
                [1, 13, 2],
                [1, 15, 2],
                [1, 17, 2],
                [2, 20, 3],
                [2, 22, 3],
                [2, 24, 3],
                [3, 26, 4],
                [3, 28, 4],
                [4, 30, 5],
                [5, 33, 5],
                [5, 35, 5],
                [6, 37, 6],
                [6, 39, 6],
                [7, 41, 6],
                [8, 43, 7],
                [8, 44, 7],
                [9, 46, 8],
                [10, 48, 8],
                [10, 50, 8],
                [11, 52, 9],
                [12, 54, 9],
                [13, 56, 10],
                [14, 57, 10],
                [14, 59, 11],
                [15, 61, 11],
                [16, 63, 11],
                [17, 64, 12],
                [18, 66, 12],
                [19, 68, 13],
                [20, 69, 13],
                [20, 71, 14],
                [21, 73, 14],
                [22, 74, 15],
                [23, 76, 15],
                [24, 77, 16],
                [25, 79, 16],
                [26, 80, 17],
                [27, 82, 17],
                [28, 84, 17],
                [29, 85, 18],
                [30, 87, 18],
                [31, 88, 19],
                [32, 90, 19],
                [33, 91, 20],
                [34, 92, 20],
                [35, 94, 21],
                [36, 95, 22],
                [37, 97, 22],
                [38, 98, 23],
                [39, 100, 23],
                [40, 101, 24],
                [41, 102, 24],
                [43, 104, 25],
                [44, 105, 25],
                [45, 106, 26],
                [46, 108, 26],
                [47, 109, 27],
                [48, 110, 27],
                [49, 112, 28],
                [50, 113, 29],
                [51, 114, 29],
                [53, 116, 30],
                [54, 117, 30],
                [55, 118, 31],
                [56, 120, 32],
                [57, 121, 32],
                [58, 122, 33],
                [59, 123, 33],
                [61, 124, 34],
                [62, 126, 35],
                [63, 127, 35],
                [64, 128, 36],
                [65, 129, 36],
                [66, 131, 37],
                [68, 132, 38],
                [69, 133, 38],
                [70, 134, 39],
                [71, 135, 40],
                [72, 136, 40],
                [74, 137, 41],
                [75, 139, 42],
                [76, 140, 42],
                [77, 141, 43],
                [78, 142, 44],
                [80, 143, 44],
                [81, 144, 45],
                [82, 145, 46],
                [83, 146, 46],
                [84, 147, 47],
                [86, 149, 48],
                [87, 150, 48],
                [88, 151, 49],
                [89, 152, 50],
                [91, 153, 51],
                [92, 154, 51],
                [93, 155, 52],
                [94, 156, 53],
                [96, 157, 54],
                [97, 158, 54],
                [98, 159, 55],
                [99, 160, 56],
                [101, 161, 57],
                [102, 162, 57],
                [103, 163, 58],
                [104, 164, 59],
                [106, 165, 60],
                [107, 166, 60],
                [108, 167, 61],
                [109, 168, 62],
                [111, 169, 63],
                [112, 170, 64],
                [113, 171, 64],
                [114, 171, 65],
                [116, 172, 66],
                [117, 173, 67],
                [118, 174, 68],
                [119, 175, 69],
                [121, 176, 69],
                [122, 177, 70],
                [123, 178, 71],
                [124, 179, 72],
                [126, 180, 73],
                [127, 180, 74],
                [128, 181, 75],
                [129, 182, 75],
                [131, 183, 76],
                [132, 184, 77],
                [133, 185, 78],
                [134, 186, 79],
                [136, 186, 80],
                [137, 187, 81],
                [138, 188, 82],
                [139, 189, 83],
                [141, 190, 84],
                [142, 191, 84],
                [143, 191, 85],
                [144, 192, 86],
                [146, 193, 87],
                [147, 194, 88],
                [148, 195, 89],
                [149, 195, 90],
                [151, 196, 91],
                [152, 197, 92],
                [153, 198, 93],
                [154, 198, 94],
                [156, 199, 95],
                [157, 200, 96],
                [158, 201, 97],
                [159, 201, 98],
                [161, 202, 99],
                [162, 203, 100],
                [163, 204, 101],
                [164, 204, 102],
                [166, 205, 103],
                [167, 206, 104],
                [168, 207, 105],
                [169, 207, 106],
                [171, 208, 108],
                [172, 209, 109],
                [173, 209, 110],
                [174, 210, 111],
                [175, 211, 112],
                [177, 211, 113],
                [178, 212, 114],
                [179, 213, 115],
                [180, 213, 116],
                [181, 214, 118],
                [183, 215, 119],
                [184, 215, 120],
                [185, 216, 121],
                [186, 217, 122],
                [187, 217, 123],
                [189, 218, 124],
                [190, 219, 126],
                [191, 219, 127],
                [192, 220, 128],
                [193, 220, 129],
                [194, 221, 131],
                [196, 222, 132],
                [197, 222, 133],
                [198, 223, 134],
                [199, 223, 135],
                [200, 224, 137],
                [201, 225, 138],
                [202, 225, 139],
                [204, 226, 141],
                [205, 226, 142],
                [206, 227, 143],
                [207, 228, 145],
                [208, 228, 146],
                [209, 229, 147],
                [210, 229, 149],
                [211, 230, 150],
                [212, 230, 151],
                [214, 231, 153],
                [215, 231, 154],
                [216, 232, 155],
                [217, 232, 157],
                [218, 233, 158],
                [219, 233, 160],
                [220, 234, 161],
                [221, 235, 163],
                [222, 235, 164],
                [223, 236, 165],
                [224, 236, 167],
                [225, 237, 168],
                [226, 237, 170],
                [227, 238, 171],
                [228, 238, 173],
                [229, 238, 175],
                [230, 239, 176],
                [231, 239, 178],
                [232, 240, 179],
                [233, 240, 181],
                [234, 241, 182],
                [235, 241, 184],
                [235, 242, 186],
                [236, 242, 187],
                [237, 243, 189],
                [238, 243, 191],
                [239, 244, 192],
                [240, 244, 194],
                [241, 244, 196],
                [241, 245, 198],
                [242, 245, 199],
                [243, 246, 201],
                [244, 246, 203],
                [245, 247, 205],
                [245, 247, 207],
                [246, 247, 209],
                [247, 248, 211],
                [247, 248, 212],
                [248, 249, 214],
                [249, 249, 216],
                [249, 249, 218],
                [250, 250, 220],
                [250, 250, 222],
                [251, 250, 225],
                [252, 251, 227],
                [252, 251, 229],
                [253, 252, 231],
                [253, 252, 233],
                [253, 252, 235],
                [254, 253, 238],
                [254, 253, 240],
                [254, 253, 242],
                [255, 254, 245],
                [255, 254, 247],
                [255, 254, 250],
                [255, 255, 252],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Circus Ink Black",
            [
                [255, 255, 255],
                [254, 254, 254],
                [253, 253, 253],
                [252, 252, 252],
                [251, 251, 251],
                [250, 250, 250],
                [249, 249, 249],
                [248, 248, 248],
                [247, 247, 247],
                [246, 246, 246],
                [245, 245, 245],
                [244, 244, 244],
                [243, 243, 243],
                [242, 242, 242],
                [241, 241, 241],
                [240, 240, 240],
                [239, 239, 239],
                [238, 238, 238],
                [237, 237, 237],
                [236, 236, 236],
                [235, 235, 235],
                [234, 234, 234],
                [233, 233, 233],
                [232, 232, 232],
                [231, 231, 231],
                [230, 230, 230],
                [229, 229, 229],
                [228, 228, 228],
                [227, 227, 227],
                [226, 226, 226],
                [225, 225, 225],
                [224, 224, 224],
                [223, 223, 223],
                [222, 222, 222],
                [221, 221, 221],
                [220, 220, 220],
                [219, 219, 219],
                [218, 218, 218],
                [217, 217, 217],
                [216, 216, 216],
                [215, 215, 215],
                [214, 214, 214],
                [213, 213, 213],
                [212, 212, 212],
                [211, 211, 211],
                [210, 210, 210],
                [209, 209, 209],
                [208, 208, 208],
                [207, 207, 207],
                [206, 206, 206],
                [205, 205, 205],
                [204, 204, 204],
                [203, 203, 203],
                [202, 202, 202],
                [201, 201, 201],
                [200, 200, 200],
                [199, 199, 199],
                [198, 198, 198],
                [197, 197, 197],
                [196, 196, 196],
                [195, 195, 195],
                [194, 194, 194],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [190, 190, 190],
                [189, 189, 189],
                [188, 188, 188],
                [187, 187, 187],
                [186, 186, 186],
                [185, 185, 185],
                [184, 184, 184],
                [183, 183, 183],
                [182, 182, 182],
                [181, 181, 181],
                [180, 180, 180],
                [179, 179, 179],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [170, 170, 170],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [161, 161, 161],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [153, 153, 153],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [148, 148, 148],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [31, 31, 31],
                [30, 30, 30],
                [29, 29, 29],
                [28, 28, 28],
                [27, 27, 27],
                [26, 26, 26],
                [25, 25, 25],
                [24, 24, 24],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [20, 20, 20],
                [19, 19, 19],
                [18, 18, 18],
                [17, 17, 17],
                [16, 16, 16],
                [15, 15, 15],
                [14, 14, 14],
                [13, 13, 13],
                [12, 12, 12],
                [11, 11, 11],
                [10, 10, 10],
                [9, 9, 9],
                [8, 8, 8],
                [7, 7, 7],
                [6, 6, 6],
                [5, 5, 5],
                [4, 4, 4],
                [3, 3, 3],
                [2, 2, 2],
                [1, 1, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Cherry",
            [
                [255, 255, 255],
                [255, 252, 255],
                [254, 250, 255],
                [254, 247, 255],
                [254, 245, 255],
                [253, 242, 254],
                [253, 240, 254],
                [253, 238, 254],
                [252, 235, 253],
                [252, 233, 253],
                [252, 231, 253],
                [251, 229, 252],
                [251, 227, 252],
                [250, 225, 251],
                [250, 222, 250],
                [250, 220, 250],
                [249, 218, 249],
                [249, 216, 249],
                [249, 214, 248],
                [248, 212, 247],
                [248, 211, 247],
                [247, 209, 246],
                [247, 207, 245],
                [247, 205, 245],
                [246, 203, 244],
                [246, 201, 243],
                [245, 199, 242],
                [245, 198, 241],
                [244, 196, 241],
                [244, 194, 240],
                [244, 192, 239],
                [243, 191, 238],
                [243, 189, 237],
                [242, 187, 236],
                [242, 186, 235],
                [241, 184, 235],
                [241, 182, 234],
                [240, 181, 233],
                [240, 179, 232],
                [239, 178, 231],
                [239, 176, 230],
                [238, 175, 229],
                [238, 173, 228],
                [238, 171, 227],
                [237, 170, 226],
                [237, 168, 225],
                [236, 167, 224],
                [236, 165, 223],
                [235, 164, 222],
                [235, 163, 221],
                [234, 161, 220],
                [233, 160, 219],
                [233, 158, 218],
                [232, 157, 217],
                [232, 155, 216],
                [231, 154, 215],
                [231, 153, 214],
                [230, 151, 212],
                [230, 150, 211],
                [229, 149, 210],
                [229, 147, 209],
                [228, 146, 208],
                [228, 145, 207],
                [227, 143, 206],
                [226, 142, 205],
                [226, 141, 204],
                [225, 139, 202],
                [225, 138, 201],
                [224, 137, 200],
                [223, 135, 199],
                [223, 134, 198],
                [222, 133, 197],
                [222, 132, 196],
                [221, 131, 194],
                [220, 129, 193],
                [220, 128, 192],
                [219, 127, 191],
                [219, 126, 190],
                [218, 124, 189],
                [217, 123, 187],
                [217, 122, 186],
                [216, 121, 185],
                [215, 120, 184],
                [215, 119, 183],
                [214, 118, 181],
                [213, 116, 180],
                [213, 115, 179],
                [212, 114, 178],
                [211, 113, 177],
                [211, 112, 175],
                [210, 111, 174],
                [209, 110, 173],
                [209, 109, 172],
                [208, 108, 171],
                [207, 106, 169],
                [207, 105, 168],
                [206, 104, 167],
                [205, 103, 166],
                [204, 102, 164],
                [204, 101, 163],
                [203, 100, 162],
                [202, 99, 161],
                [201, 98, 159],
                [201, 97, 158],
                [200, 96, 157],
                [199, 95, 156],
                [198, 94, 154],
                [198, 93, 153],
                [197, 92, 152],
                [196, 91, 151],
                [195, 90, 149],
                [195, 89, 148],
                [194, 88, 147],
                [193, 87, 146],
                [192, 86, 144],
                [191, 85, 143],
                [191, 84, 142],
                [190, 84, 141],
                [189, 83, 139],
                [188, 82, 138],
                [187, 81, 137],
                [186, 80, 136],
                [186, 79, 134],
                [185, 78, 133],
                [184, 77, 132],
                [183, 76, 131],
                [182, 75, 129],
                [181, 75, 128],
                [180, 74, 127],
                [180, 73, 126],
                [179, 72, 124],
                [178, 71, 123],
                [177, 70, 122],
                [176, 69, 121],
                [175, 69, 119],
                [174, 68, 118],
                [173, 67, 117],
                [172, 66, 116],
                [171, 65, 114],
                [171, 64, 113],
                [170, 64, 112],
                [169, 63, 111],
                [168, 62, 109],
                [167, 61, 108],
                [166, 60, 107],
                [165, 60, 106],
                [164, 59, 104],
                [163, 58, 103],
                [162, 57, 102],
                [161, 57, 101],
                [160, 56, 99],
                [159, 55, 98],
                [158, 54, 97],
                [157, 54, 96],
                [156, 53, 94],
                [155, 52, 93],
                [154, 51, 92],
                [153, 51, 91],
                [152, 50, 89],
                [151, 49, 88],
                [150, 48, 87],
                [149, 48, 86],
                [147, 47, 84],
                [146, 46, 83],
                [145, 46, 82],
                [144, 45, 81],
                [143, 44, 80],
                [142, 44, 78],
                [141, 43, 77],
                [140, 42, 76],
                [139, 42, 75],
                [137, 41, 74],
                [136, 40, 72],
                [135, 40, 71],
                [134, 39, 70],
                [133, 38, 69],
                [132, 38, 68],
                [131, 37, 66],
                [129, 36, 65],
                [128, 36, 64],
                [127, 35, 63],
                [126, 35, 62],
                [124, 34, 61],
                [123, 33, 59],
                [122, 33, 58],
                [121, 32, 57],
                [120, 32, 56],
                [118, 31, 55],
                [117, 30, 54],
                [116, 30, 53],
                [114, 29, 51],
                [113, 29, 50],
                [112, 28, 49],
                [110, 27, 48],
                [109, 27, 47],
                [108, 26, 46],
                [106, 26, 45],
                [105, 25, 44],
                [104, 25, 43],
                [102, 24, 41],
                [101, 24, 40],
                [100, 23, 39],
                [98, 23, 38],
                [97, 22, 37],
                [95, 22, 36],
                [94, 21, 35],
                [92, 20, 34],
                [91, 20, 33],
                [90, 19, 32],
                [88, 19, 31],
                [87, 18, 30],
                [85, 18, 29],
                [84, 17, 28],
                [82, 17, 27],
                [80, 17, 26],
                [79, 16, 25],
                [77, 16, 24],
                [76, 15, 23],
                [74, 15, 22],
                [73, 14, 21],
                [71, 14, 20],
                [69, 13, 20],
                [68, 13, 19],
                [66, 12, 18],
                [64, 12, 17],
                [63, 11, 16],
                [61, 11, 15],
                [59, 11, 14],
                [57, 10, 14],
                [56, 10, 13],
                [54, 9, 12],
                [52, 9, 11],
                [50, 8, 10],
                [48, 8, 10],
                [46, 8, 9],
                [44, 7, 8],
                [43, 7, 8],
                [41, 6, 7],
                [39, 6, 6],
                [37, 6, 6],
                [35, 5, 5],
                [33, 5, 5],
                [30, 5, 4],
                [28, 4, 3],
                [26, 4, 3],
                [24, 3, 2],
                [22, 3, 2],
                [20, 3, 2],
                [17, 2, 1],
                [15, 2, 1],
                [13, 2, 1],
                [10, 1, 0],
                [8, 1, 0],
                [5, 1, 0],
                [3, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Cyan",
            [
                [255, 255, 255],
                [252, 255, 255],
                [250, 255, 254],
                [247, 255, 254],
                [245, 255, 254],
                [242, 254, 253],
                [240, 254, 253],
                [238, 254, 253],
                [235, 253, 252],
                [233, 253, 252],
                [231, 253, 252],
                [229, 252, 251],
                [227, 252, 251],
                [225, 251, 250],
                [222, 250, 250],
                [220, 250, 250],
                [218, 249, 249],
                [216, 249, 249],
                [214, 248, 249],
                [212, 247, 248],
                [211, 247, 248],
                [209, 246, 247],
                [207, 245, 247],
                [205, 245, 247],
                [203, 244, 246],
                [201, 243, 246],
                [199, 242, 245],
                [198, 241, 245],
                [196, 241, 244],
                [194, 240, 244],
                [192, 239, 244],
                [191, 238, 243],
                [189, 237, 243],
                [187, 236, 242],
                [186, 235, 242],
                [184, 235, 241],
                [182, 234, 241],
                [181, 233, 240],
                [179, 232, 240],
                [178, 231, 239],
                [176, 230, 239],
                [175, 229, 238],
                [173, 228, 238],
                [171, 227, 238],
                [170, 226, 237],
                [168, 225, 237],
                [167, 224, 236],
                [165, 223, 236],
                [164, 222, 235],
                [163, 221, 235],
                [161, 220, 234],
                [160, 219, 233],
                [158, 218, 233],
                [157, 217, 232],
                [155, 216, 232],
                [154, 215, 231],
                [153, 214, 231],
                [151, 212, 230],
                [150, 211, 230],
                [149, 210, 229],
                [147, 209, 229],
                [146, 208, 228],
                [145, 207, 228],
                [143, 206, 227],
                [142, 205, 226],
                [141, 204, 226],
                [139, 202, 225],
                [138, 201, 225],
                [137, 200, 224],
                [135, 199, 223],
                [134, 198, 223],
                [133, 197, 222],
                [132, 196, 222],
                [131, 194, 221],
                [129, 193, 220],
                [128, 192, 220],
                [127, 191, 219],
                [126, 190, 219],
                [124, 189, 218],
                [123, 187, 217],
                [122, 186, 217],
                [121, 185, 216],
                [120, 184, 215],
                [119, 183, 215],
                [118, 181, 214],
                [116, 180, 213],
                [115, 179, 213],
                [114, 178, 212],
                [113, 177, 211],
                [112, 175, 211],
                [111, 174, 210],
                [110, 173, 209],
                [109, 172, 209],
                [108, 171, 208],
                [106, 169, 207],
                [105, 168, 207],
                [104, 167, 206],
                [103, 166, 205],
                [102, 164, 204],
                [101, 163, 204],
                [100, 162, 203],
                [99, 161, 202],
                [98, 159, 201],
                [97, 158, 201],
                [96, 157, 200],
                [95, 156, 199],
                [94, 154, 198],
                [93, 153, 198],
                [92, 152, 197],
                [91, 151, 196],
                [90, 149, 195],
                [89, 148, 195],
                [88, 147, 194],
                [87, 146, 193],
                [86, 144, 192],
                [85, 143, 191],
                [84, 142, 191],
                [84, 141, 190],
                [83, 139, 189],
                [82, 138, 188],
                [81, 137, 187],
                [80, 136, 186],
                [79, 134, 186],
                [78, 133, 185],
                [77, 132, 184],
                [76, 131, 183],
                [75, 129, 182],
                [75, 128, 181],
                [74, 127, 180],
                [73, 126, 180],
                [72, 124, 179],
                [71, 123, 178],
                [70, 122, 177],
                [69, 121, 176],
                [69, 119, 175],
                [68, 118, 174],
                [67, 117, 173],
                [66, 116, 172],
                [65, 114, 171],
                [64, 113, 171],
                [64, 112, 170],
                [63, 111, 169],
                [62, 109, 168],
                [61, 108, 167],
                [60, 107, 166],
                [60, 106, 165],
                [59, 104, 164],
                [58, 103, 163],
                [57, 102, 162],
                [57, 101, 161],
                [56, 99, 160],
                [55, 98, 159],
                [54, 97, 158],
                [54, 96, 157],
                [53, 94, 156],
                [52, 93, 155],
                [51, 92, 154],
                [51, 91, 153],
                [50, 89, 152],
                [49, 88, 151],
                [48, 87, 150],
                [48, 86, 149],
                [47, 84, 147],
                [46, 83, 146],
                [46, 82, 145],
                [45, 81, 144],
                [44, 80, 143],
                [44, 78, 142],
                [43, 77, 141],
                [42, 76, 140],
                [42, 75, 139],
                [41, 74, 137],
                [40, 72, 136],
                [40, 71, 135],
                [39, 70, 134],
                [38, 69, 133],
                [38, 68, 132],
                [37, 66, 131],
                [36, 65, 129],
                [36, 64, 128],
                [35, 63, 127],
                [35, 62, 126],
                [34, 61, 124],
                [33, 59, 123],
                [33, 58, 122],
                [32, 57, 121],
                [32, 56, 120],
                [31, 55, 118],
                [30, 54, 117],
                [30, 53, 116],
                [29, 51, 114],
                [29, 50, 113],
                [28, 49, 112],
                [27, 48, 110],
                [27, 47, 109],
                [26, 46, 108],
                [26, 45, 106],
                [25, 44, 105],
                [25, 43, 104],
                [24, 41, 102],
                [24, 40, 101],
                [23, 39, 100],
                [23, 38, 98],
                [22, 37, 97],
                [22, 36, 95],
                [21, 35, 94],
                [20, 34, 92],
                [20, 33, 91],
                [19, 32, 90],
                [19, 31, 88],
                [18, 30, 87],
                [18, 29, 85],
                [17, 28, 84],
                [17, 27, 82],
                [17, 26, 80],
                [16, 25, 79],
                [16, 24, 77],
                [15, 23, 76],
                [15, 22, 74],
                [14, 21, 73],
                [14, 20, 71],
                [13, 20, 69],
                [13, 19, 68],
                [12, 18, 66],
                [12, 17, 64],
                [11, 16, 63],
                [11, 15, 61],
                [11, 14, 59],
                [10, 14, 57],
                [10, 13, 56],
                [9, 12, 54],
                [9, 11, 52],
                [8, 10, 50],
                [8, 10, 48],
                [8, 9, 46],
                [7, 8, 44],
                [7, 8, 43],
                [6, 7, 41],
                [6, 6, 39],
                [6, 6, 37],
                [5, 5, 35],
                [5, 5, 33],
                [5, 4, 30],
                [4, 3, 28],
                [4, 3, 26],
                [3, 2, 24],
                [3, 2, 22],
                [3, 2, 20],
                [2, 1, 17],
                [2, 1, 15],
                [2, 1, 13],
                [1, 0, 10],
                [1, 0, 8],
                [1, 0, 5],
                [0, 0, 3],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Green",
            [
                [255, 255, 255],
                [255, 255, 252],
                [255, 254, 250],
                [255, 254, 247],
                [255, 254, 245],
                [254, 253, 242],
                [254, 253, 240],
                [254, 253, 238],
                [253, 252, 235],
                [253, 252, 233],
                [253, 252, 231],
                [252, 251, 229],
                [252, 251, 227],
                [251, 250, 225],
                [250, 250, 222],
                [250, 250, 220],
                [249, 249, 218],
                [249, 249, 216],
                [248, 249, 214],
                [247, 248, 212],
                [247, 248, 211],
                [246, 247, 209],
                [245, 247, 207],
                [245, 247, 205],
                [244, 246, 203],
                [243, 246, 201],
                [242, 245, 199],
                [241, 245, 198],
                [241, 244, 196],
                [240, 244, 194],
                [239, 244, 192],
                [238, 243, 191],
                [237, 243, 189],
                [236, 242, 187],
                [235, 242, 186],
                [235, 241, 184],
                [234, 241, 182],
                [233, 240, 181],
                [232, 240, 179],
                [231, 239, 178],
                [230, 239, 176],
                [229, 238, 175],
                [228, 238, 173],
                [227, 238, 171],
                [226, 237, 170],
                [225, 237, 168],
                [224, 236, 167],
                [223, 236, 165],
                [222, 235, 164],
                [221, 235, 163],
                [220, 234, 161],
                [219, 233, 160],
                [218, 233, 158],
                [217, 232, 157],
                [216, 232, 155],
                [215, 231, 154],
                [214, 231, 153],
                [212, 230, 151],
                [211, 230, 150],
                [210, 229, 149],
                [209, 229, 147],
                [208, 228, 146],
                [207, 228, 145],
                [206, 227, 143],
                [205, 226, 142],
                [204, 226, 141],
                [202, 225, 139],
                [201, 225, 138],
                [200, 224, 137],
                [199, 223, 135],
                [198, 223, 134],
                [197, 222, 133],
                [196, 222, 132],
                [194, 221, 131],
                [193, 220, 129],
                [192, 220, 128],
                [191, 219, 127],
                [190, 219, 126],
                [189, 218, 124],
                [187, 217, 123],
                [186, 217, 122],
                [185, 216, 121],
                [184, 215, 120],
                [183, 215, 119],
                [181, 214, 118],
                [180, 213, 116],
                [179, 213, 115],
                [178, 212, 114],
                [177, 211, 113],
                [175, 211, 112],
                [174, 210, 111],
                [173, 209, 110],
                [172, 209, 109],
                [171, 208, 108],
                [169, 207, 106],
                [168, 207, 105],
                [167, 206, 104],
                [166, 205, 103],
                [164, 204, 102],
                [163, 204, 101],
                [162, 203, 100],
                [161, 202, 99],
                [159, 201, 98],
                [158, 201, 97],
                [157, 200, 96],
                [156, 199, 95],
                [154, 198, 94],
                [153, 198, 93],
                [152, 197, 92],
                [151, 196, 91],
                [149, 195, 90],
                [148, 195, 89],
                [147, 194, 88],
                [146, 193, 87],
                [144, 192, 86],
                [143, 191, 85],
                [142, 191, 84],
                [141, 190, 84],
                [139, 189, 83],
                [138, 188, 82],
                [137, 187, 81],
                [136, 186, 80],
                [134, 186, 79],
                [133, 185, 78],
                [132, 184, 77],
                [131, 183, 76],
                [129, 182, 75],
                [128, 181, 75],
                [127, 180, 74],
                [126, 180, 73],
                [124, 179, 72],
                [123, 178, 71],
                [122, 177, 70],
                [121, 176, 69],
                [119, 175, 69],
                [118, 174, 68],
                [117, 173, 67],
                [116, 172, 66],
                [114, 171, 65],
                [113, 171, 64],
                [112, 170, 64],
                [111, 169, 63],
                [109, 168, 62],
                [108, 167, 61],
                [107, 166, 60],
                [106, 165, 60],
                [104, 164, 59],
                [103, 163, 58],
                [102, 162, 57],
                [101, 161, 57],
                [99, 160, 56],
                [98, 159, 55],
                [97, 158, 54],
                [96, 157, 54],
                [94, 156, 53],
                [93, 155, 52],
                [92, 154, 51],
                [91, 153, 51],
                [89, 152, 50],
                [88, 151, 49],
                [87, 150, 48],
                [86, 149, 48],
                [84, 147, 47],
                [83, 146, 46],
                [82, 145, 46],
                [81, 144, 45],
                [80, 143, 44],
                [78, 142, 44],
                [77, 141, 43],
                [76, 140, 42],
                [75, 139, 42],
                [74, 137, 41],
                [72, 136, 40],
                [71, 135, 40],
                [70, 134, 39],
                [69, 133, 38],
                [68, 132, 38],
                [66, 131, 37],
                [65, 129, 36],
                [64, 128, 36],
                [63, 127, 35],
                [62, 126, 35],
                [61, 124, 34],
                [59, 123, 33],
                [58, 122, 33],
                [57, 121, 32],
                [56, 120, 32],
                [55, 118, 31],
                [54, 117, 30],
                [53, 116, 30],
                [51, 114, 29],
                [50, 113, 29],
                [49, 112, 28],
                [48, 110, 27],
                [47, 109, 27],
                [46, 108, 26],
                [45, 106, 26],
                [44, 105, 25],
                [43, 104, 25],
                [41, 102, 24],
                [40, 101, 24],
                [39, 100, 23],
                [38, 98, 23],
                [37, 97, 22],
                [36, 95, 22],
                [35, 94, 21],
                [34, 92, 20],
                [33, 91, 20],
                [32, 90, 19],
                [31, 88, 19],
                [30, 87, 18],
                [29, 85, 18],
                [28, 84, 17],
                [27, 82, 17],
                [26, 80, 17],
                [25, 79, 16],
                [24, 77, 16],
                [23, 76, 15],
                [22, 74, 15],
                [21, 73, 14],
                [20, 71, 14],
                [20, 69, 13],
                [19, 68, 13],
                [18, 66, 12],
                [17, 64, 12],
                [16, 63, 11],
                [15, 61, 11],
                [14, 59, 11],
                [14, 57, 10],
                [13, 56, 10],
                [12, 54, 9],
                [11, 52, 9],
                [10, 50, 8],
                [10, 48, 8],
                [9, 46, 8],
                [8, 44, 7],
                [8, 43, 7],
                [7, 41, 6],
                [6, 39, 6],
                [6, 37, 6],
                [5, 35, 5],
                [5, 33, 5],
                [4, 30, 5],
                [3, 28, 4],
                [3, 26, 4],
                [2, 24, 3],
                [2, 22, 3],
                [2, 20, 3],
                [1, 17, 2],
                [1, 15, 2],
                [1, 13, 2],
                [0, 10, 1],
                [0, 8, 1],
                [0, 5, 1],
                [0, 3, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Mint",
            [
                [255, 255, 255],
                [252, 255, 255],
                [250, 254, 255],
                [247, 254, 255],
                [245, 254, 255],
                [242, 253, 254],
                [240, 253, 254],
                [238, 253, 254],
                [235, 252, 253],
                [233, 252, 253],
                [231, 252, 253],
                [229, 251, 252],
                [227, 251, 252],
                [225, 250, 251],
                [222, 250, 250],
                [220, 250, 250],
                [218, 249, 249],
                [216, 249, 249],
                [214, 249, 248],
                [212, 248, 247],
                [211, 248, 247],
                [209, 247, 246],
                [207, 247, 245],
                [205, 247, 245],
                [203, 246, 244],
                [201, 246, 243],
                [199, 245, 242],
                [198, 245, 241],
                [196, 244, 241],
                [194, 244, 240],
                [192, 244, 239],
                [191, 243, 238],
                [189, 243, 237],
                [187, 242, 236],
                [186, 242, 235],
                [184, 241, 235],
                [182, 241, 234],
                [181, 240, 233],
                [179, 240, 232],
                [178, 239, 231],
                [176, 239, 230],
                [175, 238, 229],
                [173, 238, 228],
                [171, 238, 227],
                [170, 237, 226],
                [168, 237, 225],
                [167, 236, 224],
                [165, 236, 223],
                [164, 235, 222],
                [163, 235, 221],
                [161, 234, 220],
                [160, 233, 219],
                [158, 233, 218],
                [157, 232, 217],
                [155, 232, 216],
                [154, 231, 215],
                [153, 231, 214],
                [151, 230, 212],
                [150, 230, 211],
                [149, 229, 210],
                [147, 229, 209],
                [146, 228, 208],
                [145, 228, 207],
                [143, 227, 206],
                [142, 226, 205],
                [141, 226, 204],
                [139, 225, 202],
                [138, 225, 201],
                [137, 224, 200],
                [135, 223, 199],
                [134, 223, 198],
                [133, 222, 197],
                [132, 222, 196],
                [131, 221, 194],
                [129, 220, 193],
                [128, 220, 192],
                [127, 219, 191],
                [126, 219, 190],
                [124, 218, 189],
                [123, 217, 187],
                [122, 217, 186],
                [121, 216, 185],
                [120, 215, 184],
                [119, 215, 183],
                [118, 214, 181],
                [116, 213, 180],
                [115, 213, 179],
                [114, 212, 178],
                [113, 211, 177],
                [112, 211, 175],
                [111, 210, 174],
                [110, 209, 173],
                [109, 209, 172],
                [108, 208, 171],
                [106, 207, 169],
                [105, 207, 168],
                [104, 206, 167],
                [103, 205, 166],
                [102, 204, 164],
                [101, 204, 163],
                [100, 203, 162],
                [99, 202, 161],
                [98, 201, 159],
                [97, 201, 158],
                [96, 200, 157],
                [95, 199, 156],
                [94, 198, 154],
                [93, 198, 153],
                [92, 197, 152],
                [91, 196, 151],
                [90, 195, 149],
                [89, 195, 148],
                [88, 194, 147],
                [87, 193, 146],
                [86, 192, 144],
                [85, 191, 143],
                [84, 191, 142],
                [84, 190, 141],
                [83, 189, 139],
                [82, 188, 138],
                [81, 187, 137],
                [80, 186, 136],
                [79, 186, 134],
                [78, 185, 133],
                [77, 184, 132],
                [76, 183, 131],
                [75, 182, 129],
                [75, 181, 128],
                [74, 180, 127],
                [73, 180, 126],
                [72, 179, 124],
                [71, 178, 123],
                [70, 177, 122],
                [69, 176, 121],
                [69, 175, 119],
                [68, 174, 118],
                [67, 173, 117],
                [66, 172, 116],
                [65, 171, 114],
                [64, 171, 113],
                [64, 170, 112],
                [63, 169, 111],
                [62, 168, 109],
                [61, 167, 108],
                [60, 166, 107],
                [60, 165, 106],
                [59, 164, 104],
                [58, 163, 103],
                [57, 162, 102],
                [57, 161, 101],
                [56, 160, 99],
                [55, 159, 98],
                [54, 158, 97],
                [54, 157, 96],
                [53, 156, 94],
                [52, 155, 93],
                [51, 154, 92],
                [51, 153, 91],
                [50, 152, 89],
                [49, 151, 88],
                [48, 150, 87],
                [48, 149, 86],
                [47, 147, 84],
                [46, 146, 83],
                [46, 145, 82],
                [45, 144, 81],
                [44, 143, 80],
                [44, 142, 78],
                [43, 141, 77],
                [42, 140, 76],
                [42, 139, 75],
                [41, 137, 74],
                [40, 136, 72],
                [40, 135, 71],
                [39, 134, 70],
                [38, 133, 69],
                [38, 132, 68],
                [37, 131, 66],
                [36, 129, 65],
                [36, 128, 64],
                [35, 127, 63],
                [35, 126, 62],
                [34, 124, 61],
                [33, 123, 59],
                [33, 122, 58],
                [32, 121, 57],
                [32, 120, 56],
                [31, 118, 55],
                [30, 117, 54],
                [30, 116, 53],
                [29, 114, 51],
                [29, 113, 50],
                [28, 112, 49],
                [27, 110, 48],
                [27, 109, 47],
                [26, 108, 46],
                [26, 106, 45],
                [25, 105, 44],
                [25, 104, 43],
                [24, 102, 41],
                [24, 101, 40],
                [23, 100, 39],
                [23, 98, 38],
                [22, 97, 37],
                [22, 95, 36],
                [21, 94, 35],
                [20, 92, 34],
                [20, 91, 33],
                [19, 90, 32],
                [19, 88, 31],
                [18, 87, 30],
                [18, 85, 29],
                [17, 84, 28],
                [17, 82, 27],
                [17, 80, 26],
                [16, 79, 25],
                [16, 77, 24],
                [15, 76, 23],
                [15, 74, 22],
                [14, 73, 21],
                [14, 71, 20],
                [13, 69, 20],
                [13, 68, 19],
                [12, 66, 18],
                [12, 64, 17],
                [11, 63, 16],
                [11, 61, 15],
                [11, 59, 14],
                [10, 57, 14],
                [10, 56, 13],
                [9, 54, 12],
                [9, 52, 11],
                [8, 50, 10],
                [8, 48, 10],
                [8, 46, 9],
                [7, 44, 8],
                [7, 43, 8],
                [6, 41, 7],
                [6, 39, 6],
                [6, 37, 6],
                [5, 35, 5],
                [5, 33, 5],
                [5, 30, 4],
                [4, 28, 3],
                [4, 26, 3],
                [3, 24, 2],
                [3, 22, 2],
                [3, 20, 2],
                [2, 17, 1],
                [2, 15, 1],
                [2, 13, 1],
                [1, 10, 0],
                [1, 8, 0],
                [1, 5, 0],
                [0, 3, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Purple",
            [
                [255, 255, 255],
                [255, 252, 255],
                [255, 250, 254],
                [255, 247, 254],
                [255, 245, 254],
                [254, 242, 253],
                [254, 240, 253],
                [254, 238, 253],
                [253, 235, 252],
                [253, 233, 252],
                [253, 231, 252],
                [252, 229, 251],
                [252, 227, 251],
                [251, 225, 250],
                [250, 222, 250],
                [250, 220, 250],
                [249, 218, 249],
                [249, 216, 249],
                [248, 214, 249],
                [247, 212, 248],
                [247, 211, 248],
                [246, 209, 247],
                [245, 207, 247],
                [245, 205, 247],
                [244, 203, 246],
                [243, 201, 246],
                [242, 199, 245],
                [241, 198, 245],
                [241, 196, 244],
                [240, 194, 244],
                [239, 192, 244],
                [238, 191, 243],
                [237, 189, 243],
                [236, 187, 242],
                [235, 186, 242],
                [235, 184, 241],
                [234, 182, 241],
                [233, 181, 240],
                [232, 179, 240],
                [231, 178, 239],
                [230, 176, 239],
                [229, 175, 238],
                [228, 173, 238],
                [227, 171, 238],
                [226, 170, 237],
                [225, 168, 237],
                [224, 167, 236],
                [223, 165, 236],
                [222, 164, 235],
                [221, 163, 235],
                [220, 161, 234],
                [219, 160, 233],
                [218, 158, 233],
                [217, 157, 232],
                [216, 155, 232],
                [215, 154, 231],
                [214, 153, 231],
                [212, 151, 230],
                [211, 150, 230],
                [210, 149, 229],
                [209, 147, 229],
                [208, 146, 228],
                [207, 145, 228],
                [206, 143, 227],
                [205, 142, 226],
                [204, 141, 226],
                [202, 139, 225],
                [201, 138, 225],
                [200, 137, 224],
                [199, 135, 223],
                [198, 134, 223],
                [197, 133, 222],
                [196, 132, 222],
                [194, 131, 221],
                [193, 129, 220],
                [192, 128, 220],
                [191, 127, 219],
                [190, 126, 219],
                [189, 124, 218],
                [187, 123, 217],
                [186, 122, 217],
                [185, 121, 216],
                [184, 120, 215],
                [183, 119, 215],
                [181, 118, 214],
                [180, 116, 213],
                [179, 115, 213],
                [178, 114, 212],
                [177, 113, 211],
                [175, 112, 211],
                [174, 111, 210],
                [173, 110, 209],
                [172, 109, 209],
                [171, 108, 208],
                [169, 106, 207],
                [168, 105, 207],
                [167, 104, 206],
                [166, 103, 205],
                [164, 102, 204],
                [163, 101, 204],
                [162, 100, 203],
                [161, 99, 202],
                [159, 98, 201],
                [158, 97, 201],
                [157, 96, 200],
                [156, 95, 199],
                [154, 94, 198],
                [153, 93, 198],
                [152, 92, 197],
                [151, 91, 196],
                [149, 90, 195],
                [148, 89, 195],
                [147, 88, 194],
                [146, 87, 193],
                [144, 86, 192],
                [143, 85, 191],
                [142, 84, 191],
                [141, 84, 190],
                [139, 83, 189],
                [138, 82, 188],
                [137, 81, 187],
                [136, 80, 186],
                [134, 79, 186],
                [133, 78, 185],
                [132, 77, 184],
                [131, 76, 183],
                [129, 75, 182],
                [128, 75, 181],
                [127, 74, 180],
                [126, 73, 180],
                [124, 72, 179],
                [123, 71, 178],
                [122, 70, 177],
                [121, 69, 176],
                [119, 69, 175],
                [118, 68, 174],
                [117, 67, 173],
                [116, 66, 172],
                [114, 65, 171],
                [113, 64, 171],
                [112, 64, 170],
                [111, 63, 169],
                [109, 62, 168],
                [108, 61, 167],
                [107, 60, 166],
                [106, 60, 165],
                [104, 59, 164],
                [103, 58, 163],
                [102, 57, 162],
                [101, 57, 161],
                [99, 56, 160],
                [98, 55, 159],
                [97, 54, 158],
                [96, 54, 157],
                [94, 53, 156],
                [93, 52, 155],
                [92, 51, 154],
                [91, 51, 153],
                [89, 50, 152],
                [88, 49, 151],
                [87, 48, 150],
                [86, 48, 149],
                [84, 47, 147],
                [83, 46, 146],
                [82, 46, 145],
                [81, 45, 144],
                [80, 44, 143],
                [78, 44, 142],
                [77, 43, 141],
                [76, 42, 140],
                [75, 42, 139],
                [74, 41, 137],
                [72, 40, 136],
                [71, 40, 135],
                [70, 39, 134],
                [69, 38, 133],
                [68, 38, 132],
                [66, 37, 131],
                [65, 36, 129],
                [64, 36, 128],
                [63, 35, 127],
                [62, 35, 126],
                [61, 34, 124],
                [59, 33, 123],
                [58, 33, 122],
                [57, 32, 121],
                [56, 32, 120],
                [55, 31, 118],
                [54, 30, 117],
                [53, 30, 116],
                [51, 29, 114],
                [50, 29, 113],
                [49, 28, 112],
                [48, 27, 110],
                [47, 27, 109],
                [46, 26, 108],
                [45, 26, 106],
                [44, 25, 105],
                [43, 25, 104],
                [41, 24, 102],
                [40, 24, 101],
                [39, 23, 100],
                [38, 23, 98],
                [37, 22, 97],
                [36, 22, 95],
                [35, 21, 94],
                [34, 20, 92],
                [33, 20, 91],
                [32, 19, 90],
                [31, 19, 88],
                [30, 18, 87],
                [29, 18, 85],
                [28, 17, 84],
                [27, 17, 82],
                [26, 17, 80],
                [25, 16, 79],
                [24, 16, 77],
                [23, 15, 76],
                [22, 15, 74],
                [21, 14, 73],
                [20, 14, 71],
                [20, 13, 69],
                [19, 13, 68],
                [18, 12, 66],
                [17, 12, 64],
                [16, 11, 63],
                [15, 11, 61],
                [14, 11, 59],
                [14, 10, 57],
                [13, 10, 56],
                [12, 9, 54],
                [11, 9, 52],
                [10, 8, 50],
                [10, 8, 48],
                [9, 8, 46],
                [8, 7, 44],
                [8, 7, 43],
                [7, 6, 41],
                [6, 6, 39],
                [6, 6, 37],
                [5, 5, 35],
                [5, 5, 33],
                [4, 5, 30],
                [3, 4, 28],
                [3, 4, 26],
                [2, 3, 24],
                [2, 3, 22],
                [2, 3, 20],
                [1, 2, 17],
                [1, 2, 15],
                [1, 2, 13],
                [0, 1, 10],
                [0, 1, 8],
                [0, 1, 5],
                [0, 0, 3],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Ink Yellow",
            [
                [255, 255, 255],
                [255, 255, 252],
                [254, 255, 250],
                [254, 255, 247],
                [254, 255, 245],
                [253, 254, 242],
                [253, 254, 240],
                [253, 254, 238],
                [252, 253, 235],
                [252, 253, 233],
                [252, 253, 231],
                [251, 252, 229],
                [251, 252, 227],
                [250, 251, 225],
                [250, 250, 222],
                [250, 250, 220],
                [249, 249, 218],
                [249, 249, 216],
                [249, 248, 214],
                [248, 247, 212],
                [248, 247, 211],
                [247, 246, 209],
                [247, 245, 207],
                [247, 245, 205],
                [246, 244, 203],
                [246, 243, 201],
                [245, 242, 199],
                [245, 241, 198],
                [244, 241, 196],
                [244, 240, 194],
                [244, 239, 192],
                [243, 238, 191],
                [243, 237, 189],
                [242, 236, 187],
                [242, 235, 186],
                [241, 235, 184],
                [241, 234, 182],
                [240, 233, 181],
                [240, 232, 179],
                [239, 231, 178],
                [239, 230, 176],
                [238, 229, 175],
                [238, 228, 173],
                [238, 227, 171],
                [237, 226, 170],
                [237, 225, 168],
                [236, 224, 167],
                [236, 223, 165],
                [235, 222, 164],
                [235, 221, 163],
                [234, 220, 161],
                [233, 219, 160],
                [233, 218, 158],
                [232, 217, 157],
                [232, 216, 155],
                [231, 215, 154],
                [231, 214, 153],
                [230, 212, 151],
                [230, 211, 150],
                [229, 210, 149],
                [229, 209, 147],
                [228, 208, 146],
                [228, 207, 145],
                [227, 206, 143],
                [226, 205, 142],
                [226, 204, 141],
                [225, 202, 139],
                [225, 201, 138],
                [224, 200, 137],
                [223, 199, 135],
                [223, 198, 134],
                [222, 197, 133],
                [222, 196, 132],
                [221, 194, 131],
                [220, 193, 129],
                [220, 192, 128],
                [219, 191, 127],
                [219, 190, 126],
                [218, 189, 124],
                [217, 187, 123],
                [217, 186, 122],
                [216, 185, 121],
                [215, 184, 120],
                [215, 183, 119],
                [214, 181, 118],
                [213, 180, 116],
                [213, 179, 115],
                [212, 178, 114],
                [211, 177, 113],
                [211, 175, 112],
                [210, 174, 111],
                [209, 173, 110],
                [209, 172, 109],
                [208, 171, 108],
                [207, 169, 106],
                [207, 168, 105],
                [206, 167, 104],
                [205, 166, 103],
                [204, 164, 102],
                [204, 163, 101],
                [203, 162, 100],
                [202, 161, 99],
                [201, 159, 98],
                [201, 158, 97],
                [200, 157, 96],
                [199, 156, 95],
                [198, 154, 94],
                [198, 153, 93],
                [197, 152, 92],
                [196, 151, 91],
                [195, 149, 90],
                [195, 148, 89],
                [194, 147, 88],
                [193, 146, 87],
                [192, 144, 86],
                [191, 143, 85],
                [191, 142, 84],
                [190, 141, 84],
                [189, 139, 83],
                [188, 138, 82],
                [187, 137, 81],
                [186, 136, 80],
                [186, 134, 79],
                [185, 133, 78],
                [184, 132, 77],
                [183, 131, 76],
                [182, 129, 75],
                [181, 128, 75],
                [180, 127, 74],
                [180, 126, 73],
                [179, 124, 72],
                [178, 123, 71],
                [177, 122, 70],
                [176, 121, 69],
                [175, 119, 69],
                [174, 118, 68],
                [173, 117, 67],
                [172, 116, 66],
                [171, 114, 65],
                [171, 113, 64],
                [170, 112, 64],
                [169, 111, 63],
                [168, 109, 62],
                [167, 108, 61],
                [166, 107, 60],
                [165, 106, 60],
                [164, 104, 59],
                [163, 103, 58],
                [162, 102, 57],
                [161, 101, 57],
                [160, 99, 56],
                [159, 98, 55],
                [158, 97, 54],
                [157, 96, 54],
                [156, 94, 53],
                [155, 93, 52],
                [154, 92, 51],
                [153, 91, 51],
                [152, 89, 50],
                [151, 88, 49],
                [150, 87, 48],
                [149, 86, 48],
                [147, 84, 47],
                [146, 83, 46],
                [145, 82, 46],
                [144, 81, 45],
                [143, 80, 44],
                [142, 78, 44],
                [141, 77, 43],
                [140, 76, 42],
                [139, 75, 42],
                [137, 74, 41],
                [136, 72, 40],
                [135, 71, 40],
                [134, 70, 39],
                [133, 69, 38],
                [132, 68, 38],
                [131, 66, 37],
                [129, 65, 36],
                [128, 64, 36],
                [127, 63, 35],
                [126, 62, 35],
                [124, 61, 34],
                [123, 59, 33],
                [122, 58, 33],
                [121, 57, 32],
                [120, 56, 32],
                [118, 55, 31],
                [117, 54, 30],
                [116, 53, 30],
                [114, 51, 29],
                [113, 50, 29],
                [112, 49, 28],
                [110, 48, 27],
                [109, 47, 27],
                [108, 46, 26],
                [106, 45, 26],
                [105, 44, 25],
                [104, 43, 25],
                [102, 41, 24],
                [101, 40, 24],
                [100, 39, 23],
                [98, 38, 23],
                [97, 37, 22],
                [95, 36, 22],
                [94, 35, 21],
                [92, 34, 20],
                [91, 33, 20],
                [90, 32, 19],
                [88, 31, 19],
                [87, 30, 18],
                [85, 29, 18],
                [84, 28, 17],
                [82, 27, 17],
                [80, 26, 17],
                [79, 25, 16],
                [77, 24, 16],
                [76, 23, 15],
                [74, 22, 15],
                [73, 21, 14],
                [71, 20, 14],
                [69, 20, 13],
                [68, 19, 13],
                [66, 18, 12],
                [64, 17, 12],
                [63, 16, 11],
                [61, 15, 11],
                [59, 14, 11],
                [57, 14, 10],
                [56, 13, 10],
                [54, 12, 9],
                [52, 11, 9],
                [50, 10, 8],
                [48, 10, 8],
                [46, 9, 8],
                [44, 8, 7],
                [43, 8, 7],
                [41, 7, 6],
                [39, 6, 6],
                [37, 6, 6],
                [35, 5, 5],
                [33, 5, 5],
                [30, 4, 5],
                [28, 3, 4],
                [26, 3, 4],
                [24, 2, 3],
                [22, 2, 3],
                [20, 2, 3],
                [17, 1, 2],
                [15, 1, 2],
                [13, 1, 2],
                [10, 0, 1],
                [8, 0, 1],
                [5, 0, 1],
                [3, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Circus Mint",
            [
                [0, 0, 0],
                [0, 3, 0],
                [1, 5, 0],
                [1, 8, 0],
                [1, 10, 0],
                [2, 13, 1],
                [2, 15, 1],
                [2, 17, 1],
                [3, 20, 2],
                [3, 22, 2],
                [3, 24, 2],
                [4, 26, 3],
                [4, 28, 3],
                [5, 30, 4],
                [5, 33, 5],
                [5, 35, 5],
                [6, 37, 6],
                [6, 39, 6],
                [6, 41, 7],
                [7, 43, 8],
                [7, 44, 8],
                [8, 46, 9],
                [8, 48, 10],
                [8, 50, 10],
                [9, 52, 11],
                [9, 54, 12],
                [10, 56, 13],
                [10, 57, 14],
                [11, 59, 14],
                [11, 61, 15],
                [11, 63, 16],
                [12, 64, 17],
                [12, 66, 18],
                [13, 68, 19],
                [13, 69, 20],
                [14, 71, 20],
                [14, 73, 21],
                [15, 74, 22],
                [15, 76, 23],
                [16, 77, 24],
                [16, 79, 25],
                [17, 80, 26],
                [17, 82, 27],
                [17, 84, 28],
                [18, 85, 29],
                [18, 87, 30],
                [19, 88, 31],
                [19, 90, 32],
                [20, 91, 33],
                [20, 92, 34],
                [21, 94, 35],
                [22, 95, 36],
                [22, 97, 37],
                [23, 98, 38],
                [23, 100, 39],
                [24, 101, 40],
                [24, 102, 41],
                [25, 104, 43],
                [25, 105, 44],
                [26, 106, 45],
                [26, 108, 46],
                [27, 109, 47],
                [27, 110, 48],
                [28, 112, 49],
                [29, 113, 50],
                [29, 114, 51],
                [30, 116, 53],
                [30, 117, 54],
                [31, 118, 55],
                [32, 120, 56],
                [32, 121, 57],
                [33, 122, 58],
                [33, 123, 59],
                [34, 124, 61],
                [35, 126, 62],
                [35, 127, 63],
                [36, 128, 64],
                [36, 129, 65],
                [37, 131, 66],
                [38, 132, 68],
                [38, 133, 69],
                [39, 134, 70],
                [40, 135, 71],
                [40, 136, 72],
                [41, 137, 74],
                [42, 139, 75],
                [42, 140, 76],
                [43, 141, 77],
                [44, 142, 78],
                [44, 143, 80],
                [45, 144, 81],
                [46, 145, 82],
                [46, 146, 83],
                [47, 147, 84],
                [48, 149, 86],
                [48, 150, 87],
                [49, 151, 88],
                [50, 152, 89],
                [51, 153, 91],
                [51, 154, 92],
                [52, 155, 93],
                [53, 156, 94],
                [54, 157, 96],
                [54, 158, 97],
                [55, 159, 98],
                [56, 160, 99],
                [57, 161, 101],
                [57, 162, 102],
                [58, 163, 103],
                [59, 164, 104],
                [60, 165, 106],
                [60, 166, 107],
                [61, 167, 108],
                [62, 168, 109],
                [63, 169, 111],
                [64, 170, 112],
                [64, 171, 113],
                [65, 171, 114],
                [66, 172, 116],
                [67, 173, 117],
                [68, 174, 118],
                [69, 175, 119],
                [69, 176, 121],
                [70, 177, 122],
                [71, 178, 123],
                [72, 179, 124],
                [73, 180, 126],
                [74, 180, 127],
                [75, 181, 128],
                [75, 182, 129],
                [76, 183, 131],
                [77, 184, 132],
                [78, 185, 133],
                [79, 186, 134],
                [80, 186, 136],
                [81, 187, 137],
                [82, 188, 138],
                [83, 189, 139],
                [84, 190, 141],
                [84, 191, 142],
                [85, 191, 143],
                [86, 192, 144],
                [87, 193, 146],
                [88, 194, 147],
                [89, 195, 148],
                [90, 195, 149],
                [91, 196, 151],
                [92, 197, 152],
                [93, 198, 153],
                [94, 198, 154],
                [95, 199, 156],
                [96, 200, 157],
                [97, 201, 158],
                [98, 201, 159],
                [99, 202, 161],
                [100, 203, 162],
                [101, 204, 163],
                [102, 204, 164],
                [103, 205, 166],
                [104, 206, 167],
                [105, 207, 168],
                [106, 207, 169],
                [108, 208, 171],
                [109, 209, 172],
                [110, 209, 173],
                [111, 210, 174],
                [112, 211, 175],
                [113, 211, 177],
                [114, 212, 178],
                [115, 213, 179],
                [116, 213, 180],
                [118, 214, 181],
                [119, 215, 183],
                [120, 215, 184],
                [121, 216, 185],
                [122, 217, 186],
                [123, 217, 187],
                [124, 218, 189],
                [126, 219, 190],
                [127, 219, 191],
                [128, 220, 192],
                [129, 220, 193],
                [131, 221, 194],
                [132, 222, 196],
                [133, 222, 197],
                [134, 223, 198],
                [135, 223, 199],
                [137, 224, 200],
                [138, 225, 201],
                [139, 225, 202],
                [141, 226, 204],
                [142, 226, 205],
                [143, 227, 206],
                [145, 228, 207],
                [146, 228, 208],
                [147, 229, 209],
                [149, 229, 210],
                [150, 230, 211],
                [151, 230, 212],
                [153, 231, 214],
                [154, 231, 215],
                [155, 232, 216],
                [157, 232, 217],
                [158, 233, 218],
                [160, 233, 219],
                [161, 234, 220],
                [163, 235, 221],
                [164, 235, 222],
                [165, 236, 223],
                [167, 236, 224],
                [168, 237, 225],
                [170, 237, 226],
                [171, 238, 227],
                [173, 238, 228],
                [175, 238, 229],
                [176, 239, 230],
                [178, 239, 231],
                [179, 240, 232],
                [181, 240, 233],
                [182, 241, 234],
                [184, 241, 235],
                [186, 242, 235],
                [187, 242, 236],
                [189, 243, 237],
                [191, 243, 238],
                [192, 244, 239],
                [194, 244, 240],
                [196, 244, 241],
                [198, 245, 241],
                [199, 245, 242],
                [201, 246, 243],
                [203, 246, 244],
                [205, 247, 245],
                [207, 247, 245],
                [209, 247, 246],
                [211, 248, 247],
                [212, 248, 247],
                [214, 249, 248],
                [216, 249, 249],
                [218, 249, 249],
                [220, 250, 250],
                [222, 250, 250],
                [225, 250, 251],
                [227, 251, 252],
                [229, 251, 252],
                [231, 252, 253],
                [233, 252, 253],
                [235, 252, 253],
                [238, 253, 254],
                [240, 253, 254],
                [242, 253, 254],
                [245, 254, 255],
                [247, 254, 255],
                [250, 254, 255],
                [252, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Circus Purple",
            [
                [0, 0, 0],
                [0, 0, 3],
                [0, 1, 5],
                [0, 1, 8],
                [0, 1, 10],
                [1, 2, 13],
                [1, 2, 15],
                [1, 2, 17],
                [2, 3, 20],
                [2, 3, 22],
                [2, 3, 24],
                [3, 4, 26],
                [3, 4, 28],
                [4, 5, 30],
                [5, 5, 33],
                [5, 5, 35],
                [6, 6, 37],
                [6, 6, 39],
                [7, 6, 41],
                [8, 7, 43],
                [8, 7, 44],
                [9, 8, 46],
                [10, 8, 48],
                [10, 8, 50],
                [11, 9, 52],
                [12, 9, 54],
                [13, 10, 56],
                [14, 10, 57],
                [14, 11, 59],
                [15, 11, 61],
                [16, 11, 63],
                [17, 12, 64],
                [18, 12, 66],
                [19, 13, 68],
                [20, 13, 69],
                [20, 14, 71],
                [21, 14, 73],
                [22, 15, 74],
                [23, 15, 76],
                [24, 16, 77],
                [25, 16, 79],
                [26, 17, 80],
                [27, 17, 82],
                [28, 17, 84],
                [29, 18, 85],
                [30, 18, 87],
                [31, 19, 88],
                [32, 19, 90],
                [33, 20, 91],
                [34, 20, 92],
                [35, 21, 94],
                [36, 22, 95],
                [37, 22, 97],
                [38, 23, 98],
                [39, 23, 100],
                [40, 24, 101],
                [41, 24, 102],
                [43, 25, 104],
                [44, 25, 105],
                [45, 26, 106],
                [46, 26, 108],
                [47, 27, 109],
                [48, 27, 110],
                [49, 28, 112],
                [50, 29, 113],
                [51, 29, 114],
                [53, 30, 116],
                [54, 30, 117],
                [55, 31, 118],
                [56, 32, 120],
                [57, 32, 121],
                [58, 33, 122],
                [59, 33, 123],
                [61, 34, 124],
                [62, 35, 126],
                [63, 35, 127],
                [64, 36, 128],
                [65, 36, 129],
                [66, 37, 131],
                [68, 38, 132],
                [69, 38, 133],
                [70, 39, 134],
                [71, 40, 135],
                [72, 40, 136],
                [74, 41, 137],
                [75, 42, 139],
                [76, 42, 140],
                [77, 43, 141],
                [78, 44, 142],
                [80, 44, 143],
                [81, 45, 144],
                [82, 46, 145],
                [83, 46, 146],
                [84, 47, 147],
                [86, 48, 149],
                [87, 48, 150],
                [88, 49, 151],
                [89, 50, 152],
                [91, 51, 153],
                [92, 51, 154],
                [93, 52, 155],
                [94, 53, 156],
                [96, 54, 157],
                [97, 54, 158],
                [98, 55, 159],
                [99, 56, 160],
                [101, 57, 161],
                [102, 57, 162],
                [103, 58, 163],
                [104, 59, 164],
                [106, 60, 165],
                [107, 60, 166],
                [108, 61, 167],
                [109, 62, 168],
                [111, 63, 169],
                [112, 64, 170],
                [113, 64, 171],
                [114, 65, 171],
                [116, 66, 172],
                [117, 67, 173],
                [118, 68, 174],
                [119, 69, 175],
                [121, 69, 176],
                [122, 70, 177],
                [123, 71, 178],
                [124, 72, 179],
                [126, 73, 180],
                [127, 74, 180],
                [128, 75, 181],
                [129, 75, 182],
                [131, 76, 183],
                [132, 77, 184],
                [133, 78, 185],
                [134, 79, 186],
                [136, 80, 186],
                [137, 81, 187],
                [138, 82, 188],
                [139, 83, 189],
                [141, 84, 190],
                [142, 84, 191],
                [143, 85, 191],
                [144, 86, 192],
                [146, 87, 193],
                [147, 88, 194],
                [148, 89, 195],
                [149, 90, 195],
                [151, 91, 196],
                [152, 92, 197],
                [153, 93, 198],
                [154, 94, 198],
                [156, 95, 199],
                [157, 96, 200],
                [158, 97, 201],
                [159, 98, 201],
                [161, 99, 202],
                [162, 100, 203],
                [163, 101, 204],
                [164, 102, 204],
                [166, 103, 205],
                [167, 104, 206],
                [168, 105, 207],
                [169, 106, 207],
                [171, 108, 208],
                [172, 109, 209],
                [173, 110, 209],
                [174, 111, 210],
                [175, 112, 211],
                [177, 113, 211],
                [178, 114, 212],
                [179, 115, 213],
                [180, 116, 213],
                [181, 118, 214],
                [183, 119, 215],
                [184, 120, 215],
                [185, 121, 216],
                [186, 122, 217],
                [187, 123, 217],
                [189, 124, 218],
                [190, 126, 219],
                [191, 127, 219],
                [192, 128, 220],
                [193, 129, 220],
                [194, 131, 221],
                [196, 132, 222],
                [197, 133, 222],
                [198, 134, 223],
                [199, 135, 223],
                [200, 137, 224],
                [201, 138, 225],
                [202, 139, 225],
                [204, 141, 226],
                [205, 142, 226],
                [206, 143, 227],
                [207, 145, 228],
                [208, 146, 228],
                [209, 147, 229],
                [210, 149, 229],
                [211, 150, 230],
                [212, 151, 230],
                [214, 153, 231],
                [215, 154, 231],
                [216, 155, 232],
                [217, 157, 232],
                [218, 158, 233],
                [219, 160, 233],
                [220, 161, 234],
                [221, 163, 235],
                [222, 164, 235],
                [223, 165, 236],
                [224, 167, 236],
                [225, 168, 237],
                [226, 170, 237],
                [227, 171, 238],
                [228, 173, 238],
                [229, 175, 238],
                [230, 176, 239],
                [231, 178, 239],
                [232, 179, 240],
                [233, 181, 240],
                [234, 182, 241],
                [235, 184, 241],
                [235, 186, 242],
                [236, 187, 242],
                [237, 189, 243],
                [238, 191, 243],
                [239, 192, 244],
                [240, 194, 244],
                [241, 196, 244],
                [241, 198, 245],
                [242, 199, 245],
                [243, 201, 246],
                [244, 203, 246],
                [245, 205, 247],
                [245, 207, 247],
                [246, 209, 247],
                [247, 211, 248],
                [247, 212, 248],
                [248, 214, 249],
                [249, 216, 249],
                [249, 218, 249],
                [250, 220, 250],
                [250, 222, 250],
                [251, 225, 250],
                [252, 227, 251],
                [252, 229, 251],
                [253, 231, 252],
                [253, 233, 252],
                [253, 235, 252],
                [254, 238, 253],
                [254, 240, 253],
                [254, 242, 253],
                [255, 245, 254],
                [255, 247, 254],
                [255, 250, 254],
                [255, 252, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Circus Yellow",
            [
                [0, 0, 0],
                [3, 0, 0],
                [5, 0, 1],
                [8, 0, 1],
                [10, 0, 1],
                [13, 1, 2],
                [15, 1, 2],
                [17, 1, 2],
                [20, 2, 3],
                [22, 2, 3],
                [24, 2, 3],
                [26, 3, 4],
                [28, 3, 4],
                [30, 4, 5],
                [33, 5, 5],
                [35, 5, 5],
                [37, 6, 6],
                [39, 6, 6],
                [41, 7, 6],
                [43, 8, 7],
                [44, 8, 7],
                [46, 9, 8],
                [48, 10, 8],
                [50, 10, 8],
                [52, 11, 9],
                [54, 12, 9],
                [56, 13, 10],
                [57, 14, 10],
                [59, 14, 11],
                [61, 15, 11],
                [63, 16, 11],
                [64, 17, 12],
                [66, 18, 12],
                [68, 19, 13],
                [69, 20, 13],
                [71, 20, 14],
                [73, 21, 14],
                [74, 22, 15],
                [76, 23, 15],
                [77, 24, 16],
                [79, 25, 16],
                [80, 26, 17],
                [82, 27, 17],
                [84, 28, 17],
                [85, 29, 18],
                [87, 30, 18],
                [88, 31, 19],
                [90, 32, 19],
                [91, 33, 20],
                [92, 34, 20],
                [94, 35, 21],
                [95, 36, 22],
                [97, 37, 22],
                [98, 38, 23],
                [100, 39, 23],
                [101, 40, 24],
                [102, 41, 24],
                [104, 43, 25],
                [105, 44, 25],
                [106, 45, 26],
                [108, 46, 26],
                [109, 47, 27],
                [110, 48, 27],
                [112, 49, 28],
                [113, 50, 29],
                [114, 51, 29],
                [116, 53, 30],
                [117, 54, 30],
                [118, 55, 31],
                [120, 56, 32],
                [121, 57, 32],
                [122, 58, 33],
                [123, 59, 33],
                [124, 61, 34],
                [126, 62, 35],
                [127, 63, 35],
                [128, 64, 36],
                [129, 65, 36],
                [131, 66, 37],
                [132, 68, 38],
                [133, 69, 38],
                [134, 70, 39],
                [135, 71, 40],
                [136, 72, 40],
                [137, 74, 41],
                [139, 75, 42],
                [140, 76, 42],
                [141, 77, 43],
                [142, 78, 44],
                [143, 80, 44],
                [144, 81, 45],
                [145, 82, 46],
                [146, 83, 46],
                [147, 84, 47],
                [149, 86, 48],
                [150, 87, 48],
                [151, 88, 49],
                [152, 89, 50],
                [153, 91, 51],
                [154, 92, 51],
                [155, 93, 52],
                [156, 94, 53],
                [157, 96, 54],
                [158, 97, 54],
                [159, 98, 55],
                [160, 99, 56],
                [161, 101, 57],
                [162, 102, 57],
                [163, 103, 58],
                [164, 104, 59],
                [165, 106, 60],
                [166, 107, 60],
                [167, 108, 61],
                [168, 109, 62],
                [169, 111, 63],
                [170, 112, 64],
                [171, 113, 64],
                [171, 114, 65],
                [172, 116, 66],
                [173, 117, 67],
                [174, 118, 68],
                [175, 119, 69],
                [176, 121, 69],
                [177, 122, 70],
                [178, 123, 71],
                [179, 124, 72],
                [180, 126, 73],
                [180, 127, 74],
                [181, 128, 75],
                [182, 129, 75],
                [183, 131, 76],
                [184, 132, 77],
                [185, 133, 78],
                [186, 134, 79],
                [186, 136, 80],
                [187, 137, 81],
                [188, 138, 82],
                [189, 139, 83],
                [190, 141, 84],
                [191, 142, 84],
                [191, 143, 85],
                [192, 144, 86],
                [193, 146, 87],
                [194, 147, 88],
                [195, 148, 89],
                [195, 149, 90],
                [196, 151, 91],
                [197, 152, 92],
                [198, 153, 93],
                [198, 154, 94],
                [199, 156, 95],
                [200, 157, 96],
                [201, 158, 97],
                [201, 159, 98],
                [202, 161, 99],
                [203, 162, 100],
                [204, 163, 101],
                [204, 164, 102],
                [205, 166, 103],
                [206, 167, 104],
                [207, 168, 105],
                [207, 169, 106],
                [208, 171, 108],
                [209, 172, 109],
                [209, 173, 110],
                [210, 174, 111],
                [211, 175, 112],
                [211, 177, 113],
                [212, 178, 114],
                [213, 179, 115],
                [213, 180, 116],
                [214, 181, 118],
                [215, 183, 119],
                [215, 184, 120],
                [216, 185, 121],
                [217, 186, 122],
                [217, 187, 123],
                [218, 189, 124],
                [219, 190, 126],
                [219, 191, 127],
                [220, 192, 128],
                [220, 193, 129],
                [221, 194, 131],
                [222, 196, 132],
                [222, 197, 133],
                [223, 198, 134],
                [223, 199, 135],
                [224, 200, 137],
                [225, 201, 138],
                [225, 202, 139],
                [226, 204, 141],
                [226, 205, 142],
                [227, 206, 143],
                [228, 207, 145],
                [228, 208, 146],
                [229, 209, 147],
                [229, 210, 149],
                [230, 211, 150],
                [230, 212, 151],
                [231, 214, 153],
                [231, 215, 154],
                [232, 216, 155],
                [232, 217, 157],
                [233, 218, 158],
                [233, 219, 160],
                [234, 220, 161],
                [235, 221, 163],
                [235, 222, 164],
                [236, 223, 165],
                [236, 224, 167],
                [237, 225, 168],
                [237, 226, 170],
                [238, 227, 171],
                [238, 228, 173],
                [238, 229, 175],
                [239, 230, 176],
                [239, 231, 178],
                [240, 232, 179],
                [240, 233, 181],
                [241, 234, 182],
                [241, 235, 184],
                [242, 235, 186],
                [242, 236, 187],
                [243, 237, 189],
                [243, 238, 191],
                [244, 239, 192],
                [244, 240, 194],
                [244, 241, 196],
                [245, 241, 198],
                [245, 242, 199],
                [246, 243, 201],
                [246, 244, 203],
                [247, 245, 205],
                [247, 245, 207],
                [247, 246, 209],
                [248, 247, 211],
                [248, 247, 212],
                [249, 248, 214],
                [249, 249, 216],
                [249, 249, 218],
                [250, 250, 220],
                [250, 250, 222],
                [250, 251, 225],
                [251, 252, 227],
                [251, 252, 229],
                [252, 253, 231],
                [252, 253, 233],
                [252, 253, 235],
                [253, 254, 238],
                [253, 254, 240],
                [253, 254, 242],
                [254, 255, 245],
                [254, 255, 247],
                [254, 255, 250],
                [255, 255, 252],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Cyan",
            [
                [0, 0, 0],
                [0, 1, 1],
                [0, 2, 2],
                [0, 3, 3],
                [0, 4, 4],
                [0, 5, 5],
                [0, 6, 6],
                [0, 7, 7],
                [0, 8, 8],
                [0, 9, 9],
                [0, 10, 10],
                [0, 11, 11],
                [0, 12, 12],
                [0, 13, 13],
                [0, 14, 14],
                [0, 15, 15],
                [0, 16, 16],
                [0, 17, 17],
                [0, 18, 18],
                [0, 19, 19],
                [0, 20, 20],
                [0, 21, 21],
                [0, 22, 22],
                [0, 23, 23],
                [0, 24, 24],
                [0, 25, 25],
                [0, 26, 26],
                [0, 27, 27],
                [0, 28, 28],
                [0, 29, 29],
                [0, 30, 30],
                [0, 31, 31],
                [0, 32, 32],
                [0, 33, 33],
                [0, 34, 34],
                [0, 35, 35],
                [0, 36, 36],
                [0, 37, 37],
                [0, 38, 38],
                [0, 39, 39],
                [0, 40, 40],
                [0, 41, 41],
                [0, 42, 42],
                [0, 43, 43],
                [0, 44, 44],
                [0, 45, 45],
                [0, 46, 46],
                [0, 47, 47],
                [0, 48, 48],
                [0, 49, 49],
                [0, 50, 50],
                [0, 51, 51],
                [0, 52, 52],
                [0, 53, 53],
                [0, 54, 54],
                [0, 55, 55],
                [0, 56, 56],
                [0, 57, 57],
                [0, 58, 58],
                [0, 59, 59],
                [0, 60, 60],
                [0, 61, 61],
                [0, 62, 62],
                [0, 63, 63],
                [0, 64, 64],
                [0, 65, 65],
                [0, 66, 66],
                [0, 67, 67],
                [0, 68, 68],
                [0, 69, 69],
                [0, 70, 70],
                [0, 71, 71],
                [0, 72, 72],
                [0, 73, 73],
                [0, 74, 74],
                [0, 75, 75],
                [0, 76, 76],
                [0, 77, 77],
                [0, 78, 78],
                [0, 79, 79],
                [0, 80, 80],
                [0, 81, 81],
                [0, 82, 82],
                [0, 83, 83],
                [0, 84, 84],
                [0, 85, 85],
                [0, 86, 86],
                [0, 87, 87],
                [0, 88, 88],
                [0, 89, 89],
                [0, 90, 90],
                [0, 91, 91],
                [0, 92, 92],
                [0, 93, 93],
                [0, 94, 94],
                [0, 95, 95],
                [0, 96, 96],
                [0, 97, 97],
                [0, 98, 98],
                [0, 99, 99],
                [0, 100, 100],
                [0, 101, 101],
                [0, 102, 102],
                [0, 103, 103],
                [0, 104, 104],
                [0, 105, 105],
                [0, 106, 106],
                [0, 107, 107],
                [0, 108, 108],
                [0, 109, 109],
                [0, 110, 110],
                [0, 111, 111],
                [0, 112, 112],
                [0, 113, 113],
                [0, 114, 114],
                [0, 115, 115],
                [0, 116, 116],
                [0, 117, 117],
                [0, 118, 118],
                [0, 119, 119],
                [0, 120, 120],
                [0, 121, 121],
                [0, 122, 122],
                [0, 123, 123],
                [0, 124, 124],
                [0, 125, 125],
                [0, 126, 126],
                [0, 127, 127],
                [0, 128, 128],
                [0, 129, 129],
                [0, 130, 130],
                [0, 131, 131],
                [0, 132, 132],
                [0, 133, 133],
                [0, 134, 134],
                [0, 135, 135],
                [0, 136, 136],
                [0, 137, 137],
                [0, 138, 138],
                [0, 139, 139],
                [0, 140, 140],
                [0, 141, 141],
                [0, 142, 142],
                [0, 143, 143],
                [0, 144, 144],
                [0, 145, 145],
                [0, 146, 146],
                [0, 147, 147],
                [0, 148, 148],
                [0, 149, 149],
                [0, 150, 150],
                [0, 151, 151],
                [0, 152, 152],
                [0, 153, 153],
                [0, 154, 154],
                [0, 155, 155],
                [0, 156, 156],
                [0, 157, 157],
                [0, 158, 158],
                [0, 159, 159],
                [0, 160, 160],
                [0, 161, 161],
                [0, 162, 162],
                [0, 163, 163],
                [0, 164, 164],
                [0, 165, 165],
                [0, 166, 166],
                [0, 167, 167],
                [0, 168, 168],
                [0, 169, 169],
                [0, 170, 170],
                [0, 171, 171],
                [0, 172, 172],
                [0, 173, 173],
                [0, 174, 174],
                [0, 175, 175],
                [0, 176, 176],
                [0, 177, 177],
                [0, 178, 178],
                [0, 179, 179],
                [0, 180, 180],
                [0, 181, 181],
                [0, 182, 182],
                [0, 183, 183],
                [0, 184, 184],
                [0, 185, 185],
                [0, 186, 186],
                [0, 187, 187],
                [0, 188, 188],
                [0, 189, 189],
                [0, 190, 190],
                [0, 191, 191],
                [0, 192, 192],
                [0, 193, 193],
                [0, 194, 194],
                [0, 195, 195],
                [0, 196, 196],
                [0, 197, 197],
                [0, 198, 198],
                [0, 199, 199],
                [0, 200, 200],
                [0, 201, 201],
                [0, 202, 202],
                [0, 203, 203],
                [0, 204, 204],
                [0, 205, 205],
                [0, 206, 206],
                [0, 207, 207],
                [0, 208, 208],
                [0, 209, 209],
                [0, 210, 210],
                [0, 211, 211],
                [0, 212, 212],
                [0, 213, 213],
                [0, 214, 214],
                [0, 215, 215],
                [0, 216, 216],
                [0, 217, 217],
                [0, 218, 218],
                [0, 219, 219],
                [0, 220, 220],
                [0, 221, 221],
                [0, 222, 222],
                [0, 223, 223],
                [0, 224, 224],
                [0, 225, 225],
                [0, 226, 226],
                [0, 227, 227],
                [0, 228, 228],
                [0, 229, 229],
                [0, 230, 230],
                [0, 231, 231],
                [0, 232, 232],
                [0, 233, 233],
                [0, 234, 234],
                [0, 235, 235],
                [0, 236, 236],
                [0, 237, 237],
                [0, 238, 238],
                [0, 239, 239],
                [0, 240, 240],
                [0, 241, 241],
                [0, 242, 242],
                [0, 243, 243],
                [0, 244, 244],
                [0, 245, 245],
                [0, 246, 246],
                [0, 247, 247],
                [0, 248, 248],
                [0, 249, 249],
                [0, 250, 250],
                [0, 251, 251],
                [0, 252, 252],
                [0, 253, 253],
                [0, 254, 254],
                [0, 255, 255],
            ],
        );

        m.insert(
            "Cyan Hot",
            [
                [0, 0, 0],
                [0, 1, 2],
                [0, 2, 5],
                [0, 4, 8],
                [0, 5, 11],
                [0, 7, 14],
                [0, 8, 17],
                [0, 10, 20],
                [0, 11, 23],
                [0, 12, 26],
                [0, 14, 29],
                [0, 15, 32],
                [0, 17, 35],
                [0, 18, 38],
                [0, 20, 41],
                [0, 21, 44],
                [0, 23, 47],
                [0, 24, 50],
                [0, 25, 53],
                [0, 27, 56],
                [0, 28, 59],
                [0, 30, 62],
                [0, 31, 65],
                [0, 33, 68],
                [0, 34, 71],
                [0, 36, 74],
                [0, 37, 77],
                [0, 38, 80],
                [0, 40, 83],
                [0, 41, 86],
                [0, 43, 89],
                [0, 44, 92],
                [0, 46, 95],
                [0, 47, 98],
                [0, 49, 101],
                [0, 50, 104],
                [0, 51, 107],
                [0, 53, 110],
                [0, 54, 113],
                [0, 56, 116],
                [0, 57, 119],
                [0, 59, 122],
                [0, 60, 125],
                [0, 61, 128],
                [0, 63, 131],
                [0, 64, 134],
                [0, 66, 137],
                [0, 67, 140],
                [0, 69, 143],
                [0, 70, 146],
                [0, 72, 149],
                [0, 73, 152],
                [0, 74, 155],
                [0, 76, 158],
                [0, 77, 161],
                [0, 79, 164],
                [0, 80, 167],
                [0, 82, 170],
                [0, 83, 173],
                [0, 85, 176],
                [0, 86, 179],
                [0, 87, 182],
                [0, 89, 185],
                [0, 90, 188],
                [0, 92, 191],
                [0, 93, 194],
                [0, 95, 197],
                [0, 96, 200],
                [0, 98, 203],
                [0, 99, 206],
                [0, 100, 209],
                [0, 102, 212],
                [0, 103, 215],
                [0, 105, 218],
                [0, 106, 221],
                [0, 108, 224],
                [0, 109, 227],
                [0, 110, 230],
                [0, 112, 233],
                [0, 113, 236],
                [0, 115, 239],
                [0, 116, 242],
                [0, 118, 245],
                [0, 119, 248],
                [0, 123, 255],
                [0, 123, 255],
                [0, 124, 255],
                [0, 126, 255],
                [0, 127, 255],
                [0, 129, 255],
                [0, 130, 255],
                [0, 132, 255],
                [0, 133, 255],
                [0, 135, 255],
                [0, 136, 255],
                [0, 138, 255],
                [0, 140, 255],
                [0, 141, 255],
                [0, 143, 255],
                [0, 144, 255],
                [0, 146, 255],
                [0, 147, 255],
                [0, 149, 255],
                [0, 150, 255],
                [0, 152, 255],
                [0, 153, 255],
                [0, 155, 255],
                [0, 157, 255],
                [0, 158, 255],
                [0, 160, 255],
                [0, 161, 255],
                [0, 163, 255],
                [0, 164, 255],
                [0, 166, 255],
                [0, 167, 255],
                [0, 169, 255],
                [0, 170, 255],
                [0, 172, 255],
                [0, 174, 255],
                [0, 175, 255],
                [0, 177, 255],
                [0, 178, 255],
                [0, 180, 255],
                [0, 181, 255],
                [0, 183, 255],
                [0, 184, 255],
                [0, 186, 255],
                [0, 187, 255],
                [0, 189, 255],
                [0, 191, 255],
                [0, 192, 255],
                [0, 194, 255],
                [0, 195, 255],
                [0, 197, 255],
                [0, 198, 255],
                [0, 200, 255],
                [0, 201, 255],
                [0, 203, 255],
                [0, 204, 255],
                [0, 206, 255],
                [0, 208, 255],
                [0, 209, 255],
                [0, 211, 255],
                [0, 212, 255],
                [0, 214, 255],
                [0, 215, 255],
                [0, 217, 255],
                [0, 218, 255],
                [0, 220, 255],
                [0, 222, 255],
                [0, 223, 255],
                [0, 225, 255],
                [0, 226, 255],
                [0, 228, 255],
                [0, 229, 255],
                [0, 231, 255],
                [0, 232, 255],
                [0, 234, 255],
                [0, 235, 255],
                [0, 237, 255],
                [0, 239, 255],
                [0, 240, 255],
                [0, 242, 255],
                [0, 243, 255],
                [0, 245, 255],
                [0, 246, 255],
                [0, 248, 255],
                [0, 249, 255],
                [0, 251, 255],
                [0, 255, 255],
                [0, 255, 255],
                [2, 255, 255],
                [5, 255, 255],
                [8, 255, 255],
                [11, 255, 255],
                [14, 255, 255],
                [17, 255, 255],
                [20, 255, 255],
                [23, 255, 255],
                [26, 255, 255],
                [29, 255, 255],
                [32, 255, 255],
                [35, 255, 255],
                [38, 255, 255],
                [41, 255, 255],
                [44, 255, 255],
                [47, 255, 255],
                [50, 255, 255],
                [53, 255, 255],
                [56, 255, 255],
                [59, 255, 255],
                [62, 255, 255],
                [65, 255, 255],
                [68, 255, 255],
                [71, 255, 255],
                [74, 255, 255],
                [77, 255, 255],
                [80, 255, 255],
                [83, 255, 255],
                [86, 255, 255],
                [89, 255, 255],
                [92, 255, 255],
                [95, 255, 255],
                [98, 255, 255],
                [101, 255, 255],
                [104, 255, 255],
                [107, 255, 255],
                [110, 255, 255],
                [113, 255, 255],
                [116, 255, 255],
                [119, 255, 255],
                [122, 255, 255],
                [125, 255, 255],
                [128, 255, 255],
                [131, 255, 255],
                [134, 255, 255],
                [137, 255, 255],
                [140, 255, 255],
                [143, 255, 255],
                [146, 255, 255],
                [149, 255, 255],
                [152, 255, 255],
                [155, 255, 255],
                [158, 255, 255],
                [161, 255, 255],
                [164, 255, 255],
                [167, 255, 255],
                [170, 255, 255],
                [173, 255, 255],
                [176, 255, 255],
                [179, 255, 255],
                [182, 255, 255],
                [185, 255, 255],
                [188, 255, 255],
                [191, 255, 255],
                [194, 255, 255],
                [197, 255, 255],
                [200, 255, 255],
                [203, 255, 255],
                [206, 255, 255],
                [209, 255, 255],
                [212, 255, 255],
                [215, 255, 255],
                [218, 255, 255],
                [221, 255, 255],
                [224, 255, 255],
                [227, 255, 255],
                [230, 255, 255],
                [233, 255, 255],
                [236, 255, 255],
                [239, 255, 255],
                [242, 255, 255],
                [245, 255, 255],
                [248, 255, 255],
                [251, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Duo Cherry",
            [
                [0, 0, 0],
                [2, 0, 1],
                [4, 0, 2],
                [6, 0, 3],
                [8, 0, 4],
                [10, 0, 5],
                [12, 0, 6],
                [14, 0, 7],
                [16, 0, 8],
                [18, 0, 9],
                [20, 0, 10],
                [22, 0, 11],
                [23, 0, 12],
                [25, 0, 13],
                [27, 0, 14],
                [29, 0, 15],
                [31, 0, 16],
                [33, 0, 17],
                [35, 0, 18],
                [37, 0, 19],
                [38, 0, 20],
                [40, 0, 21],
                [42, 0, 22],
                [44, 0, 23],
                [46, 0, 24],
                [48, 0, 25],
                [49, 0, 26],
                [51, 0, 27],
                [53, 0, 28],
                [55, 0, 29],
                [56, 0, 30],
                [58, 0, 31],
                [60, 0, 32],
                [62, 0, 33],
                [63, 0, 34],
                [65, 0, 35],
                [67, 0, 36],
                [69, 0, 37],
                [70, 0, 38],
                [72, 0, 39],
                [74, 0, 40],
                [75, 0, 41],
                [77, 0, 42],
                [79, 0, 43],
                [80, 0, 44],
                [82, 0, 45],
                [84, 0, 46],
                [85, 0, 47],
                [87, 0, 48],
                [89, 0, 49],
                [90, 0, 50],
                [92, 0, 51],
                [93, 0, 52],
                [95, 0, 53],
                [97, 0, 54],
                [98, 0, 55],
                [100, 0, 56],
                [101, 0, 57],
                [103, 0, 58],
                [104, 0, 59],
                [106, 0, 60],
                [107, 0, 61],
                [109, 0, 62],
                [110, 0, 63],
                [112, 0, 64],
                [113, 0, 65],
                [115, 0, 66],
                [116, 0, 67],
                [118, 0, 68],
                [119, 0, 69],
                [121, 0, 70],
                [122, 0, 71],
                [124, 0, 72],
                [125, 0, 73],
                [127, 0, 74],
                [128, 0, 75],
                [129, 0, 76],
                [131, 0, 77],
                [132, 0, 78],
                [134, 0, 79],
                [135, 0, 80],
                [136, 0, 81],
                [138, 0, 82],
                [139, 0, 83],
                [140, 0, 84],
                [142, 0, 85],
                [143, 0, 86],
                [144, 0, 87],
                [146, 0, 88],
                [147, 0, 89],
                [148, 0, 90],
                [150, 0, 91],
                [151, 0, 92],
                [152, 0, 93],
                [153, 0, 94],
                [155, 0, 95],
                [156, 0, 96],
                [157, 0, 97],
                [158, 0, 98],
                [160, 0, 99],
                [161, 0, 100],
                [162, 0, 101],
                [163, 0, 102],
                [164, 0, 103],
                [166, 0, 104],
                [167, 0, 105],
                [168, 0, 106],
                [169, 0, 107],
                [170, 0, 108],
                [171, 0, 109],
                [173, 0, 110],
                [174, 0, 111],
                [175, 0, 112],
                [176, 0, 113],
                [177, 0, 114],
                [178, 0, 115],
                [179, 0, 116],
                [180, 0, 117],
                [181, 0, 118],
                [182, 0, 119],
                [184, 0, 120],
                [185, 0, 121],
                [186, 0, 122],
                [187, 0, 123],
                [188, 0, 124],
                [189, 0, 125],
                [190, 0, 126],
                [191, 0, 127],
                [192, 0, 128],
                [193, 0, 129],
                [194, 0, 130],
                [195, 0, 131],
                [196, 0, 132],
                [197, 0, 133],
                [198, 0, 134],
                [199, 0, 135],
                [199, 0, 136],
                [200, 0, 137],
                [201, 0, 138],
                [202, 0, 139],
                [203, 0, 140],
                [204, 0, 141],
                [205, 0, 142],
                [206, 0, 143],
                [207, 0, 144],
                [208, 0, 145],
                [208, 0, 146],
                [209, 0, 147],
                [210, 0, 148],
                [211, 0, 149],
                [212, 0, 150],
                [213, 0, 151],
                [213, 0, 152],
                [214, 0, 153],
                [215, 0, 154],
                [216, 0, 155],
                [217, 0, 156],
                [217, 0, 157],
                [218, 0, 158],
                [219, 0, 159],
                [220, 0, 160],
                [220, 0, 161],
                [221, 0, 162],
                [222, 0, 163],
                [223, 0, 164],
                [223, 0, 165],
                [224, 0, 166],
                [225, 0, 167],
                [225, 0, 168],
                [226, 0, 169],
                [227, 0, 170],
                [227, 0, 171],
                [228, 0, 172],
                [229, 0, 173],
                [229, 0, 174],
                [230, 0, 175],
                [231, 0, 176],
                [231, 0, 177],
                [232, 0, 178],
                [232, 0, 179],
                [233, 0, 180],
                [234, 0, 181],
                [234, 0, 182],
                [235, 0, 183],
                [235, 0, 184],
                [236, 0, 185],
                [236, 0, 186],
                [237, 0, 187],
                [237, 0, 188],
                [238, 0, 189],
                [238, 0, 190],
                [239, 0, 191],
                [239, 0, 192],
                [240, 0, 193],
                [240, 0, 194],
                [241, 0, 195],
                [241, 0, 196],
                [242, 0, 197],
                [242, 0, 198],
                [243, 0, 199],
                [243, 0, 200],
                [244, 0, 201],
                [244, 0, 202],
                [244, 0, 203],
                [245, 0, 204],
                [245, 0, 205],
                [246, 0, 206],
                [246, 0, 207],
                [246, 0, 208],
                [247, 0, 209],
                [247, 0, 210],
                [247, 0, 211],
                [248, 0, 212],
                [248, 0, 213],
                [248, 0, 214],
                [249, 0, 215],
                [249, 0, 216],
                [249, 0, 217],
                [250, 0, 218],
                [250, 0, 219],
                [250, 0, 220],
                [250, 0, 221],
                [251, 0, 222],
                [251, 0, 223],
                [251, 0, 224],
                [251, 0, 225],
                [252, 0, 226],
                [252, 0, 227],
                [252, 0, 228],
                [252, 0, 229],
                [253, 0, 230],
                [253, 0, 231],
                [253, 0, 232],
                [253, 0, 233],
                [253, 0, 234],
                [253, 0, 235],
                [254, 0, 236],
                [254, 0, 237],
                [254, 0, 238],
                [254, 0, 239],
                [254, 0, 240],
                [254, 0, 241],
                [254, 0, 242],
                [254, 0, 243],
                [255, 0, 244],
                [255, 0, 245],
                [255, 0, 246],
                [255, 0, 247],
                [255, 0, 248],
                [255, 0, 249],
                [255, 0, 250],
                [255, 0, 251],
                [255, 0, 252],
                [255, 0, 253],
                [255, 0, 254],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Duo Cyan",
            [
                [0, 0, 0],
                [0, 1, 2],
                [0, 2, 4],
                [0, 3, 6],
                [0, 4, 8],
                [0, 5, 10],
                [0, 6, 12],
                [0, 7, 14],
                [0, 8, 16],
                [0, 9, 18],
                [0, 10, 20],
                [0, 11, 22],
                [0, 12, 23],
                [0, 13, 25],
                [0, 14, 27],
                [0, 15, 29],
                [0, 16, 31],
                [0, 17, 33],
                [0, 18, 35],
                [0, 19, 37],
                [0, 20, 38],
                [0, 21, 40],
                [0, 22, 42],
                [0, 23, 44],
                [0, 24, 46],
                [0, 25, 48],
                [0, 26, 49],
                [0, 27, 51],
                [0, 28, 53],
                [0, 29, 55],
                [0, 30, 56],
                [0, 31, 58],
                [0, 32, 60],
                [0, 33, 62],
                [0, 34, 63],
                [0, 35, 65],
                [0, 36, 67],
                [0, 37, 69],
                [0, 38, 70],
                [0, 39, 72],
                [0, 40, 74],
                [0, 41, 75],
                [0, 42, 77],
                [0, 43, 79],
                [0, 44, 80],
                [0, 45, 82],
                [0, 46, 84],
                [0, 47, 85],
                [0, 48, 87],
                [0, 49, 89],
                [0, 50, 90],
                [0, 51, 92],
                [0, 52, 93],
                [0, 53, 95],
                [0, 54, 97],
                [0, 55, 98],
                [0, 56, 100],
                [0, 57, 101],
                [0, 58, 103],
                [0, 59, 104],
                [0, 60, 106],
                [0, 61, 107],
                [0, 62, 109],
                [0, 63, 110],
                [0, 64, 112],
                [0, 65, 113],
                [0, 66, 115],
                [0, 67, 116],
                [0, 68, 118],
                [0, 69, 119],
                [0, 70, 121],
                [0, 71, 122],
                [0, 72, 124],
                [0, 73, 125],
                [0, 74, 127],
                [0, 75, 128],
                [0, 76, 129],
                [0, 77, 131],
                [0, 78, 132],
                [0, 79, 134],
                [0, 80, 135],
                [0, 81, 136],
                [0, 82, 138],
                [0, 83, 139],
                [0, 84, 140],
                [0, 85, 142],
                [0, 86, 143],
                [0, 87, 144],
                [0, 88, 146],
                [0, 89, 147],
                [0, 90, 148],
                [0, 91, 150],
                [0, 92, 151],
                [0, 93, 152],
                [0, 94, 153],
                [0, 95, 155],
                [0, 96, 156],
                [0, 97, 157],
                [0, 98, 158],
                [0, 99, 160],
                [0, 100, 161],
                [0, 101, 162],
                [0, 102, 163],
                [0, 103, 164],
                [0, 104, 166],
                [0, 105, 167],
                [0, 106, 168],
                [0, 107, 169],
                [0, 108, 170],
                [0, 109, 171],
                [0, 110, 173],
                [0, 111, 174],
                [0, 112, 175],
                [0, 113, 176],
                [0, 114, 177],
                [0, 115, 178],
                [0, 116, 179],
                [0, 117, 180],
                [0, 118, 181],
                [0, 119, 182],
                [0, 120, 184],
                [0, 121, 185],
                [0, 122, 186],
                [0, 123, 187],
                [0, 124, 188],
                [0, 125, 189],
                [0, 126, 190],
                [0, 127, 191],
                [0, 128, 192],
                [0, 129, 193],
                [0, 130, 194],
                [0, 131, 195],
                [0, 132, 196],
                [0, 133, 197],
                [0, 134, 198],
                [0, 135, 199],
                [0, 136, 199],
                [0, 137, 200],
                [0, 138, 201],
                [0, 139, 202],
                [0, 140, 203],
                [0, 141, 204],
                [0, 142, 205],
                [0, 143, 206],
                [0, 144, 207],
                [0, 145, 208],
                [0, 146, 208],
                [0, 147, 209],
                [0, 148, 210],
                [0, 149, 211],
                [0, 150, 212],
                [0, 151, 213],
                [0, 152, 213],
                [0, 153, 214],
                [0, 154, 215],
                [0, 155, 216],
                [0, 156, 217],
                [0, 157, 217],
                [0, 158, 218],
                [0, 159, 219],
                [0, 160, 220],
                [0, 161, 220],
                [0, 162, 221],
                [0, 163, 222],
                [0, 164, 223],
                [0, 165, 223],
                [0, 166, 224],
                [0, 167, 225],
                [0, 168, 225],
                [0, 169, 226],
                [0, 170, 227],
                [0, 171, 227],
                [0, 172, 228],
                [0, 173, 229],
                [0, 174, 229],
                [0, 175, 230],
                [0, 176, 231],
                [0, 177, 231],
                [0, 178, 232],
                [0, 179, 232],
                [0, 180, 233],
                [0, 181, 234],
                [0, 182, 234],
                [0, 183, 235],
                [0, 184, 235],
                [0, 185, 236],
                [0, 186, 236],
                [0, 187, 237],
                [0, 188, 237],
                [0, 189, 238],
                [0, 190, 238],
                [0, 191, 239],
                [0, 192, 239],
                [0, 193, 240],
                [0, 194, 240],
                [0, 195, 241],
                [0, 196, 241],
                [0, 197, 242],
                [0, 198, 242],
                [0, 199, 243],
                [0, 200, 243],
                [0, 201, 244],
                [0, 202, 244],
                [0, 203, 244],
                [0, 204, 245],
                [0, 205, 245],
                [0, 206, 246],
                [0, 207, 246],
                [0, 208, 246],
                [0, 209, 247],
                [0, 210, 247],
                [0, 211, 247],
                [0, 212, 248],
                [0, 213, 248],
                [0, 214, 248],
                [0, 215, 249],
                [0, 216, 249],
                [0, 217, 249],
                [0, 218, 250],
                [0, 219, 250],
                [0, 220, 250],
                [0, 221, 250],
                [0, 222, 251],
                [0, 223, 251],
                [0, 224, 251],
                [0, 225, 251],
                [0, 226, 252],
                [0, 227, 252],
                [0, 228, 252],
                [0, 229, 252],
                [0, 230, 253],
                [0, 231, 253],
                [0, 232, 253],
                [0, 233, 253],
                [0, 234, 253],
                [0, 235, 253],
                [0, 236, 254],
                [0, 237, 254],
                [0, 238, 254],
                [0, 239, 254],
                [0, 240, 254],
                [0, 241, 254],
                [0, 242, 254],
                [0, 243, 254],
                [0, 244, 255],
                [0, 245, 255],
                [0, 246, 255],
                [0, 247, 255],
                [0, 248, 255],
                [0, 249, 255],
                [0, 250, 255],
                [0, 251, 255],
                [0, 252, 255],
                [0, 253, 255],
                [0, 254, 255],
                [0, 255, 255],
            ],
        );

        m.insert(
            "Duo Green",
            [
                [0, 0, 0],
                [1, 2, 0],
                [2, 4, 0],
                [3, 6, 0],
                [4, 8, 0],
                [5, 10, 0],
                [6, 12, 0],
                [7, 14, 0],
                [8, 16, 0],
                [9, 18, 0],
                [10, 20, 0],
                [11, 22, 0],
                [12, 23, 0],
                [13, 25, 0],
                [14, 27, 0],
                [15, 29, 0],
                [16, 31, 0],
                [17, 33, 0],
                [18, 35, 0],
                [19, 37, 0],
                [20, 38, 0],
                [21, 40, 0],
                [22, 42, 0],
                [23, 44, 0],
                [24, 46, 0],
                [25, 48, 0],
                [26, 49, 0],
                [27, 51, 0],
                [28, 53, 0],
                [29, 55, 0],
                [30, 56, 0],
                [31, 58, 0],
                [32, 60, 0],
                [33, 62, 0],
                [34, 63, 0],
                [35, 65, 0],
                [36, 67, 0],
                [37, 69, 0],
                [38, 70, 0],
                [39, 72, 0],
                [40, 74, 0],
                [41, 75, 0],
                [42, 77, 0],
                [43, 79, 0],
                [44, 80, 0],
                [45, 82, 0],
                [46, 84, 0],
                [47, 85, 0],
                [48, 87, 0],
                [49, 89, 0],
                [50, 90, 0],
                [51, 92, 0],
                [52, 93, 0],
                [53, 95, 0],
                [54, 97, 0],
                [55, 98, 0],
                [56, 100, 0],
                [57, 101, 0],
                [58, 103, 0],
                [59, 104, 0],
                [60, 106, 0],
                [61, 107, 0],
                [62, 109, 0],
                [63, 110, 0],
                [64, 112, 0],
                [65, 113, 0],
                [66, 115, 0],
                [67, 116, 0],
                [68, 118, 0],
                [69, 119, 0],
                [70, 121, 0],
                [71, 122, 0],
                [72, 124, 0],
                [73, 125, 0],
                [74, 127, 0],
                [75, 128, 0],
                [76, 129, 0],
                [77, 131, 0],
                [78, 132, 0],
                [79, 134, 0],
                [80, 135, 0],
                [81, 136, 0],
                [82, 138, 0],
                [83, 139, 0],
                [84, 140, 0],
                [85, 142, 0],
                [86, 143, 0],
                [87, 144, 0],
                [88, 146, 0],
                [89, 147, 0],
                [90, 148, 0],
                [91, 150, 0],
                [92, 151, 0],
                [93, 152, 0],
                [94, 153, 0],
                [95, 155, 0],
                [96, 156, 0],
                [97, 157, 0],
                [98, 158, 0],
                [99, 160, 0],
                [100, 161, 0],
                [101, 162, 0],
                [102, 163, 0],
                [103, 164, 0],
                [104, 166, 0],
                [105, 167, 0],
                [106, 168, 0],
                [107, 169, 0],
                [108, 170, 0],
                [109, 171, 0],
                [110, 173, 0],
                [111, 174, 0],
                [112, 175, 0],
                [113, 176, 0],
                [114, 177, 0],
                [115, 178, 0],
                [116, 179, 0],
                [117, 180, 0],
                [118, 181, 0],
                [119, 182, 0],
                [120, 184, 0],
                [121, 185, 0],
                [122, 186, 0],
                [123, 187, 0],
                [124, 188, 0],
                [125, 189, 0],
                [126, 190, 0],
                [127, 191, 0],
                [128, 192, 0],
                [129, 193, 0],
                [130, 194, 0],
                [131, 195, 0],
                [132, 196, 0],
                [133, 197, 0],
                [134, 198, 0],
                [135, 199, 0],
                [136, 199, 0],
                [137, 200, 0],
                [138, 201, 0],
                [139, 202, 0],
                [140, 203, 0],
                [141, 204, 0],
                [142, 205, 0],
                [143, 206, 0],
                [144, 207, 0],
                [145, 208, 0],
                [146, 208, 0],
                [147, 209, 0],
                [148, 210, 0],
                [149, 211, 0],
                [150, 212, 0],
                [151, 213, 0],
                [152, 213, 0],
                [153, 214, 0],
                [154, 215, 0],
                [155, 216, 0],
                [156, 217, 0],
                [157, 217, 0],
                [158, 218, 0],
                [159, 219, 0],
                [160, 220, 0],
                [161, 220, 0],
                [162, 221, 0],
                [163, 222, 0],
                [164, 223, 0],
                [165, 223, 0],
                [166, 224, 0],
                [167, 225, 0],
                [168, 225, 0],
                [169, 226, 0],
                [170, 227, 0],
                [171, 227, 0],
                [172, 228, 0],
                [173, 229, 0],
                [174, 229, 0],
                [175, 230, 0],
                [176, 231, 0],
                [177, 231, 0],
                [178, 232, 0],
                [179, 232, 0],
                [180, 233, 0],
                [181, 234, 0],
                [182, 234, 0],
                [183, 235, 0],
                [184, 235, 0],
                [185, 236, 0],
                [186, 236, 0],
                [187, 237, 0],
                [188, 237, 0],
                [189, 238, 0],
                [190, 238, 0],
                [191, 239, 0],
                [192, 239, 0],
                [193, 240, 0],
                [194, 240, 0],
                [195, 241, 0],
                [196, 241, 0],
                [197, 242, 0],
                [198, 242, 0],
                [199, 243, 0],
                [200, 243, 0],
                [201, 244, 0],
                [202, 244, 0],
                [203, 244, 0],
                [204, 245, 0],
                [205, 245, 0],
                [206, 246, 0],
                [207, 246, 0],
                [208, 246, 0],
                [209, 247, 0],
                [210, 247, 0],
                [211, 247, 0],
                [212, 248, 0],
                [213, 248, 0],
                [214, 248, 0],
                [215, 249, 0],
                [216, 249, 0],
                [217, 249, 0],
                [218, 250, 0],
                [219, 250, 0],
                [220, 250, 0],
                [221, 250, 0],
                [222, 251, 0],
                [223, 251, 0],
                [224, 251, 0],
                [225, 251, 0],
                [226, 252, 0],
                [227, 252, 0],
                [228, 252, 0],
                [229, 252, 0],
                [230, 253, 0],
                [231, 253, 0],
                [232, 253, 0],
                [233, 253, 0],
                [234, 253, 0],
                [235, 253, 0],
                [236, 254, 0],
                [237, 254, 0],
                [238, 254, 0],
                [239, 254, 0],
                [240, 254, 0],
                [241, 254, 0],
                [242, 254, 0],
                [243, 254, 0],
                [244, 255, 0],
                [245, 255, 0],
                [246, 255, 0],
                [247, 255, 0],
                [248, 255, 0],
                [249, 255, 0],
                [250, 255, 0],
                [251, 255, 0],
                [252, 255, 0],
                [253, 255, 0],
                [254, 255, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "Duo Intense Cherry",
            [
                [0, 0, 0],
                [4, 0, 1],
                [8, 0, 2],
                [12, 0, 3],
                [16, 0, 4],
                [19, 0, 5],
                [23, 0, 6],
                [27, 0, 7],
                [31, 0, 8],
                [34, 0, 9],
                [38, 0, 10],
                [41, 0, 11],
                [45, 0, 12],
                [48, 0, 13],
                [52, 0, 14],
                [55, 0, 15],
                [58, 0, 16],
                [61, 0, 17],
                [65, 0, 18],
                [68, 0, 19],
                [71, 0, 20],
                [74, 0, 21],
                [77, 0, 22],
                [80, 0, 23],
                [83, 0, 24],
                [86, 0, 25],
                [89, 0, 26],
                [92, 0, 27],
                [95, 0, 28],
                [98, 0, 29],
                [100, 0, 30],
                [103, 0, 31],
                [106, 0, 32],
                [109, 0, 33],
                [111, 0, 34],
                [114, 0, 35],
                [116, 0, 36],
                [119, 0, 37],
                [121, 0, 38],
                [124, 0, 39],
                [126, 0, 40],
                [129, 0, 41],
                [131, 0, 42],
                [133, 0, 43],
                [135, 0, 44],
                [138, 0, 45],
                [140, 0, 46],
                [142, 0, 47],
                [144, 0, 48],
                [146, 0, 49],
                [148, 0, 50],
                [151, 0, 51],
                [153, 0, 52],
                [155, 0, 53],
                [157, 0, 54],
                [159, 0, 55],
                [160, 0, 56],
                [162, 0, 57],
                [164, 0, 58],
                [166, 0, 59],
                [168, 0, 60],
                [170, 0, 61],
                [171, 0, 62],
                [173, 0, 63],
                [175, 0, 64],
                [176, 0, 65],
                [178, 0, 66],
                [180, 0, 67],
                [181, 0, 68],
                [183, 0, 69],
                [184, 0, 70],
                [186, 0, 71],
                [187, 0, 72],
                [189, 0, 73],
                [190, 0, 74],
                [192, 0, 75],
                [193, 0, 76],
                [194, 0, 77],
                [196, 0, 78],
                [197, 0, 79],
                [198, 0, 80],
                [200, 0, 81],
                [201, 0, 82],
                [202, 0, 83],
                [203, 0, 84],
                [205, 0, 85],
                [206, 0, 86],
                [207, 0, 87],
                [208, 0, 88],
                [209, 0, 89],
                [210, 0, 90],
                [211, 0, 91],
                [212, 0, 92],
                [213, 0, 93],
                [214, 0, 94],
                [215, 0, 95],
                [216, 0, 96],
                [217, 0, 97],
                [218, 0, 98],
                [219, 0, 99],
                [220, 0, 100],
                [221, 0, 101],
                [222, 0, 102],
                [223, 0, 103],
                [224, 0, 104],
                [224, 0, 105],
                [225, 0, 106],
                [226, 0, 107],
                [227, 0, 108],
                [228, 0, 109],
                [228, 0, 110],
                [229, 0, 111],
                [230, 0, 112],
                [230, 0, 113],
                [231, 0, 114],
                [232, 0, 115],
                [232, 0, 116],
                [233, 0, 117],
                [234, 0, 118],
                [234, 0, 119],
                [235, 0, 120],
                [236, 0, 121],
                [236, 0, 122],
                [237, 0, 123],
                [237, 0, 124],
                [238, 0, 125],
                [238, 0, 126],
                [239, 0, 127],
                [239, 0, 128],
                [240, 0, 129],
                [240, 0, 130],
                [241, 0, 131],
                [241, 0, 132],
                [242, 0, 133],
                [242, 0, 134],
                [242, 0, 135],
                [243, 0, 136],
                [243, 0, 137],
                [244, 0, 138],
                [244, 0, 139],
                [244, 0, 140],
                [245, 0, 141],
                [245, 0, 142],
                [246, 0, 143],
                [246, 0, 144],
                [246, 0, 145],
                [246, 0, 146],
                [247, 0, 147],
                [247, 0, 148],
                [247, 0, 149],
                [248, 0, 150],
                [248, 0, 151],
                [248, 0, 152],
                [248, 0, 153],
                [249, 0, 154],
                [249, 0, 155],
                [249, 0, 156],
                [249, 0, 157],
                [250, 0, 158],
                [250, 0, 159],
                [250, 0, 160],
                [250, 0, 161],
                [250, 0, 162],
                [251, 0, 163],
                [251, 0, 164],
                [251, 0, 165],
                [251, 0, 166],
                [251, 0, 167],
                [252, 0, 168],
                [252, 0, 169],
                [252, 0, 170],
                [252, 0, 171],
                [252, 0, 172],
                [252, 0, 173],
                [252, 0, 174],
                [253, 0, 175],
                [253, 0, 176],
                [253, 0, 177],
                [253, 0, 178],
                [253, 0, 179],
                [253, 0, 180],
                [253, 0, 181],
                [253, 0, 182],
                [253, 0, 183],
                [253, 0, 184],
                [254, 0, 185],
                [254, 0, 186],
                [254, 0, 187],
                [254, 0, 188],
                [254, 0, 189],
                [254, 0, 190],
                [254, 0, 191],
                [254, 0, 192],
                [254, 0, 193],
                [254, 0, 194],
                [254, 0, 195],
                [254, 0, 196],
                [254, 0, 197],
                [254, 0, 198],
                [254, 0, 199],
                [254, 0, 200],
                [254, 0, 201],
                [255, 0, 202],
                [255, 0, 203],
                [255, 0, 204],
                [255, 0, 205],
                [255, 0, 206],
                [255, 0, 207],
                [255, 0, 208],
                [255, 0, 209],
                [255, 0, 210],
                [255, 0, 211],
                [255, 0, 212],
                [255, 0, 213],
                [255, 0, 214],
                [255, 0, 215],
                [255, 0, 216],
                [255, 0, 217],
                [255, 0, 218],
                [255, 0, 219],
                [255, 0, 220],
                [255, 0, 221],
                [255, 0, 222],
                [255, 0, 223],
                [255, 0, 224],
                [255, 0, 225],
                [255, 0, 226],
                [255, 0, 227],
                [255, 0, 228],
                [255, 0, 229],
                [255, 0, 230],
                [255, 0, 231],
                [255, 0, 232],
                [255, 0, 233],
                [255, 0, 234],
                [255, 0, 235],
                [255, 0, 236],
                [255, 0, 237],
                [255, 0, 238],
                [255, 0, 239],
                [255, 0, 240],
                [255, 0, 241],
                [255, 0, 242],
                [255, 0, 243],
                [255, 0, 244],
                [255, 0, 245],
                [255, 0, 246],
                [255, 0, 247],
                [255, 0, 248],
                [255, 0, 249],
                [255, 0, 250],
                [255, 0, 251],
                [255, 0, 252],
                [255, 0, 253],
                [255, 0, 254],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Duo Intense Cyan",
            [
                [0, 0, 0],
                [0, 1, 4],
                [0, 2, 8],
                [0, 3, 12],
                [0, 4, 16],
                [0, 5, 19],
                [0, 6, 23],
                [0, 7, 27],
                [0, 8, 31],
                [0, 9, 34],
                [0, 10, 38],
                [0, 11, 41],
                [0, 12, 45],
                [0, 13, 48],
                [0, 14, 52],
                [0, 15, 55],
                [0, 16, 58],
                [0, 17, 61],
                [0, 18, 65],
                [0, 19, 68],
                [0, 20, 71],
                [0, 21, 74],
                [0, 22, 77],
                [0, 23, 80],
                [0, 24, 83],
                [0, 25, 86],
                [0, 26, 89],
                [0, 27, 92],
                [0, 28, 95],
                [0, 29, 98],
                [0, 30, 100],
                [0, 31, 103],
                [0, 32, 106],
                [0, 33, 109],
                [0, 34, 111],
                [0, 35, 114],
                [0, 36, 116],
                [0, 37, 119],
                [0, 38, 121],
                [0, 39, 124],
                [0, 40, 126],
                [0, 41, 129],
                [0, 42, 131],
                [0, 43, 133],
                [0, 44, 135],
                [0, 45, 138],
                [0, 46, 140],
                [0, 47, 142],
                [0, 48, 144],
                [0, 49, 146],
                [0, 50, 148],
                [0, 51, 151],
                [0, 52, 153],
                [0, 53, 155],
                [0, 54, 157],
                [0, 55, 159],
                [0, 56, 160],
                [0, 57, 162],
                [0, 58, 164],
                [0, 59, 166],
                [0, 60, 168],
                [0, 61, 170],
                [0, 62, 171],
                [0, 63, 173],
                [0, 64, 175],
                [0, 65, 176],
                [0, 66, 178],
                [0, 67, 180],
                [0, 68, 181],
                [0, 69, 183],
                [0, 70, 184],
                [0, 71, 186],
                [0, 72, 187],
                [0, 73, 189],
                [0, 74, 190],
                [0, 75, 192],
                [0, 76, 193],
                [0, 77, 194],
                [0, 78, 196],
                [0, 79, 197],
                [0, 80, 198],
                [0, 81, 200],
                [0, 82, 201],
                [0, 83, 202],
                [0, 84, 203],
                [0, 85, 205],
                [0, 86, 206],
                [0, 87, 207],
                [0, 88, 208],
                [0, 89, 209],
                [0, 90, 210],
                [0, 91, 211],
                [0, 92, 212],
                [0, 93, 213],
                [0, 94, 214],
                [0, 95, 215],
                [0, 96, 216],
                [0, 97, 217],
                [0, 98, 218],
                [0, 99, 219],
                [0, 100, 220],
                [0, 101, 221],
                [0, 102, 222],
                [0, 103, 223],
                [0, 104, 224],
                [0, 105, 224],
                [0, 106, 225],
                [0, 107, 226],
                [0, 108, 227],
                [0, 109, 228],
                [0, 110, 228],
                [0, 111, 229],
                [0, 112, 230],
                [0, 113, 230],
                [0, 114, 231],
                [0, 115, 232],
                [0, 116, 232],
                [0, 117, 233],
                [0, 118, 234],
                [0, 119, 234],
                [0, 120, 235],
                [0, 121, 236],
                [0, 122, 236],
                [0, 123, 237],
                [0, 124, 237],
                [0, 125, 238],
                [0, 126, 238],
                [0, 127, 239],
                [0, 128, 239],
                [0, 129, 240],
                [0, 130, 240],
                [0, 131, 241],
                [0, 132, 241],
                [0, 133, 242],
                [0, 134, 242],
                [0, 135, 242],
                [0, 136, 243],
                [0, 137, 243],
                [0, 138, 244],
                [0, 139, 244],
                [0, 140, 244],
                [0, 141, 245],
                [0, 142, 245],
                [0, 143, 246],
                [0, 144, 246],
                [0, 145, 246],
                [0, 146, 246],
                [0, 147, 247],
                [0, 148, 247],
                [0, 149, 247],
                [0, 150, 248],
                [0, 151, 248],
                [0, 152, 248],
                [0, 153, 248],
                [0, 154, 249],
                [0, 155, 249],
                [0, 156, 249],
                [0, 157, 249],
                [0, 158, 250],
                [0, 159, 250],
                [0, 160, 250],
                [0, 161, 250],
                [0, 162, 250],
                [0, 163, 251],
                [0, 164, 251],
                [0, 165, 251],
                [0, 166, 251],
                [0, 167, 251],
                [0, 168, 252],
                [0, 169, 252],
                [0, 170, 252],
                [0, 171, 252],
                [0, 172, 252],
                [0, 173, 252],
                [0, 174, 252],
                [0, 175, 253],
                [0, 176, 253],
                [0, 177, 253],
                [0, 178, 253],
                [0, 179, 253],
                [0, 180, 253],
                [0, 181, 253],
                [0, 182, 253],
                [0, 183, 253],
                [0, 184, 253],
                [0, 185, 254],
                [0, 186, 254],
                [0, 187, 254],
                [0, 188, 254],
                [0, 189, 254],
                [0, 190, 254],
                [0, 191, 254],
                [0, 192, 254],
                [0, 193, 254],
                [0, 194, 254],
                [0, 195, 254],
                [0, 196, 254],
                [0, 197, 254],
                [0, 198, 254],
                [0, 199, 254],
                [0, 200, 254],
                [0, 201, 254],
                [0, 202, 255],
                [0, 203, 255],
                [0, 204, 255],
                [0, 205, 255],
                [0, 206, 255],
                [0, 207, 255],
                [0, 208, 255],
                [0, 209, 255],
                [0, 210, 255],
                [0, 211, 255],
                [0, 212, 255],
                [0, 213, 255],
                [0, 214, 255],
                [0, 215, 255],
                [0, 216, 255],
                [0, 217, 255],
                [0, 218, 255],
                [0, 219, 255],
                [0, 220, 255],
                [0, 221, 255],
                [0, 222, 255],
                [0, 223, 255],
                [0, 224, 255],
                [0, 225, 255],
                [0, 226, 255],
                [0, 227, 255],
                [0, 228, 255],
                [0, 229, 255],
                [0, 230, 255],
                [0, 231, 255],
                [0, 232, 255],
                [0, 233, 255],
                [0, 234, 255],
                [0, 235, 255],
                [0, 236, 255],
                [0, 237, 255],
                [0, 238, 255],
                [0, 239, 255],
                [0, 240, 255],
                [0, 241, 255],
                [0, 242, 255],
                [0, 243, 255],
                [0, 244, 255],
                [0, 245, 255],
                [0, 246, 255],
                [0, 247, 255],
                [0, 248, 255],
                [0, 249, 255],
                [0, 250, 255],
                [0, 251, 255],
                [0, 252, 255],
                [0, 253, 255],
                [0, 254, 255],
                [0, 255, 255],
            ],
        );

        m.insert(
            "Duo Intense Green",
            [
                [0, 0, 0],
                [1, 4, 0],
                [2, 8, 0],
                [3, 12, 0],
                [4, 16, 0],
                [5, 19, 0],
                [6, 23, 0],
                [7, 27, 0],
                [8, 31, 0],
                [9, 34, 0],
                [10, 38, 0],
                [11, 41, 0],
                [12, 45, 0],
                [13, 48, 0],
                [14, 52, 0],
                [15, 55, 0],
                [16, 58, 0],
                [17, 61, 0],
                [18, 65, 0],
                [19, 68, 0],
                [20, 71, 0],
                [21, 74, 0],
                [22, 77, 0],
                [23, 80, 0],
                [24, 83, 0],
                [25, 86, 0],
                [26, 89, 0],
                [27, 92, 0],
                [28, 95, 0],
                [29, 98, 0],
                [30, 100, 0],
                [31, 103, 0],
                [32, 106, 0],
                [33, 109, 0],
                [34, 111, 0],
                [35, 114, 0],
                [36, 116, 0],
                [37, 119, 0],
                [38, 121, 0],
                [39, 124, 0],
                [40, 126, 0],
                [41, 129, 0],
                [42, 131, 0],
                [43, 133, 0],
                [44, 135, 0],
                [45, 138, 0],
                [46, 140, 0],
                [47, 142, 0],
                [48, 144, 0],
                [49, 146, 0],
                [50, 148, 0],
                [51, 151, 0],
                [52, 153, 0],
                [53, 155, 0],
                [54, 157, 0],
                [55, 159, 0],
                [56, 160, 0],
                [57, 162, 0],
                [58, 164, 0],
                [59, 166, 0],
                [60, 168, 0],
                [61, 170, 0],
                [62, 171, 0],
                [63, 173, 0],
                [64, 175, 0],
                [65, 176, 0],
                [66, 178, 0],
                [67, 180, 0],
                [68, 181, 0],
                [69, 183, 0],
                [70, 184, 0],
                [71, 186, 0],
                [72, 187, 0],
                [73, 189, 0],
                [74, 190, 0],
                [75, 192, 0],
                [76, 193, 0],
                [77, 194, 0],
                [78, 196, 0],
                [79, 197, 0],
                [80, 198, 0],
                [81, 200, 0],
                [82, 201, 0],
                [83, 202, 0],
                [84, 203, 0],
                [85, 205, 0],
                [86, 206, 0],
                [87, 207, 0],
                [88, 208, 0],
                [89, 209, 0],
                [90, 210, 0],
                [91, 211, 0],
                [92, 212, 0],
                [93, 213, 0],
                [94, 214, 0],
                [95, 215, 0],
                [96, 216, 0],
                [97, 217, 0],
                [98, 218, 0],
                [99, 219, 0],
                [100, 220, 0],
                [101, 221, 0],
                [102, 222, 0],
                [103, 223, 0],
                [104, 224, 0],
                [105, 224, 0],
                [106, 225, 0],
                [107, 226, 0],
                [108, 227, 0],
                [109, 228, 0],
                [110, 228, 0],
                [111, 229, 0],
                [112, 230, 0],
                [113, 230, 0],
                [114, 231, 0],
                [115, 232, 0],
                [116, 232, 0],
                [117, 233, 0],
                [118, 234, 0],
                [119, 234, 0],
                [120, 235, 0],
                [121, 236, 0],
                [122, 236, 0],
                [123, 237, 0],
                [124, 237, 0],
                [125, 238, 0],
                [126, 238, 0],
                [127, 239, 0],
                [128, 239, 0],
                [129, 240, 0],
                [130, 240, 0],
                [131, 241, 0],
                [132, 241, 0],
                [133, 242, 0],
                [134, 242, 0],
                [135, 242, 0],
                [136, 243, 0],
                [137, 243, 0],
                [138, 244, 0],
                [139, 244, 0],
                [140, 244, 0],
                [141, 245, 0],
                [142, 245, 0],
                [143, 246, 0],
                [144, 246, 0],
                [145, 246, 0],
                [146, 246, 0],
                [147, 247, 0],
                [148, 247, 0],
                [149, 247, 0],
                [150, 248, 0],
                [151, 248, 0],
                [152, 248, 0],
                [153, 248, 0],
                [154, 249, 0],
                [155, 249, 0],
                [156, 249, 0],
                [157, 249, 0],
                [158, 250, 0],
                [159, 250, 0],
                [160, 250, 0],
                [161, 250, 0],
                [162, 250, 0],
                [163, 251, 0],
                [164, 251, 0],
                [165, 251, 0],
                [166, 251, 0],
                [167, 251, 0],
                [168, 252, 0],
                [169, 252, 0],
                [170, 252, 0],
                [171, 252, 0],
                [172, 252, 0],
                [173, 252, 0],
                [174, 252, 0],
                [175, 253, 0],
                [176, 253, 0],
                [177, 253, 0],
                [178, 253, 0],
                [179, 253, 0],
                [180, 253, 0],
                [181, 253, 0],
                [182, 253, 0],
                [183, 253, 0],
                [184, 253, 0],
                [185, 254, 0],
                [186, 254, 0],
                [187, 254, 0],
                [188, 254, 0],
                [189, 254, 0],
                [190, 254, 0],
                [191, 254, 0],
                [192, 254, 0],
                [193, 254, 0],
                [194, 254, 0],
                [195, 254, 0],
                [196, 254, 0],
                [197, 254, 0],
                [198, 254, 0],
                [199, 254, 0],
                [200, 254, 0],
                [201, 254, 0],
                [202, 255, 0],
                [203, 255, 0],
                [204, 255, 0],
                [205, 255, 0],
                [206, 255, 0],
                [207, 255, 0],
                [208, 255, 0],
                [209, 255, 0],
                [210, 255, 0],
                [211, 255, 0],
                [212, 255, 0],
                [213, 255, 0],
                [214, 255, 0],
                [215, 255, 0],
                [216, 255, 0],
                [217, 255, 0],
                [218, 255, 0],
                [219, 255, 0],
                [220, 255, 0],
                [221, 255, 0],
                [222, 255, 0],
                [223, 255, 0],
                [224, 255, 0],
                [225, 255, 0],
                [226, 255, 0],
                [227, 255, 0],
                [228, 255, 0],
                [229, 255, 0],
                [230, 255, 0],
                [231, 255, 0],
                [232, 255, 0],
                [233, 255, 0],
                [234, 255, 0],
                [235, 255, 0],
                [236, 255, 0],
                [237, 255, 0],
                [238, 255, 0],
                [239, 255, 0],
                [240, 255, 0],
                [241, 255, 0],
                [242, 255, 0],
                [243, 255, 0],
                [244, 255, 0],
                [245, 255, 0],
                [246, 255, 0],
                [247, 255, 0],
                [248, 255, 0],
                [249, 255, 0],
                [250, 255, 0],
                [251, 255, 0],
                [252, 255, 0],
                [253, 255, 0],
                [254, 255, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "Duo Intense Mint",
            [
                [0, 0, 0],
                [0, 4, 1],
                [0, 8, 2],
                [0, 12, 3],
                [0, 16, 4],
                [0, 19, 5],
                [0, 23, 6],
                [0, 27, 7],
                [0, 31, 8],
                [0, 34, 9],
                [0, 38, 10],
                [0, 41, 11],
                [0, 45, 12],
                [0, 48, 13],
                [0, 52, 14],
                [0, 55, 15],
                [0, 58, 16],
                [0, 61, 17],
                [0, 65, 18],
                [0, 68, 19],
                [0, 71, 20],
                [0, 74, 21],
                [0, 77, 22],
                [0, 80, 23],
                [0, 83, 24],
                [0, 86, 25],
                [0, 89, 26],
                [0, 92, 27],
                [0, 95, 28],
                [0, 98, 29],
                [0, 100, 30],
                [0, 103, 31],
                [0, 106, 32],
                [0, 109, 33],
                [0, 111, 34],
                [0, 114, 35],
                [0, 116, 36],
                [0, 119, 37],
                [0, 121, 38],
                [0, 124, 39],
                [0, 126, 40],
                [0, 129, 41],
                [0, 131, 42],
                [0, 133, 43],
                [0, 135, 44],
                [0, 138, 45],
                [0, 140, 46],
                [0, 142, 47],
                [0, 144, 48],
                [0, 146, 49],
                [0, 148, 50],
                [0, 151, 51],
                [0, 153, 52],
                [0, 155, 53],
                [0, 157, 54],
                [0, 159, 55],
                [0, 160, 56],
                [0, 162, 57],
                [0, 164, 58],
                [0, 166, 59],
                [0, 168, 60],
                [0, 170, 61],
                [0, 171, 62],
                [0, 173, 63],
                [0, 175, 64],
                [0, 176, 65],
                [0, 178, 66],
                [0, 180, 67],
                [0, 181, 68],
                [0, 183, 69],
                [0, 184, 70],
                [0, 186, 71],
                [0, 187, 72],
                [0, 189, 73],
                [0, 190, 74],
                [0, 192, 75],
                [0, 193, 76],
                [0, 194, 77],
                [0, 196, 78],
                [0, 197, 79],
                [0, 198, 80],
                [0, 200, 81],
                [0, 201, 82],
                [0, 202, 83],
                [0, 203, 84],
                [0, 205, 85],
                [0, 206, 86],
                [0, 207, 87],
                [0, 208, 88],
                [0, 209, 89],
                [0, 210, 90],
                [0, 211, 91],
                [0, 212, 92],
                [0, 213, 93],
                [0, 214, 94],
                [0, 215, 95],
                [0, 216, 96],
                [0, 217, 97],
                [0, 218, 98],
                [0, 219, 99],
                [0, 220, 100],
                [0, 221, 101],
                [0, 222, 102],
                [0, 223, 103],
                [0, 224, 104],
                [0, 224, 105],
                [0, 225, 106],
                [0, 226, 107],
                [0, 227, 108],
                [0, 228, 109],
                [0, 228, 110],
                [0, 229, 111],
                [0, 230, 112],
                [0, 230, 113],
                [0, 231, 114],
                [0, 232, 115],
                [0, 232, 116],
                [0, 233, 117],
                [0, 234, 118],
                [0, 234, 119],
                [0, 235, 120],
                [0, 236, 121],
                [0, 236, 122],
                [0, 237, 123],
                [0, 237, 124],
                [0, 238, 125],
                [0, 238, 126],
                [0, 239, 127],
                [0, 239, 128],
                [0, 240, 129],
                [0, 240, 130],
                [0, 241, 131],
                [0, 241, 132],
                [0, 242, 133],
                [0, 242, 134],
                [0, 242, 135],
                [0, 243, 136],
                [0, 243, 137],
                [0, 244, 138],
                [0, 244, 139],
                [0, 244, 140],
                [0, 245, 141],
                [0, 245, 142],
                [0, 246, 143],
                [0, 246, 144],
                [0, 246, 145],
                [0, 246, 146],
                [0, 247, 147],
                [0, 247, 148],
                [0, 247, 149],
                [0, 248, 150],
                [0, 248, 151],
                [0, 248, 152],
                [0, 248, 153],
                [0, 249, 154],
                [0, 249, 155],
                [0, 249, 156],
                [0, 249, 157],
                [0, 250, 158],
                [0, 250, 159],
                [0, 250, 160],
                [0, 250, 161],
                [0, 250, 162],
                [0, 251, 163],
                [0, 251, 164],
                [0, 251, 165],
                [0, 251, 166],
                [0, 251, 167],
                [0, 252, 168],
                [0, 252, 169],
                [0, 252, 170],
                [0, 252, 171],
                [0, 252, 172],
                [0, 252, 173],
                [0, 252, 174],
                [0, 253, 175],
                [0, 253, 176],
                [0, 253, 177],
                [0, 253, 178],
                [0, 253, 179],
                [0, 253, 180],
                [0, 253, 181],
                [0, 253, 182],
                [0, 253, 183],
                [0, 253, 184],
                [0, 254, 185],
                [0, 254, 186],
                [0, 254, 187],
                [0, 254, 188],
                [0, 254, 189],
                [0, 254, 190],
                [0, 254, 191],
                [0, 254, 192],
                [0, 254, 193],
                [0, 254, 194],
                [0, 254, 195],
                [0, 254, 196],
                [0, 254, 197],
                [0, 254, 198],
                [0, 254, 199],
                [0, 254, 200],
                [0, 254, 201],
                [0, 255, 202],
                [0, 255, 203],
                [0, 255, 204],
                [0, 255, 205],
                [0, 255, 206],
                [0, 255, 207],
                [0, 255, 208],
                [0, 255, 209],
                [0, 255, 210],
                [0, 255, 211],
                [0, 255, 212],
                [0, 255, 213],
                [0, 255, 214],
                [0, 255, 215],
                [0, 255, 216],
                [0, 255, 217],
                [0, 255, 218],
                [0, 255, 219],
                [0, 255, 220],
                [0, 255, 221],
                [0, 255, 222],
                [0, 255, 223],
                [0, 255, 224],
                [0, 255, 225],
                [0, 255, 226],
                [0, 255, 227],
                [0, 255, 228],
                [0, 255, 229],
                [0, 255, 230],
                [0, 255, 231],
                [0, 255, 232],
                [0, 255, 233],
                [0, 255, 234],
                [0, 255, 235],
                [0, 255, 236],
                [0, 255, 237],
                [0, 255, 238],
                [0, 255, 239],
                [0, 255, 240],
                [0, 255, 241],
                [0, 255, 242],
                [0, 255, 243],
                [0, 255, 244],
                [0, 255, 245],
                [0, 255, 246],
                [0, 255, 247],
                [0, 255, 248],
                [0, 255, 249],
                [0, 255, 250],
                [0, 255, 251],
                [0, 255, 252],
                [0, 255, 253],
                [0, 255, 254],
                [0, 255, 255],
            ],
        );

        m.insert(
            "Duo Intense Purple",
            [
                [0, 0, 0],
                [1, 0, 4],
                [2, 0, 8],
                [3, 0, 12],
                [4, 0, 16],
                [5, 0, 19],
                [6, 0, 23],
                [7, 0, 27],
                [8, 0, 31],
                [9, 0, 34],
                [10, 0, 38],
                [11, 0, 41],
                [12, 0, 45],
                [13, 0, 48],
                [14, 0, 52],
                [15, 0, 55],
                [16, 0, 58],
                [17, 0, 61],
                [18, 0, 65],
                [19, 0, 68],
                [20, 0, 71],
                [21, 0, 74],
                [22, 0, 77],
                [23, 0, 80],
                [24, 0, 83],
                [25, 0, 86],
                [26, 0, 89],
                [27, 0, 92],
                [28, 0, 95],
                [29, 0, 98],
                [30, 0, 100],
                [31, 0, 103],
                [32, 0, 106],
                [33, 0, 109],
                [34, 0, 111],
                [35, 0, 114],
                [36, 0, 116],
                [37, 0, 119],
                [38, 0, 121],
                [39, 0, 124],
                [40, 0, 126],
                [41, 0, 129],
                [42, 0, 131],
                [43, 0, 133],
                [44, 0, 135],
                [45, 0, 138],
                [46, 0, 140],
                [47, 0, 142],
                [48, 0, 144],
                [49, 0, 146],
                [50, 0, 148],
                [51, 0, 151],
                [52, 0, 153],
                [53, 0, 155],
                [54, 0, 157],
                [55, 0, 159],
                [56, 0, 160],
                [57, 0, 162],
                [58, 0, 164],
                [59, 0, 166],
                [60, 0, 168],
                [61, 0, 170],
                [62, 0, 171],
                [63, 0, 173],
                [64, 0, 175],
                [65, 0, 176],
                [66, 0, 178],
                [67, 0, 180],
                [68, 0, 181],
                [69, 0, 183],
                [70, 0, 184],
                [71, 0, 186],
                [72, 0, 187],
                [73, 0, 189],
                [74, 0, 190],
                [75, 0, 192],
                [76, 0, 193],
                [77, 0, 194],
                [78, 0, 196],
                [79, 0, 197],
                [80, 0, 198],
                [81, 0, 200],
                [82, 0, 201],
                [83, 0, 202],
                [84, 0, 203],
                [85, 0, 205],
                [86, 0, 206],
                [87, 0, 207],
                [88, 0, 208],
                [89, 0, 209],
                [90, 0, 210],
                [91, 0, 211],
                [92, 0, 212],
                [93, 0, 213],
                [94, 0, 214],
                [95, 0, 215],
                [96, 0, 216],
                [97, 0, 217],
                [98, 0, 218],
                [99, 0, 219],
                [100, 0, 220],
                [101, 0, 221],
                [102, 0, 222],
                [103, 0, 223],
                [104, 0, 224],
                [105, 0, 224],
                [106, 0, 225],
                [107, 0, 226],
                [108, 0, 227],
                [109, 0, 228],
                [110, 0, 228],
                [111, 0, 229],
                [112, 0, 230],
                [113, 0, 230],
                [114, 0, 231],
                [115, 0, 232],
                [116, 0, 232],
                [117, 0, 233],
                [118, 0, 234],
                [119, 0, 234],
                [120, 0, 235],
                [121, 0, 236],
                [122, 0, 236],
                [123, 0, 237],
                [124, 0, 237],
                [125, 0, 238],
                [126, 0, 238],
                [127, 0, 239],
                [128, 0, 239],
                [129, 0, 240],
                [130, 0, 240],
                [131, 0, 241],
                [132, 0, 241],
                [133, 0, 242],
                [134, 0, 242],
                [135, 0, 242],
                [136, 0, 243],
                [137, 0, 243],
                [138, 0, 244],
                [139, 0, 244],
                [140, 0, 244],
                [141, 0, 245],
                [142, 0, 245],
                [143, 0, 246],
                [144, 0, 246],
                [145, 0, 246],
                [146, 0, 246],
                [147, 0, 247],
                [148, 0, 247],
                [149, 0, 247],
                [150, 0, 248],
                [151, 0, 248],
                [152, 0, 248],
                [153, 0, 248],
                [154, 0, 249],
                [155, 0, 249],
                [156, 0, 249],
                [157, 0, 249],
                [158, 0, 250],
                [159, 0, 250],
                [160, 0, 250],
                [161, 0, 250],
                [162, 0, 250],
                [163, 0, 251],
                [164, 0, 251],
                [165, 0, 251],
                [166, 0, 251],
                [167, 0, 251],
                [168, 0, 252],
                [169, 0, 252],
                [170, 0, 252],
                [171, 0, 252],
                [172, 0, 252],
                [173, 0, 252],
                [174, 0, 252],
                [175, 0, 253],
                [176, 0, 253],
                [177, 0, 253],
                [178, 0, 253],
                [179, 0, 253],
                [180, 0, 253],
                [181, 0, 253],
                [182, 0, 253],
                [183, 0, 253],
                [184, 0, 253],
                [185, 0, 254],
                [186, 0, 254],
                [187, 0, 254],
                [188, 0, 254],
                [189, 0, 254],
                [190, 0, 254],
                [191, 0, 254],
                [192, 0, 254],
                [193, 0, 254],
                [194, 0, 254],
                [195, 0, 254],
                [196, 0, 254],
                [197, 0, 254],
                [198, 0, 254],
                [199, 0, 254],
                [200, 0, 254],
                [201, 0, 254],
                [202, 0, 255],
                [203, 0, 255],
                [204, 0, 255],
                [205, 0, 255],
                [206, 0, 255],
                [207, 0, 255],
                [208, 0, 255],
                [209, 0, 255],
                [210, 0, 255],
                [211, 0, 255],
                [212, 0, 255],
                [213, 0, 255],
                [214, 0, 255],
                [215, 0, 255],
                [216, 0, 255],
                [217, 0, 255],
                [218, 0, 255],
                [219, 0, 255],
                [220, 0, 255],
                [221, 0, 255],
                [222, 0, 255],
                [223, 0, 255],
                [224, 0, 255],
                [225, 0, 255],
                [226, 0, 255],
                [227, 0, 255],
                [228, 0, 255],
                [229, 0, 255],
                [230, 0, 255],
                [231, 0, 255],
                [232, 0, 255],
                [233, 0, 255],
                [234, 0, 255],
                [235, 0, 255],
                [236, 0, 255],
                [237, 0, 255],
                [238, 0, 255],
                [239, 0, 255],
                [240, 0, 255],
                [241, 0, 255],
                [242, 0, 255],
                [243, 0, 255],
                [244, 0, 255],
                [245, 0, 255],
                [246, 0, 255],
                [247, 0, 255],
                [248, 0, 255],
                [249, 0, 255],
                [250, 0, 255],
                [251, 0, 255],
                [252, 0, 255],
                [253, 0, 255],
                [254, 0, 255],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Duo Intense Yellow",
            [
                [0, 0, 0],
                [4, 1, 0],
                [8, 2, 0],
                [12, 3, 0],
                [16, 4, 0],
                [19, 5, 0],
                [23, 6, 0],
                [27, 7, 0],
                [31, 8, 0],
                [34, 9, 0],
                [38, 10, 0],
                [41, 11, 0],
                [45, 12, 0],
                [48, 13, 0],
                [52, 14, 0],
                [55, 15, 0],
                [58, 16, 0],
                [61, 17, 0],
                [65, 18, 0],
                [68, 19, 0],
                [71, 20, 0],
                [74, 21, 0],
                [77, 22, 0],
                [80, 23, 0],
                [83, 24, 0],
                [86, 25, 0],
                [89, 26, 0],
                [92, 27, 0],
                [95, 28, 0],
                [98, 29, 0],
                [100, 30, 0],
                [103, 31, 0],
                [106, 32, 0],
                [109, 33, 0],
                [111, 34, 0],
                [114, 35, 0],
                [116, 36, 0],
                [119, 37, 0],
                [121, 38, 0],
                [124, 39, 0],
                [126, 40, 0],
                [129, 41, 0],
                [131, 42, 0],
                [133, 43, 0],
                [135, 44, 0],
                [138, 45, 0],
                [140, 46, 0],
                [142, 47, 0],
                [144, 48, 0],
                [146, 49, 0],
                [148, 50, 0],
                [151, 51, 0],
                [153, 52, 0],
                [155, 53, 0],
                [157, 54, 0],
                [159, 55, 0],
                [160, 56, 0],
                [162, 57, 0],
                [164, 58, 0],
                [166, 59, 0],
                [168, 60, 0],
                [170, 61, 0],
                [171, 62, 0],
                [173, 63, 0],
                [175, 64, 0],
                [176, 65, 0],
                [178, 66, 0],
                [180, 67, 0],
                [181, 68, 0],
                [183, 69, 0],
                [184, 70, 0],
                [186, 71, 0],
                [187, 72, 0],
                [189, 73, 0],
                [190, 74, 0],
                [192, 75, 0],
                [193, 76, 0],
                [194, 77, 0],
                [196, 78, 0],
                [197, 79, 0],
                [198, 80, 0],
                [200, 81, 0],
                [201, 82, 0],
                [202, 83, 0],
                [203, 84, 0],
                [205, 85, 0],
                [206, 86, 0],
                [207, 87, 0],
                [208, 88, 0],
                [209, 89, 0],
                [210, 90, 0],
                [211, 91, 0],
                [212, 92, 0],
                [213, 93, 0],
                [214, 94, 0],
                [215, 95, 0],
                [216, 96, 0],
                [217, 97, 0],
                [218, 98, 0],
                [219, 99, 0],
                [220, 100, 0],
                [221, 101, 0],
                [222, 102, 0],
                [223, 103, 0],
                [224, 104, 0],
                [224, 105, 0],
                [225, 106, 0],
                [226, 107, 0],
                [227, 108, 0],
                [228, 109, 0],
                [228, 110, 0],
                [229, 111, 0],
                [230, 112, 0],
                [230, 113, 0],
                [231, 114, 0],
                [232, 115, 0],
                [232, 116, 0],
                [233, 117, 0],
                [234, 118, 0],
                [234, 119, 0],
                [235, 120, 0],
                [236, 121, 0],
                [236, 122, 0],
                [237, 123, 0],
                [237, 124, 0],
                [238, 125, 0],
                [238, 126, 0],
                [239, 127, 0],
                [239, 128, 0],
                [240, 129, 0],
                [240, 130, 0],
                [241, 131, 0],
                [241, 132, 0],
                [242, 133, 0],
                [242, 134, 0],
                [242, 135, 0],
                [243, 136, 0],
                [243, 137, 0],
                [244, 138, 0],
                [244, 139, 0],
                [244, 140, 0],
                [245, 141, 0],
                [245, 142, 0],
                [246, 143, 0],
                [246, 144, 0],
                [246, 145, 0],
                [246, 146, 0],
                [247, 147, 0],
                [247, 148, 0],
                [247, 149, 0],
                [248, 150, 0],
                [248, 151, 0],
                [248, 152, 0],
                [248, 153, 0],
                [249, 154, 0],
                [249, 155, 0],
                [249, 156, 0],
                [249, 157, 0],
                [250, 158, 0],
                [250, 159, 0],
                [250, 160, 0],
                [250, 161, 0],
                [250, 162, 0],
                [251, 163, 0],
                [251, 164, 0],
                [251, 165, 0],
                [251, 166, 0],
                [251, 167, 0],
                [252, 168, 0],
                [252, 169, 0],
                [252, 170, 0],
                [252, 171, 0],
                [252, 172, 0],
                [252, 173, 0],
                [252, 174, 0],
                [253, 175, 0],
                [253, 176, 0],
                [253, 177, 0],
                [253, 178, 0],
                [253, 179, 0],
                [253, 180, 0],
                [253, 181, 0],
                [253, 182, 0],
                [253, 183, 0],
                [253, 184, 0],
                [254, 185, 0],
                [254, 186, 0],
                [254, 187, 0],
                [254, 188, 0],
                [254, 189, 0],
                [254, 190, 0],
                [254, 191, 0],
                [254, 192, 0],
                [254, 193, 0],
                [254, 194, 0],
                [254, 195, 0],
                [254, 196, 0],
                [254, 197, 0],
                [254, 198, 0],
                [254, 199, 0],
                [254, 200, 0],
                [254, 201, 0],
                [255, 202, 0],
                [255, 203, 0],
                [255, 204, 0],
                [255, 205, 0],
                [255, 206, 0],
                [255, 207, 0],
                [255, 208, 0],
                [255, 209, 0],
                [255, 210, 0],
                [255, 211, 0],
                [255, 212, 0],
                [255, 213, 0],
                [255, 214, 0],
                [255, 215, 0],
                [255, 216, 0],
                [255, 217, 0],
                [255, 218, 0],
                [255, 219, 0],
                [255, 220, 0],
                [255, 221, 0],
                [255, 222, 0],
                [255, 223, 0],
                [255, 224, 0],
                [255, 225, 0],
                [255, 226, 0],
                [255, 227, 0],
                [255, 228, 0],
                [255, 229, 0],
                [255, 230, 0],
                [255, 231, 0],
                [255, 232, 0],
                [255, 233, 0],
                [255, 234, 0],
                [255, 235, 0],
                [255, 236, 0],
                [255, 237, 0],
                [255, 238, 0],
                [255, 239, 0],
                [255, 240, 0],
                [255, 241, 0],
                [255, 242, 0],
                [255, 243, 0],
                [255, 244, 0],
                [255, 245, 0],
                [255, 246, 0],
                [255, 247, 0],
                [255, 248, 0],
                [255, 249, 0],
                [255, 250, 0],
                [255, 251, 0],
                [255, 252, 0],
                [255, 253, 0],
                [255, 254, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "Duo Mint",
            [
                [0, 0, 0],
                [0, 2, 1],
                [0, 4, 2],
                [0, 6, 3],
                [0, 8, 4],
                [0, 10, 5],
                [0, 12, 6],
                [0, 14, 7],
                [0, 16, 8],
                [0, 18, 9],
                [0, 20, 10],
                [0, 22, 11],
                [0, 23, 12],
                [0, 25, 13],
                [0, 27, 14],
                [0, 29, 15],
                [0, 31, 16],
                [0, 33, 17],
                [0, 35, 18],
                [0, 37, 19],
                [0, 38, 20],
                [0, 40, 21],
                [0, 42, 22],
                [0, 44, 23],
                [0, 46, 24],
                [0, 48, 25],
                [0, 49, 26],
                [0, 51, 27],
                [0, 53, 28],
                [0, 55, 29],
                [0, 56, 30],
                [0, 58, 31],
                [0, 60, 32],
                [0, 62, 33],
                [0, 63, 34],
                [0, 65, 35],
                [0, 67, 36],
                [0, 69, 37],
                [0, 70, 38],
                [0, 72, 39],
                [0, 74, 40],
                [0, 75, 41],
                [0, 77, 42],
                [0, 79, 43],
                [0, 80, 44],
                [0, 82, 45],
                [0, 84, 46],
                [0, 85, 47],
                [0, 87, 48],
                [0, 89, 49],
                [0, 90, 50],
                [0, 92, 51],
                [0, 93, 52],
                [0, 95, 53],
                [0, 97, 54],
                [0, 98, 55],
                [0, 100, 56],
                [0, 101, 57],
                [0, 103, 58],
                [0, 104, 59],
                [0, 106, 60],
                [0, 107, 61],
                [0, 109, 62],
                [0, 110, 63],
                [0, 112, 64],
                [0, 113, 65],
                [0, 115, 66],
                [0, 116, 67],
                [0, 118, 68],
                [0, 119, 69],
                [0, 121, 70],
                [0, 122, 71],
                [0, 124, 72],
                [0, 125, 73],
                [0, 127, 74],
                [0, 128, 75],
                [0, 129, 76],
                [0, 131, 77],
                [0, 132, 78],
                [0, 134, 79],
                [0, 135, 80],
                [0, 136, 81],
                [0, 138, 82],
                [0, 139, 83],
                [0, 140, 84],
                [0, 142, 85],
                [0, 143, 86],
                [0, 144, 87],
                [0, 146, 88],
                [0, 147, 89],
                [0, 148, 90],
                [0, 150, 91],
                [0, 151, 92],
                [0, 152, 93],
                [0, 153, 94],
                [0, 155, 95],
                [0, 156, 96],
                [0, 157, 97],
                [0, 158, 98],
                [0, 160, 99],
                [0, 161, 100],
                [0, 162, 101],
                [0, 163, 102],
                [0, 164, 103],
                [0, 166, 104],
                [0, 167, 105],
                [0, 168, 106],
                [0, 169, 107],
                [0, 170, 108],
                [0, 171, 109],
                [0, 173, 110],
                [0, 174, 111],
                [0, 175, 112],
                [0, 176, 113],
                [0, 177, 114],
                [0, 178, 115],
                [0, 179, 116],
                [0, 180, 117],
                [0, 181, 118],
                [0, 182, 119],
                [0, 184, 120],
                [0, 185, 121],
                [0, 186, 122],
                [0, 187, 123],
                [0, 188, 124],
                [0, 189, 125],
                [0, 190, 126],
                [0, 191, 127],
                [0, 192, 128],
                [0, 193, 129],
                [0, 194, 130],
                [0, 195, 131],
                [0, 196, 132],
                [0, 197, 133],
                [0, 198, 134],
                [0, 199, 135],
                [0, 199, 136],
                [0, 200, 137],
                [0, 201, 138],
                [0, 202, 139],
                [0, 203, 140],
                [0, 204, 141],
                [0, 205, 142],
                [0, 206, 143],
                [0, 207, 144],
                [0, 208, 145],
                [0, 208, 146],
                [0, 209, 147],
                [0, 210, 148],
                [0, 211, 149],
                [0, 212, 150],
                [0, 213, 151],
                [0, 213, 152],
                [0, 214, 153],
                [0, 215, 154],
                [0, 216, 155],
                [0, 217, 156],
                [0, 217, 157],
                [0, 218, 158],
                [0, 219, 159],
                [0, 220, 160],
                [0, 220, 161],
                [0, 221, 162],
                [0, 222, 163],
                [0, 223, 164],
                [0, 223, 165],
                [0, 224, 166],
                [0, 225, 167],
                [0, 225, 168],
                [0, 226, 169],
                [0, 227, 170],
                [0, 227, 171],
                [0, 228, 172],
                [0, 229, 173],
                [0, 229, 174],
                [0, 230, 175],
                [0, 231, 176],
                [0, 231, 177],
                [0, 232, 178],
                [0, 232, 179],
                [0, 233, 180],
                [0, 234, 181],
                [0, 234, 182],
                [0, 235, 183],
                [0, 235, 184],
                [0, 236, 185],
                [0, 236, 186],
                [0, 237, 187],
                [0, 237, 188],
                [0, 238, 189],
                [0, 238, 190],
                [0, 239, 191],
                [0, 239, 192],
                [0, 240, 193],
                [0, 240, 194],
                [0, 241, 195],
                [0, 241, 196],
                [0, 242, 197],
                [0, 242, 198],
                [0, 243, 199],
                [0, 243, 200],
                [0, 244, 201],
                [0, 244, 202],
                [0, 244, 203],
                [0, 245, 204],
                [0, 245, 205],
                [0, 246, 206],
                [0, 246, 207],
                [0, 246, 208],
                [0, 247, 209],
                [0, 247, 210],
                [0, 247, 211],
                [0, 248, 212],
                [0, 248, 213],
                [0, 248, 214],
                [0, 249, 215],
                [0, 249, 216],
                [0, 249, 217],
                [0, 250, 218],
                [0, 250, 219],
                [0, 250, 220],
                [0, 250, 221],
                [0, 251, 222],
                [0, 251, 223],
                [0, 251, 224],
                [0, 251, 225],
                [0, 252, 226],
                [0, 252, 227],
                [0, 252, 228],
                [0, 252, 229],
                [0, 253, 230],
                [0, 253, 231],
                [0, 253, 232],
                [0, 253, 233],
                [0, 253, 234],
                [0, 253, 235],
                [0, 254, 236],
                [0, 254, 237],
                [0, 254, 238],
                [0, 254, 239],
                [0, 254, 240],
                [0, 254, 241],
                [0, 254, 242],
                [0, 254, 243],
                [0, 255, 244],
                [0, 255, 245],
                [0, 255, 246],
                [0, 255, 247],
                [0, 255, 248],
                [0, 255, 249],
                [0, 255, 250],
                [0, 255, 251],
                [0, 255, 252],
                [0, 255, 253],
                [0, 255, 254],
                [0, 255, 255],
            ],
        );

        m.insert(
            "Duo Purple",
            [
                [0, 0, 0],
                [1, 0, 2],
                [2, 0, 4],
                [3, 0, 6],
                [4, 0, 8],
                [5, 0, 10],
                [6, 0, 12],
                [7, 0, 14],
                [8, 0, 16],
                [9, 0, 18],
                [10, 0, 20],
                [11, 0, 22],
                [12, 0, 23],
                [13, 0, 25],
                [14, 0, 27],
                [15, 0, 29],
                [16, 0, 31],
                [17, 0, 33],
                [18, 0, 35],
                [19, 0, 37],
                [20, 0, 38],
                [21, 0, 40],
                [22, 0, 42],
                [23, 0, 44],
                [24, 0, 46],
                [25, 0, 48],
                [26, 0, 49],
                [27, 0, 51],
                [28, 0, 53],
                [29, 0, 55],
                [30, 0, 56],
                [31, 0, 58],
                [32, 0, 60],
                [33, 0, 62],
                [34, 0, 63],
                [35, 0, 65],
                [36, 0, 67],
                [37, 0, 69],
                [38, 0, 70],
                [39, 0, 72],
                [40, 0, 74],
                [41, 0, 75],
                [42, 0, 77],
                [43, 0, 79],
                [44, 0, 80],
                [45, 0, 82],
                [46, 0, 84],
                [47, 0, 85],
                [48, 0, 87],
                [49, 0, 89],
                [50, 0, 90],
                [51, 0, 92],
                [52, 0, 93],
                [53, 0, 95],
                [54, 0, 97],
                [55, 0, 98],
                [56, 0, 100],
                [57, 0, 101],
                [58, 0, 103],
                [59, 0, 104],
                [60, 0, 106],
                [61, 0, 107],
                [62, 0, 109],
                [63, 0, 110],
                [64, 0, 112],
                [65, 0, 113],
                [66, 0, 115],
                [67, 0, 116],
                [68, 0, 118],
                [69, 0, 119],
                [70, 0, 121],
                [71, 0, 122],
                [72, 0, 124],
                [73, 0, 125],
                [74, 0, 127],
                [75, 0, 128],
                [76, 0, 129],
                [77, 0, 131],
                [78, 0, 132],
                [79, 0, 134],
                [80, 0, 135],
                [81, 0, 136],
                [82, 0, 138],
                [83, 0, 139],
                [84, 0, 140],
                [85, 0, 142],
                [86, 0, 143],
                [87, 0, 144],
                [88, 0, 146],
                [89, 0, 147],
                [90, 0, 148],
                [91, 0, 150],
                [92, 0, 151],
                [93, 0, 152],
                [94, 0, 153],
                [95, 0, 155],
                [96, 0, 156],
                [97, 0, 157],
                [98, 0, 158],
                [99, 0, 160],
                [100, 0, 161],
                [101, 0, 162],
                [102, 0, 163],
                [103, 0, 164],
                [104, 0, 166],
                [105, 0, 167],
                [106, 0, 168],
                [107, 0, 169],
                [108, 0, 170],
                [109, 0, 171],
                [110, 0, 173],
                [111, 0, 174],
                [112, 0, 175],
                [113, 0, 176],
                [114, 0, 177],
                [115, 0, 178],
                [116, 0, 179],
                [117, 0, 180],
                [118, 0, 181],
                [119, 0, 182],
                [120, 0, 184],
                [121, 0, 185],
                [122, 0, 186],
                [123, 0, 187],
                [124, 0, 188],
                [125, 0, 189],
                [126, 0, 190],
                [127, 0, 191],
                [128, 0, 192],
                [129, 0, 193],
                [130, 0, 194],
                [131, 0, 195],
                [132, 0, 196],
                [133, 0, 197],
                [134, 0, 198],
                [135, 0, 199],
                [136, 0, 199],
                [137, 0, 200],
                [138, 0, 201],
                [139, 0, 202],
                [140, 0, 203],
                [141, 0, 204],
                [142, 0, 205],
                [143, 0, 206],
                [144, 0, 207],
                [145, 0, 208],
                [146, 0, 208],
                [147, 0, 209],
                [148, 0, 210],
                [149, 0, 211],
                [150, 0, 212],
                [151, 0, 213],
                [152, 0, 213],
                [153, 0, 214],
                [154, 0, 215],
                [155, 0, 216],
                [156, 0, 217],
                [157, 0, 217],
                [158, 0, 218],
                [159, 0, 219],
                [160, 0, 220],
                [161, 0, 220],
                [162, 0, 221],
                [163, 0, 222],
                [164, 0, 223],
                [165, 0, 223],
                [166, 0, 224],
                [167, 0, 225],
                [168, 0, 225],
                [169, 0, 226],
                [170, 0, 227],
                [171, 0, 227],
                [172, 0, 228],
                [173, 0, 229],
                [174, 0, 229],
                [175, 0, 230],
                [176, 0, 231],
                [177, 0, 231],
                [178, 0, 232],
                [179, 0, 232],
                [180, 0, 233],
                [181, 0, 234],
                [182, 0, 234],
                [183, 0, 235],
                [184, 0, 235],
                [185, 0, 236],
                [186, 0, 236],
                [187, 0, 237],
                [188, 0, 237],
                [189, 0, 238],
                [190, 0, 238],
                [191, 0, 239],
                [192, 0, 239],
                [193, 0, 240],
                [194, 0, 240],
                [195, 0, 241],
                [196, 0, 241],
                [197, 0, 242],
                [198, 0, 242],
                [199, 0, 243],
                [200, 0, 243],
                [201, 0, 244],
                [202, 0, 244],
                [203, 0, 244],
                [204, 0, 245],
                [205, 0, 245],
                [206, 0, 246],
                [207, 0, 246],
                [208, 0, 246],
                [209, 0, 247],
                [210, 0, 247],
                [211, 0, 247],
                [212, 0, 248],
                [213, 0, 248],
                [214, 0, 248],
                [215, 0, 249],
                [216, 0, 249],
                [217, 0, 249],
                [218, 0, 250],
                [219, 0, 250],
                [220, 0, 250],
                [221, 0, 250],
                [222, 0, 251],
                [223, 0, 251],
                [224, 0, 251],
                [225, 0, 251],
                [226, 0, 252],
                [227, 0, 252],
                [228, 0, 252],
                [229, 0, 252],
                [230, 0, 253],
                [231, 0, 253],
                [232, 0, 253],
                [233, 0, 253],
                [234, 0, 253],
                [235, 0, 253],
                [236, 0, 254],
                [237, 0, 254],
                [238, 0, 254],
                [239, 0, 254],
                [240, 0, 254],
                [241, 0, 254],
                [242, 0, 254],
                [243, 0, 254],
                [244, 0, 255],
                [245, 0, 255],
                [246, 0, 255],
                [247, 0, 255],
                [248, 0, 255],
                [249, 0, 255],
                [250, 0, 255],
                [251, 0, 255],
                [252, 0, 255],
                [253, 0, 255],
                [254, 0, 255],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Duo Yellow",
            [
                [0, 0, 0],
                [2, 1, 0],
                [4, 2, 0],
                [6, 3, 0],
                [8, 4, 0],
                [10, 5, 0],
                [12, 6, 0],
                [14, 7, 0],
                [16, 8, 0],
                [18, 9, 0],
                [20, 10, 0],
                [22, 11, 0],
                [23, 12, 0],
                [25, 13, 0],
                [27, 14, 0],
                [29, 15, 0],
                [31, 16, 0],
                [33, 17, 0],
                [35, 18, 0],
                [37, 19, 0],
                [38, 20, 0],
                [40, 21, 0],
                [42, 22, 0],
                [44, 23, 0],
                [46, 24, 0],
                [48, 25, 0],
                [49, 26, 0],
                [51, 27, 0],
                [53, 28, 0],
                [55, 29, 0],
                [56, 30, 0],
                [58, 31, 0],
                [60, 32, 0],
                [62, 33, 0],
                [63, 34, 0],
                [65, 35, 0],
                [67, 36, 0],
                [69, 37, 0],
                [70, 38, 0],
                [72, 39, 0],
                [74, 40, 0],
                [75, 41, 0],
                [77, 42, 0],
                [79, 43, 0],
                [80, 44, 0],
                [82, 45, 0],
                [84, 46, 0],
                [85, 47, 0],
                [87, 48, 0],
                [89, 49, 0],
                [90, 50, 0],
                [92, 51, 0],
                [93, 52, 0],
                [95, 53, 0],
                [97, 54, 0],
                [98, 55, 0],
                [100, 56, 0],
                [101, 57, 0],
                [103, 58, 0],
                [104, 59, 0],
                [106, 60, 0],
                [107, 61, 0],
                [109, 62, 0],
                [110, 63, 0],
                [112, 64, 0],
                [113, 65, 0],
                [115, 66, 0],
                [116, 67, 0],
                [118, 68, 0],
                [119, 69, 0],
                [121, 70, 0],
                [122, 71, 0],
                [124, 72, 0],
                [125, 73, 0],
                [127, 74, 0],
                [128, 75, 0],
                [129, 76, 0],
                [131, 77, 0],
                [132, 78, 0],
                [134, 79, 0],
                [135, 80, 0],
                [136, 81, 0],
                [138, 82, 0],
                [139, 83, 0],
                [140, 84, 0],
                [142, 85, 0],
                [143, 86, 0],
                [144, 87, 0],
                [146, 88, 0],
                [147, 89, 0],
                [148, 90, 0],
                [150, 91, 0],
                [151, 92, 0],
                [152, 93, 0],
                [153, 94, 0],
                [155, 95, 0],
                [156, 96, 0],
                [157, 97, 0],
                [158, 98, 0],
                [160, 99, 0],
                [161, 100, 0],
                [162, 101, 0],
                [163, 102, 0],
                [164, 103, 0],
                [166, 104, 0],
                [167, 105, 0],
                [168, 106, 0],
                [169, 107, 0],
                [170, 108, 0],
                [171, 109, 0],
                [173, 110, 0],
                [174, 111, 0],
                [175, 112, 0],
                [176, 113, 0],
                [177, 114, 0],
                [178, 115, 0],
                [179, 116, 0],
                [180, 117, 0],
                [181, 118, 0],
                [182, 119, 0],
                [184, 120, 0],
                [185, 121, 0],
                [186, 122, 0],
                [187, 123, 0],
                [188, 124, 0],
                [189, 125, 0],
                [190, 126, 0],
                [191, 127, 0],
                [192, 128, 0],
                [193, 129, 0],
                [194, 130, 0],
                [195, 131, 0],
                [196, 132, 0],
                [197, 133, 0],
                [198, 134, 0],
                [199, 135, 0],
                [199, 136, 0],
                [200, 137, 0],
                [201, 138, 0],
                [202, 139, 0],
                [203, 140, 0],
                [204, 141, 0],
                [205, 142, 0],
                [206, 143, 0],
                [207, 144, 0],
                [208, 145, 0],
                [208, 146, 0],
                [209, 147, 0],
                [210, 148, 0],
                [211, 149, 0],
                [212, 150, 0],
                [213, 151, 0],
                [213, 152, 0],
                [214, 153, 0],
                [215, 154, 0],
                [216, 155, 0],
                [217, 156, 0],
                [217, 157, 0],
                [218, 158, 0],
                [219, 159, 0],
                [220, 160, 0],
                [220, 161, 0],
                [221, 162, 0],
                [222, 163, 0],
                [223, 164, 0],
                [223, 165, 0],
                [224, 166, 0],
                [225, 167, 0],
                [225, 168, 0],
                [226, 169, 0],
                [227, 170, 0],
                [227, 171, 0],
                [228, 172, 0],
                [229, 173, 0],
                [229, 174, 0],
                [230, 175, 0],
                [231, 176, 0],
                [231, 177, 0],
                [232, 178, 0],
                [232, 179, 0],
                [233, 180, 0],
                [234, 181, 0],
                [234, 182, 0],
                [235, 183, 0],
                [235, 184, 0],
                [236, 185, 0],
                [236, 186, 0],
                [237, 187, 0],
                [237, 188, 0],
                [238, 189, 0],
                [238, 190, 0],
                [239, 191, 0],
                [239, 192, 0],
                [240, 193, 0],
                [240, 194, 0],
                [241, 195, 0],
                [241, 196, 0],
                [242, 197, 0],
                [242, 198, 0],
                [243, 199, 0],
                [243, 200, 0],
                [244, 201, 0],
                [244, 202, 0],
                [244, 203, 0],
                [245, 204, 0],
                [245, 205, 0],
                [246, 206, 0],
                [246, 207, 0],
                [246, 208, 0],
                [247, 209, 0],
                [247, 210, 0],
                [247, 211, 0],
                [248, 212, 0],
                [248, 213, 0],
                [248, 214, 0],
                [249, 215, 0],
                [249, 216, 0],
                [249, 217, 0],
                [250, 218, 0],
                [250, 219, 0],
                [250, 220, 0],
                [250, 221, 0],
                [251, 222, 0],
                [251, 223, 0],
                [251, 224, 0],
                [251, 225, 0],
                [252, 226, 0],
                [252, 227, 0],
                [252, 228, 0],
                [252, 229, 0],
                [253, 230, 0],
                [253, 231, 0],
                [253, 232, 0],
                [253, 233, 0],
                [253, 234, 0],
                [253, 235, 0],
                [254, 236, 0],
                [254, 237, 0],
                [254, 238, 0],
                [254, 239, 0],
                [254, 240, 0],
                [254, 241, 0],
                [254, 242, 0],
                [254, 243, 0],
                [255, 244, 0],
                [255, 245, 0],
                [255, 246, 0],
                [255, 247, 0],
                [255, 248, 0],
                [255, 249, 0],
                [255, 250, 0],
                [255, 251, 0],
                [255, 252, 0],
                [255, 253, 0],
                [255, 254, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "Fire",
            [
                [0, 0, 0],
                [0, 0, 7],
                [0, 0, 15],
                [0, 0, 22],
                [0, 0, 30],
                [0, 0, 38],
                [0, 0, 45],
                [0, 0, 53],
                [0, 0, 61],
                [0, 0, 65],
                [0, 0, 69],
                [0, 0, 74],
                [0, 0, 78],
                [0, 0, 82],
                [0, 0, 87],
                [0, 0, 91],
                [1, 0, 96],
                [4, 0, 100],
                [7, 0, 104],
                [10, 0, 108],
                [13, 0, 113],
                [16, 0, 117],
                [19, 0, 121],
                [22, 0, 125],
                [25, 0, 130],
                [28, 0, 134],
                [31, 0, 138],
                [34, 0, 143],
                [37, 0, 147],
                [40, 0, 151],
                [43, 0, 156],
                [46, 0, 160],
                [49, 0, 165],
                [52, 0, 168],
                [55, 0, 171],
                [58, 0, 175],
                [61, 0, 178],
                [64, 0, 181],
                [67, 0, 185],
                [70, 0, 188],
                [73, 0, 192],
                [76, 0, 195],
                [79, 0, 199],
                [82, 0, 202],
                [85, 0, 206],
                [88, 0, 209],
                [91, 0, 213],
                [94, 0, 216],
                [98, 0, 220],
                [101, 0, 220],
                [104, 0, 221],
                [107, 0, 222],
                [110, 0, 223],
                [113, 0, 224],
                [116, 0, 225],
                [119, 0, 226],
                [122, 0, 227],
                [125, 0, 224],
                [128, 0, 222],
                [131, 0, 220],
                [134, 0, 218],
                [137, 0, 216],
                [140, 0, 214],
                [143, 0, 212],
                [146, 0, 210],
                [148, 0, 206],
                [150, 0, 202],
                [152, 0, 199],
                [154, 0, 195],
                [156, 0, 191],
                [158, 0, 188],
                [160, 0, 184],
                [162, 0, 181],
                [163, 0, 177],
                [164, 0, 173],
                [166, 0, 169],
                [167, 0, 166],
                [168, 0, 162],
                [170, 0, 158],
                [171, 0, 154],
                [173, 0, 151],
                [174, 0, 147],
                [175, 0, 143],
                [177, 0, 140],
                [178, 0, 136],
                [179, 0, 132],
                [181, 0, 129],
                [182, 0, 125],
                [184, 0, 122],
                [185, 0, 118],
                [186, 0, 114],
                [188, 0, 111],
                [189, 0, 107],
                [190, 0, 103],
                [192, 0, 100],
                [193, 0, 96],
                [195, 0, 93],
                [196, 1, 89],
                [198, 3, 85],
                [199, 5, 82],
                [201, 7, 78],
                [202, 8, 74],
                [204, 10, 71],
                [205, 12, 67],
                [207, 14, 64],
                [208, 16, 60],
                [209, 19, 56],
                [210, 21, 53],
                [212, 24, 49],
                [213, 27, 45],
                [214, 29, 42],
                [215, 32, 38],
                [217, 35, 35],
                [218, 37, 31],
                [220, 40, 27],
                [221, 43, 23],
                [223, 46, 20],
                [224, 48, 16],
                [226, 51, 12],
                [227, 54, 8],
                [229, 57, 5],
                [230, 59, 4],
                [231, 62, 3],
                [233, 65, 3],
                [234, 68, 2],
                [235, 70, 1],
                [237, 73, 1],
                [238, 76, 0],
                [240, 79, 0],
                [241, 81, 0],
                [243, 84, 0],
                [244, 87, 0],
                [246, 90, 0],
                [247, 92, 0],
                [249, 95, 0],
                [250, 98, 0],
                [252, 101, 0],
                [252, 103, 0],
                [252, 105, 0],
                [253, 107, 0],
                [253, 109, 0],
                [253, 111, 0],
                [254, 113, 0],
                [254, 115, 0],
                [255, 117, 0],
                [255, 119, 0],
                [255, 121, 0],
                [255, 123, 0],
                [255, 125, 0],
                [255, 127, 0],
                [255, 129, 0],
                [255, 131, 0],
                [255, 133, 0],
                [255, 134, 0],
                [255, 136, 0],
                [255, 138, 0],
                [255, 140, 0],
                [255, 141, 0],
                [255, 143, 0],
                [255, 145, 0],
                [255, 147, 0],
                [255, 148, 0],
                [255, 150, 0],
                [255, 152, 0],
                [255, 154, 0],
                [255, 155, 0],
                [255, 157, 0],
                [255, 159, 0],
                [255, 161, 0],
                [255, 162, 0],
                [255, 164, 0],
                [255, 166, 0],
                [255, 168, 0],
                [255, 169, 0],
                [255, 171, 0],
                [255, 173, 0],
                [255, 175, 0],
                [255, 176, 0],
                [255, 178, 0],
                [255, 180, 0],
                [255, 182, 0],
                [255, 184, 0],
                [255, 186, 0],
                [255, 188, 0],
                [255, 190, 0],
                [255, 191, 0],
                [255, 193, 0],
                [255, 195, 0],
                [255, 197, 0],
                [255, 199, 0],
                [255, 201, 0],
                [255, 203, 0],
                [255, 205, 0],
                [255, 206, 0],
                [255, 208, 0],
                [255, 210, 0],
                [255, 212, 0],
                [255, 213, 0],
                [255, 215, 0],
                [255, 217, 0],
                [255, 219, 0],
                [255, 220, 0],
                [255, 222, 0],
                [255, 224, 0],
                [255, 226, 0],
                [255, 228, 0],
                [255, 230, 0],
                [255, 232, 0],
                [255, 234, 0],
                [255, 235, 4],
                [255, 237, 8],
                [255, 239, 13],
                [255, 241, 17],
                [255, 242, 21],
                [255, 244, 26],
                [255, 246, 30],
                [255, 248, 35],
                [255, 248, 42],
                [255, 249, 50],
                [255, 250, 58],
                [255, 251, 66],
                [255, 252, 74],
                [255, 253, 82],
                [255, 254, 90],
                [255, 255, 98],
                [255, 255, 105],
                [255, 255, 113],
                [255, 255, 121],
                [255, 255, 129],
                [255, 255, 136],
                [255, 255, 144],
                [255, 255, 152],
                [255, 255, 160],
                [255, 255, 167],
                [255, 255, 175],
                [255, 255, 183],
                [255, 255, 191],
                [255, 255, 199],
                [255, 255, 207],
                [255, 255, 215],
                [255, 255, 223],
                [255, 255, 227],
                [255, 255, 231],
                [255, 255, 235],
                [255, 255, 239],
                [255, 255, 243],
                [255, 255, 247],
                [255, 255, 251],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays",
            [
                [0, 0, 0],
                [1, 1, 1],
                [2, 2, 2],
                [3, 3, 3],
                [4, 4, 4],
                [5, 5, 5],
                [6, 6, 6],
                [7, 7, 7],
                [8, 8, 8],
                [9, 9, 9],
                [10, 10, 10],
                [11, 11, 11],
                [12, 12, 12],
                [13, 13, 13],
                [14, 14, 14],
                [15, 15, 15],
                [16, 16, 16],
                [17, 17, 17],
                [18, 18, 18],
                [19, 19, 19],
                [20, 20, 20],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [24, 24, 24],
                [25, 25, 25],
                [26, 26, 26],
                [27, 27, 27],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [31, 31, 31],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [91, 91, 91],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [101, 101, 101],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [120, 120, 120],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [125, 125, 125],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [131, 131, 131],
                [132, 132, 132],
                [133, 133, 133],
                [134, 134, 134],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [148, 148, 148],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [153, 153, 153],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [161, 161, 161],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [170, 170, 170],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [179, 179, 179],
                [180, 180, 180],
                [181, 181, 181],
                [182, 182, 182],
                [183, 183, 183],
                [184, 184, 184],
                [185, 185, 185],
                [186, 186, 186],
                [187, 187, 187],
                [188, 188, 188],
                [189, 189, 189],
                [190, 190, 190],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [194, 194, 194],
                [195, 195, 195],
                [196, 196, 196],
                [197, 197, 197],
                [198, 198, 198],
                [199, 199, 199],
                [200, 200, 200],
                [201, 201, 201],
                [202, 202, 202],
                [203, 203, 203],
                [204, 204, 204],
                [205, 205, 205],
                [206, 206, 206],
                [207, 207, 207],
                [208, 208, 208],
                [209, 209, 209],
                [210, 210, 210],
                [211, 211, 211],
                [212, 212, 212],
                [213, 213, 213],
                [214, 214, 214],
                [215, 215, 215],
                [216, 216, 216],
                [217, 217, 217],
                [218, 218, 218],
                [219, 219, 219],
                [220, 220, 220],
                [221, 221, 221],
                [222, 222, 222],
                [223, 223, 223],
                [224, 224, 224],
                [225, 225, 225],
                [226, 226, 226],
                [227, 227, 227],
                [228, 228, 228],
                [229, 229, 229],
                [230, 230, 230],
                [231, 231, 231],
                [232, 232, 232],
                [233, 233, 233],
                [234, 234, 234],
                [235, 235, 235],
                [236, 236, 236],
                [237, 237, 237],
                [238, 238, 238],
                [239, 239, 239],
                [240, 240, 240],
                [241, 241, 241],
                [242, 242, 242],
                [243, 243, 243],
                [244, 244, 244],
                [245, 245, 245],
                [246, 246, 246],
                [247, 247, 247],
                [248, 248, 248],
                [249, 249, 249],
                [250, 250, 250],
                [251, 251, 251],
                [252, 252, 252],
                [253, 253, 253],
                [254, 254, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=0.25",
            [
                [0, 0, 0],
                [64, 64, 64],
                [76, 76, 76],
                [84, 84, 84],
                [90, 90, 90],
                [95, 95, 95],
                [100, 100, 100],
                [104, 104, 104],
                [107, 107, 107],
                [111, 111, 111],
                [113, 113, 113],
                [116, 116, 116],
                [119, 119, 119],
                [121, 121, 121],
                [123, 123, 123],
                [126, 126, 126],
                [128, 128, 128],
                [130, 130, 130],
                [131, 131, 131],
                [133, 133, 133],
                [135, 135, 135],
                [137, 137, 137],
                [138, 138, 138],
                [140, 140, 140],
                [141, 141, 141],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [147, 147, 147],
                [148, 148, 148],
                [149, 149, 149],
                [151, 151, 151],
                [152, 152, 152],
                [153, 153, 153],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [161, 161, 161],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [170, 170, 170],
                [171, 171, 171],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [175, 175, 175],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [178, 178, 178],
                [179, 179, 179],
                [180, 180, 180],
                [180, 180, 180],
                [181, 181, 181],
                [182, 182, 182],
                [183, 183, 183],
                [183, 183, 183],
                [184, 184, 184],
                [185, 185, 185],
                [185, 185, 185],
                [186, 186, 186],
                [187, 187, 187],
                [187, 187, 187],
                [188, 188, 188],
                [188, 188, 188],
                [189, 189, 189],
                [190, 190, 190],
                [190, 190, 190],
                [191, 191, 191],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [193, 193, 193],
                [194, 194, 194],
                [194, 194, 194],
                [195, 195, 195],
                [195, 195, 195],
                [196, 196, 196],
                [197, 197, 197],
                [197, 197, 197],
                [198, 198, 198],
                [198, 198, 198],
                [199, 199, 199],
                [199, 199, 199],
                [200, 200, 200],
                [200, 200, 200],
                [201, 201, 201],
                [201, 201, 201],
                [202, 202, 202],
                [202, 202, 202],
                [203, 203, 203],
                [203, 203, 203],
                [204, 204, 204],
                [204, 204, 204],
                [205, 205, 205],
                [205, 205, 205],
                [206, 206, 206],
                [206, 206, 206],
                [207, 207, 207],
                [207, 207, 207],
                [208, 208, 208],
                [208, 208, 208],
                [209, 209, 209],
                [209, 209, 209],
                [209, 209, 209],
                [210, 210, 210],
                [210, 210, 210],
                [211, 211, 211],
                [211, 211, 211],
                [212, 212, 212],
                [212, 212, 212],
                [213, 213, 213],
                [213, 213, 213],
                [213, 213, 213],
                [214, 214, 214],
                [214, 214, 214],
                [215, 215, 215],
                [215, 215, 215],
                [215, 215, 215],
                [216, 216, 216],
                [216, 216, 216],
                [217, 217, 217],
                [217, 217, 217],
                [218, 218, 218],
                [218, 218, 218],
                [218, 218, 218],
                [219, 219, 219],
                [219, 219, 219],
                [220, 220, 220],
                [220, 220, 220],
                [220, 220, 220],
                [221, 221, 221],
                [221, 221, 221],
                [221, 221, 221],
                [222, 222, 222],
                [222, 222, 222],
                [223, 223, 223],
                [223, 223, 223],
                [223, 223, 223],
                [224, 224, 224],
                [224, 224, 224],
                [224, 224, 224],
                [225, 225, 225],
                [225, 225, 225],
                [226, 226, 226],
                [226, 226, 226],
                [226, 226, 226],
                [227, 227, 227],
                [227, 227, 227],
                [227, 227, 227],
                [228, 228, 228],
                [228, 228, 228],
                [228, 228, 228],
                [229, 229, 229],
                [229, 229, 229],
                [229, 229, 229],
                [230, 230, 230],
                [230, 230, 230],
                [230, 230, 230],
                [231, 231, 231],
                [231, 231, 231],
                [231, 231, 231],
                [232, 232, 232],
                [232, 232, 232],
                [232, 232, 232],
                [233, 233, 233],
                [233, 233, 233],
                [233, 233, 233],
                [234, 234, 234],
                [234, 234, 234],
                [234, 234, 234],
                [235, 235, 235],
                [235, 235, 235],
                [235, 235, 235],
                [236, 236, 236],
                [236, 236, 236],
                [236, 236, 236],
                [237, 237, 237],
                [237, 237, 237],
                [237, 237, 237],
                [238, 238, 238],
                [238, 238, 238],
                [238, 238, 238],
                [238, 238, 238],
                [239, 239, 239],
                [239, 239, 239],
                [239, 239, 239],
                [240, 240, 240],
                [240, 240, 240],
                [240, 240, 240],
                [241, 241, 241],
                [241, 241, 241],
                [241, 241, 241],
                [241, 241, 241],
                [242, 242, 242],
                [242, 242, 242],
                [242, 242, 242],
                [243, 243, 243],
                [243, 243, 243],
                [243, 243, 243],
                [243, 243, 243],
                [244, 244, 244],
                [244, 244, 244],
                [244, 244, 244],
                [245, 245, 245],
                [245, 245, 245],
                [245, 245, 245],
                [245, 245, 245],
                [246, 246, 246],
                [246, 246, 246],
                [246, 246, 246],
                [247, 247, 247],
                [247, 247, 247],
                [247, 247, 247],
                [247, 247, 247],
                [248, 248, 248],
                [248, 248, 248],
                [248, 248, 248],
                [249, 249, 249],
                [249, 249, 249],
                [249, 249, 249],
                [249, 249, 249],
                [250, 250, 250],
                [250, 250, 250],
                [250, 250, 250],
                [250, 250, 250],
                [251, 251, 251],
                [251, 251, 251],
                [251, 251, 251],
                [251, 251, 251],
                [252, 252, 252],
                [252, 252, 252],
                [252, 252, 252],
                [252, 252, 252],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [255, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=0.25 inverted",
            [
                [255, 255, 255],
                [255, 255, 255],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [252, 252, 252],
                [252, 252, 252],
                [252, 252, 252],
                [252, 252, 252],
                [251, 251, 251],
                [251, 251, 251],
                [251, 251, 251],
                [251, 251, 251],
                [250, 250, 250],
                [250, 250, 250],
                [250, 250, 250],
                [250, 250, 250],
                [249, 249, 249],
                [249, 249, 249],
                [249, 249, 249],
                [249, 249, 249],
                [248, 248, 248],
                [248, 248, 248],
                [248, 248, 248],
                [247, 247, 247],
                [247, 247, 247],
                [247, 247, 247],
                [247, 247, 247],
                [246, 246, 246],
                [246, 246, 246],
                [246, 246, 246],
                [245, 245, 245],
                [245, 245, 245],
                [245, 245, 245],
                [245, 245, 245],
                [244, 244, 244],
                [244, 244, 244],
                [244, 244, 244],
                [243, 243, 243],
                [243, 243, 243],
                [243, 243, 243],
                [243, 243, 243],
                [242, 242, 242],
                [242, 242, 242],
                [242, 242, 242],
                [241, 241, 241],
                [241, 241, 241],
                [241, 241, 241],
                [241, 241, 241],
                [240, 240, 240],
                [240, 240, 240],
                [240, 240, 240],
                [239, 239, 239],
                [239, 239, 239],
                [239, 239, 239],
                [238, 238, 238],
                [238, 238, 238],
                [238, 238, 238],
                [238, 238, 238],
                [237, 237, 237],
                [237, 237, 237],
                [237, 237, 237],
                [236, 236, 236],
                [236, 236, 236],
                [236, 236, 236],
                [235, 235, 235],
                [235, 235, 235],
                [235, 235, 235],
                [234, 234, 234],
                [234, 234, 234],
                [234, 234, 234],
                [233, 233, 233],
                [233, 233, 233],
                [233, 233, 233],
                [232, 232, 232],
                [232, 232, 232],
                [232, 232, 232],
                [231, 231, 231],
                [231, 231, 231],
                [231, 231, 231],
                [230, 230, 230],
                [230, 230, 230],
                [230, 230, 230],
                [229, 229, 229],
                [229, 229, 229],
                [229, 229, 229],
                [228, 228, 228],
                [228, 228, 228],
                [228, 228, 228],
                [227, 227, 227],
                [227, 227, 227],
                [227, 227, 227],
                [226, 226, 226],
                [226, 226, 226],
                [226, 226, 226],
                [225, 225, 225],
                [225, 225, 225],
                [224, 224, 224],
                [224, 224, 224],
                [224, 224, 224],
                [223, 223, 223],
                [223, 223, 223],
                [223, 223, 223],
                [222, 222, 222],
                [222, 222, 222],
                [221, 221, 221],
                [221, 221, 221],
                [221, 221, 221],
                [220, 220, 220],
                [220, 220, 220],
                [220, 220, 220],
                [219, 219, 219],
                [219, 219, 219],
                [218, 218, 218],
                [218, 218, 218],
                [218, 218, 218],
                [217, 217, 217],
                [217, 217, 217],
                [216, 216, 216],
                [216, 216, 216],
                [215, 215, 215],
                [215, 215, 215],
                [215, 215, 215],
                [214, 214, 214],
                [214, 214, 214],
                [213, 213, 213],
                [213, 213, 213],
                [213, 213, 213],
                [212, 212, 212],
                [212, 212, 212],
                [211, 211, 211],
                [211, 211, 211],
                [210, 210, 210],
                [210, 210, 210],
                [209, 209, 209],
                [209, 209, 209],
                [209, 209, 209],
                [208, 208, 208],
                [208, 208, 208],
                [207, 207, 207],
                [207, 207, 207],
                [206, 206, 206],
                [206, 206, 206],
                [205, 205, 205],
                [205, 205, 205],
                [204, 204, 204],
                [204, 204, 204],
                [203, 203, 203],
                [203, 203, 203],
                [202, 202, 202],
                [202, 202, 202],
                [201, 201, 201],
                [201, 201, 201],
                [200, 200, 200],
                [200, 200, 200],
                [199, 199, 199],
                [199, 199, 199],
                [198, 198, 198],
                [198, 198, 198],
                [197, 197, 197],
                [197, 197, 197],
                [196, 196, 196],
                [195, 195, 195],
                [195, 195, 195],
                [194, 194, 194],
                [194, 194, 194],
                [193, 193, 193],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [191, 191, 191],
                [190, 190, 190],
                [190, 190, 190],
                [189, 189, 189],
                [188, 188, 188],
                [188, 188, 188],
                [187, 187, 187],
                [187, 187, 187],
                [186, 186, 186],
                [185, 185, 185],
                [185, 185, 185],
                [184, 184, 184],
                [183, 183, 183],
                [183, 183, 183],
                [182, 182, 182],
                [181, 181, 181],
                [180, 180, 180],
                [180, 180, 180],
                [179, 179, 179],
                [178, 178, 178],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [175, 175, 175],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [171, 171, 171],
                [170, 170, 170],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [161, 161, 161],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [153, 153, 153],
                [152, 152, 152],
                [151, 151, 151],
                [149, 149, 149],
                [148, 148, 148],
                [147, 147, 147],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [141, 141, 141],
                [140, 140, 140],
                [138, 138, 138],
                [137, 137, 137],
                [135, 135, 135],
                [133, 133, 133],
                [131, 131, 131],
                [130, 130, 130],
                [128, 128, 128],
                [126, 126, 126],
                [123, 123, 123],
                [121, 121, 121],
                [119, 119, 119],
                [116, 116, 116],
                [113, 113, 113],
                [111, 111, 111],
                [107, 107, 107],
                [104, 104, 104],
                [100, 100, 100],
                [95, 95, 95],
                [90, 90, 90],
                [84, 84, 84],
                [76, 76, 76],
                [64, 64, 64],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=0.50",
            [
                [0, 0, 0],
                [16, 16, 16],
                [23, 23, 23],
                [28, 28, 28],
                [32, 32, 32],
                [36, 36, 36],
                [39, 39, 39],
                [42, 42, 42],
                [45, 45, 45],
                [48, 48, 48],
                [50, 50, 50],
                [53, 53, 53],
                [55, 55, 55],
                [58, 58, 58],
                [60, 60, 60],
                [62, 62, 62],
                [64, 64, 64],
                [66, 66, 66],
                [68, 68, 68],
                [70, 70, 70],
                [71, 71, 71],
                [73, 73, 73],
                [75, 75, 75],
                [77, 77, 77],
                [78, 78, 78],
                [80, 80, 80],
                [81, 81, 81],
                [83, 83, 83],
                [84, 84, 84],
                [86, 86, 86],
                [87, 87, 87],
                [89, 89, 89],
                [90, 90, 90],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [100, 100, 100],
                [101, 101, 101],
                [102, 102, 102],
                [103, 103, 103],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [125, 125, 125],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [131, 131, 131],
                [132, 132, 132],
                [133, 133, 133],
                [134, 134, 134],
                [135, 135, 135],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [148, 148, 148],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [151, 151, 151],
                [152, 152, 152],
                [153, 153, 153],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [156, 156, 156],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [160, 160, 160],
                [161, 161, 161],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [170, 170, 170],
                [170, 170, 170],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [176, 176, 176],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [179, 179, 179],
                [179, 179, 179],
                [180, 180, 180],
                [181, 181, 181],
                [181, 181, 181],
                [182, 182, 182],
                [183, 183, 183],
                [183, 183, 183],
                [184, 184, 184],
                [185, 185, 185],
                [186, 186, 186],
                [186, 186, 186],
                [187, 187, 187],
                [188, 188, 188],
                [188, 188, 188],
                [189, 189, 189],
                [190, 190, 190],
                [190, 190, 190],
                [191, 191, 191],
                [192, 192, 192],
                [192, 192, 192],
                [193, 193, 193],
                [194, 194, 194],
                [194, 194, 194],
                [195, 195, 195],
                [196, 196, 196],
                [196, 196, 196],
                [197, 197, 197],
                [198, 198, 198],
                [198, 198, 198],
                [199, 199, 199],
                [199, 199, 199],
                [200, 200, 200],
                [201, 201, 201],
                [201, 201, 201],
                [202, 202, 202],
                [203, 203, 203],
                [203, 203, 203],
                [204, 204, 204],
                [204, 204, 204],
                [205, 205, 205],
                [206, 206, 206],
                [206, 206, 206],
                [207, 207, 207],
                [208, 208, 208],
                [208, 208, 208],
                [209, 209, 209],
                [209, 209, 209],
                [210, 210, 210],
                [211, 211, 211],
                [211, 211, 211],
                [212, 212, 212],
                [212, 212, 212],
                [213, 213, 213],
                [214, 214, 214],
                [214, 214, 214],
                [215, 215, 215],
                [215, 215, 215],
                [216, 216, 216],
                [217, 217, 217],
                [217, 217, 217],
                [218, 218, 218],
                [218, 218, 218],
                [219, 219, 219],
                [220, 220, 220],
                [220, 220, 220],
                [221, 221, 221],
                [221, 221, 221],
                [222, 222, 222],
                [222, 222, 222],
                [223, 223, 223],
                [224, 224, 224],
                [224, 224, 224],
                [225, 225, 225],
                [225, 225, 225],
                [226, 226, 226],
                [226, 226, 226],
                [227, 227, 227],
                [228, 228, 228],
                [228, 228, 228],
                [229, 229, 229],
                [229, 229, 229],
                [230, 230, 230],
                [230, 230, 230],
                [231, 231, 231],
                [231, 231, 231],
                [232, 232, 232],
                [233, 233, 233],
                [233, 233, 233],
                [234, 234, 234],
                [234, 234, 234],
                [235, 235, 235],
                [235, 235, 235],
                [236, 236, 236],
                [236, 236, 236],
                [237, 237, 237],
                [237, 237, 237],
                [238, 238, 238],
                [238, 238, 238],
                [239, 239, 239],
                [240, 240, 240],
                [240, 240, 240],
                [241, 241, 241],
                [241, 241, 241],
                [242, 242, 242],
                [242, 242, 242],
                [243, 243, 243],
                [243, 243, 243],
                [244, 244, 244],
                [244, 244, 244],
                [245, 245, 245],
                [245, 245, 245],
                [246, 246, 246],
                [246, 246, 246],
                [247, 247, 247],
                [247, 247, 247],
                [248, 248, 248],
                [248, 248, 248],
                [249, 249, 249],
                [249, 249, 249],
                [250, 250, 250],
                [250, 250, 250],
                [251, 251, 251],
                [251, 251, 251],
                [252, 252, 252],
                [252, 252, 252],
                [253, 253, 253],
                [253, 253, 253],
                [254, 254, 254],
                [254, 254, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=0.50 inverted",
            [
                [255, 255, 255],
                [254, 254, 254],
                [254, 254, 254],
                [253, 253, 253],
                [253, 253, 253],
                [252, 252, 252],
                [252, 252, 252],
                [251, 251, 251],
                [251, 251, 251],
                [250, 250, 250],
                [250, 250, 250],
                [249, 249, 249],
                [249, 249, 249],
                [248, 248, 248],
                [248, 248, 248],
                [247, 247, 247],
                [247, 247, 247],
                [246, 246, 246],
                [246, 246, 246],
                [245, 245, 245],
                [245, 245, 245],
                [244, 244, 244],
                [244, 244, 244],
                [243, 243, 243],
                [243, 243, 243],
                [242, 242, 242],
                [242, 242, 242],
                [241, 241, 241],
                [241, 241, 241],
                [240, 240, 240],
                [240, 240, 240],
                [239, 239, 239],
                [238, 238, 238],
                [238, 238, 238],
                [237, 237, 237],
                [237, 237, 237],
                [236, 236, 236],
                [236, 236, 236],
                [235, 235, 235],
                [235, 235, 235],
                [234, 234, 234],
                [234, 234, 234],
                [233, 233, 233],
                [233, 233, 233],
                [232, 232, 232],
                [231, 231, 231],
                [231, 231, 231],
                [230, 230, 230],
                [230, 230, 230],
                [229, 229, 229],
                [229, 229, 229],
                [228, 228, 228],
                [228, 228, 228],
                [227, 227, 227],
                [226, 226, 226],
                [226, 226, 226],
                [225, 225, 225],
                [225, 225, 225],
                [224, 224, 224],
                [224, 224, 224],
                [223, 223, 223],
                [222, 222, 222],
                [222, 222, 222],
                [221, 221, 221],
                [221, 221, 221],
                [220, 220, 220],
                [220, 220, 220],
                [219, 219, 219],
                [218, 218, 218],
                [218, 218, 218],
                [217, 217, 217],
                [217, 217, 217],
                [216, 216, 216],
                [215, 215, 215],
                [215, 215, 215],
                [214, 214, 214],
                [214, 214, 214],
                [213, 213, 213],
                [212, 212, 212],
                [212, 212, 212],
                [211, 211, 211],
                [211, 211, 211],
                [210, 210, 210],
                [209, 209, 209],
                [209, 209, 209],
                [208, 208, 208],
                [208, 208, 208],
                [207, 207, 207],
                [206, 206, 206],
                [206, 206, 206],
                [205, 205, 205],
                [204, 204, 204],
                [204, 204, 204],
                [203, 203, 203],
                [203, 203, 203],
                [202, 202, 202],
                [201, 201, 201],
                [201, 201, 201],
                [200, 200, 200],
                [199, 199, 199],
                [199, 199, 199],
                [198, 198, 198],
                [198, 198, 198],
                [197, 197, 197],
                [196, 196, 196],
                [196, 196, 196],
                [195, 195, 195],
                [194, 194, 194],
                [194, 194, 194],
                [193, 193, 193],
                [192, 192, 192],
                [192, 192, 192],
                [191, 191, 191],
                [190, 190, 190],
                [190, 190, 190],
                [189, 189, 189],
                [188, 188, 188],
                [188, 188, 188],
                [187, 187, 187],
                [186, 186, 186],
                [186, 186, 186],
                [185, 185, 185],
                [184, 184, 184],
                [183, 183, 183],
                [183, 183, 183],
                [182, 182, 182],
                [181, 181, 181],
                [181, 181, 181],
                [180, 180, 180],
                [179, 179, 179],
                [179, 179, 179],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [176, 176, 176],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [170, 170, 170],
                [170, 170, 170],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [161, 161, 161],
                [160, 160, 160],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [156, 156, 156],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [153, 153, 153],
                [152, 152, 152],
                [151, 151, 151],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [148, 148, 148],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [90, 90, 90],
                [89, 89, 89],
                [87, 87, 87],
                [86, 86, 86],
                [84, 84, 84],
                [83, 83, 83],
                [81, 81, 81],
                [80, 80, 80],
                [78, 78, 78],
                [77, 77, 77],
                [75, 75, 75],
                [73, 73, 73],
                [71, 71, 71],
                [70, 70, 70],
                [68, 68, 68],
                [66, 66, 66],
                [64, 64, 64],
                [62, 62, 62],
                [60, 60, 60],
                [58, 58, 58],
                [55, 55, 55],
                [53, 53, 53],
                [50, 50, 50],
                [48, 48, 48],
                [45, 45, 45],
                [42, 42, 42],
                [39, 39, 39],
                [36, 36, 36],
                [32, 32, 32],
                [28, 28, 28],
                [23, 23, 23],
                [16, 16, 16],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=0.75",
            [
                [0, 0, 0],
                [4, 4, 4],
                [7, 7, 7],
                [9, 9, 9],
                [11, 11, 11],
                [13, 13, 13],
                [15, 15, 15],
                [17, 17, 17],
                [19, 19, 19],
                [21, 21, 21],
                [22, 22, 22],
                [24, 24, 24],
                [26, 26, 26],
                [27, 27, 27],
                [29, 29, 29],
                [30, 30, 30],
                [32, 32, 32],
                [33, 33, 33],
                [35, 35, 35],
                [36, 36, 36],
                [38, 38, 38],
                [39, 39, 39],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [91, 91, 91],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [101, 101, 101],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [120, 120, 120],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [124, 124, 124],
                [125, 125, 125],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [131, 131, 131],
                [132, 132, 132],
                [133, 133, 133],
                [134, 134, 134],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [138, 138, 138],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [148, 148, 148],
                [148, 148, 148],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [153, 153, 153],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [157, 157, 157],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [161, 161, 161],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [170, 170, 170],
                [170, 170, 170],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [176, 176, 176],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [179, 179, 179],
                [180, 180, 180],
                [181, 181, 181],
                [181, 181, 181],
                [182, 182, 182],
                [183, 183, 183],
                [184, 184, 184],
                [185, 185, 185],
                [186, 186, 186],
                [186, 186, 186],
                [187, 187, 187],
                [188, 188, 188],
                [189, 189, 189],
                [190, 190, 190],
                [191, 191, 191],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [194, 194, 194],
                [195, 195, 195],
                [196, 196, 196],
                [196, 196, 196],
                [197, 197, 197],
                [198, 198, 198],
                [199, 199, 199],
                [200, 200, 200],
                [200, 200, 200],
                [201, 201, 201],
                [202, 202, 202],
                [203, 203, 203],
                [204, 204, 204],
                [205, 205, 205],
                [205, 205, 205],
                [206, 206, 206],
                [207, 207, 207],
                [208, 208, 208],
                [209, 209, 209],
                [209, 209, 209],
                [210, 210, 210],
                [211, 211, 211],
                [212, 212, 212],
                [213, 213, 213],
                [213, 213, 213],
                [214, 214, 214],
                [215, 215, 215],
                [216, 216, 216],
                [216, 216, 216],
                [217, 217, 217],
                [218, 218, 218],
                [219, 219, 219],
                [220, 220, 220],
                [220, 220, 220],
                [221, 221, 221],
                [222, 222, 222],
                [223, 223, 223],
                [224, 224, 224],
                [224, 224, 224],
                [225, 225, 225],
                [226, 226, 226],
                [227, 227, 227],
                [227, 227, 227],
                [228, 228, 228],
                [229, 229, 229],
                [230, 230, 230],
                [231, 231, 231],
                [231, 231, 231],
                [232, 232, 232],
                [233, 233, 233],
                [234, 234, 234],
                [234, 234, 234],
                [235, 235, 235],
                [236, 236, 236],
                [237, 237, 237],
                [238, 238, 238],
                [238, 238, 238],
                [239, 239, 239],
                [240, 240, 240],
                [241, 241, 241],
                [241, 241, 241],
                [242, 242, 242],
                [243, 243, 243],
                [244, 244, 244],
                [244, 244, 244],
                [245, 245, 245],
                [246, 246, 246],
                [247, 247, 247],
                [247, 247, 247],
                [248, 248, 248],
                [249, 249, 249],
                [250, 250, 250],
                [250, 250, 250],
                [251, 251, 251],
                [252, 252, 252],
                [253, 253, 253],
                [253, 253, 253],
                [254, 254, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=0.75 inverted",
            [
                [255, 255, 255],
                [254, 254, 254],
                [253, 253, 253],
                [253, 253, 253],
                [252, 252, 252],
                [251, 251, 251],
                [250, 250, 250],
                [250, 250, 250],
                [249, 249, 249],
                [248, 248, 248],
                [247, 247, 247],
                [247, 247, 247],
                [246, 246, 246],
                [245, 245, 245],
                [244, 244, 244],
                [244, 244, 244],
                [243, 243, 243],
                [242, 242, 242],
                [241, 241, 241],
                [241, 241, 241],
                [240, 240, 240],
                [239, 239, 239],
                [238, 238, 238],
                [238, 238, 238],
                [237, 237, 237],
                [236, 236, 236],
                [235, 235, 235],
                [234, 234, 234],
                [234, 234, 234],
                [233, 233, 233],
                [232, 232, 232],
                [231, 231, 231],
                [231, 231, 231],
                [230, 230, 230],
                [229, 229, 229],
                [228, 228, 228],
                [227, 227, 227],
                [227, 227, 227],
                [226, 226, 226],
                [225, 225, 225],
                [224, 224, 224],
                [224, 224, 224],
                [223, 223, 223],
                [222, 222, 222],
                [221, 221, 221],
                [220, 220, 220],
                [220, 220, 220],
                [219, 219, 219],
                [218, 218, 218],
                [217, 217, 217],
                [216, 216, 216],
                [216, 216, 216],
                [215, 215, 215],
                [214, 214, 214],
                [213, 213, 213],
                [213, 213, 213],
                [212, 212, 212],
                [211, 211, 211],
                [210, 210, 210],
                [209, 209, 209],
                [209, 209, 209],
                [208, 208, 208],
                [207, 207, 207],
                [206, 206, 206],
                [205, 205, 205],
                [205, 205, 205],
                [204, 204, 204],
                [203, 203, 203],
                [202, 202, 202],
                [201, 201, 201],
                [200, 200, 200],
                [200, 200, 200],
                [199, 199, 199],
                [198, 198, 198],
                [197, 197, 197],
                [196, 196, 196],
                [196, 196, 196],
                [195, 195, 195],
                [194, 194, 194],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [191, 191, 191],
                [190, 190, 190],
                [189, 189, 189],
                [188, 188, 188],
                [187, 187, 187],
                [186, 186, 186],
                [186, 186, 186],
                [185, 185, 185],
                [184, 184, 184],
                [183, 183, 183],
                [182, 182, 182],
                [181, 181, 181],
                [181, 181, 181],
                [180, 180, 180],
                [179, 179, 179],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [176, 176, 176],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [170, 170, 170],
                [170, 170, 170],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [161, 161, 161],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [157, 157, 157],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [153, 153, 153],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [148, 148, 148],
                [148, 148, 148],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [138, 138, 138],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [39, 39, 39],
                [38, 38, 38],
                [36, 36, 36],
                [35, 35, 35],
                [33, 33, 33],
                [32, 32, 32],
                [30, 30, 30],
                [29, 29, 29],
                [27, 27, 27],
                [26, 26, 26],
                [24, 24, 24],
                [22, 22, 22],
                [21, 21, 21],
                [19, 19, 19],
                [17, 17, 17],
                [15, 15, 15],
                [13, 13, 13],
                [11, 11, 11],
                [9, 9, 9],
                [7, 7, 7],
                [4, 4, 4],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=1.00 inverted",
            [
                [255, 255, 255],
                [254, 254, 254],
                [253, 253, 253],
                [252, 252, 252],
                [251, 251, 251],
                [250, 250, 250],
                [249, 249, 249],
                [248, 248, 248],
                [247, 247, 247],
                [246, 246, 246],
                [245, 245, 245],
                [244, 244, 244],
                [243, 243, 243],
                [242, 242, 242],
                [241, 241, 241],
                [240, 240, 240],
                [239, 239, 239],
                [238, 238, 238],
                [237, 237, 237],
                [236, 236, 236],
                [235, 235, 235],
                [234, 234, 234],
                [233, 233, 233],
                [232, 232, 232],
                [231, 231, 231],
                [230, 230, 230],
                [229, 229, 229],
                [228, 228, 228],
                [227, 227, 227],
                [226, 226, 226],
                [225, 225, 225],
                [224, 224, 224],
                [223, 223, 223],
                [222, 222, 222],
                [221, 221, 221],
                [220, 220, 220],
                [219, 219, 219],
                [218, 218, 218],
                [217, 217, 217],
                [216, 216, 216],
                [215, 215, 215],
                [214, 214, 214],
                [213, 213, 213],
                [212, 212, 212],
                [211, 211, 211],
                [210, 210, 210],
                [209, 209, 209],
                [208, 208, 208],
                [207, 207, 207],
                [206, 206, 206],
                [205, 205, 205],
                [204, 204, 204],
                [203, 203, 203],
                [202, 202, 202],
                [201, 201, 201],
                [200, 200, 200],
                [199, 199, 199],
                [198, 198, 198],
                [197, 197, 197],
                [196, 196, 196],
                [195, 195, 195],
                [194, 194, 194],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [190, 190, 190],
                [189, 189, 189],
                [188, 188, 188],
                [187, 187, 187],
                [186, 186, 186],
                [185, 185, 185],
                [184, 184, 184],
                [183, 183, 183],
                [182, 182, 182],
                [181, 181, 181],
                [180, 180, 180],
                [179, 179, 179],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [170, 170, 170],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [161, 161, 161],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [153, 153, 153],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [148, 148, 148],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [31, 31, 31],
                [30, 30, 30],
                [29, 29, 29],
                [28, 28, 28],
                [27, 27, 27],
                [26, 26, 26],
                [25, 25, 25],
                [24, 24, 24],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [20, 20, 20],
                [19, 19, 19],
                [18, 18, 18],
                [17, 17, 17],
                [16, 16, 16],
                [15, 15, 15],
                [14, 14, 14],
                [13, 13, 13],
                [12, 12, 12],
                [11, 11, 11],
                [10, 10, 10],
                [9, 9, 9],
                [8, 8, 8],
                [7, 7, 7],
                [6, 6, 6],
                [5, 5, 5],
                [4, 4, 4],
                [3, 3, 3],
                [2, 2, 2],
                [1, 1, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=1.25",
            [
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [2, 2, 2],
                [2, 2, 2],
                [3, 3, 3],
                [3, 3, 3],
                [4, 4, 4],
                [4, 4, 4],
                [5, 5, 5],
                [6, 6, 6],
                [6, 6, 6],
                [7, 7, 7],
                [7, 7, 7],
                [8, 8, 8],
                [9, 9, 9],
                [9, 9, 9],
                [10, 10, 10],
                [11, 11, 11],
                [11, 11, 11],
                [12, 12, 12],
                [13, 13, 13],
                [13, 13, 13],
                [14, 14, 14],
                [15, 15, 15],
                [15, 15, 15],
                [16, 16, 16],
                [17, 17, 17],
                [18, 18, 18],
                [18, 18, 18],
                [19, 19, 19],
                [20, 20, 20],
                [21, 21, 21],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [24, 24, 24],
                [24, 24, 24],
                [25, 25, 25],
                [26, 26, 26],
                [27, 27, 27],
                [28, 28, 28],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [31, 31, 31],
                [32, 32, 32],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [91, 91, 91],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [101, 101, 101],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [125, 125, 125],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [131, 131, 131],
                [132, 132, 132],
                [134, 134, 134],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [144, 144, 144],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [148, 148, 148],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [168, 168, 168],
                [170, 170, 170],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [177, 177, 177],
                [178, 178, 178],
                [179, 179, 179],
                [180, 180, 180],
                [181, 181, 181],
                [182, 182, 182],
                [184, 184, 184],
                [185, 185, 185],
                [186, 186, 186],
                [187, 187, 187],
                [188, 188, 188],
                [189, 189, 189],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [194, 194, 194],
                [195, 195, 195],
                [196, 196, 196],
                [198, 198, 198],
                [199, 199, 199],
                [200, 200, 200],
                [201, 201, 201],
                [202, 202, 202],
                [204, 204, 204],
                [205, 205, 205],
                [206, 206, 206],
                [207, 207, 207],
                [208, 208, 208],
                [210, 210, 210],
                [211, 211, 211],
                [212, 212, 212],
                [213, 213, 213],
                [214, 214, 214],
                [216, 216, 216],
                [217, 217, 217],
                [218, 218, 218],
                [219, 219, 219],
                [220, 220, 220],
                [222, 222, 222],
                [223, 223, 223],
                [224, 224, 224],
                [225, 225, 225],
                [227, 227, 227],
                [228, 228, 228],
                [229, 229, 229],
                [230, 230, 230],
                [231, 231, 231],
                [233, 233, 233],
                [234, 234, 234],
                [235, 235, 235],
                [236, 236, 236],
                [238, 238, 238],
                [239, 239, 239],
                [240, 240, 240],
                [241, 241, 241],
                [243, 243, 243],
                [244, 244, 244],
                [245, 245, 245],
                [246, 246, 246],
                [248, 248, 248],
                [249, 249, 249],
                [250, 250, 250],
                [251, 251, 251],
                [253, 253, 253],
                [254, 254, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=1.25 inverted",
            [
                [255, 255, 255],
                [254, 254, 254],
                [253, 253, 253],
                [251, 251, 251],
                [250, 250, 250],
                [249, 249, 249],
                [248, 248, 248],
                [246, 246, 246],
                [245, 245, 245],
                [244, 244, 244],
                [243, 243, 243],
                [241, 241, 241],
                [240, 240, 240],
                [239, 239, 239],
                [238, 238, 238],
                [236, 236, 236],
                [235, 235, 235],
                [234, 234, 234],
                [233, 233, 233],
                [231, 231, 231],
                [230, 230, 230],
                [229, 229, 229],
                [228, 228, 228],
                [227, 227, 227],
                [225, 225, 225],
                [224, 224, 224],
                [223, 223, 223],
                [222, 222, 222],
                [220, 220, 220],
                [219, 219, 219],
                [218, 218, 218],
                [217, 217, 217],
                [216, 216, 216],
                [214, 214, 214],
                [213, 213, 213],
                [212, 212, 212],
                [211, 211, 211],
                [210, 210, 210],
                [208, 208, 208],
                [207, 207, 207],
                [206, 206, 206],
                [205, 205, 205],
                [204, 204, 204],
                [202, 202, 202],
                [201, 201, 201],
                [200, 200, 200],
                [199, 199, 199],
                [198, 198, 198],
                [196, 196, 196],
                [195, 195, 195],
                [194, 194, 194],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [189, 189, 189],
                [188, 188, 188],
                [187, 187, 187],
                [186, 186, 186],
                [185, 185, 185],
                [184, 184, 184],
                [182, 182, 182],
                [181, 181, 181],
                [180, 180, 180],
                [179, 179, 179],
                [178, 178, 178],
                [177, 177, 177],
                [175, 175, 175],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [170, 170, 170],
                [168, 168, 168],
                [167, 167, 167],
                [166, 166, 166],
                [165, 165, 165],
                [164, 164, 164],
                [163, 163, 163],
                [162, 162, 162],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [148, 148, 148],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [144, 144, 144],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [134, 134, 134],
                [132, 132, 132],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [37, 37, 37],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [32, 32, 32],
                [31, 31, 31],
                [30, 30, 30],
                [29, 29, 29],
                [28, 28, 28],
                [28, 28, 28],
                [27, 27, 27],
                [26, 26, 26],
                [25, 25, 25],
                [24, 24, 24],
                [24, 24, 24],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [19, 19, 19],
                [18, 18, 18],
                [18, 18, 18],
                [17, 17, 17],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [13, 13, 13],
                [13, 13, 13],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=1.50",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [5, 5, 5],
                [5, 5, 5],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [7, 7, 7],
                [7, 7, 7],
                [8, 8, 8],
                [8, 8, 8],
                [9, 9, 9],
                [9, 9, 9],
                [10, 10, 10],
                [10, 10, 10],
                [11, 11, 11],
                [11, 11, 11],
                [12, 12, 12],
                [12, 12, 12],
                [13, 13, 13],
                [14, 14, 14],
                [14, 14, 14],
                [15, 15, 15],
                [15, 15, 15],
                [16, 16, 16],
                [16, 16, 16],
                [17, 17, 17],
                [18, 18, 18],
                [18, 18, 18],
                [19, 19, 19],
                [20, 20, 20],
                [20, 20, 20],
                [21, 21, 21],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [23, 23, 23],
                [24, 24, 24],
                [25, 25, 25],
                [26, 26, 26],
                [26, 26, 26],
                [27, 27, 27],
                [28, 28, 28],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [31, 31, 31],
                [31, 31, 31],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [46, 46, 46],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [53, 53, 53],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [91, 91, 91],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [119, 119, 119],
                [120, 120, 120],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [132, 132, 132],
                [133, 133, 133],
                [134, 134, 134],
                [135, 135, 135],
                [136, 136, 136],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [144, 144, 144],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [161, 161, 161],
                [163, 163, 163],
                [164, 164, 164],
                [165, 165, 165],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [180, 180, 180],
                [181, 181, 181],
                [182, 182, 182],
                [184, 184, 184],
                [185, 185, 185],
                [187, 187, 187],
                [188, 188, 188],
                [189, 189, 189],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [195, 195, 195],
                [196, 196, 196],
                [197, 197, 197],
                [199, 199, 199],
                [200, 200, 200],
                [202, 202, 202],
                [203, 203, 203],
                [204, 204, 204],
                [206, 206, 206],
                [207, 207, 207],
                [209, 209, 209],
                [210, 210, 210],
                [211, 211, 211],
                [213, 213, 213],
                [214, 214, 214],
                [216, 216, 216],
                [217, 217, 217],
                [218, 218, 218],
                [220, 220, 220],
                [221, 221, 221],
                [223, 223, 223],
                [224, 224, 224],
                [226, 226, 226],
                [227, 227, 227],
                [228, 228, 228],
                [230, 230, 230],
                [231, 231, 231],
                [233, 233, 233],
                [234, 234, 234],
                [236, 236, 236],
                [237, 237, 237],
                [239, 239, 239],
                [240, 240, 240],
                [242, 242, 242],
                [243, 243, 243],
                [245, 245, 245],
                [246, 246, 246],
                [248, 248, 248],
                [249, 249, 249],
                [251, 251, 251],
                [252, 252, 252],
                [254, 254, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=1.50 inverted",
            [
                [255, 255, 255],
                [254, 254, 254],
                [252, 252, 252],
                [251, 251, 251],
                [249, 249, 249],
                [248, 248, 248],
                [246, 246, 246],
                [245, 245, 245],
                [243, 243, 243],
                [242, 242, 242],
                [240, 240, 240],
                [239, 239, 239],
                [237, 237, 237],
                [236, 236, 236],
                [234, 234, 234],
                [233, 233, 233],
                [231, 231, 231],
                [230, 230, 230],
                [228, 228, 228],
                [227, 227, 227],
                [226, 226, 226],
                [224, 224, 224],
                [223, 223, 223],
                [221, 221, 221],
                [220, 220, 220],
                [218, 218, 218],
                [217, 217, 217],
                [216, 216, 216],
                [214, 214, 214],
                [213, 213, 213],
                [211, 211, 211],
                [210, 210, 210],
                [209, 209, 209],
                [207, 207, 207],
                [206, 206, 206],
                [204, 204, 204],
                [203, 203, 203],
                [202, 202, 202],
                [200, 200, 200],
                [199, 199, 199],
                [197, 197, 197],
                [196, 196, 196],
                [195, 195, 195],
                [193, 193, 193],
                [192, 192, 192],
                [191, 191, 191],
                [189, 189, 189],
                [188, 188, 188],
                [187, 187, 187],
                [185, 185, 185],
                [184, 184, 184],
                [182, 182, 182],
                [181, 181, 181],
                [180, 180, 180],
                [178, 178, 178],
                [177, 177, 177],
                [176, 176, 176],
                [174, 174, 174],
                [173, 173, 173],
                [172, 172, 172],
                [171, 171, 171],
                [169, 169, 169],
                [168, 168, 168],
                [167, 167, 167],
                [165, 165, 165],
                [164, 164, 164],
                [163, 163, 163],
                [161, 161, 161],
                [160, 160, 160],
                [159, 159, 159],
                [158, 158, 158],
                [156, 156, 156],
                [155, 155, 155],
                [154, 154, 154],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [149, 149, 149],
                [147, 147, 147],
                [146, 146, 146],
                [145, 145, 145],
                [144, 144, 144],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [138, 138, 138],
                [136, 136, 136],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [37, 37, 37],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [34, 34, 34],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [31, 31, 31],
                [31, 31, 31],
                [30, 30, 30],
                [29, 29, 29],
                [28, 28, 28],
                [28, 28, 28],
                [27, 27, 27],
                [26, 26, 26],
                [26, 26, 26],
                [25, 25, 25],
                [24, 24, 24],
                [23, 23, 23],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [20, 20, 20],
                [19, 19, 19],
                [18, 18, 18],
                [18, 18, 18],
                [17, 17, 17],
                [16, 16, 16],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [14, 14, 14],
                [13, 13, 13],
                [12, 12, 12],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=1.75",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [7, 7, 7],
                [7, 7, 7],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [9, 9, 9],
                [9, 9, 9],
                [10, 10, 10],
                [10, 10, 10],
                [10, 10, 10],
                [11, 11, 11],
                [11, 11, 11],
                [12, 12, 12],
                [12, 12, 12],
                [13, 13, 13],
                [13, 13, 13],
                [14, 14, 14],
                [14, 14, 14],
                [15, 15, 15],
                [15, 15, 15],
                [16, 16, 16],
                [16, 16, 16],
                [17, 17, 17],
                [17, 17, 17],
                [18, 18, 18],
                [19, 19, 19],
                [19, 19, 19],
                [20, 20, 20],
                [20, 20, 20],
                [21, 21, 21],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [23, 23, 23],
                [24, 24, 24],
                [25, 25, 25],
                [25, 25, 25],
                [26, 26, 26],
                [27, 27, 27],
                [27, 27, 27],
                [28, 28, 28],
                [29, 29, 29],
                [29, 29, 29],
                [30, 30, 30],
                [31, 31, 31],
                [31, 31, 31],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [40, 40, 40],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [100, 100, 100],
                [101, 101, 101],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [120, 120, 120],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [125, 125, 125],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [131, 131, 131],
                [132, 132, 132],
                [133, 133, 133],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [147, 147, 147],
                [148, 148, 148],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [154, 154, 154],
                [155, 155, 155],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [161, 161, 161],
                [162, 162, 162],
                [164, 164, 164],
                [165, 165, 165],
                [167, 167, 167],
                [168, 168, 168],
                [170, 170, 170],
                [171, 171, 171],
                [173, 173, 173],
                [174, 174, 174],
                [176, 176, 176],
                [177, 177, 177],
                [179, 179, 179],
                [180, 180, 180],
                [182, 182, 182],
                [183, 183, 183],
                [185, 185, 185],
                [186, 186, 186],
                [188, 188, 188],
                [189, 189, 189],
                [191, 191, 191],
                [192, 192, 192],
                [194, 194, 194],
                [195, 195, 195],
                [197, 197, 197],
                [199, 199, 199],
                [200, 200, 200],
                [202, 202, 202],
                [203, 203, 203],
                [205, 205, 205],
                [206, 206, 206],
                [208, 208, 208],
                [210, 210, 210],
                [211, 211, 211],
                [213, 213, 213],
                [214, 214, 214],
                [216, 216, 216],
                [218, 218, 218],
                [219, 219, 219],
                [221, 221, 221],
                [223, 223, 223],
                [224, 224, 224],
                [226, 226, 226],
                [228, 228, 228],
                [229, 229, 229],
                [231, 231, 231],
                [233, 233, 233],
                [234, 234, 234],
                [236, 236, 236],
                [238, 238, 238],
                [239, 239, 239],
                [241, 241, 241],
                [243, 243, 243],
                [245, 245, 245],
                [246, 246, 246],
                [248, 248, 248],
                [250, 250, 250],
                [252, 252, 252],
                [253, 253, 253],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=1.75 inverted",
            [
                [255, 255, 255],
                [253, 253, 253],
                [252, 252, 252],
                [250, 250, 250],
                [248, 248, 248],
                [246, 246, 246],
                [245, 245, 245],
                [243, 243, 243],
                [241, 241, 241],
                [239, 239, 239],
                [238, 238, 238],
                [236, 236, 236],
                [234, 234, 234],
                [233, 233, 233],
                [231, 231, 231],
                [229, 229, 229],
                [228, 228, 228],
                [226, 226, 226],
                [224, 224, 224],
                [223, 223, 223],
                [221, 221, 221],
                [219, 219, 219],
                [218, 218, 218],
                [216, 216, 216],
                [214, 214, 214],
                [213, 213, 213],
                [211, 211, 211],
                [210, 210, 210],
                [208, 208, 208],
                [206, 206, 206],
                [205, 205, 205],
                [203, 203, 203],
                [202, 202, 202],
                [200, 200, 200],
                [199, 199, 199],
                [197, 197, 197],
                [195, 195, 195],
                [194, 194, 194],
                [192, 192, 192],
                [191, 191, 191],
                [189, 189, 189],
                [188, 188, 188],
                [186, 186, 186],
                [185, 185, 185],
                [183, 183, 183],
                [182, 182, 182],
                [180, 180, 180],
                [179, 179, 179],
                [177, 177, 177],
                [176, 176, 176],
                [174, 174, 174],
                [173, 173, 173],
                [171, 171, 171],
                [170, 170, 170],
                [168, 168, 168],
                [167, 167, 167],
                [165, 165, 165],
                [164, 164, 164],
                [162, 162, 162],
                [161, 161, 161],
                [159, 159, 159],
                [158, 158, 158],
                [157, 157, 157],
                [155, 155, 155],
                [154, 154, 154],
                [152, 152, 152],
                [151, 151, 151],
                [150, 150, 150],
                [148, 148, 148],
                [147, 147, 147],
                [145, 145, 145],
                [144, 144, 144],
                [143, 143, 143],
                [141, 141, 141],
                [140, 140, 140],
                [139, 139, 139],
                [137, 137, 137],
                [136, 136, 136],
                [135, 135, 135],
                [133, 133, 133],
                [132, 132, 132],
                [131, 131, 131],
                [129, 129, 129],
                [128, 128, 128],
                [127, 127, 127],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [122, 122, 122],
                [120, 120, 120],
                [119, 119, 119],
                [118, 118, 118],
                [117, 117, 117],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [40, 40, 40],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [37, 37, 37],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [34, 34, 34],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [31, 31, 31],
                [31, 31, 31],
                [30, 30, 30],
                [29, 29, 29],
                [29, 29, 29],
                [28, 28, 28],
                [27, 27, 27],
                [27, 27, 27],
                [26, 26, 26],
                [25, 25, 25],
                [25, 25, 25],
                [24, 24, 24],
                [23, 23, 23],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [20, 20, 20],
                [19, 19, 19],
                [19, 19, 19],
                [18, 18, 18],
                [17, 17, 17],
                [17, 17, 17],
                [16, 16, 16],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [14, 14, 14],
                [13, 13, 13],
                [13, 13, 13],
                [12, 12, 12],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [10, 10, 10],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Grays g=2.00",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [7, 7, 7],
                [7, 7, 7],
                [7, 7, 7],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [9, 9, 9],
                [9, 9, 9],
                [9, 9, 9],
                [10, 10, 10],
                [10, 10, 10],
                [11, 11, 11],
                [11, 11, 11],
                [11, 11, 11],
                [12, 12, 12],
                [12, 12, 12],
                [13, 13, 13],
                [13, 13, 13],
                [14, 14, 14],
                [14, 14, 14],
                [15, 15, 15],
                [15, 15, 15],
                [16, 16, 16],
                [16, 16, 16],
                [17, 17, 17],
                [17, 17, 17],
                [18, 18, 18],
                [18, 18, 18],
                [19, 19, 19],
                [19, 19, 19],
                [20, 20, 20],
                [20, 20, 20],
                [21, 21, 21],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [23, 23, 23],
                [24, 24, 24],
                [24, 24, 24],
                [25, 25, 25],
                [26, 26, 26],
                [26, 26, 26],
                [27, 27, 27],
                [28, 28, 28],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [30, 30, 30],
                [31, 31, 31],
                [32, 32, 32],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [35, 35, 35],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [38, 38, 38],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [42, 42, 42],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [91, 91, 91],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [119, 119, 119],
                [120, 120, 120],
                [121, 121, 121],
                [123, 123, 123],
                [124, 124, 124],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [130, 130, 130],
                [131, 131, 131],
                [133, 133, 133],
                [134, 134, 134],
                [136, 136, 136],
                [137, 137, 137],
                [139, 139, 139],
                [140, 140, 140],
                [142, 142, 142],
                [143, 143, 143],
                [145, 145, 145],
                [146, 146, 146],
                [148, 148, 148],
                [149, 149, 149],
                [151, 151, 151],
                [152, 152, 152],
                [154, 154, 154],
                [155, 155, 155],
                [157, 157, 157],
                [158, 158, 158],
                [160, 160, 160],
                [162, 162, 162],
                [163, 163, 163],
                [165, 165, 165],
                [166, 166, 166],
                [168, 168, 168],
                [170, 170, 170],
                [171, 171, 171],
                [173, 173, 173],
                [175, 175, 175],
                [176, 176, 176],
                [178, 178, 178],
                [180, 180, 180],
                [181, 181, 181],
                [183, 183, 183],
                [185, 185, 185],
                [186, 186, 186],
                [188, 188, 188],
                [190, 190, 190],
                [192, 192, 192],
                [193, 193, 193],
                [195, 195, 195],
                [197, 197, 197],
                [199, 199, 199],
                [200, 200, 200],
                [202, 202, 202],
                [204, 204, 204],
                [206, 206, 206],
                [207, 207, 207],
                [209, 209, 209],
                [211, 211, 211],
                [213, 213, 213],
                [215, 215, 215],
                [217, 217, 217],
                [218, 218, 218],
                [220, 220, 220],
                [222, 222, 222],
                [224, 224, 224],
                [226, 226, 226],
                [228, 228, 228],
                [230, 230, 230],
                [232, 232, 232],
                [233, 233, 233],
                [235, 235, 235],
                [237, 237, 237],
                [239, 239, 239],
                [241, 241, 241],
                [243, 243, 243],
                [245, 245, 245],
                [247, 247, 247],
                [249, 249, 249],
                [251, 251, 251],
                [253, 253, 253],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Grays g=2.00 inverted",
            [
                [255, 255, 255],
                [253, 253, 253],
                [251, 251, 251],
                [249, 249, 249],
                [247, 247, 247],
                [245, 245, 245],
                [243, 243, 243],
                [241, 241, 241],
                [239, 239, 239],
                [237, 237, 237],
                [235, 235, 235],
                [233, 233, 233],
                [232, 232, 232],
                [230, 230, 230],
                [228, 228, 228],
                [226, 226, 226],
                [224, 224, 224],
                [222, 222, 222],
                [220, 220, 220],
                [218, 218, 218],
                [217, 217, 217],
                [215, 215, 215],
                [213, 213, 213],
                [211, 211, 211],
                [209, 209, 209],
                [207, 207, 207],
                [206, 206, 206],
                [204, 204, 204],
                [202, 202, 202],
                [200, 200, 200],
                [199, 199, 199],
                [197, 197, 197],
                [195, 195, 195],
                [193, 193, 193],
                [192, 192, 192],
                [190, 190, 190],
                [188, 188, 188],
                [186, 186, 186],
                [185, 185, 185],
                [183, 183, 183],
                [181, 181, 181],
                [180, 180, 180],
                [178, 178, 178],
                [176, 176, 176],
                [175, 175, 175],
                [173, 173, 173],
                [171, 171, 171],
                [170, 170, 170],
                [168, 168, 168],
                [166, 166, 166],
                [165, 165, 165],
                [163, 163, 163],
                [162, 162, 162],
                [160, 160, 160],
                [158, 158, 158],
                [157, 157, 157],
                [155, 155, 155],
                [154, 154, 154],
                [152, 152, 152],
                [151, 151, 151],
                [149, 149, 149],
                [148, 148, 148],
                [146, 146, 146],
                [145, 145, 145],
                [143, 143, 143],
                [142, 142, 142],
                [140, 140, 140],
                [139, 139, 139],
                [137, 137, 137],
                [136, 136, 136],
                [134, 134, 134],
                [133, 133, 133],
                [131, 131, 131],
                [130, 130, 130],
                [128, 128, 128],
                [127, 127, 127],
                [126, 126, 126],
                [124, 124, 124],
                [123, 123, 123],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [43, 43, 43],
                [42, 42, 42],
                [42, 42, 42],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [38, 38, 38],
                [37, 37, 37],
                [36, 36, 36],
                [35, 35, 35],
                [35, 35, 35],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [32, 32, 32],
                [31, 31, 31],
                [30, 30, 30],
                [30, 30, 30],
                [29, 29, 29],
                [28, 28, 28],
                [28, 28, 28],
                [27, 27, 27],
                [26, 26, 26],
                [26, 26, 26],
                [25, 25, 25],
                [24, 24, 24],
                [24, 24, 24],
                [23, 23, 23],
                [23, 23, 23],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [20, 20, 20],
                [19, 19, 19],
                [19, 19, 19],
                [18, 18, 18],
                [18, 18, 18],
                [17, 17, 17],
                [17, 17, 17],
                [16, 16, 16],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [14, 14, 14],
                [13, 13, 13],
                [13, 13, 13],
                [12, 12, 12],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Green",
            [
                [0, 0, 0],
                [0, 1, 0],
                [0, 2, 0],
                [0, 3, 0],
                [0, 4, 0],
                [0, 5, 0],
                [0, 6, 0],
                [0, 7, 0],
                [0, 8, 0],
                [0, 9, 0],
                [0, 10, 0],
                [0, 11, 0],
                [0, 12, 0],
                [0, 13, 0],
                [0, 14, 0],
                [0, 15, 0],
                [0, 16, 0],
                [0, 17, 0],
                [0, 18, 0],
                [0, 19, 0],
                [0, 20, 0],
                [0, 21, 0],
                [0, 22, 0],
                [0, 23, 0],
                [0, 24, 0],
                [0, 25, 0],
                [0, 26, 0],
                [0, 27, 0],
                [0, 28, 0],
                [0, 29, 0],
                [0, 30, 0],
                [0, 31, 0],
                [0, 32, 0],
                [0, 33, 0],
                [0, 34, 0],
                [0, 35, 0],
                [0, 36, 0],
                [0, 37, 0],
                [0, 38, 0],
                [0, 39, 0],
                [0, 40, 0],
                [0, 41, 0],
                [0, 42, 0],
                [0, 43, 0],
                [0, 44, 0],
                [0, 45, 0],
                [0, 46, 0],
                [0, 47, 0],
                [0, 48, 0],
                [0, 49, 0],
                [0, 50, 0],
                [0, 51, 0],
                [0, 52, 0],
                [0, 53, 0],
                [0, 54, 0],
                [0, 55, 0],
                [0, 56, 0],
                [0, 57, 0],
                [0, 58, 0],
                [0, 59, 0],
                [0, 60, 0],
                [0, 61, 0],
                [0, 62, 0],
                [0, 63, 0],
                [0, 64, 0],
                [0, 65, 0],
                [0, 66, 0],
                [0, 67, 0],
                [0, 68, 0],
                [0, 69, 0],
                [0, 70, 0],
                [0, 71, 0],
                [0, 72, 0],
                [0, 73, 0],
                [0, 74, 0],
                [0, 75, 0],
                [0, 76, 0],
                [0, 77, 0],
                [0, 78, 0],
                [0, 79, 0],
                [0, 80, 0],
                [0, 81, 0],
                [0, 82, 0],
                [0, 83, 0],
                [0, 84, 0],
                [0, 85, 0],
                [0, 86, 0],
                [0, 87, 0],
                [0, 88, 0],
                [0, 89, 0],
                [0, 90, 0],
                [0, 91, 0],
                [0, 92, 0],
                [0, 93, 0],
                [0, 94, 0],
                [0, 95, 0],
                [0, 96, 0],
                [0, 97, 0],
                [0, 98, 0],
                [0, 99, 0],
                [0, 100, 0],
                [0, 101, 0],
                [0, 102, 0],
                [0, 103, 0],
                [0, 104, 0],
                [0, 105, 0],
                [0, 106, 0],
                [0, 107, 0],
                [0, 108, 0],
                [0, 109, 0],
                [0, 110, 0],
                [0, 111, 0],
                [0, 112, 0],
                [0, 113, 0],
                [0, 114, 0],
                [0, 115, 0],
                [0, 116, 0],
                [0, 117, 0],
                [0, 118, 0],
                [0, 119, 0],
                [0, 120, 0],
                [0, 121, 0],
                [0, 122, 0],
                [0, 123, 0],
                [0, 124, 0],
                [0, 125, 0],
                [0, 126, 0],
                [0, 127, 0],
                [0, 128, 0],
                [0, 129, 0],
                [0, 130, 0],
                [0, 131, 0],
                [0, 132, 0],
                [0, 133, 0],
                [0, 134, 0],
                [0, 135, 0],
                [0, 136, 0],
                [0, 137, 0],
                [0, 138, 0],
                [0, 139, 0],
                [0, 140, 0],
                [0, 141, 0],
                [0, 142, 0],
                [0, 143, 0],
                [0, 144, 0],
                [0, 145, 0],
                [0, 146, 0],
                [0, 147, 0],
                [0, 148, 0],
                [0, 149, 0],
                [0, 150, 0],
                [0, 151, 0],
                [0, 152, 0],
                [0, 153, 0],
                [0, 154, 0],
                [0, 155, 0],
                [0, 156, 0],
                [0, 157, 0],
                [0, 158, 0],
                [0, 159, 0],
                [0, 160, 0],
                [0, 161, 0],
                [0, 162, 0],
                [0, 163, 0],
                [0, 164, 0],
                [0, 165, 0],
                [0, 166, 0],
                [0, 167, 0],
                [0, 168, 0],
                [0, 169, 0],
                [0, 170, 0],
                [0, 171, 0],
                [0, 172, 0],
                [0, 173, 0],
                [0, 174, 0],
                [0, 175, 0],
                [0, 176, 0],
                [0, 177, 0],
                [0, 178, 0],
                [0, 179, 0],
                [0, 180, 0],
                [0, 181, 0],
                [0, 182, 0],
                [0, 183, 0],
                [0, 184, 0],
                [0, 185, 0],
                [0, 186, 0],
                [0, 187, 0],
                [0, 188, 0],
                [0, 189, 0],
                [0, 190, 0],
                [0, 191, 0],
                [0, 192, 0],
                [0, 193, 0],
                [0, 194, 0],
                [0, 195, 0],
                [0, 196, 0],
                [0, 197, 0],
                [0, 198, 0],
                [0, 199, 0],
                [0, 200, 0],
                [0, 201, 0],
                [0, 202, 0],
                [0, 203, 0],
                [0, 204, 0],
                [0, 205, 0],
                [0, 206, 0],
                [0, 207, 0],
                [0, 208, 0],
                [0, 209, 0],
                [0, 210, 0],
                [0, 211, 0],
                [0, 212, 0],
                [0, 213, 0],
                [0, 214, 0],
                [0, 215, 0],
                [0, 216, 0],
                [0, 217, 0],
                [0, 218, 0],
                [0, 219, 0],
                [0, 220, 0],
                [0, 221, 0],
                [0, 222, 0],
                [0, 223, 0],
                [0, 224, 0],
                [0, 225, 0],
                [0, 226, 0],
                [0, 227, 0],
                [0, 228, 0],
                [0, 229, 0],
                [0, 230, 0],
                [0, 231, 0],
                [0, 232, 0],
                [0, 233, 0],
                [0, 234, 0],
                [0, 235, 0],
                [0, 236, 0],
                [0, 237, 0],
                [0, 238, 0],
                [0, 239, 0],
                [0, 240, 0],
                [0, 241, 0],
                [0, 242, 0],
                [0, 243, 0],
                [0, 244, 0],
                [0, 245, 0],
                [0, 246, 0],
                [0, 247, 0],
                [0, 248, 0],
                [0, 249, 0],
                [0, 250, 0],
                [0, 251, 0],
                [0, 252, 0],
                [0, 253, 0],
                [0, 254, 0],
                [0, 255, 0],
            ],
        );

        m.insert(
            "Green Fire Blue",
            [
                [0, 0, 0],
                [0, 1, 2],
                [0, 2, 5],
                [0, 3, 7],
                [0, 5, 10],
                [0, 6, 13],
                [0, 7, 15],
                [0, 9, 18],
                [0, 10, 21],
                [0, 11, 23],
                [0, 13, 26],
                [0, 14, 29],
                [0, 15, 31],
                [0, 17, 34],
                [0, 18, 37],
                [0, 19, 39],
                [0, 21, 42],
                [0, 22, 45],
                [0, 23, 47],
                [0, 25, 50],
                [0, 26, 53],
                [0, 27, 55],
                [0, 29, 58],
                [0, 30, 61],
                [0, 31, 63],
                [0, 33, 66],
                [0, 34, 69],
                [0, 35, 71],
                [0, 37, 74],
                [0, 38, 77],
                [0, 39, 79],
                [0, 41, 82],
                [0, 42, 85],
                [0, 43, 87],
                [0, 45, 90],
                [0, 46, 92],
                [0, 47, 95],
                [0, 49, 98],
                [0, 50, 100],
                [0, 51, 103],
                [0, 53, 106],
                [0, 54, 108],
                [0, 55, 111],
                [0, 57, 114],
                [0, 58, 116],
                [0, 59, 119],
                [0, 61, 122],
                [0, 62, 124],
                [0, 63, 127],
                [0, 65, 130],
                [0, 66, 132],
                [0, 67, 135],
                [0, 69, 138],
                [0, 70, 140],
                [0, 71, 143],
                [0, 73, 146],
                [0, 74, 148],
                [0, 75, 151],
                [0, 77, 154],
                [0, 78, 156],
                [0, 79, 159],
                [0, 81, 162],
                [0, 82, 164],
                [0, 85, 170],
                [0, 85, 170],
                [0, 87, 167],
                [0, 90, 164],
                [0, 92, 162],
                [0, 95, 159],
                [0, 98, 156],
                [0, 100, 154],
                [0, 103, 151],
                [0, 106, 148],
                [0, 108, 146],
                [0, 111, 143],
                [0, 114, 140],
                [0, 116, 138],
                [0, 119, 135],
                [0, 122, 132],
                [0, 124, 130],
                [0, 127, 127],
                [0, 130, 124],
                [0, 132, 122],
                [0, 135, 119],
                [0, 138, 116],
                [0, 140, 114],
                [0, 143, 111],
                [0, 146, 108],
                [0, 148, 106],
                [0, 151, 103],
                [0, 154, 100],
                [0, 156, 98],
                [0, 159, 95],
                [0, 162, 92],
                [0, 164, 90],
                [0, 167, 87],
                [0, 170, 85],
                [0, 172, 82],
                [0, 175, 79],
                [0, 177, 77],
                [0, 180, 74],
                [0, 183, 71],
                [0, 185, 69],
                [0, 188, 66],
                [0, 191, 63],
                [0, 193, 61],
                [0, 196, 58],
                [0, 199, 55],
                [0, 201, 53],
                [0, 204, 50],
                [0, 207, 47],
                [0, 209, 45],
                [0, 212, 42],
                [0, 215, 39],
                [0, 217, 37],
                [0, 220, 34],
                [0, 223, 31],
                [0, 225, 29],
                [0, 228, 26],
                [0, 231, 23],
                [0, 233, 21],
                [0, 236, 18],
                [0, 239, 15],
                [0, 241, 13],
                [0, 244, 10],
                [0, 247, 7],
                [0, 249, 5],
                [0, 255, 0],
                [0, 255, 0],
                [3, 255, 0],
                [7, 255, 0],
                [11, 255, 0],
                [15, 255, 0],
                [19, 255, 0],
                [23, 255, 0],
                [27, 255, 0],
                [31, 255, 0],
                [35, 255, 0],
                [39, 255, 0],
                [43, 255, 0],
                [47, 255, 0],
                [51, 255, 0],
                [55, 255, 0],
                [59, 255, 0],
                [63, 255, 0],
                [67, 255, 0],
                [71, 255, 0],
                [75, 255, 0],
                [79, 255, 0],
                [83, 255, 0],
                [87, 255, 0],
                [91, 255, 0],
                [95, 255, 0],
                [99, 255, 0],
                [103, 255, 0],
                [107, 255, 0],
                [111, 255, 0],
                [115, 255, 0],
                [119, 255, 0],
                [123, 255, 0],
                [127, 255, 0],
                [131, 255, 0],
                [135, 255, 0],
                [139, 255, 0],
                [143, 255, 0],
                [147, 255, 0],
                [151, 255, 0],
                [155, 255, 0],
                [159, 255, 0],
                [163, 255, 0],
                [167, 255, 0],
                [171, 255, 0],
                [175, 255, 0],
                [179, 255, 0],
                [183, 255, 0],
                [187, 255, 0],
                [191, 255, 0],
                [195, 255, 0],
                [199, 255, 0],
                [203, 255, 0],
                [207, 255, 0],
                [211, 255, 0],
                [215, 255, 0],
                [219, 255, 0],
                [223, 255, 0],
                [227, 255, 0],
                [231, 255, 0],
                [235, 255, 0],
                [239, 255, 0],
                [243, 255, 0],
                [247, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 3],
                [255, 255, 7],
                [255, 255, 11],
                [255, 255, 15],
                [255, 255, 19],
                [255, 255, 23],
                [255, 255, 27],
                [255, 255, 31],
                [255, 255, 35],
                [255, 255, 39],
                [255, 255, 43],
                [255, 255, 47],
                [255, 255, 51],
                [255, 255, 55],
                [255, 255, 59],
                [255, 255, 63],
                [255, 255, 67],
                [255, 255, 71],
                [255, 255, 75],
                [255, 255, 79],
                [255, 255, 83],
                [255, 255, 87],
                [255, 255, 91],
                [255, 255, 95],
                [255, 255, 99],
                [255, 255, 103],
                [255, 255, 107],
                [255, 255, 111],
                [255, 255, 115],
                [255, 255, 119],
                [255, 255, 123],
                [255, 255, 127],
                [255, 255, 131],
                [255, 255, 135],
                [255, 255, 139],
                [255, 255, 143],
                [255, 255, 147],
                [255, 255, 151],
                [255, 255, 155],
                [255, 255, 159],
                [255, 255, 163],
                [255, 255, 167],
                [255, 255, 171],
                [255, 255, 175],
                [255, 255, 179],
                [255, 255, 183],
                [255, 255, 187],
                [255, 255, 191],
                [255, 255, 195],
                [255, 255, 199],
                [255, 255, 203],
                [255, 255, 207],
                [255, 255, 211],
                [255, 255, 215],
                [255, 255, 219],
                [255, 255, 223],
                [255, 255, 227],
                [255, 255, 231],
                [255, 255, 235],
                [255, 255, 239],
                [255, 255, 243],
                [255, 255, 247],
                [255, 255, 255],
            ],
        );

        m.insert(
            "HiLo",
            [
                [0, 0, 255],
                [1, 1, 1],
                [2, 2, 2],
                [3, 3, 3],
                [4, 4, 4],
                [5, 5, 5],
                [6, 6, 6],
                [7, 7, 7],
                [8, 8, 8],
                [9, 9, 9],
                [10, 10, 10],
                [11, 11, 11],
                [12, 12, 12],
                [13, 13, 13],
                [14, 14, 14],
                [15, 15, 15],
                [16, 16, 16],
                [17, 17, 17],
                [18, 18, 18],
                [19, 19, 19],
                [20, 20, 20],
                [21, 21, 21],
                [22, 22, 22],
                [23, 23, 23],
                [24, 24, 24],
                [25, 25, 25],
                [26, 26, 26],
                [27, 27, 27],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [31, 31, 31],
                [32, 32, 32],
                [33, 33, 33],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [75, 75, 75],
                [76, 76, 76],
                [77, 77, 77],
                [78, 78, 78],
                [79, 79, 79],
                [80, 80, 80],
                [81, 81, 81],
                [82, 82, 82],
                [83, 83, 83],
                [84, 84, 84],
                [85, 85, 85],
                [86, 86, 86],
                [87, 87, 87],
                [88, 88, 88],
                [89, 89, 89],
                [90, 90, 90],
                [91, 91, 91],
                [92, 92, 92],
                [93, 93, 93],
                [94, 94, 94],
                [95, 95, 95],
                [96, 96, 96],
                [97, 97, 97],
                [98, 98, 98],
                [99, 99, 99],
                [100, 100, 100],
                [101, 101, 101],
                [102, 102, 102],
                [103, 103, 103],
                [104, 104, 104],
                [105, 105, 105],
                [106, 106, 106],
                [107, 107, 107],
                [108, 108, 108],
                [109, 109, 109],
                [110, 110, 110],
                [111, 111, 111],
                [112, 112, 112],
                [113, 113, 113],
                [114, 114, 114],
                [115, 115, 115],
                [116, 116, 116],
                [117, 117, 117],
                [118, 118, 118],
                [119, 119, 119],
                [120, 120, 120],
                [121, 121, 121],
                [122, 122, 122],
                [123, 123, 123],
                [124, 124, 124],
                [125, 125, 125],
                [126, 126, 126],
                [127, 127, 127],
                [128, 128, 128],
                [129, 129, 129],
                [130, 130, 130],
                [131, 131, 131],
                [132, 132, 132],
                [133, 133, 133],
                [134, 134, 134],
                [135, 135, 135],
                [136, 136, 136],
                [137, 137, 137],
                [138, 138, 138],
                [139, 139, 139],
                [140, 140, 140],
                [141, 141, 141],
                [142, 142, 142],
                [143, 143, 143],
                [144, 144, 144],
                [145, 145, 145],
                [146, 146, 146],
                [147, 147, 147],
                [148, 148, 148],
                [149, 149, 149],
                [150, 150, 150],
                [151, 151, 151],
                [152, 152, 152],
                [153, 153, 153],
                [154, 154, 154],
                [155, 155, 155],
                [156, 156, 156],
                [157, 157, 157],
                [158, 158, 158],
                [159, 159, 159],
                [160, 160, 160],
                [161, 161, 161],
                [162, 162, 162],
                [163, 163, 163],
                [164, 164, 164],
                [165, 165, 165],
                [166, 166, 166],
                [167, 167, 167],
                [168, 168, 168],
                [169, 169, 169],
                [170, 170, 170],
                [171, 171, 171],
                [172, 172, 172],
                [173, 173, 173],
                [174, 174, 174],
                [175, 175, 175],
                [176, 176, 176],
                [177, 177, 177],
                [178, 178, 178],
                [179, 179, 179],
                [180, 180, 180],
                [181, 181, 181],
                [182, 182, 182],
                [183, 183, 183],
                [184, 184, 184],
                [185, 185, 185],
                [186, 186, 186],
                [187, 187, 187],
                [188, 188, 188],
                [189, 189, 189],
                [190, 190, 190],
                [191, 191, 191],
                [192, 192, 192],
                [193, 193, 193],
                [194, 194, 194],
                [195, 195, 195],
                [196, 196, 196],
                [197, 197, 197],
                [198, 198, 198],
                [199, 199, 199],
                [200, 200, 200],
                [201, 201, 201],
                [202, 202, 202],
                [203, 203, 203],
                [204, 204, 204],
                [205, 205, 205],
                [206, 206, 206],
                [207, 207, 207],
                [208, 208, 208],
                [209, 209, 209],
                [210, 210, 210],
                [211, 211, 211],
                [212, 212, 212],
                [213, 213, 213],
                [214, 214, 214],
                [215, 215, 215],
                [216, 216, 216],
                [217, 217, 217],
                [218, 218, 218],
                [219, 219, 219],
                [220, 220, 220],
                [221, 221, 221],
                [222, 222, 222],
                [223, 223, 223],
                [224, 224, 224],
                [225, 225, 225],
                [226, 226, 226],
                [227, 227, 227],
                [228, 228, 228],
                [229, 229, 229],
                [230, 230, 230],
                [231, 231, 231],
                [232, 232, 232],
                [233, 233, 233],
                [234, 234, 234],
                [235, 235, 235],
                [236, 236, 236],
                [237, 237, 237],
                [238, 238, 238],
                [239, 239, 239],
                [240, 240, 240],
                [241, 241, 241],
                [242, 242, 242],
                [243, 243, 243],
                [244, 244, 244],
                [245, 245, 245],
                [246, 246, 246],
                [247, 247, 247],
                [248, 248, 248],
                [249, 249, 249],
                [250, 250, 250],
                [251, 251, 251],
                [252, 252, 252],
                [253, 253, 253],
                [254, 254, 254],
                [255, 0, 0],
            ],
        );

        m.insert(
            "I Blue",
            [
                [255, 255, 255],
                [254, 254, 255],
                [253, 253, 255],
                [252, 252, 255],
                [251, 251, 255],
                [250, 250, 255],
                [249, 249, 255],
                [248, 248, 255],
                [247, 247, 255],
                [246, 246, 255],
                [245, 245, 255],
                [244, 244, 255],
                [243, 243, 255],
                [242, 242, 255],
                [241, 241, 255],
                [240, 240, 255],
                [239, 239, 255],
                [238, 238, 255],
                [237, 237, 255],
                [236, 236, 255],
                [235, 235, 255],
                [234, 234, 255],
                [233, 233, 255],
                [232, 232, 255],
                [231, 231, 255],
                [230, 230, 255],
                [229, 229, 255],
                [228, 228, 255],
                [227, 227, 255],
                [226, 226, 255],
                [225, 225, 255],
                [224, 224, 255],
                [223, 223, 255],
                [222, 222, 255],
                [221, 221, 255],
                [220, 220, 255],
                [219, 219, 255],
                [218, 218, 255],
                [217, 217, 255],
                [216, 216, 255],
                [215, 215, 255],
                [214, 214, 255],
                [213, 213, 255],
                [212, 212, 255],
                [211, 211, 255],
                [210, 210, 255],
                [209, 209, 255],
                [208, 208, 255],
                [207, 207, 255],
                [206, 206, 255],
                [205, 205, 255],
                [204, 204, 255],
                [203, 203, 255],
                [202, 202, 255],
                [201, 201, 255],
                [200, 200, 255],
                [199, 199, 255],
                [198, 198, 255],
                [197, 197, 255],
                [196, 196, 255],
                [195, 195, 255],
                [194, 194, 255],
                [193, 193, 255],
                [192, 192, 255],
                [191, 191, 255],
                [190, 190, 255],
                [189, 189, 255],
                [188, 188, 255],
                [187, 187, 255],
                [186, 186, 255],
                [185, 185, 255],
                [184, 184, 255],
                [183, 183, 255],
                [182, 182, 255],
                [181, 181, 255],
                [180, 180, 255],
                [179, 179, 255],
                [178, 178, 255],
                [177, 177, 255],
                [176, 176, 255],
                [175, 175, 255],
                [174, 174, 255],
                [173, 173, 255],
                [172, 172, 255],
                [171, 171, 255],
                [170, 170, 255],
                [169, 169, 255],
                [168, 168, 255],
                [167, 167, 255],
                [166, 166, 255],
                [165, 165, 255],
                [164, 164, 255],
                [163, 163, 255],
                [162, 162, 255],
                [161, 161, 255],
                [160, 160, 255],
                [159, 159, 255],
                [158, 158, 255],
                [157, 157, 255],
                [156, 156, 255],
                [155, 155, 255],
                [154, 154, 255],
                [153, 153, 255],
                [152, 152, 255],
                [151, 151, 255],
                [150, 150, 255],
                [149, 149, 255],
                [148, 148, 255],
                [147, 147, 255],
                [146, 146, 255],
                [145, 145, 255],
                [144, 144, 255],
                [143, 143, 255],
                [142, 142, 255],
                [141, 141, 255],
                [140, 140, 255],
                [139, 139, 255],
                [138, 138, 255],
                [137, 137, 255],
                [136, 136, 255],
                [135, 135, 255],
                [134, 134, 255],
                [133, 133, 255],
                [132, 132, 255],
                [131, 131, 255],
                [130, 130, 255],
                [129, 129, 255],
                [128, 128, 255],
                [127, 127, 255],
                [126, 126, 255],
                [125, 125, 255],
                [124, 124, 255],
                [123, 123, 255],
                [122, 122, 255],
                [121, 121, 255],
                [120, 120, 255],
                [119, 119, 255],
                [118, 118, 255],
                [117, 117, 255],
                [116, 116, 255],
                [115, 115, 255],
                [114, 114, 255],
                [113, 113, 255],
                [112, 112, 255],
                [111, 111, 255],
                [110, 110, 255],
                [109, 109, 255],
                [108, 108, 255],
                [107, 107, 255],
                [106, 106, 255],
                [105, 105, 255],
                [104, 104, 255],
                [103, 103, 255],
                [102, 102, 255],
                [101, 101, 255],
                [100, 100, 255],
                [99, 99, 255],
                [98, 98, 255],
                [97, 97, 255],
                [96, 96, 255],
                [95, 95, 255],
                [94, 94, 255],
                [93, 93, 255],
                [92, 92, 255],
                [91, 91, 255],
                [90, 90, 255],
                [89, 89, 255],
                [88, 88, 255],
                [87, 87, 255],
                [86, 86, 255],
                [85, 85, 255],
                [84, 84, 255],
                [83, 83, 255],
                [82, 82, 255],
                [81, 81, 255],
                [80, 80, 255],
                [79, 79, 255],
                [78, 78, 255],
                [77, 77, 255],
                [76, 76, 255],
                [75, 75, 255],
                [74, 74, 255],
                [73, 73, 255],
                [72, 72, 255],
                [71, 71, 255],
                [70, 70, 255],
                [69, 69, 255],
                [68, 68, 255],
                [67, 67, 255],
                [66, 66, 255],
                [65, 65, 255],
                [64, 64, 255],
                [63, 63, 255],
                [62, 62, 255],
                [61, 61, 255],
                [60, 60, 255],
                [59, 59, 255],
                [58, 58, 255],
                [57, 57, 255],
                [56, 56, 255],
                [55, 55, 255],
                [54, 54, 255],
                [53, 53, 255],
                [52, 52, 255],
                [51, 51, 255],
                [50, 50, 255],
                [49, 49, 255],
                [48, 48, 255],
                [47, 47, 255],
                [46, 46, 255],
                [45, 45, 255],
                [44, 44, 255],
                [43, 43, 255],
                [42, 42, 255],
                [41, 41, 255],
                [40, 40, 255],
                [39, 39, 255],
                [38, 38, 255],
                [37, 37, 255],
                [36, 36, 255],
                [35, 35, 255],
                [34, 34, 255],
                [33, 33, 255],
                [32, 32, 255],
                [31, 31, 255],
                [30, 30, 255],
                [29, 29, 255],
                [28, 28, 255],
                [27, 27, 255],
                [26, 26, 255],
                [25, 25, 255],
                [24, 24, 255],
                [23, 23, 255],
                [22, 22, 255],
                [21, 21, 255],
                [20, 20, 255],
                [19, 19, 255],
                [18, 18, 255],
                [17, 17, 255],
                [16, 16, 255],
                [15, 15, 255],
                [14, 14, 255],
                [13, 13, 255],
                [12, 12, 255],
                [11, 11, 255],
                [10, 10, 255],
                [9, 9, 255],
                [8, 8, 255],
                [7, 7, 255],
                [6, 6, 255],
                [5, 5, 255],
                [4, 4, 255],
                [3, 3, 255],
                [2, 2, 255],
                [1, 1, 255],
                [0, 0, 255],
            ],
        );

        m.insert(
            "I Bordeaux",
            [
                [255, 255, 255],
                [254, 254, 254],
                [254, 253, 253],
                [254, 252, 252],
                [254, 251, 251],
                [254, 250, 251],
                [253, 249, 250],
                [253, 248, 249],
                [253, 247, 248],
                [253, 246, 247],
                [253, 245, 247],
                [252, 244, 246],
                [252, 243, 245],
                [252, 242, 244],
                [252, 241, 243],
                [252, 240, 243],
                [251, 239, 242],
                [251, 238, 241],
                [251, 237, 240],
                [251, 236, 239],
                [251, 235, 239],
                [250, 234, 238],
                [250, 233, 237],
                [250, 232, 236],
                [250, 231, 235],
                [250, 230, 235],
                [249, 229, 234],
                [249, 228, 233],
                [249, 227, 232],
                [249, 226, 231],
                [249, 225, 231],
                [248, 224, 230],
                [248, 223, 229],
                [248, 222, 228],
                [248, 221, 227],
                [248, 220, 227],
                [247, 219, 226],
                [247, 218, 225],
                [247, 217, 224],
                [247, 216, 223],
                [247, 215, 223],
                [246, 214, 222],
                [246, 213, 221],
                [246, 212, 220],
                [246, 211, 219],
                [246, 210, 219],
                [245, 209, 218],
                [245, 208, 217],
                [245, 207, 216],
                [245, 206, 215],
                [245, 205, 215],
                [244, 204, 214],
                [244, 203, 213],
                [244, 202, 212],
                [244, 201, 211],
                [244, 200, 211],
                [243, 199, 210],
                [243, 198, 209],
                [243, 197, 208],
                [243, 196, 207],
                [243, 195, 207],
                [242, 194, 206],
                [242, 193, 205],
                [242, 192, 204],
                [242, 191, 204],
                [242, 190, 203],
                [241, 189, 202],
                [241, 188, 201],
                [241, 187, 200],
                [241, 186, 200],
                [241, 185, 199],
                [240, 184, 198],
                [240, 183, 197],
                [240, 182, 196],
                [240, 181, 196],
                [240, 180, 195],
                [239, 179, 194],
                [239, 178, 193],
                [239, 177, 192],
                [239, 176, 192],
                [239, 175, 191],
                [238, 174, 190],
                [238, 173, 189],
                [238, 172, 188],
                [238, 171, 188],
                [238, 170, 187],
                [237, 169, 186],
                [237, 168, 185],
                [237, 167, 184],
                [237, 166, 184],
                [237, 165, 183],
                [236, 164, 182],
                [236, 163, 181],
                [236, 162, 180],
                [236, 161, 180],
                [236, 160, 179],
                [235, 159, 178],
                [235, 158, 177],
                [235, 157, 176],
                [235, 156, 176],
                [235, 155, 175],
                [234, 154, 174],
                [234, 153, 173],
                [234, 152, 172],
                [234, 151, 172],
                [234, 150, 171],
                [233, 149, 170],
                [233, 148, 169],
                [233, 147, 168],
                [233, 146, 168],
                [233, 145, 167],
                [232, 144, 166],
                [232, 143, 165],
                [232, 142, 164],
                [232, 141, 164],
                [232, 140, 163],
                [231, 139, 162],
                [231, 138, 161],
                [231, 137, 160],
                [231, 136, 160],
                [231, 135, 159],
                [230, 134, 158],
                [230, 133, 157],
                [230, 132, 156],
                [230, 131, 156],
                [230, 130, 155],
                [229, 129, 154],
                [229, 128, 153],
                [229, 127, 153],
                [229, 126, 152],
                [229, 125, 151],
                [228, 124, 150],
                [228, 123, 149],
                [228, 122, 149],
                [228, 121, 148],
                [228, 120, 147],
                [227, 119, 146],
                [227, 118, 145],
                [227, 117, 145],
                [227, 116, 144],
                [227, 115, 143],
                [226, 114, 142],
                [226, 113, 141],
                [226, 112, 141],
                [226, 111, 140],
                [226, 110, 139],
                [225, 109, 138],
                [225, 108, 137],
                [225, 107, 137],
                [225, 106, 136],
                [225, 105, 135],
                [224, 104, 134],
                [224, 103, 133],
                [224, 102, 133],
                [224, 101, 132],
                [224, 100, 131],
                [223, 99, 130],
                [223, 98, 129],
                [223, 97, 129],
                [223, 96, 128],
                [223, 95, 127],
                [222, 94, 126],
                [222, 93, 125],
                [222, 92, 125],
                [222, 91, 124],
                [222, 90, 123],
                [221, 89, 122],
                [221, 88, 121],
                [221, 87, 121],
                [221, 86, 120],
                [221, 85, 119],
                [220, 84, 118],
                [220, 83, 117],
                [220, 82, 117],
                [220, 81, 116],
                [220, 80, 115],
                [219, 79, 114],
                [219, 78, 113],
                [219, 77, 113],
                [219, 76, 112],
                [219, 75, 111],
                [218, 74, 110],
                [218, 73, 109],
                [218, 72, 109],
                [218, 71, 108],
                [218, 70, 107],
                [217, 69, 106],
                [217, 68, 105],
                [217, 67, 105],
                [217, 66, 104],
                [217, 65, 103],
                [216, 64, 102],
                [216, 63, 102],
                [216, 62, 101],
                [216, 61, 100],
                [216, 60, 99],
                [215, 59, 98],
                [215, 58, 98],
                [215, 57, 97],
                [215, 56, 96],
                [215, 55, 95],
                [214, 54, 94],
                [214, 53, 94],
                [214, 52, 93],
                [214, 51, 92],
                [214, 50, 91],
                [213, 49, 90],
                [213, 48, 90],
                [213, 47, 89],
                [213, 46, 88],
                [213, 45, 87],
                [212, 44, 86],
                [212, 43, 86],
                [212, 42, 85],
                [212, 41, 84],
                [212, 40, 83],
                [211, 39, 82],
                [211, 38, 82],
                [211, 37, 81],
                [211, 36, 80],
                [211, 35, 79],
                [210, 34, 78],
                [210, 33, 78],
                [210, 32, 77],
                [210, 31, 76],
                [210, 30, 75],
                [209, 29, 74],
                [209, 28, 74],
                [209, 27, 73],
                [209, 26, 72],
                [209, 25, 71],
                [208, 24, 70],
                [208, 23, 70],
                [208, 22, 69],
                [208, 21, 68],
                [208, 20, 67],
                [207, 19, 66],
                [207, 18, 66],
                [207, 17, 65],
                [207, 16, 64],
                [207, 15, 63],
                [206, 14, 62],
                [206, 13, 62],
                [206, 12, 61],
                [206, 11, 60],
                [206, 10, 59],
                [205, 9, 58],
                [205, 8, 58],
                [205, 7, 57],
                [205, 6, 56],
                [205, 5, 55],
                [204, 4, 54],
                [204, 3, 54],
                [204, 2, 53],
                [204, 1, 52],
                [204, 0, 51],
            ],
        );

        m.insert(
            "I Cyan",
            [
                [255, 255, 255],
                [254, 255, 255],
                [253, 255, 255],
                [252, 255, 255],
                [251, 255, 255],
                [250, 255, 255],
                [249, 255, 255],
                [248, 255, 255],
                [247, 255, 255],
                [246, 255, 255],
                [245, 255, 255],
                [244, 255, 255],
                [243, 255, 255],
                [242, 255, 255],
                [241, 255, 255],
                [240, 255, 255],
                [239, 255, 255],
                [238, 255, 255],
                [237, 255, 255],
                [236, 255, 255],
                [235, 255, 255],
                [234, 255, 255],
                [233, 255, 255],
                [232, 255, 255],
                [231, 255, 255],
                [230, 255, 255],
                [229, 255, 255],
                [228, 255, 255],
                [227, 255, 255],
                [226, 255, 255],
                [225, 255, 255],
                [224, 255, 255],
                [223, 255, 255],
                [222, 255, 255],
                [221, 255, 255],
                [220, 255, 255],
                [219, 255, 255],
                [218, 255, 255],
                [217, 255, 255],
                [216, 255, 255],
                [215, 255, 255],
                [214, 255, 255],
                [213, 255, 255],
                [212, 255, 255],
                [211, 255, 255],
                [210, 255, 255],
                [209, 255, 255],
                [208, 255, 255],
                [207, 255, 255],
                [206, 255, 255],
                [205, 255, 255],
                [204, 255, 255],
                [203, 255, 255],
                [202, 255, 255],
                [201, 255, 255],
                [200, 255, 255],
                [199, 255, 255],
                [198, 255, 255],
                [197, 255, 255],
                [196, 255, 255],
                [195, 255, 255],
                [194, 255, 255],
                [193, 255, 255],
                [192, 255, 255],
                [191, 255, 255],
                [190, 255, 255],
                [189, 255, 255],
                [188, 255, 255],
                [187, 255, 255],
                [186, 255, 255],
                [185, 255, 255],
                [184, 255, 255],
                [183, 255, 255],
                [182, 255, 255],
                [181, 255, 255],
                [180, 255, 255],
                [179, 255, 255],
                [178, 255, 255],
                [177, 255, 255],
                [176, 255, 255],
                [175, 255, 255],
                [174, 255, 255],
                [173, 255, 255],
                [172, 255, 255],
                [171, 255, 255],
                [170, 255, 255],
                [169, 255, 255],
                [168, 255, 255],
                [167, 255, 255],
                [166, 255, 255],
                [165, 255, 255],
                [164, 255, 255],
                [163, 255, 255],
                [162, 255, 255],
                [161, 255, 255],
                [160, 255, 255],
                [159, 255, 255],
                [158, 255, 255],
                [157, 255, 255],
                [156, 255, 255],
                [155, 255, 255],
                [154, 255, 255],
                [153, 255, 255],
                [152, 255, 255],
                [151, 255, 255],
                [150, 255, 255],
                [149, 255, 255],
                [148, 255, 255],
                [147, 255, 255],
                [146, 255, 255],
                [145, 255, 255],
                [144, 255, 255],
                [143, 255, 255],
                [142, 255, 255],
                [141, 255, 255],
                [140, 255, 255],
                [139, 255, 255],
                [138, 255, 255],
                [137, 255, 255],
                [136, 255, 255],
                [135, 255, 255],
                [134, 255, 255],
                [133, 255, 255],
                [132, 255, 255],
                [131, 255, 255],
                [130, 255, 255],
                [129, 255, 255],
                [128, 255, 255],
                [127, 255, 255],
                [126, 255, 255],
                [125, 255, 255],
                [124, 255, 255],
                [123, 255, 255],
                [122, 255, 255],
                [121, 255, 255],
                [120, 255, 255],
                [119, 255, 255],
                [118, 255, 255],
                [117, 255, 255],
                [116, 255, 255],
                [115, 255, 255],
                [114, 255, 255],
                [113, 255, 255],
                [112, 255, 255],
                [111, 255, 255],
                [110, 255, 255],
                [109, 255, 255],
                [108, 255, 255],
                [107, 255, 255],
                [106, 255, 255],
                [105, 255, 255],
                [104, 255, 255],
                [103, 255, 255],
                [102, 255, 255],
                [101, 255, 255],
                [100, 255, 255],
                [99, 255, 255],
                [98, 255, 255],
                [97, 255, 255],
                [96, 255, 255],
                [95, 255, 255],
                [94, 255, 255],
                [93, 255, 255],
                [92, 255, 255],
                [91, 255, 255],
                [90, 255, 255],
                [89, 255, 255],
                [88, 255, 255],
                [87, 255, 255],
                [86, 255, 255],
                [85, 255, 255],
                [84, 255, 255],
                [83, 255, 255],
                [82, 255, 255],
                [81, 255, 255],
                [80, 255, 255],
                [79, 255, 255],
                [78, 255, 255],
                [77, 255, 255],
                [76, 255, 255],
                [75, 255, 255],
                [74, 255, 255],
                [73, 255, 255],
                [72, 255, 255],
                [71, 255, 255],
                [70, 255, 255],
                [69, 255, 255],
                [68, 255, 255],
                [67, 255, 255],
                [66, 255, 255],
                [65, 255, 255],
                [64, 255, 255],
                [63, 255, 255],
                [62, 255, 255],
                [61, 255, 255],
                [60, 255, 255],
                [59, 255, 255],
                [58, 255, 255],
                [57, 255, 255],
                [56, 255, 255],
                [55, 255, 255],
                [54, 255, 255],
                [53, 255, 255],
                [52, 255, 255],
                [51, 255, 255],
                [50, 255, 255],
                [49, 255, 255],
                [48, 255, 255],
                [47, 255, 255],
                [46, 255, 255],
                [45, 255, 255],
                [44, 255, 255],
                [43, 255, 255],
                [42, 255, 255],
                [41, 255, 255],
                [40, 255, 255],
                [39, 255, 255],
                [38, 255, 255],
                [37, 255, 255],
                [36, 255, 255],
                [35, 255, 255],
                [34, 255, 255],
                [33, 255, 255],
                [32, 255, 255],
                [31, 255, 255],
                [30, 255, 255],
                [29, 255, 255],
                [28, 255, 255],
                [27, 255, 255],
                [26, 255, 255],
                [25, 255, 255],
                [24, 255, 255],
                [23, 255, 255],
                [22, 255, 255],
                [21, 255, 255],
                [20, 255, 255],
                [19, 255, 255],
                [18, 255, 255],
                [17, 255, 255],
                [16, 255, 255],
                [15, 255, 255],
                [14, 255, 255],
                [13, 255, 255],
                [12, 255, 255],
                [11, 255, 255],
                [10, 255, 255],
                [9, 255, 255],
                [8, 255, 255],
                [7, 255, 255],
                [6, 255, 255],
                [5, 255, 255],
                [4, 255, 255],
                [3, 255, 255],
                [2, 255, 255],
                [1, 255, 255],
                [0, 255, 255],
            ],
        );

        m.insert(
            "I Forest",
            [
                [255, 255, 255],
                [254, 254, 254],
                [253, 254, 253],
                [252, 253, 252],
                [251, 253, 251],
                [250, 253, 250],
                [249, 252, 249],
                [248, 252, 248],
                [247, 251, 247],
                [246, 251, 246],
                [245, 251, 245],
                [244, 250, 244],
                [243, 250, 243],
                [242, 249, 242],
                [241, 249, 241],
                [240, 249, 240],
                [239, 248, 239],
                [238, 248, 238],
                [237, 247, 237],
                [236, 247, 236],
                [235, 247, 235],
                [234, 246, 234],
                [233, 246, 233],
                [232, 245, 232],
                [231, 245, 231],
                [230, 245, 230],
                [229, 244, 229],
                [228, 244, 228],
                [227, 243, 227],
                [226, 243, 226],
                [225, 243, 225],
                [224, 242, 224],
                [223, 242, 223],
                [222, 241, 222],
                [221, 241, 221],
                [220, 241, 220],
                [219, 240, 219],
                [218, 240, 218],
                [217, 239, 217],
                [216, 239, 216],
                [215, 239, 215],
                [214, 238, 214],
                [213, 238, 213],
                [212, 237, 212],
                [211, 237, 211],
                [210, 237, 210],
                [209, 236, 209],
                [208, 236, 208],
                [207, 235, 207],
                [206, 235, 206],
                [205, 235, 205],
                [204, 234, 204],
                [203, 234, 203],
                [202, 233, 202],
                [201, 233, 201],
                [200, 233, 200],
                [199, 232, 199],
                [198, 232, 198],
                [197, 231, 197],
                [196, 231, 196],
                [195, 231, 195],
                [194, 230, 194],
                [193, 230, 193],
                [192, 229, 192],
                [191, 229, 191],
                [190, 229, 190],
                [189, 228, 189],
                [188, 228, 188],
                [187, 227, 187],
                [186, 227, 186],
                [185, 227, 185],
                [184, 226, 184],
                [183, 226, 183],
                [182, 225, 182],
                [181, 225, 181],
                [180, 225, 180],
                [179, 224, 179],
                [178, 224, 178],
                [177, 223, 177],
                [176, 223, 176],
                [175, 223, 175],
                [174, 222, 174],
                [173, 222, 173],
                [172, 221, 172],
                [171, 221, 171],
                [170, 221, 170],
                [169, 220, 169],
                [168, 220, 168],
                [167, 219, 167],
                [166, 219, 166],
                [165, 219, 165],
                [164, 218, 164],
                [163, 218, 163],
                [162, 217, 162],
                [161, 217, 161],
                [160, 217, 160],
                [159, 216, 159],
                [158, 216, 158],
                [157, 215, 157],
                [156, 215, 156],
                [155, 215, 155],
                [154, 214, 154],
                [153, 214, 153],
                [152, 213, 152],
                [151, 213, 151],
                [150, 213, 150],
                [149, 212, 149],
                [148, 212, 148],
                [147, 211, 147],
                [146, 211, 146],
                [145, 211, 145],
                [144, 210, 144],
                [143, 210, 143],
                [142, 209, 142],
                [141, 209, 141],
                [140, 209, 140],
                [139, 208, 139],
                [138, 208, 138],
                [137, 207, 137],
                [136, 207, 136],
                [135, 207, 135],
                [134, 206, 134],
                [133, 206, 133],
                [132, 205, 132],
                [131, 205, 131],
                [130, 205, 130],
                [129, 204, 129],
                [128, 204, 128],
                [127, 204, 127],
                [126, 203, 126],
                [125, 203, 125],
                [124, 202, 124],
                [123, 202, 123],
                [122, 202, 122],
                [121, 201, 121],
                [120, 201, 120],
                [119, 200, 119],
                [118, 200, 118],
                [117, 200, 117],
                [116, 199, 116],
                [115, 199, 115],
                [114, 198, 114],
                [113, 198, 113],
                [112, 198, 112],
                [111, 197, 111],
                [110, 197, 110],
                [109, 196, 109],
                [108, 196, 108],
                [107, 196, 107],
                [106, 195, 106],
                [105, 195, 105],
                [104, 194, 104],
                [103, 194, 103],
                [102, 194, 102],
                [101, 193, 101],
                [100, 193, 100],
                [99, 192, 99],
                [98, 192, 98],
                [97, 192, 97],
                [96, 191, 96],
                [95, 191, 95],
                [94, 190, 94],
                [93, 190, 93],
                [92, 190, 92],
                [91, 189, 91],
                [90, 189, 90],
                [89, 188, 89],
                [88, 188, 88],
                [87, 188, 87],
                [86, 187, 86],
                [85, 187, 85],
                [84, 186, 84],
                [83, 186, 83],
                [82, 186, 82],
                [81, 185, 81],
                [80, 185, 80],
                [79, 184, 79],
                [78, 184, 78],
                [77, 184, 77],
                [76, 183, 76],
                [75, 183, 75],
                [74, 182, 74],
                [73, 182, 73],
                [72, 182, 72],
                [71, 181, 71],
                [70, 181, 70],
                [69, 180, 69],
                [68, 180, 68],
                [67, 180, 67],
                [66, 179, 66],
                [65, 179, 65],
                [64, 178, 64],
                [63, 178, 63],
                [62, 178, 62],
                [61, 177, 61],
                [60, 177, 60],
                [59, 176, 59],
                [58, 176, 58],
                [57, 176, 57],
                [56, 175, 56],
                [55, 175, 55],
                [54, 174, 54],
                [53, 174, 53],
                [52, 174, 52],
                [51, 173, 51],
                [50, 173, 50],
                [49, 172, 49],
                [48, 172, 48],
                [47, 172, 47],
                [46, 171, 46],
                [45, 171, 45],
                [44, 170, 44],
                [43, 170, 43],
                [42, 170, 42],
                [41, 169, 41],
                [40, 169, 40],
                [39, 168, 39],
                [38, 168, 38],
                [37, 168, 37],
                [36, 167, 36],
                [35, 167, 35],
                [34, 166, 34],
                [33, 166, 33],
                [32, 166, 32],
                [31, 165, 31],
                [30, 165, 30],
                [29, 164, 29],
                [28, 164, 28],
                [27, 164, 27],
                [26, 163, 26],
                [25, 163, 25],
                [24, 162, 24],
                [23, 162, 23],
                [22, 162, 22],
                [21, 161, 21],
                [20, 161, 20],
                [19, 160, 19],
                [18, 160, 18],
                [17, 160, 17],
                [16, 159, 16],
                [15, 159, 15],
                [14, 158, 14],
                [13, 158, 13],
                [12, 158, 12],
                [11, 157, 11],
                [10, 157, 10],
                [9, 156, 9],
                [8, 156, 8],
                [7, 156, 7],
                [6, 155, 6],
                [5, 155, 5],
                [4, 154, 4],
                [3, 154, 3],
                [2, 154, 2],
                [1, 153, 1],
                [0, 153, 0],
            ],
        );

        m.insert(
            "I Green",
            [
                [255, 255, 255],
                [254, 255, 254],
                [253, 255, 253],
                [252, 255, 252],
                [251, 255, 251],
                [250, 255, 250],
                [249, 255, 249],
                [248, 255, 248],
                [247, 255, 247],
                [246, 255, 246],
                [245, 255, 245],
                [244, 255, 244],
                [243, 255, 243],
                [242, 255, 242],
                [241, 255, 241],
                [240, 255, 240],
                [239, 255, 239],
                [238, 255, 238],
                [237, 255, 237],
                [236, 255, 236],
                [235, 255, 235],
                [234, 255, 234],
                [233, 255, 233],
                [232, 255, 232],
                [231, 255, 231],
                [230, 255, 230],
                [229, 255, 229],
                [228, 255, 228],
                [227, 255, 227],
                [226, 255, 226],
                [225, 255, 225],
                [224, 255, 224],
                [223, 255, 223],
                [222, 255, 222],
                [221, 255, 221],
                [220, 255, 220],
                [219, 255, 219],
                [218, 255, 218],
                [217, 255, 217],
                [216, 255, 216],
                [215, 255, 215],
                [214, 255, 214],
                [213, 255, 213],
                [212, 255, 212],
                [211, 255, 211],
                [210, 255, 210],
                [209, 255, 209],
                [208, 255, 208],
                [207, 255, 207],
                [206, 255, 206],
                [205, 255, 205],
                [204, 255, 204],
                [203, 255, 203],
                [202, 255, 202],
                [201, 255, 201],
                [200, 255, 200],
                [199, 255, 199],
                [198, 255, 198],
                [197, 255, 197],
                [196, 255, 196],
                [195, 255, 195],
                [194, 255, 194],
                [193, 255, 193],
                [192, 255, 192],
                [191, 255, 191],
                [190, 255, 190],
                [189, 255, 189],
                [188, 255, 188],
                [187, 255, 187],
                [186, 255, 186],
                [185, 255, 185],
                [184, 255, 184],
                [183, 255, 183],
                [182, 255, 182],
                [181, 255, 181],
                [180, 255, 180],
                [179, 255, 179],
                [178, 255, 178],
                [177, 255, 177],
                [176, 255, 176],
                [175, 255, 175],
                [174, 255, 174],
                [173, 255, 173],
                [172, 255, 172],
                [171, 255, 171],
                [170, 255, 170],
                [169, 255, 169],
                [168, 255, 168],
                [167, 255, 167],
                [166, 255, 166],
                [165, 255, 165],
                [164, 255, 164],
                [163, 255, 163],
                [162, 255, 162],
                [161, 255, 161],
                [160, 255, 160],
                [159, 255, 159],
                [158, 255, 158],
                [157, 255, 157],
                [156, 255, 156],
                [155, 255, 155],
                [154, 255, 154],
                [153, 255, 153],
                [152, 255, 152],
                [151, 255, 151],
                [150, 255, 150],
                [149, 255, 149],
                [148, 255, 148],
                [147, 255, 147],
                [146, 255, 146],
                [145, 255, 145],
                [144, 255, 144],
                [143, 255, 143],
                [142, 255, 142],
                [141, 255, 141],
                [140, 255, 140],
                [139, 255, 139],
                [138, 255, 138],
                [137, 255, 137],
                [136, 255, 136],
                [135, 255, 135],
                [134, 255, 134],
                [133, 255, 133],
                [132, 255, 132],
                [131, 255, 131],
                [130, 255, 130],
                [129, 255, 129],
                [128, 255, 128],
                [127, 255, 127],
                [126, 255, 126],
                [125, 255, 125],
                [124, 255, 124],
                [123, 255, 123],
                [122, 255, 122],
                [121, 255, 121],
                [120, 255, 120],
                [119, 255, 119],
                [118, 255, 118],
                [117, 255, 117],
                [116, 255, 116],
                [115, 255, 115],
                [114, 255, 114],
                [113, 255, 113],
                [112, 255, 112],
                [111, 255, 111],
                [110, 255, 110],
                [109, 255, 109],
                [108, 255, 108],
                [107, 255, 107],
                [106, 255, 106],
                [105, 255, 105],
                [104, 255, 104],
                [103, 255, 103],
                [102, 255, 102],
                [101, 255, 101],
                [100, 255, 100],
                [99, 255, 99],
                [98, 255, 98],
                [97, 255, 97],
                [96, 255, 96],
                [95, 255, 95],
                [94, 255, 94],
                [93, 255, 93],
                [92, 255, 92],
                [91, 255, 91],
                [90, 255, 90],
                [89, 255, 89],
                [88, 255, 88],
                [87, 255, 87],
                [86, 255, 86],
                [85, 255, 85],
                [84, 255, 84],
                [83, 255, 83],
                [82, 255, 82],
                [81, 255, 81],
                [80, 255, 80],
                [79, 255, 79],
                [78, 255, 78],
                [77, 255, 77],
                [76, 255, 76],
                [75, 255, 75],
                [74, 255, 74],
                [73, 255, 73],
                [72, 255, 72],
                [71, 255, 71],
                [70, 255, 70],
                [69, 255, 69],
                [68, 255, 68],
                [67, 255, 67],
                [66, 255, 66],
                [65, 255, 65],
                [64, 255, 64],
                [63, 255, 63],
                [62, 255, 62],
                [61, 255, 61],
                [60, 255, 60],
                [59, 255, 59],
                [58, 255, 58],
                [57, 255, 57],
                [56, 255, 56],
                [55, 255, 55],
                [54, 255, 54],
                [53, 255, 53],
                [52, 255, 52],
                [51, 255, 51],
                [50, 255, 50],
                [49, 255, 49],
                [48, 255, 48],
                [47, 255, 47],
                [46, 255, 46],
                [45, 255, 45],
                [44, 255, 44],
                [43, 255, 43],
                [42, 255, 42],
                [41, 255, 41],
                [40, 255, 40],
                [39, 255, 39],
                [38, 255, 38],
                [37, 255, 37],
                [36, 255, 36],
                [35, 255, 35],
                [34, 255, 34],
                [33, 255, 33],
                [32, 255, 32],
                [31, 255, 31],
                [30, 255, 30],
                [29, 255, 29],
                [28, 255, 28],
                [27, 255, 27],
                [26, 255, 26],
                [25, 255, 25],
                [24, 255, 24],
                [23, 255, 23],
                [22, 255, 22],
                [21, 255, 21],
                [20, 255, 20],
                [19, 255, 19],
                [18, 255, 18],
                [17, 255, 17],
                [16, 255, 16],
                [15, 255, 15],
                [14, 255, 14],
                [13, 255, 13],
                [12, 255, 12],
                [11, 255, 11],
                [10, 255, 10],
                [9, 255, 9],
                [8, 255, 8],
                [7, 255, 7],
                [6, 255, 6],
                [5, 255, 5],
                [4, 255, 4],
                [3, 255, 3],
                [2, 255, 2],
                [1, 255, 1],
                [0, 255, 0],
            ],
        );

        m.insert(
            "I Magenta",
            [
                [255, 255, 255],
                [255, 254, 255],
                [255, 253, 255],
                [255, 252, 255],
                [255, 251, 255],
                [255, 250, 255],
                [255, 249, 255],
                [255, 248, 255],
                [255, 247, 255],
                [255, 246, 255],
                [255, 245, 255],
                [255, 244, 255],
                [255, 243, 255],
                [255, 242, 255],
                [255, 241, 255],
                [255, 240, 255],
                [255, 239, 255],
                [255, 238, 255],
                [255, 237, 255],
                [255, 236, 255],
                [255, 235, 255],
                [255, 234, 255],
                [255, 233, 255],
                [255, 232, 255],
                [255, 231, 255],
                [255, 230, 255],
                [255, 229, 255],
                [255, 228, 255],
                [255, 227, 255],
                [255, 226, 255],
                [255, 225, 255],
                [255, 224, 255],
                [255, 223, 255],
                [255, 222, 255],
                [255, 221, 255],
                [255, 220, 255],
                [255, 219, 255],
                [255, 218, 255],
                [255, 217, 255],
                [255, 216, 255],
                [255, 215, 255],
                [255, 214, 255],
                [255, 213, 255],
                [255, 212, 255],
                [255, 211, 255],
                [255, 210, 255],
                [255, 209, 255],
                [255, 208, 255],
                [255, 207, 255],
                [255, 206, 255],
                [255, 205, 255],
                [255, 204, 255],
                [255, 203, 255],
                [255, 202, 255],
                [255, 201, 255],
                [255, 200, 255],
                [255, 199, 255],
                [255, 198, 255],
                [255, 197, 255],
                [255, 196, 255],
                [255, 195, 255],
                [255, 194, 255],
                [255, 193, 255],
                [255, 192, 255],
                [255, 191, 255],
                [255, 190, 255],
                [255, 189, 255],
                [255, 188, 255],
                [255, 187, 255],
                [255, 186, 255],
                [255, 185, 255],
                [255, 184, 255],
                [255, 183, 255],
                [255, 182, 255],
                [255, 181, 255],
                [255, 180, 255],
                [255, 179, 255],
                [255, 178, 255],
                [255, 177, 255],
                [255, 176, 255],
                [255, 175, 255],
                [255, 174, 255],
                [255, 173, 255],
                [255, 172, 255],
                [255, 171, 255],
                [255, 170, 255],
                [255, 169, 255],
                [255, 168, 255],
                [255, 167, 255],
                [255, 166, 255],
                [255, 165, 255],
                [255, 164, 255],
                [255, 163, 255],
                [255, 162, 255],
                [255, 161, 255],
                [255, 160, 255],
                [255, 159, 255],
                [255, 158, 255],
                [255, 157, 255],
                [255, 156, 255],
                [255, 155, 255],
                [255, 154, 255],
                [255, 153, 255],
                [255, 152, 255],
                [255, 151, 255],
                [255, 150, 255],
                [255, 149, 255],
                [255, 148, 255],
                [255, 147, 255],
                [255, 146, 255],
                [255, 145, 255],
                [255, 144, 255],
                [255, 143, 255],
                [255, 142, 255],
                [255, 141, 255],
                [255, 140, 255],
                [255, 139, 255],
                [255, 138, 255],
                [255, 137, 255],
                [255, 136, 255],
                [255, 135, 255],
                [255, 134, 255],
                [255, 133, 255],
                [255, 132, 255],
                [255, 131, 255],
                [255, 130, 255],
                [255, 129, 255],
                [255, 128, 255],
                [255, 127, 255],
                [255, 126, 255],
                [255, 125, 255],
                [255, 124, 255],
                [255, 123, 255],
                [255, 122, 255],
                [255, 121, 255],
                [255, 120, 255],
                [255, 119, 255],
                [255, 118, 255],
                [255, 117, 255],
                [255, 116, 255],
                [255, 115, 255],
                [255, 114, 255],
                [255, 113, 255],
                [255, 112, 255],
                [255, 111, 255],
                [255, 110, 255],
                [255, 109, 255],
                [255, 108, 255],
                [255, 107, 255],
                [255, 106, 255],
                [255, 105, 255],
                [255, 104, 255],
                [255, 103, 255],
                [255, 102, 255],
                [255, 101, 255],
                [255, 100, 255],
                [255, 99, 255],
                [255, 98, 255],
                [255, 97, 255],
                [255, 96, 255],
                [255, 95, 255],
                [255, 94, 255],
                [255, 93, 255],
                [255, 92, 255],
                [255, 91, 255],
                [255, 90, 255],
                [255, 89, 255],
                [255, 88, 255],
                [255, 87, 255],
                [255, 86, 255],
                [255, 85, 255],
                [255, 84, 255],
                [255, 83, 255],
                [255, 82, 255],
                [255, 81, 255],
                [255, 80, 255],
                [255, 79, 255],
                [255, 78, 255],
                [255, 77, 255],
                [255, 76, 255],
                [255, 75, 255],
                [255, 74, 255],
                [255, 73, 255],
                [255, 72, 255],
                [255, 71, 255],
                [255, 70, 255],
                [255, 69, 255],
                [255, 68, 255],
                [255, 67, 255],
                [255, 66, 255],
                [255, 65, 255],
                [255, 64, 255],
                [255, 63, 255],
                [255, 62, 255],
                [255, 61, 255],
                [255, 60, 255],
                [255, 59, 255],
                [255, 58, 255],
                [255, 57, 255],
                [255, 56, 255],
                [255, 55, 255],
                [255, 54, 255],
                [255, 53, 255],
                [255, 52, 255],
                [255, 51, 255],
                [255, 50, 255],
                [255, 49, 255],
                [255, 48, 255],
                [255, 47, 255],
                [255, 46, 255],
                [255, 45, 255],
                [255, 44, 255],
                [255, 43, 255],
                [255, 42, 255],
                [255, 41, 255],
                [255, 40, 255],
                [255, 39, 255],
                [255, 38, 255],
                [255, 37, 255],
                [255, 36, 255],
                [255, 35, 255],
                [255, 34, 255],
                [255, 33, 255],
                [255, 32, 255],
                [255, 31, 255],
                [255, 30, 255],
                [255, 29, 255],
                [255, 28, 255],
                [255, 27, 255],
                [255, 26, 255],
                [255, 25, 255],
                [255, 24, 255],
                [255, 23, 255],
                [255, 22, 255],
                [255, 21, 255],
                [255, 20, 255],
                [255, 19, 255],
                [255, 18, 255],
                [255, 17, 255],
                [255, 16, 255],
                [255, 15, 255],
                [255, 14, 255],
                [255, 13, 255],
                [255, 12, 255],
                [255, 11, 255],
                [255, 10, 255],
                [255, 9, 255],
                [255, 8, 255],
                [255, 7, 255],
                [255, 6, 255],
                [255, 5, 255],
                [255, 4, 255],
                [255, 3, 255],
                [255, 2, 255],
                [255, 1, 255],
                [255, 0, 255],
            ],
        );

        m.insert(
            "I Purple",
            [
                [255, 255, 255],
                [254, 254, 254],
                [254, 253, 254],
                [254, 252, 254],
                [254, 251, 254],
                [254, 250, 254],
                [253, 249, 253],
                [253, 248, 253],
                [253, 247, 253],
                [253, 246, 253],
                [253, 245, 253],
                [252, 244, 252],
                [252, 243, 252],
                [252, 242, 252],
                [252, 241, 252],
                [252, 240, 252],
                [251, 239, 251],
                [251, 238, 251],
                [251, 237, 251],
                [251, 236, 251],
                [251, 235, 251],
                [250, 234, 250],
                [250, 233, 250],
                [250, 232, 250],
                [250, 231, 250],
                [250, 230, 250],
                [249, 229, 249],
                [249, 228, 249],
                [249, 227, 249],
                [249, 226, 249],
                [249, 225, 249],
                [248, 224, 248],
                [248, 223, 248],
                [248, 222, 248],
                [248, 221, 248],
                [248, 220, 248],
                [247, 219, 247],
                [247, 218, 247],
                [247, 217, 247],
                [247, 216, 247],
                [247, 215, 247],
                [246, 214, 246],
                [246, 213, 246],
                [246, 212, 246],
                [246, 211, 246],
                [246, 210, 246],
                [245, 209, 245],
                [245, 208, 245],
                [245, 207, 245],
                [245, 206, 245],
                [245, 205, 245],
                [244, 204, 244],
                [244, 203, 244],
                [244, 202, 244],
                [244, 201, 244],
                [244, 200, 244],
                [243, 199, 243],
                [243, 198, 243],
                [243, 197, 243],
                [243, 196, 243],
                [243, 195, 243],
                [242, 194, 242],
                [242, 193, 242],
                [242, 192, 242],
                [242, 191, 242],
                [242, 190, 242],
                [241, 189, 241],
                [241, 188, 241],
                [241, 187, 241],
                [241, 186, 241],
                [241, 185, 241],
                [240, 184, 240],
                [240, 183, 240],
                [240, 182, 240],
                [240, 181, 240],
                [240, 180, 240],
                [239, 179, 239],
                [239, 178, 239],
                [239, 177, 239],
                [239, 176, 239],
                [239, 175, 239],
                [238, 174, 238],
                [238, 173, 238],
                [238, 172, 238],
                [238, 171, 238],
                [238, 170, 238],
                [237, 169, 237],
                [237, 168, 237],
                [237, 167, 237],
                [237, 166, 237],
                [237, 165, 237],
                [236, 164, 236],
                [236, 163, 236],
                [236, 162, 236],
                [236, 161, 236],
                [236, 160, 236],
                [235, 159, 235],
                [235, 158, 235],
                [235, 157, 235],
                [235, 156, 235],
                [235, 155, 235],
                [234, 154, 234],
                [234, 153, 234],
                [234, 152, 234],
                [234, 151, 234],
                [234, 150, 234],
                [233, 149, 233],
                [233, 148, 233],
                [233, 147, 233],
                [233, 146, 233],
                [233, 145, 233],
                [232, 144, 232],
                [232, 143, 232],
                [232, 142, 232],
                [232, 141, 232],
                [232, 140, 232],
                [231, 139, 231],
                [231, 138, 231],
                [231, 137, 231],
                [231, 136, 231],
                [231, 135, 231],
                [230, 134, 230],
                [230, 133, 230],
                [230, 132, 230],
                [230, 131, 230],
                [230, 130, 230],
                [229, 129, 229],
                [229, 128, 229],
                [229, 127, 229],
                [229, 126, 229],
                [229, 125, 229],
                [228, 124, 228],
                [228, 123, 228],
                [228, 122, 228],
                [228, 121, 228],
                [228, 120, 228],
                [227, 119, 227],
                [227, 118, 227],
                [227, 117, 227],
                [227, 116, 227],
                [227, 115, 227],
                [226, 114, 226],
                [226, 113, 226],
                [226, 112, 226],
                [226, 111, 226],
                [226, 110, 226],
                [225, 109, 225],
                [225, 108, 225],
                [225, 107, 225],
                [225, 106, 225],
                [225, 105, 225],
                [224, 104, 224],
                [224, 103, 224],
                [224, 102, 224],
                [224, 101, 224],
                [224, 100, 224],
                [223, 99, 223],
                [223, 98, 223],
                [223, 97, 223],
                [223, 96, 223],
                [223, 95, 223],
                [222, 94, 222],
                [222, 93, 222],
                [222, 92, 222],
                [222, 91, 222],
                [222, 90, 222],
                [221, 89, 221],
                [221, 88, 221],
                [221, 87, 221],
                [221, 86, 221],
                [221, 85, 221],
                [220, 84, 220],
                [220, 83, 220],
                [220, 82, 220],
                [220, 81, 220],
                [220, 80, 220],
                [219, 79, 219],
                [219, 78, 219],
                [219, 77, 219],
                [219, 76, 219],
                [219, 75, 219],
                [218, 74, 218],
                [218, 73, 218],
                [218, 72, 218],
                [218, 71, 218],
                [218, 70, 218],
                [217, 69, 217],
                [217, 68, 217],
                [217, 67, 217],
                [217, 66, 217],
                [217, 65, 217],
                [216, 64, 216],
                [216, 63, 216],
                [216, 62, 216],
                [216, 61, 216],
                [216, 60, 216],
                [215, 59, 215],
                [215, 58, 215],
                [215, 57, 215],
                [215, 56, 215],
                [215, 55, 215],
                [214, 54, 214],
                [214, 53, 214],
                [214, 52, 214],
                [214, 51, 214],
                [214, 50, 214],
                [213, 49, 213],
                [213, 48, 213],
                [213, 47, 213],
                [213, 46, 213],
                [213, 45, 213],
                [212, 44, 212],
                [212, 43, 212],
                [212, 42, 212],
                [212, 41, 212],
                [212, 40, 212],
                [211, 39, 211],
                [211, 38, 211],
                [211, 37, 211],
                [211, 36, 211],
                [211, 35, 211],
                [210, 34, 210],
                [210, 33, 210],
                [210, 32, 210],
                [210, 31, 210],
                [210, 30, 210],
                [209, 29, 209],
                [209, 28, 209],
                [209, 27, 209],
                [209, 26, 209],
                [209, 25, 209],
                [208, 24, 208],
                [208, 23, 208],
                [208, 22, 208],
                [208, 21, 208],
                [208, 20, 208],
                [207, 19, 207],
                [207, 18, 207],
                [207, 17, 207],
                [207, 16, 207],
                [207, 15, 207],
                [206, 14, 206],
                [206, 13, 206],
                [206, 12, 206],
                [206, 11, 206],
                [206, 10, 206],
                [205, 9, 205],
                [205, 8, 205],
                [205, 7, 205],
                [205, 6, 205],
                [205, 5, 205],
                [204, 4, 204],
                [204, 3, 204],
                [204, 2, 204],
                [204, 1, 204],
                [204, 0, 204],
            ],
        );

        m.insert(
            "I Red",
            [
                [255, 255, 255],
                [255, 254, 254],
                [255, 253, 253],
                [255, 252, 252],
                [255, 251, 251],
                [255, 250, 250],
                [255, 249, 249],
                [255, 248, 248],
                [255, 247, 247],
                [255, 246, 246],
                [255, 245, 245],
                [255, 244, 244],
                [255, 243, 243],
                [255, 242, 242],
                [255, 241, 241],
                [255, 240, 240],
                [255, 239, 239],
                [255, 238, 238],
                [255, 237, 237],
                [255, 236, 236],
                [255, 235, 235],
                [255, 234, 234],
                [255, 233, 233],
                [255, 232, 232],
                [255, 231, 231],
                [255, 230, 230],
                [255, 229, 229],
                [255, 228, 228],
                [255, 227, 227],
                [255, 226, 226],
                [255, 225, 225],
                [255, 224, 224],
                [255, 223, 223],
                [255, 222, 222],
                [255, 221, 221],
                [255, 220, 220],
                [255, 219, 219],
                [255, 218, 218],
                [255, 217, 217],
                [255, 216, 216],
                [255, 215, 215],
                [255, 214, 214],
                [255, 213, 213],
                [255, 212, 212],
                [255, 211, 211],
                [255, 210, 210],
                [255, 209, 209],
                [255, 208, 208],
                [255, 207, 207],
                [255, 206, 206],
                [255, 205, 205],
                [255, 204, 204],
                [255, 203, 203],
                [255, 202, 202],
                [255, 201, 201],
                [255, 200, 200],
                [255, 199, 199],
                [255, 198, 198],
                [255, 197, 197],
                [255, 196, 196],
                [255, 195, 195],
                [255, 194, 194],
                [255, 193, 193],
                [255, 192, 192],
                [255, 191, 191],
                [255, 190, 190],
                [255, 189, 189],
                [255, 188, 188],
                [255, 187, 187],
                [255, 186, 186],
                [255, 185, 185],
                [255, 184, 184],
                [255, 183, 183],
                [255, 182, 182],
                [255, 181, 181],
                [255, 180, 180],
                [255, 179, 179],
                [255, 178, 178],
                [255, 177, 177],
                [255, 176, 176],
                [255, 175, 175],
                [255, 174, 174],
                [255, 173, 173],
                [255, 172, 172],
                [255, 171, 171],
                [255, 170, 170],
                [255, 169, 169],
                [255, 168, 168],
                [255, 167, 167],
                [255, 166, 166],
                [255, 165, 165],
                [255, 164, 164],
                [255, 163, 163],
                [255, 162, 162],
                [255, 161, 161],
                [255, 160, 160],
                [255, 159, 159],
                [255, 158, 158],
                [255, 157, 157],
                [255, 156, 156],
                [255, 155, 155],
                [255, 154, 154],
                [255, 153, 153],
                [255, 152, 152],
                [255, 151, 151],
                [255, 150, 150],
                [255, 149, 149],
                [255, 148, 148],
                [255, 147, 147],
                [255, 146, 146],
                [255, 145, 145],
                [255, 144, 144],
                [255, 143, 143],
                [255, 142, 142],
                [255, 141, 141],
                [255, 140, 140],
                [255, 139, 139],
                [255, 138, 138],
                [255, 137, 137],
                [255, 136, 136],
                [255, 135, 135],
                [255, 134, 134],
                [255, 133, 133],
                [255, 132, 132],
                [255, 131, 131],
                [255, 130, 130],
                [255, 129, 129],
                [255, 128, 128],
                [255, 127, 127],
                [255, 126, 126],
                [255, 125, 125],
                [255, 124, 124],
                [255, 123, 123],
                [255, 122, 122],
                [255, 121, 121],
                [255, 120, 120],
                [255, 119, 119],
                [255, 118, 118],
                [255, 117, 117],
                [255, 116, 116],
                [255, 115, 115],
                [255, 114, 114],
                [255, 113, 113],
                [255, 112, 112],
                [255, 111, 111],
                [255, 110, 110],
                [255, 109, 109],
                [255, 108, 108],
                [255, 107, 107],
                [255, 106, 106],
                [255, 105, 105],
                [255, 104, 104],
                [255, 103, 103],
                [255, 102, 102],
                [255, 101, 101],
                [255, 100, 100],
                [255, 99, 99],
                [255, 98, 98],
                [255, 97, 97],
                [255, 96, 96],
                [255, 95, 95],
                [255, 94, 94],
                [255, 93, 93],
                [255, 92, 92],
                [255, 91, 91],
                [255, 90, 90],
                [255, 89, 89],
                [255, 88, 88],
                [255, 87, 87],
                [255, 86, 86],
                [255, 85, 85],
                [255, 84, 84],
                [255, 83, 83],
                [255, 82, 82],
                [255, 81, 81],
                [255, 80, 80],
                [255, 79, 79],
                [255, 78, 78],
                [255, 77, 77],
                [255, 76, 76],
                [255, 75, 75],
                [255, 74, 74],
                [255, 73, 73],
                [255, 72, 72],
                [255, 71, 71],
                [255, 70, 70],
                [255, 69, 69],
                [255, 68, 68],
                [255, 67, 67],
                [255, 66, 66],
                [255, 65, 65],
                [255, 64, 64],
                [255, 63, 63],
                [255, 62, 62],
                [255, 61, 61],
                [255, 60, 60],
                [255, 59, 59],
                [255, 58, 58],
                [255, 57, 57],
                [255, 56, 56],
                [255, 55, 55],
                [255, 54, 54],
                [255, 53, 53],
                [255, 52, 52],
                [255, 51, 51],
                [255, 50, 50],
                [255, 49, 49],
                [255, 48, 48],
                [255, 47, 47],
                [255, 46, 46],
                [255, 45, 45],
                [255, 44, 44],
                [255, 43, 43],
                [255, 42, 42],
                [255, 41, 41],
                [255, 40, 40],
                [255, 39, 39],
                [255, 38, 38],
                [255, 37, 37],
                [255, 36, 36],
                [255, 35, 35],
                [255, 34, 34],
                [255, 33, 33],
                [255, 32, 32],
                [255, 31, 31],
                [255, 30, 30],
                [255, 29, 29],
                [255, 28, 28],
                [255, 27, 27],
                [255, 26, 26],
                [255, 25, 25],
                [255, 24, 24],
                [255, 23, 23],
                [255, 22, 22],
                [255, 21, 21],
                [255, 20, 20],
                [255, 19, 19],
                [255, 18, 18],
                [255, 17, 17],
                [255, 16, 16],
                [255, 15, 15],
                [255, 14, 14],
                [255, 13, 13],
                [255, 12, 12],
                [255, 11, 11],
                [255, 10, 10],
                [255, 9, 9],
                [255, 8, 8],
                [255, 7, 7],
                [255, 6, 6],
                [255, 5, 5],
                [255, 4, 4],
                [255, 3, 3],
                [255, 2, 2],
                [255, 1, 1],
                [255, 0, 0],
            ],
        );

        m.insert(
            "I Yellow",
            [
                [255, 255, 255],
                [255, 255, 254],
                [255, 255, 253],
                [255, 255, 252],
                [255, 255, 251],
                [255, 255, 250],
                [255, 255, 249],
                [255, 255, 248],
                [255, 255, 247],
                [255, 255, 246],
                [255, 255, 245],
                [255, 255, 244],
                [255, 255, 243],
                [255, 255, 242],
                [255, 255, 241],
                [255, 255, 240],
                [255, 255, 239],
                [255, 255, 238],
                [255, 255, 237],
                [255, 255, 236],
                [255, 255, 235],
                [255, 255, 234],
                [255, 255, 233],
                [255, 255, 232],
                [255, 255, 231],
                [255, 255, 230],
                [255, 255, 229],
                [255, 255, 228],
                [255, 255, 227],
                [255, 255, 226],
                [255, 255, 225],
                [255, 255, 224],
                [255, 255, 223],
                [255, 255, 222],
                [255, 255, 221],
                [255, 255, 220],
                [255, 255, 219],
                [255, 255, 218],
                [255, 255, 217],
                [255, 255, 216],
                [255, 255, 215],
                [255, 255, 214],
                [255, 255, 213],
                [255, 255, 212],
                [255, 255, 211],
                [255, 255, 210],
                [255, 255, 209],
                [255, 255, 208],
                [255, 255, 207],
                [255, 255, 206],
                [255, 255, 205],
                [255, 255, 204],
                [255, 255, 203],
                [255, 255, 202],
                [255, 255, 201],
                [255, 255, 200],
                [255, 255, 199],
                [255, 255, 198],
                [255, 255, 197],
                [255, 255, 196],
                [255, 255, 195],
                [255, 255, 194],
                [255, 255, 193],
                [255, 255, 192],
                [255, 255, 191],
                [255, 255, 190],
                [255, 255, 189],
                [255, 255, 188],
                [255, 255, 187],
                [255, 255, 186],
                [255, 255, 185],
                [255, 255, 184],
                [255, 255, 183],
                [255, 255, 182],
                [255, 255, 181],
                [255, 255, 180],
                [255, 255, 179],
                [255, 255, 178],
                [255, 255, 177],
                [255, 255, 176],
                [255, 255, 175],
                [255, 255, 174],
                [255, 255, 173],
                [255, 255, 172],
                [255, 255, 171],
                [255, 255, 170],
                [255, 255, 169],
                [255, 255, 168],
                [255, 255, 167],
                [255, 255, 166],
                [255, 255, 165],
                [255, 255, 164],
                [255, 255, 163],
                [255, 255, 162],
                [255, 255, 161],
                [255, 255, 160],
                [255, 255, 159],
                [255, 255, 158],
                [255, 255, 157],
                [255, 255, 156],
                [255, 255, 155],
                [255, 255, 154],
                [255, 255, 153],
                [255, 255, 152],
                [255, 255, 151],
                [255, 255, 150],
                [255, 255, 149],
                [255, 255, 148],
                [255, 255, 147],
                [255, 255, 146],
                [255, 255, 145],
                [255, 255, 144],
                [255, 255, 143],
                [255, 255, 142],
                [255, 255, 141],
                [255, 255, 140],
                [255, 255, 139],
                [255, 255, 138],
                [255, 255, 137],
                [255, 255, 136],
                [255, 255, 135],
                [255, 255, 134],
                [255, 255, 133],
                [255, 255, 132],
                [255, 255, 131],
                [255, 255, 130],
                [255, 255, 129],
                [255, 255, 128],
                [255, 255, 127],
                [255, 255, 126],
                [255, 255, 125],
                [255, 255, 124],
                [255, 255, 123],
                [255, 255, 122],
                [255, 255, 121],
                [255, 255, 120],
                [255, 255, 119],
                [255, 255, 118],
                [255, 255, 117],
                [255, 255, 116],
                [255, 255, 115],
                [255, 255, 114],
                [255, 255, 113],
                [255, 255, 112],
                [255, 255, 111],
                [255, 255, 110],
                [255, 255, 109],
                [255, 255, 108],
                [255, 255, 107],
                [255, 255, 106],
                [255, 255, 105],
                [255, 255, 104],
                [255, 255, 103],
                [255, 255, 102],
                [255, 255, 101],
                [255, 255, 100],
                [255, 255, 99],
                [255, 255, 98],
                [255, 255, 97],
                [255, 255, 96],
                [255, 255, 95],
                [255, 255, 94],
                [255, 255, 93],
                [255, 255, 92],
                [255, 255, 91],
                [255, 255, 90],
                [255, 255, 89],
                [255, 255, 88],
                [255, 255, 87],
                [255, 255, 86],
                [255, 255, 85],
                [255, 255, 84],
                [255, 255, 83],
                [255, 255, 82],
                [255, 255, 81],
                [255, 255, 80],
                [255, 255, 79],
                [255, 255, 78],
                [255, 255, 77],
                [255, 255, 76],
                [255, 255, 75],
                [255, 255, 74],
                [255, 255, 73],
                [255, 255, 72],
                [255, 255, 71],
                [255, 255, 70],
                [255, 255, 69],
                [255, 255, 68],
                [255, 255, 67],
                [255, 255, 66],
                [255, 255, 65],
                [255, 255, 64],
                [255, 255, 63],
                [255, 255, 62],
                [255, 255, 61],
                [255, 255, 60],
                [255, 255, 59],
                [255, 255, 58],
                [255, 255, 57],
                [255, 255, 56],
                [255, 255, 55],
                [255, 255, 54],
                [255, 255, 53],
                [255, 255, 52],
                [255, 255, 51],
                [255, 255, 50],
                [255, 255, 49],
                [255, 255, 48],
                [255, 255, 47],
                [255, 255, 46],
                [255, 255, 45],
                [255, 255, 44],
                [255, 255, 43],
                [255, 255, 42],
                [255, 255, 41],
                [255, 255, 40],
                [255, 255, 39],
                [255, 255, 38],
                [255, 255, 37],
                [255, 255, 36],
                [255, 255, 35],
                [255, 255, 34],
                [255, 255, 33],
                [255, 255, 32],
                [255, 255, 31],
                [255, 255, 30],
                [255, 255, 29],
                [255, 255, 28],
                [255, 255, 27],
                [255, 255, 26],
                [255, 255, 25],
                [255, 255, 24],
                [255, 255, 23],
                [255, 255, 22],
                [255, 255, 21],
                [255, 255, 20],
                [255, 255, 19],
                [255, 255, 18],
                [255, 255, 17],
                [255, 255, 16],
                [255, 255, 15],
                [255, 255, 14],
                [255, 255, 13],
                [255, 255, 12],
                [255, 255, 11],
                [255, 255, 10],
                [255, 255, 9],
                [255, 255, 8],
                [255, 255, 7],
                [255, 255, 6],
                [255, 255, 5],
                [255, 255, 4],
                [255, 255, 3],
                [255, 255, 2],
                [255, 255, 1],
                [255, 255, 0],
            ],
        );

        m.insert(
            "ICA",
            [
                [204, 204, 255],
                [202, 202, 255],
                [201, 200, 255],
                [199, 198, 255],
                [198, 196, 255],
                [196, 194, 255],
                [195, 192, 255],
                [194, 190, 255],
                [192, 188, 255],
                [191, 187, 255],
                [189, 185, 255],
                [188, 183, 255],
                [186, 181, 255],
                [185, 179, 255],
                [184, 177, 255],
                [182, 175, 255],
                [181, 173, 255],
                [179, 171, 255],
                [178, 170, 255],
                [177, 168, 255],
                [175, 166, 255],
                [174, 164, 255],
                [172, 162, 255],
                [171, 160, 255],
                [169, 158, 255],
                [168, 156, 255],
                [167, 154, 255],
                [165, 153, 255],
                [164, 151, 255],
                [162, 149, 255],
                [161, 147, 255],
                [160, 145, 255],
                [158, 143, 255],
                [157, 141, 255],
                [155, 139, 255],
                [154, 137, 255],
                [152, 136, 255],
                [151, 134, 255],
                [150, 132, 255],
                [148, 130, 255],
                [147, 128, 255],
                [145, 126, 255],
                [144, 124, 255],
                [143, 122, 255],
                [141, 120, 255],
                [140, 119, 255],
                [138, 117, 255],
                [137, 115, 255],
                [135, 113, 255],
                [134, 111, 255],
                [133, 109, 255],
                [131, 107, 255],
                [130, 105, 255],
                [128, 103, 255],
                [127, 102, 255],
                [126, 100, 255],
                [124, 98, 255],
                [123, 96, 255],
                [121, 94, 255],
                [120, 92, 255],
                [118, 90, 255],
                [117, 88, 255],
                [116, 86, 255],
                [114, 85, 255],
                [113, 83, 255],
                [111, 81, 255],
                [110, 79, 255],
                [109, 77, 255],
                [107, 75, 255],
                [106, 73, 255],
                [104, 71, 255],
                [103, 69, 255],
                [101, 68, 255],
                [100, 66, 255],
                [99, 64, 255],
                [97, 62, 255],
                [96, 60, 255],
                [94, 58, 255],
                [93, 56, 255],
                [92, 54, 255],
                [90, 52, 255],
                [89, 51, 255],
                [87, 49, 255],
                [86, 47, 255],
                [84, 45, 255],
                [83, 43, 255],
                [82, 41, 255],
                [80, 39, 255],
                [79, 37, 255],
                [77, 35, 255],
                [76, 34, 255],
                [75, 32, 255],
                [73, 30, 255],
                [72, 28, 255],
                [70, 26, 255],
                [69, 24, 255],
                [67, 22, 255],
                [66, 20, 255],
                [65, 18, 255],
                [63, 17, 255],
                [62, 15, 255],
                [60, 13, 255],
                [59, 11, 255],
                [58, 9, 255],
                [56, 7, 255],
                [55, 5, 255],
                [53, 3, 255],
                [52, 1, 255],
                [51, 0, 255],
                [48, 0, 242],
                [45, 0, 229],
                [43, 0, 216],
                [40, 0, 204],
                [38, 0, 191],
                [35, 0, 178],
                [33, 0, 165],
                [30, 0, 153],
                [28, 0, 140],
                [25, 0, 127],
                [22, 0, 114],
                [20, 0, 102],
                [17, 0, 89],
                [15, 0, 76],
                [12, 0, 63],
                [10, 0, 51],
                [7, 0, 38],
                [5, 0, 25],
                [2, 0, 12],
                [0, 0, 0],
                [5, 3, 0],
                [10, 6, 0],
                [15, 9, 0],
                [20, 12, 0],
                [25, 15, 0],
                [30, 18, 0],
                [35, 21, 0],
                [40, 24, 0],
                [45, 27, 0],
                [50, 30, 0],
                [56, 33, 0],
                [61, 36, 0],
                [66, 39, 0],
                [71, 42, 0],
                [76, 45, 0],
                [81, 48, 0],
                [86, 52, 0],
                [91, 55, 0],
                [96, 58, 0],
                [101, 61, 0],
                [107, 64, 0],
                [112, 67, 0],
                [117, 70, 0],
                [122, 73, 0],
                [127, 76, 0],
                [132, 79, 0],
                [137, 82, 0],
                [142, 85, 0],
                [147, 88, 0],
                [153, 91, 0],
                [158, 94, 0],
                [163, 97, 0],
                [168, 100, 0],
                [173, 104, 0],
                [178, 107, 0],
                [183, 110, 0],
                [188, 113, 0],
                [193, 116, 0],
                [198, 119, 0],
                [204, 122, 0],
                [209, 125, 0],
                [214, 128, 0],
                [219, 131, 0],
                [224, 134, 0],
                [229, 137, 0],
                [234, 140, 0],
                [239, 143, 0],
                [244, 146, 0],
                [249, 149, 0],
                [255, 153, 0],
                [255, 154, 2],
                [255, 155, 5],
                [255, 156, 7],
                [255, 158, 10],
                [255, 159, 13],
                [255, 160, 15],
                [255, 162, 18],
                [255, 163, 21],
                [255, 164, 23],
                [255, 166, 26],
                [255, 167, 29],
                [255, 168, 31],
                [255, 170, 34],
                [255, 171, 37],
                [255, 172, 39],
                [255, 174, 42],
                [255, 175, 45],
                [255, 176, 47],
                [255, 178, 50],
                [255, 179, 52],
                [255, 180, 55],
                [255, 182, 58],
                [255, 183, 60],
                [255, 184, 63],
                [255, 186, 66],
                [255, 187, 68],
                [255, 188, 71],
                [255, 190, 74],
                [255, 191, 76],
                [255, 192, 79],
                [255, 194, 82],
                [255, 195, 84],
                [255, 196, 87],
                [255, 198, 90],
                [255, 199, 92],
                [255, 200, 95],
                [255, 202, 98],
                [255, 203, 100],
                [255, 204, 103],
                [255, 205, 105],
                [255, 207, 108],
                [255, 208, 111],
                [255, 209, 113],
                [255, 211, 116],
                [255, 212, 119],
                [255, 213, 121],
                [255, 215, 124],
                [255, 216, 127],
                [255, 217, 129],
                [255, 219, 132],
                [255, 220, 135],
                [255, 221, 137],
                [255, 223, 140],
                [255, 224, 143],
                [255, 225, 145],
                [255, 227, 148],
                [255, 228, 151],
                [255, 229, 153],
                [255, 231, 156],
                [255, 232, 158],
                [255, 233, 161],
                [255, 235, 164],
                [255, 236, 166],
                [255, 237, 169],
                [255, 239, 172],
                [255, 240, 174],
                [255, 241, 177],
                [255, 243, 180],
                [255, 244, 182],
                [255, 245, 185],
                [255, 247, 188],
                [255, 248, 190],
                [255, 249, 193],
                [255, 251, 196],
                [255, 252, 198],
                [255, 253, 201],
                [255, 255, 204],
            ],
        );

        m.insert(
            "ICA2",
            [
                [255, 255, 0],
                [252, 254, 0],
                [250, 254, 0],
                [247, 253, 0],
                [245, 253, 0],
                [243, 252, 0],
                [240, 252, 0],
                [238, 251, 0],
                [236, 251, 0],
                [233, 250, 0],
                [231, 250, 0],
                [229, 249, 0],
                [226, 249, 0],
                [224, 248, 0],
                [221, 248, 0],
                [219, 247, 0],
                [217, 247, 0],
                [214, 246, 0],
                [212, 246, 0],
                [210, 246, 0],
                [207, 245, 0],
                [205, 245, 0],
                [203, 244, 0],
                [200, 244, 0],
                [198, 243, 0],
                [195, 243, 0],
                [193, 242, 0],
                [191, 242, 0],
                [188, 241, 0],
                [186, 241, 0],
                [184, 240, 0],
                [181, 240, 0],
                [179, 239, 0],
                [177, 239, 0],
                [174, 238, 0],
                [172, 238, 0],
                [169, 237, 0],
                [167, 237, 0],
                [165, 237, 0],
                [162, 236, 0],
                [160, 236, 0],
                [158, 235, 0],
                [155, 235, 0],
                [153, 234, 0],
                [151, 234, 0],
                [148, 233, 0],
                [146, 233, 0],
                [144, 232, 0],
                [141, 232, 0],
                [139, 231, 0],
                [136, 231, 0],
                [134, 230, 0],
                [132, 230, 0],
                [129, 229, 0],
                [127, 229, 0],
                [125, 229, 0],
                [122, 228, 0],
                [120, 228, 0],
                [118, 227, 0],
                [115, 227, 0],
                [113, 226, 0],
                [110, 226, 0],
                [108, 225, 0],
                [106, 225, 0],
                [103, 224, 0],
                [101, 224, 0],
                [99, 223, 0],
                [96, 223, 0],
                [94, 222, 0],
                [92, 222, 0],
                [89, 221, 0],
                [87, 221, 0],
                [84, 220, 0],
                [82, 220, 0],
                [80, 220, 0],
                [77, 219, 0],
                [75, 219, 0],
                [73, 218, 0],
                [70, 218, 0],
                [68, 217, 0],
                [66, 217, 0],
                [63, 216, 0],
                [61, 216, 0],
                [59, 215, 0],
                [56, 215, 0],
                [54, 214, 0],
                [51, 214, 0],
                [49, 213, 0],
                [47, 213, 0],
                [44, 212, 0],
                [42, 212, 0],
                [40, 212, 0],
                [37, 211, 0],
                [35, 211, 0],
                [33, 210, 0],
                [30, 210, 0],
                [28, 209, 0],
                [25, 209, 0],
                [23, 208, 0],
                [21, 208, 0],
                [18, 207, 0],
                [16, 207, 0],
                [14, 206, 0],
                [11, 206, 0],
                [9, 205, 0],
                [7, 205, 0],
                [4, 204, 0],
                [2, 204, 0],
                [0, 204, 0],
                [0, 193, 0],
                [0, 183, 0],
                [0, 173, 0],
                [0, 163, 0],
                [0, 153, 0],
                [0, 142, 0],
                [0, 132, 0],
                [0, 122, 0],
                [0, 112, 0],
                [0, 102, 0],
                [0, 91, 0],
                [0, 81, 0],
                [0, 71, 0],
                [0, 61, 0],
                [0, 51, 0],
                [0, 40, 0],
                [0, 30, 0],
                [0, 20, 0],
                [0, 10, 0],
                [0, 0, 0],
                [5, 3, 0],
                [10, 6, 0],
                [15, 9, 0],
                [20, 12, 0],
                [25, 15, 0],
                [30, 18, 0],
                [35, 21, 0],
                [40, 24, 0],
                [45, 27, 0],
                [50, 30, 0],
                [56, 33, 0],
                [61, 36, 0],
                [66, 39, 0],
                [71, 42, 0],
                [76, 45, 0],
                [81, 48, 0],
                [86, 52, 0],
                [91, 55, 0],
                [96, 58, 0],
                [101, 61, 0],
                [107, 64, 0],
                [112, 67, 0],
                [117, 70, 0],
                [122, 73, 0],
                [127, 76, 0],
                [132, 79, 0],
                [137, 82, 0],
                [142, 85, 0],
                [147, 88, 0],
                [153, 91, 0],
                [158, 94, 0],
                [163, 97, 0],
                [168, 100, 0],
                [173, 104, 0],
                [178, 107, 0],
                [183, 110, 0],
                [188, 113, 0],
                [193, 116, 0],
                [198, 119, 0],
                [204, 122, 0],
                [209, 125, 0],
                [214, 128, 0],
                [219, 131, 0],
                [224, 134, 0],
                [229, 137, 0],
                [234, 140, 0],
                [239, 143, 0],
                [244, 146, 0],
                [249, 149, 0],
                [255, 153, 0],
                [255, 154, 2],
                [255, 155, 5],
                [255, 156, 7],
                [255, 158, 10],
                [255, 159, 13],
                [255, 160, 15],
                [255, 162, 18],
                [255, 163, 21],
                [255, 164, 23],
                [255, 166, 26],
                [255, 167, 29],
                [255, 168, 31],
                [255, 170, 34],
                [255, 171, 37],
                [255, 172, 39],
                [255, 174, 42],
                [255, 175, 45],
                [255, 176, 47],
                [255, 178, 50],
                [255, 179, 52],
                [255, 180, 55],
                [255, 182, 58],
                [255, 183, 60],
                [255, 184, 63],
                [255, 186, 66],
                [255, 187, 68],
                [255, 188, 71],
                [255, 190, 74],
                [255, 191, 76],
                [255, 192, 79],
                [255, 194, 82],
                [255, 195, 84],
                [255, 196, 87],
                [255, 198, 90],
                [255, 199, 92],
                [255, 200, 95],
                [255, 202, 98],
                [255, 203, 100],
                [255, 204, 103],
                [255, 205, 105],
                [255, 207, 108],
                [255, 208, 111],
                [255, 209, 113],
                [255, 211, 116],
                [255, 212, 119],
                [255, 213, 121],
                [255, 215, 124],
                [255, 216, 127],
                [255, 217, 129],
                [255, 219, 132],
                [255, 220, 135],
                [255, 221, 137],
                [255, 223, 140],
                [255, 224, 143],
                [255, 225, 145],
                [255, 227, 148],
                [255, 228, 151],
                [255, 229, 153],
                [255, 231, 156],
                [255, 232, 158],
                [255, 233, 161],
                [255, 235, 164],
                [255, 236, 166],
                [255, 237, 169],
                [255, 239, 172],
                [255, 240, 174],
                [255, 241, 177],
                [255, 243, 180],
                [255, 244, 182],
                [255, 245, 185],
                [255, 247, 188],
                [255, 248, 190],
                [255, 249, 193],
                [255, 251, 196],
                [255, 252, 198],
                [255, 253, 201],
                [255, 255, 204],
            ],
        );

        m.insert(
            "ICA3",
            [
                [255, 204, 255],
                [254, 202, 254],
                [254, 200, 254],
                [253, 198, 253],
                [253, 196, 253],
                [252, 194, 252],
                [252, 192, 252],
                [251, 190, 251],
                [251, 188, 251],
                [250, 187, 250],
                [250, 185, 250],
                [249, 183, 249],
                [249, 181, 249],
                [248, 179, 248],
                [248, 177, 248],
                [247, 175, 247],
                [247, 173, 247],
                [246, 171, 246],
                [246, 170, 246],
                [246, 168, 246],
                [245, 166, 245],
                [245, 164, 245],
                [244, 162, 244],
                [244, 160, 244],
                [243, 158, 243],
                [243, 156, 243],
                [242, 154, 242],
                [242, 153, 242],
                [241, 151, 241],
                [241, 149, 241],
                [240, 147, 240],
                [240, 145, 240],
                [239, 143, 239],
                [239, 141, 239],
                [238, 139, 238],
                [238, 137, 238],
                [237, 136, 237],
                [237, 134, 237],
                [237, 132, 237],
                [236, 130, 236],
                [236, 128, 236],
                [235, 126, 235],
                [235, 124, 235],
                [234, 122, 234],
                [234, 120, 234],
                [233, 119, 233],
                [233, 117, 233],
                [232, 115, 232],
                [232, 113, 232],
                [231, 111, 231],
                [231, 109, 231],
                [230, 107, 230],
                [230, 105, 230],
                [229, 103, 229],
                [229, 102, 229],
                [229, 100, 229],
                [228, 98, 228],
                [228, 96, 228],
                [227, 94, 227],
                [227, 92, 227],
                [226, 90, 226],
                [226, 88, 226],
                [225, 86, 225],
                [225, 85, 225],
                [224, 83, 224],
                [224, 81, 224],
                [223, 79, 223],
                [223, 77, 223],
                [222, 75, 222],
                [222, 73, 222],
                [221, 71, 221],
                [221, 69, 221],
                [220, 68, 220],
                [220, 66, 220],
                [220, 64, 220],
                [219, 62, 219],
                [219, 60, 219],
                [218, 58, 218],
                [218, 56, 218],
                [217, 54, 217],
                [217, 52, 217],
                [216, 51, 216],
                [216, 49, 216],
                [215, 47, 215],
                [215, 45, 215],
                [214, 43, 214],
                [214, 41, 214],
                [213, 39, 213],
                [213, 37, 213],
                [212, 35, 212],
                [212, 34, 212],
                [212, 32, 212],
                [211, 30, 211],
                [211, 28, 211],
                [210, 26, 210],
                [210, 24, 210],
                [209, 22, 209],
                [209, 20, 209],
                [208, 18, 208],
                [208, 17, 208],
                [207, 15, 207],
                [207, 13, 207],
                [206, 11, 206],
                [206, 9, 206],
                [205, 7, 205],
                [205, 5, 205],
                [204, 3, 204],
                [204, 1, 204],
                [204, 0, 204],
                [193, 0, 193],
                [183, 0, 183],
                [173, 0, 173],
                [163, 0, 163],
                [153, 0, 153],
                [142, 0, 142],
                [132, 0, 132],
                [122, 0, 122],
                [112, 0, 112],
                [102, 0, 102],
                [91, 0, 91],
                [81, 0, 81],
                [71, 0, 71],
                [61, 0, 61],
                [51, 0, 51],
                [40, 0, 40],
                [30, 0, 30],
                [20, 0, 20],
                [10, 0, 10],
                [0, 0, 0],
                [12, 5, 0],
                [25, 10, 0],
                [38, 15, 0],
                [51, 20, 0],
                [63, 25, 0],
                [76, 30, 0],
                [89, 35, 0],
                [102, 40, 0],
                [114, 45, 0],
                [127, 50, 0],
                [140, 56, 0],
                [153, 61, 0],
                [165, 66, 0],
                [178, 71, 0],
                [191, 76, 0],
                [204, 81, 0],
                [216, 86, 0],
                [229, 91, 0],
                [242, 96, 0],
                [255, 102, 0],
                [255, 103, 1],
                [255, 104, 3],
                [255, 106, 5],
                [255, 107, 7],
                [255, 109, 9],
                [255, 110, 11],
                [255, 112, 13],
                [255, 113, 15],
                [255, 114, 17],
                [255, 116, 19],
                [255, 117, 20],
                [255, 119, 22],
                [255, 120, 24],
                [255, 122, 26],
                [255, 123, 28],
                [255, 124, 30],
                [255, 126, 32],
                [255, 127, 34],
                [255, 129, 36],
                [255, 130, 38],
                [255, 132, 40],
                [255, 133, 41],
                [255, 134, 43],
                [255, 136, 45],
                [255, 137, 47],
                [255, 139, 49],
                [255, 140, 51],
                [255, 142, 53],
                [255, 143, 55],
                [255, 144, 57],
                [255, 146, 59],
                [255, 147, 61],
                [255, 149, 62],
                [255, 150, 64],
                [255, 152, 66],
                [255, 153, 68],
                [255, 154, 70],
                [255, 156, 72],
                [255, 157, 74],
                [255, 159, 76],
                [255, 160, 78],
                [255, 162, 80],
                [255, 163, 81],
                [255, 164, 83],
                [255, 166, 85],
                [255, 167, 87],
                [255, 169, 89],
                [255, 170, 91],
                [255, 172, 93],
                [255, 173, 95],
                [255, 174, 97],
                [255, 176, 99],
                [255, 177, 101],
                [255, 179, 102],
                [255, 180, 104],
                [255, 182, 106],
                [255, 183, 108],
                [255, 184, 110],
                [255, 186, 112],
                [255, 187, 114],
                [255, 189, 116],
                [255, 190, 118],
                [255, 192, 120],
                [255, 193, 122],
                [255, 194, 123],
                [255, 196, 125],
                [255, 197, 127],
                [255, 199, 129],
                [255, 200, 131],
                [255, 202, 133],
                [255, 203, 135],
                [255, 204, 137],
                [255, 206, 139],
                [255, 207, 141],
                [255, 209, 142],
                [255, 210, 144],
                [255, 212, 146],
                [255, 213, 148],
                [255, 214, 150],
                [255, 216, 152],
                [255, 217, 154],
                [255, 219, 156],
                [255, 220, 158],
                [255, 222, 160],
                [255, 223, 162],
                [255, 224, 163],
                [255, 226, 165],
                [255, 227, 167],
                [255, 229, 169],
                [255, 230, 171],
                [255, 232, 173],
                [255, 233, 175],
                [255, 234, 177],
                [255, 236, 179],
                [255, 237, 181],
                [255, 239, 183],
                [255, 240, 184],
                [255, 242, 186],
                [255, 243, 188],
                [255, 244, 190],
                [255, 246, 192],
                [255, 247, 194],
                [255, 249, 196],
                [255, 250, 198],
                [255, 252, 200],
                [255, 253, 202],
                [255, 255, 204],
            ],
        );

        m.insert(
            "Ice",
            [
                [0, 156, 140],
                [0, 157, 140],
                [0, 158, 141],
                [0, 159, 142],
                [0, 160, 143],
                [0, 161, 144],
                [0, 162, 145],
                [0, 163, 146],
                [0, 165, 147],
                [0, 166, 148],
                [0, 167, 149],
                [0, 169, 151],
                [0, 170, 152],
                [0, 171, 153],
                [0, 173, 155],
                [0, 174, 156],
                [0, 176, 158],
                [0, 177, 159],
                [0, 178, 160],
                [0, 179, 161],
                [0, 180, 162],
                [0, 181, 163],
                [0, 182, 164],
                [0, 183, 165],
                [0, 184, 166],
                [0, 184, 166],
                [0, 185, 167],
                [0, 186, 167],
                [0, 187, 168],
                [0, 187, 168],
                [0, 188, 169],
                [0, 189, 169],
                [0, 190, 170],
                [0, 190, 170],
                [0, 191, 171],
                [0, 192, 172],
                [0, 193, 173],
                [0, 193, 173],
                [0, 194, 174],
                [0, 195, 175],
                [0, 196, 176],
                [2, 195, 180],
                [4, 195, 184],
                [7, 194, 188],
                [9, 194, 192],
                [11, 194, 196],
                [14, 193, 200],
                [16, 193, 204],
                [19, 193, 209],
                [20, 191, 210],
                [21, 190, 211],
                [22, 189, 213],
                [24, 188, 214],
                [25, 187, 215],
                [26, 186, 217],
                [27, 185, 218],
                [29, 184, 220],
                [31, 182, 221],
                [34, 180, 223],
                [36, 179, 225],
                [39, 177, 227],
                [42, 175, 228],
                [44, 174, 230],
                [47, 172, 232],
                [50, 171, 234],
                [49, 169, 232],
                [49, 168, 231],
                [49, 167, 230],
                [49, 166, 229],
                [48, 165, 228],
                [48, 164, 227],
                [48, 163, 226],
                [48, 162, 225],
                [51, 160, 226],
                [55, 158, 227],
                [59, 156, 229],
                [63, 154, 230],
                [67, 152, 231],
                [71, 150, 233],
                [75, 148, 234],
                [79, 146, 236],
                [83, 143, 237],
                [87, 140, 238],
                [91, 138, 239],
                [95, 135, 241],
                [99, 132, 242],
                [103, 130, 243],
                [107, 127, 244],
                [112, 125, 246],
                [114, 122, 246],
                [117, 120, 247],
                [120, 118, 247],
                [123, 116, 248],
                [125, 113, 248],
                [128, 111, 249],
                [131, 109, 249],
                [134, 107, 250],
                [137, 105, 250],
                [140, 103, 250],
                [143, 101, 250],
                [146, 100, 250],
                [149, 98, 250],
                [152, 96, 250],
                [155, 94, 250],
                [158, 93, 251],
                [161, 91, 250],
                [165, 90, 250],
                [168, 88, 250],
                [172, 87, 250],
                [175, 85, 250],
                [179, 84, 250],
                [182, 82, 250],
                [186, 81, 250],
                [187, 81, 250],
                [189, 82, 250],
                [191, 83, 250],
                [193, 84, 250],
                [195, 84, 250],
                [197, 85, 250],
                [199, 86, 250],
                [201, 87, 250],
                [203, 87, 249],
                [205, 88, 248],
                [207, 88, 248],
                [209, 89, 247],
                [211, 90, 246],
                [213, 90, 246],
                [215, 91, 245],
                [217, 92, 245],
                [218, 92, 243],
                [220, 93, 241],
                [221, 93, 239],
                [223, 94, 237],
                [224, 95, 235],
                [226, 95, 233],
                [227, 96, 231],
                [229, 97, 230],
                [230, 96, 230],
                [232, 96, 230],
                [233, 96, 230],
                [235, 96, 230],
                [237, 95, 230],
                [238, 95, 230],
                [240, 95, 230],
                [242, 95, 230],
                [243, 94, 229],
                [244, 94, 228],
                [245, 94, 227],
                [246, 94, 226],
                [247, 93, 225],
                [248, 93, 224],
                [249, 93, 223],
                [250, 93, 222],
                [250, 93, 219],
                [250, 93, 217],
                [250, 93, 214],
                [250, 93, 212],
                [250, 93, 209],
                [250, 93, 207],
                [250, 93, 204],
                [250, 93, 202],
                [250, 92, 199],
                [250, 92, 196],
                [250, 91, 193],
                [250, 91, 191],
                [250, 91, 188],
                [250, 90, 185],
                [250, 90, 182],
                [250, 90, 180],
                [250, 89, 177],
                [250, 88, 175],
                [250, 88, 173],
                [250, 87, 171],
                [250, 86, 169],
                [250, 86, 167],
                [250, 85, 165],
                [250, 85, 163],
                [250, 83, 160],
                [250, 81, 157],
                [250, 79, 155],
                [250, 77, 152],
                [250, 75, 149],
                [250, 73, 147],
                [250, 71, 144],
                [251, 69, 142],
                [250, 68, 139],
                [250, 67, 137],
                [250, 67, 134],
                [250, 66, 132],
                [250, 65, 130],
                [250, 65, 127],
                [250, 64, 125],
                [250, 64, 123],
                [250, 62, 121],
                [250, 61, 120],
                [250, 60, 119],
                [250, 59, 118],
                [250, 57, 117],
                [250, 56, 116],
                [250, 55, 115],
                [250, 54, 114],
                [250, 53, 113],
                [250, 52, 112],
                [250, 51, 111],
                [250, 50, 110],
                [250, 49, 109],
                [250, 48, 108],
                [250, 47, 107],
                [250, 47, 106],
                [250, 45, 104],
                [250, 44, 103],
                [250, 42, 101],
                [250, 41, 100],
                [250, 39, 98],
                [250, 38, 97],
                [250, 36, 95],
                [250, 35, 94],
                [250, 33, 92],
                [250, 31, 91],
                [250, 29, 90],
                [250, 27, 89],
                [250, 25, 87],
                [250, 23, 86],
                [250, 21, 85],
                [251, 19, 84],
                [251, 16, 81],
                [251, 14, 79],
                [251, 11, 76],
                [251, 9, 74],
                [251, 7, 71],
                [251, 4, 69],
                [251, 2, 66],
                [251, 0, 64],
                [250, 0, 59],
                [249, 1, 54],
                [248, 1, 49],
                [247, 2, 45],
                [246, 2, 40],
                [245, 3, 35],
                [244, 3, 30],
                [243, 4, 26],
                [241, 3, 26],
                [239, 3, 26],
                [238, 2, 26],
                [236, 2, 26],
                [234, 1, 26],
                [233, 1, 26],
                [231, 0, 26],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
                [230, 0, 27],
            ],
        );

        m.insert(
            "Ink Black",
            [
                [255, 255, 255],
                [252, 252, 252],
                [249, 249, 249],
                [246, 246, 246],
                [243, 243, 243],
                [241, 241, 241],
                [238, 238, 238],
                [235, 235, 235],
                [232, 232, 232],
                [230, 230, 230],
                [227, 227, 227],
                [224, 224, 224],
                [222, 222, 222],
                [219, 219, 219],
                [217, 217, 217],
                [214, 214, 214],
                [212, 212, 212],
                [210, 210, 210],
                [207, 207, 207],
                [205, 205, 205],
                [203, 203, 203],
                [200, 200, 200],
                [198, 198, 198],
                [196, 196, 196],
                [194, 194, 194],
                [192, 192, 192],
                [189, 189, 189],
                [187, 187, 187],
                [185, 185, 185],
                [183, 183, 183],
                [181, 181, 181],
                [179, 179, 179],
                [177, 177, 177],
                [175, 175, 175],
                [174, 174, 174],
                [172, 172, 172],
                [170, 170, 170],
                [168, 168, 168],
                [166, 166, 166],
                [164, 164, 164],
                [163, 163, 163],
                [161, 161, 161],
                [159, 159, 159],
                [157, 157, 157],
                [156, 156, 156],
                [154, 154, 154],
                [153, 153, 153],
                [151, 151, 151],
                [149, 149, 149],
                [148, 148, 148],
                [146, 146, 146],
                [145, 145, 145],
                [143, 143, 143],
                [142, 142, 142],
                [140, 140, 140],
                [139, 139, 139],
                [137, 137, 137],
                [136, 136, 136],
                [134, 134, 134],
                [133, 133, 133],
                [132, 132, 132],
                [130, 130, 130],
                [129, 129, 129],
                [128, 128, 128],
                [126, 126, 126],
                [125, 125, 125],
                [124, 124, 124],
                [123, 123, 123],
                [121, 121, 121],
                [120, 120, 120],
                [119, 119, 119],
                [118, 118, 118],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [113, 113, 113],
                [112, 112, 112],
                [111, 111, 111],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [106, 106, 106],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [75, 75, 75],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [68, 68, 68],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [60, 60, 60],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [56, 56, 56],
                [55, 55, 55],
                [54, 54, 54],
                [54, 54, 54],
                [53, 53, 53],
                [52, 52, 52],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [50, 50, 50],
                [49, 49, 49],
                [49, 49, 49],
                [48, 48, 48],
                [47, 47, 47],
                [47, 47, 47],
                [46, 46, 46],
                [45, 45, 45],
                [45, 45, 45],
                [44, 44, 44],
                [44, 44, 44],
                [43, 43, 43],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [41, 41, 41],
                [40, 40, 40],
                [40, 40, 40],
                [39, 39, 39],
                [38, 38, 38],
                [38, 38, 38],
                [37, 37, 37],
                [37, 37, 37],
                [36, 36, 36],
                [36, 36, 36],
                [35, 35, 35],
                [35, 35, 35],
                [34, 34, 34],
                [33, 33, 33],
                [33, 33, 33],
                [32, 32, 32],
                [32, 32, 32],
                [31, 31, 31],
                [31, 31, 31],
                [30, 30, 30],
                [30, 30, 30],
                [29, 29, 29],
                [29, 29, 29],
                [28, 28, 28],
                [28, 28, 28],
                [27, 27, 27],
                [27, 27, 27],
                [26, 26, 26],
                [26, 26, 26],
                [25, 25, 25],
                [25, 25, 25],
                [24, 24, 24],
                [24, 24, 24],
                [23, 23, 23],
                [23, 23, 23],
                [22, 22, 22],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [20, 20, 20],
                [19, 19, 19],
                [19, 19, 19],
                [19, 19, 19],
                [18, 18, 18],
                [18, 18, 18],
                [17, 17, 17],
                [17, 17, 17],
                [16, 16, 16],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [14, 14, 14],
                [13, 13, 13],
                [13, 13, 13],
                [12, 12, 12],
                [12, 12, 12],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [10, 10, 10],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Cherry",
            [
                [255, 255, 255],
                [254, 249, 253],
                [253, 243, 251],
                [252, 238, 249],
                [251, 232, 247],
                [250, 226, 245],
                [249, 221, 243],
                [248, 216, 241],
                [247, 211, 239],
                [246, 206, 237],
                [245, 201, 235],
                [244, 196, 233],
                [243, 191, 232],
                [242, 186, 230],
                [241, 182, 228],
                [240, 177, 226],
                [239, 173, 224],
                [238, 169, 222],
                [237, 164, 220],
                [236, 160, 218],
                [235, 156, 217],
                [234, 152, 215],
                [233, 148, 213],
                [232, 145, 211],
                [231, 141, 209],
                [230, 137, 207],
                [229, 134, 206],
                [228, 130, 204],
                [227, 127, 202],
                [226, 124, 200],
                [225, 120, 199],
                [224, 117, 197],
                [223, 114, 195],
                [222, 111, 193],
                [221, 108, 192],
                [220, 105, 190],
                [219, 102, 188],
                [218, 100, 186],
                [217, 97, 185],
                [216, 94, 183],
                [215, 92, 181],
                [214, 89, 180],
                [213, 87, 178],
                [212, 84, 176],
                [211, 82, 175],
                [210, 80, 173],
                [209, 77, 171],
                [208, 75, 170],
                [207, 73, 168],
                [206, 71, 166],
                [205, 69, 165],
                [204, 67, 163],
                [203, 65, 162],
                [202, 63, 160],
                [201, 61, 158],
                [200, 59, 157],
                [199, 58, 155],
                [198, 56, 154],
                [197, 54, 152],
                [196, 53, 151],
                [195, 51, 149],
                [194, 49, 148],
                [193, 48, 146],
                [192, 46, 145],
                [191, 45, 143],
                [190, 44, 142],
                [189, 42, 140],
                [188, 41, 139],
                [187, 40, 137],
                [186, 38, 136],
                [185, 37, 134],
                [184, 36, 133],
                [183, 35, 131],
                [182, 34, 130],
                [181, 33, 128],
                [180, 32, 127],
                [179, 31, 126],
                [178, 29, 124],
                [177, 29, 123],
                [176, 28, 121],
                [175, 27, 120],
                [174, 26, 119],
                [173, 25, 117],
                [172, 24, 116],
                [171, 23, 115],
                [170, 22, 113],
                [169, 22, 112],
                [168, 21, 111],
                [167, 20, 109],
                [166, 19, 108],
                [165, 19, 107],
                [164, 18, 105],
                [163, 17, 104],
                [162, 17, 103],
                [161, 16, 102],
                [160, 16, 100],
                [159, 15, 99],
                [158, 14, 98],
                [157, 14, 97],
                [156, 13, 95],
                [155, 13, 94],
                [154, 12, 93],
                [153, 12, 92],
                [152, 11, 91],
                [151, 11, 89],
                [150, 11, 88],
                [149, 10, 87],
                [148, 10, 86],
                [147, 9, 85],
                [146, 9, 84],
                [145, 9, 82],
                [144, 8, 81],
                [143, 8, 80],
                [142, 8, 79],
                [141, 7, 78],
                [140, 7, 77],
                [139, 7, 76],
                [138, 6, 75],
                [137, 6, 74],
                [136, 6, 73],
                [135, 6, 71],
                [134, 5, 70],
                [133, 5, 69],
                [132, 5, 68],
                [131, 5, 67],
                [130, 4, 66],
                [129, 4, 65],
                [128, 4, 64],
                [127, 4, 63],
                [126, 4, 62],
                [125, 4, 61],
                [124, 3, 60],
                [123, 3, 59],
                [122, 3, 58],
                [121, 3, 57],
                [120, 3, 56],
                [119, 3, 56],
                [118, 3, 55],
                [117, 2, 54],
                [116, 2, 53],
                [115, 2, 52],
                [114, 2, 51],
                [113, 2, 50],
                [112, 2, 49],
                [111, 2, 48],
                [110, 2, 47],
                [109, 2, 47],
                [108, 1, 46],
                [107, 1, 45],
                [106, 1, 44],
                [105, 1, 43],
                [104, 1, 42],
                [103, 1, 42],
                [102, 1, 41],
                [101, 1, 40],
                [100, 1, 39],
                [99, 1, 38],
                [98, 1, 38],
                [97, 1, 37],
                [96, 1, 36],
                [95, 1, 35],
                [94, 1, 35],
                [93, 1, 34],
                [92, 1, 33],
                [91, 1, 32],
                [90, 0, 32],
                [89, 0, 31],
                [88, 0, 30],
                [87, 0, 30],
                [86, 0, 29],
                [85, 0, 28],
                [84, 0, 28],
                [83, 0, 27],
                [82, 0, 26],
                [81, 0, 26],
                [80, 0, 25],
                [79, 0, 24],
                [78, 0, 24],
                [77, 0, 23],
                [76, 0, 23],
                [75, 0, 22],
                [74, 0, 21],
                [73, 0, 21],
                [72, 0, 20],
                [71, 0, 20],
                [70, 0, 19],
                [69, 0, 19],
                [68, 0, 18],
                [67, 0, 18],
                [66, 0, 17],
                [65, 0, 17],
                [64, 0, 16],
                [63, 0, 16],
                [62, 0, 15],
                [61, 0, 15],
                [60, 0, 14],
                [59, 0, 14],
                [58, 0, 13],
                [57, 0, 13],
                [56, 0, 12],
                [55, 0, 12],
                [54, 0, 11],
                [53, 0, 11],
                [52, 0, 11],
                [51, 0, 10],
                [50, 0, 10],
                [49, 0, 9],
                [48, 0, 9],
                [47, 0, 9],
                [46, 0, 8],
                [45, 0, 8],
                [44, 0, 8],
                [43, 0, 7],
                [42, 0, 7],
                [41, 0, 7],
                [40, 0, 6],
                [39, 0, 6],
                [38, 0, 6],
                [37, 0, 5],
                [36, 0, 5],
                [35, 0, 5],
                [34, 0, 5],
                [33, 0, 4],
                [32, 0, 4],
                [31, 0, 4],
                [30, 0, 4],
                [29, 0, 3],
                [28, 0, 3],
                [27, 0, 3],
                [26, 0, 3],
                [25, 0, 2],
                [24, 0, 2],
                [23, 0, 2],
                [22, 0, 2],
                [21, 0, 2],
                [20, 0, 2],
                [19, 0, 1],
                [18, 0, 1],
                [17, 0, 1],
                [16, 0, 1],
                [15, 0, 1],
                [14, 0, 1],
                [13, 0, 1],
                [12, 0, 1],
                [11, 0, 0],
                [10, 0, 0],
                [9, 0, 0],
                [8, 0, 0],
                [7, 0, 0],
                [6, 0, 0],
                [5, 0, 0],
                [4, 0, 0],
                [3, 0, 0],
                [2, 0, 0],
                [1, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Cyan",
            [
                [255, 255, 255],
                [249, 253, 254],
                [243, 251, 253],
                [238, 249, 252],
                [232, 247, 251],
                [226, 245, 250],
                [221, 243, 249],
                [216, 241, 248],
                [211, 239, 247],
                [206, 237, 246],
                [201, 235, 245],
                [196, 233, 244],
                [191, 232, 243],
                [186, 230, 242],
                [182, 228, 241],
                [177, 226, 240],
                [173, 224, 239],
                [169, 222, 238],
                [164, 220, 237],
                [160, 218, 236],
                [156, 217, 235],
                [152, 215, 234],
                [148, 213, 233],
                [145, 211, 232],
                [141, 209, 231],
                [137, 207, 230],
                [134, 206, 229],
                [130, 204, 228],
                [127, 202, 227],
                [124, 200, 226],
                [120, 199, 225],
                [117, 197, 224],
                [114, 195, 223],
                [111, 193, 222],
                [108, 192, 221],
                [105, 190, 220],
                [102, 188, 219],
                [100, 186, 218],
                [97, 185, 217],
                [94, 183, 216],
                [92, 181, 215],
                [89, 180, 214],
                [87, 178, 213],
                [84, 176, 212],
                [82, 175, 211],
                [80, 173, 210],
                [77, 171, 209],
                [75, 170, 208],
                [73, 168, 207],
                [71, 166, 206],
                [69, 165, 205],
                [67, 163, 204],
                [65, 162, 203],
                [63, 160, 202],
                [61, 158, 201],
                [59, 157, 200],
                [58, 155, 199],
                [56, 154, 198],
                [54, 152, 197],
                [53, 151, 196],
                [51, 149, 195],
                [49, 148, 194],
                [48, 146, 193],
                [46, 145, 192],
                [45, 143, 191],
                [44, 142, 190],
                [42, 140, 189],
                [41, 139, 188],
                [40, 137, 187],
                [38, 136, 186],
                [37, 134, 185],
                [36, 133, 184],
                [35, 131, 183],
                [34, 130, 182],
                [33, 128, 181],
                [32, 127, 180],
                [31, 126, 179],
                [29, 124, 178],
                [29, 123, 177],
                [28, 121, 176],
                [27, 120, 175],
                [26, 119, 174],
                [25, 117, 173],
                [24, 116, 172],
                [23, 115, 171],
                [22, 113, 170],
                [22, 112, 169],
                [21, 111, 168],
                [20, 109, 167],
                [19, 108, 166],
                [19, 107, 165],
                [18, 105, 164],
                [17, 104, 163],
                [17, 103, 162],
                [16, 102, 161],
                [16, 100, 160],
                [15, 99, 159],
                [14, 98, 158],
                [14, 97, 157],
                [13, 95, 156],
                [13, 94, 155],
                [12, 93, 154],
                [12, 92, 153],
                [11, 91, 152],
                [11, 89, 151],
                [11, 88, 150],
                [10, 87, 149],
                [10, 86, 148],
                [9, 85, 147],
                [9, 84, 146],
                [9, 82, 145],
                [8, 81, 144],
                [8, 80, 143],
                [8, 79, 142],
                [7, 78, 141],
                [7, 77, 140],
                [7, 76, 139],
                [6, 75, 138],
                [6, 74, 137],
                [6, 73, 136],
                [6, 71, 135],
                [5, 70, 134],
                [5, 69, 133],
                [5, 68, 132],
                [5, 67, 131],
                [4, 66, 130],
                [4, 65, 129],
                [4, 64, 128],
                [4, 63, 127],
                [4, 62, 126],
                [4, 61, 125],
                [3, 60, 124],
                [3, 59, 123],
                [3, 58, 122],
                [3, 57, 121],
                [3, 56, 120],
                [3, 56, 119],
                [3, 55, 118],
                [2, 54, 117],
                [2, 53, 116],
                [2, 52, 115],
                [2, 51, 114],
                [2, 50, 113],
                [2, 49, 112],
                [2, 48, 111],
                [2, 47, 110],
                [2, 47, 109],
                [1, 46, 108],
                [1, 45, 107],
                [1, 44, 106],
                [1, 43, 105],
                [1, 42, 104],
                [1, 42, 103],
                [1, 41, 102],
                [1, 40, 101],
                [1, 39, 100],
                [1, 38, 99],
                [1, 38, 98],
                [1, 37, 97],
                [1, 36, 96],
                [1, 35, 95],
                [1, 35, 94],
                [1, 34, 93],
                [1, 33, 92],
                [1, 32, 91],
                [0, 32, 90],
                [0, 31, 89],
                [0, 30, 88],
                [0, 30, 87],
                [0, 29, 86],
                [0, 28, 85],
                [0, 28, 84],
                [0, 27, 83],
                [0, 26, 82],
                [0, 26, 81],
                [0, 25, 80],
                [0, 24, 79],
                [0, 24, 78],
                [0, 23, 77],
                [0, 23, 76],
                [0, 22, 75],
                [0, 21, 74],
                [0, 21, 73],
                [0, 20, 72],
                [0, 20, 71],
                [0, 19, 70],
                [0, 19, 69],
                [0, 18, 68],
                [0, 18, 67],
                [0, 17, 66],
                [0, 17, 65],
                [0, 16, 64],
                [0, 16, 63],
                [0, 15, 62],
                [0, 15, 61],
                [0, 14, 60],
                [0, 14, 59],
                [0, 13, 58],
                [0, 13, 57],
                [0, 12, 56],
                [0, 12, 55],
                [0, 11, 54],
                [0, 11, 53],
                [0, 11, 52],
                [0, 10, 51],
                [0, 10, 50],
                [0, 9, 49],
                [0, 9, 48],
                [0, 9, 47],
                [0, 8, 46],
                [0, 8, 45],
                [0, 8, 44],
                [0, 7, 43],
                [0, 7, 42],
                [0, 7, 41],
                [0, 6, 40],
                [0, 6, 39],
                [0, 6, 38],
                [0, 5, 37],
                [0, 5, 36],
                [0, 5, 35],
                [0, 5, 34],
                [0, 4, 33],
                [0, 4, 32],
                [0, 4, 31],
                [0, 4, 30],
                [0, 3, 29],
                [0, 3, 28],
                [0, 3, 27],
                [0, 3, 26],
                [0, 2, 25],
                [0, 2, 24],
                [0, 2, 23],
                [0, 2, 22],
                [0, 2, 21],
                [0, 2, 20],
                [0, 1, 19],
                [0, 1, 18],
                [0, 1, 17],
                [0, 1, 16],
                [0, 1, 15],
                [0, 1, 14],
                [0, 1, 13],
                [0, 1, 12],
                [0, 0, 11],
                [0, 0, 10],
                [0, 0, 9],
                [0, 0, 8],
                [0, 0, 7],
                [0, 0, 6],
                [0, 0, 5],
                [0, 0, 4],
                [0, 0, 3],
                [0, 0, 2],
                [0, 0, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Green",
            [
                [255, 255, 255],
                [253, 254, 249],
                [251, 253, 243],
                [249, 252, 238],
                [247, 251, 232],
                [245, 250, 226],
                [243, 249, 221],
                [241, 248, 216],
                [239, 247, 211],
                [237, 246, 206],
                [235, 245, 201],
                [233, 244, 196],
                [232, 243, 191],
                [230, 242, 186],
                [228, 241, 182],
                [226, 240, 177],
                [224, 239, 173],
                [222, 238, 169],
                [220, 237, 164],
                [218, 236, 160],
                [217, 235, 156],
                [215, 234, 152],
                [213, 233, 148],
                [211, 232, 145],
                [209, 231, 141],
                [207, 230, 137],
                [206, 229, 134],
                [204, 228, 130],
                [202, 227, 127],
                [200, 226, 124],
                [199, 225, 120],
                [197, 224, 117],
                [195, 223, 114],
                [193, 222, 111],
                [192, 221, 108],
                [190, 220, 105],
                [188, 219, 102],
                [186, 218, 100],
                [185, 217, 97],
                [183, 216, 94],
                [181, 215, 92],
                [180, 214, 89],
                [178, 213, 87],
                [176, 212, 84],
                [175, 211, 82],
                [173, 210, 80],
                [171, 209, 77],
                [170, 208, 75],
                [168, 207, 73],
                [166, 206, 71],
                [165, 205, 69],
                [163, 204, 67],
                [162, 203, 65],
                [160, 202, 63],
                [158, 201, 61],
                [157, 200, 59],
                [155, 199, 58],
                [154, 198, 56],
                [152, 197, 54],
                [151, 196, 53],
                [149, 195, 51],
                [148, 194, 49],
                [146, 193, 48],
                [145, 192, 46],
                [143, 191, 45],
                [142, 190, 44],
                [140, 189, 42],
                [139, 188, 41],
                [137, 187, 40],
                [136, 186, 38],
                [134, 185, 37],
                [133, 184, 36],
                [131, 183, 35],
                [130, 182, 34],
                [128, 181, 33],
                [127, 180, 32],
                [126, 179, 31],
                [124, 178, 29],
                [123, 177, 29],
                [121, 176, 28],
                [120, 175, 27],
                [119, 174, 26],
                [117, 173, 25],
                [116, 172, 24],
                [115, 171, 23],
                [113, 170, 22],
                [112, 169, 22],
                [111, 168, 21],
                [109, 167, 20],
                [108, 166, 19],
                [107, 165, 19],
                [105, 164, 18],
                [104, 163, 17],
                [103, 162, 17],
                [102, 161, 16],
                [100, 160, 16],
                [99, 159, 15],
                [98, 158, 14],
                [97, 157, 14],
                [95, 156, 13],
                [94, 155, 13],
                [93, 154, 12],
                [92, 153, 12],
                [91, 152, 11],
                [89, 151, 11],
                [88, 150, 11],
                [87, 149, 10],
                [86, 148, 10],
                [85, 147, 9],
                [84, 146, 9],
                [82, 145, 9],
                [81, 144, 8],
                [80, 143, 8],
                [79, 142, 8],
                [78, 141, 7],
                [77, 140, 7],
                [76, 139, 7],
                [75, 138, 6],
                [74, 137, 6],
                [73, 136, 6],
                [71, 135, 6],
                [70, 134, 5],
                [69, 133, 5],
                [68, 132, 5],
                [67, 131, 5],
                [66, 130, 4],
                [65, 129, 4],
                [64, 128, 4],
                [63, 127, 4],
                [62, 126, 4],
                [61, 125, 4],
                [60, 124, 3],
                [59, 123, 3],
                [58, 122, 3],
                [57, 121, 3],
                [56, 120, 3],
                [56, 119, 3],
                [55, 118, 3],
                [54, 117, 2],
                [53, 116, 2],
                [52, 115, 2],
                [51, 114, 2],
                [50, 113, 2],
                [49, 112, 2],
                [48, 111, 2],
                [47, 110, 2],
                [47, 109, 2],
                [46, 108, 1],
                [45, 107, 1],
                [44, 106, 1],
                [43, 105, 1],
                [42, 104, 1],
                [42, 103, 1],
                [41, 102, 1],
                [40, 101, 1],
                [39, 100, 1],
                [38, 99, 1],
                [38, 98, 1],
                [37, 97, 1],
                [36, 96, 1],
                [35, 95, 1],
                [35, 94, 1],
                [34, 93, 1],
                [33, 92, 1],
                [32, 91, 1],
                [32, 90, 0],
                [31, 89, 0],
                [30, 88, 0],
                [30, 87, 0],
                [29, 86, 0],
                [28, 85, 0],
                [28, 84, 0],
                [27, 83, 0],
                [26, 82, 0],
                [26, 81, 0],
                [25, 80, 0],
                [24, 79, 0],
                [24, 78, 0],
                [23, 77, 0],
                [23, 76, 0],
                [22, 75, 0],
                [21, 74, 0],
                [21, 73, 0],
                [20, 72, 0],
                [20, 71, 0],
                [19, 70, 0],
                [19, 69, 0],
                [18, 68, 0],
                [18, 67, 0],
                [17, 66, 0],
                [17, 65, 0],
                [16, 64, 0],
                [16, 63, 0],
                [15, 62, 0],
                [15, 61, 0],
                [14, 60, 0],
                [14, 59, 0],
                [13, 58, 0],
                [13, 57, 0],
                [12, 56, 0],
                [12, 55, 0],
                [11, 54, 0],
                [11, 53, 0],
                [11, 52, 0],
                [10, 51, 0],
                [10, 50, 0],
                [9, 49, 0],
                [9, 48, 0],
                [9, 47, 0],
                [8, 46, 0],
                [8, 45, 0],
                [8, 44, 0],
                [7, 43, 0],
                [7, 42, 0],
                [7, 41, 0],
                [6, 40, 0],
                [6, 39, 0],
                [6, 38, 0],
                [5, 37, 0],
                [5, 36, 0],
                [5, 35, 0],
                [5, 34, 0],
                [4, 33, 0],
                [4, 32, 0],
                [4, 31, 0],
                [4, 30, 0],
                [3, 29, 0],
                [3, 28, 0],
                [3, 27, 0],
                [3, 26, 0],
                [2, 25, 0],
                [2, 24, 0],
                [2, 23, 0],
                [2, 22, 0],
                [2, 21, 0],
                [2, 20, 0],
                [1, 19, 0],
                [1, 18, 0],
                [1, 17, 0],
                [1, 16, 0],
                [1, 15, 0],
                [1, 14, 0],
                [1, 13, 0],
                [1, 12, 0],
                [0, 11, 0],
                [0, 10, 0],
                [0, 9, 0],
                [0, 8, 0],
                [0, 7, 0],
                [0, 6, 0],
                [0, 5, 0],
                [0, 4, 0],
                [0, 3, 0],
                [0, 2, 0],
                [0, 1, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Mint",
            [
                [255, 255, 255],
                [249, 254, 253],
                [243, 253, 251],
                [238, 252, 249],
                [232, 251, 247],
                [226, 250, 245],
                [221, 249, 243],
                [216, 248, 241],
                [211, 247, 239],
                [206, 246, 237],
                [201, 245, 235],
                [196, 244, 233],
                [191, 243, 232],
                [186, 242, 230],
                [182, 241, 228],
                [177, 240, 226],
                [173, 239, 224],
                [169, 238, 222],
                [164, 237, 220],
                [160, 236, 218],
                [156, 235, 217],
                [152, 234, 215],
                [148, 233, 213],
                [145, 232, 211],
                [141, 231, 209],
                [137, 230, 207],
                [134, 229, 206],
                [130, 228, 204],
                [127, 227, 202],
                [124, 226, 200],
                [120, 225, 199],
                [117, 224, 197],
                [114, 223, 195],
                [111, 222, 193],
                [108, 221, 192],
                [105, 220, 190],
                [102, 219, 188],
                [100, 218, 186],
                [97, 217, 185],
                [94, 216, 183],
                [92, 215, 181],
                [89, 214, 180],
                [87, 213, 178],
                [84, 212, 176],
                [82, 211, 175],
                [80, 210, 173],
                [77, 209, 171],
                [75, 208, 170],
                [73, 207, 168],
                [71, 206, 166],
                [69, 205, 165],
                [67, 204, 163],
                [65, 203, 162],
                [63, 202, 160],
                [61, 201, 158],
                [59, 200, 157],
                [58, 199, 155],
                [56, 198, 154],
                [54, 197, 152],
                [53, 196, 151],
                [51, 195, 149],
                [49, 194, 148],
                [48, 193, 146],
                [46, 192, 145],
                [45, 191, 143],
                [44, 190, 142],
                [42, 189, 140],
                [41, 188, 139],
                [40, 187, 137],
                [38, 186, 136],
                [37, 185, 134],
                [36, 184, 133],
                [35, 183, 131],
                [34, 182, 130],
                [33, 181, 128],
                [32, 180, 127],
                [31, 179, 126],
                [29, 178, 124],
                [29, 177, 123],
                [28, 176, 121],
                [27, 175, 120],
                [26, 174, 119],
                [25, 173, 117],
                [24, 172, 116],
                [23, 171, 115],
                [22, 170, 113],
                [22, 169, 112],
                [21, 168, 111],
                [20, 167, 109],
                [19, 166, 108],
                [19, 165, 107],
                [18, 164, 105],
                [17, 163, 104],
                [17, 162, 103],
                [16, 161, 102],
                [16, 160, 100],
                [15, 159, 99],
                [14, 158, 98],
                [14, 157, 97],
                [13, 156, 95],
                [13, 155, 94],
                [12, 154, 93],
                [12, 153, 92],
                [11, 152, 91],
                [11, 151, 89],
                [11, 150, 88],
                [10, 149, 87],
                [10, 148, 86],
                [9, 147, 85],
                [9, 146, 84],
                [9, 145, 82],
                [8, 144, 81],
                [8, 143, 80],
                [8, 142, 79],
                [7, 141, 78],
                [7, 140, 77],
                [7, 139, 76],
                [6, 138, 75],
                [6, 137, 74],
                [6, 136, 73],
                [6, 135, 71],
                [5, 134, 70],
                [5, 133, 69],
                [5, 132, 68],
                [5, 131, 67],
                [4, 130, 66],
                [4, 129, 65],
                [4, 128, 64],
                [4, 127, 63],
                [4, 126, 62],
                [4, 125, 61],
                [3, 124, 60],
                [3, 123, 59],
                [3, 122, 58],
                [3, 121, 57],
                [3, 120, 56],
                [3, 119, 56],
                [3, 118, 55],
                [2, 117, 54],
                [2, 116, 53],
                [2, 115, 52],
                [2, 114, 51],
                [2, 113, 50],
                [2, 112, 49],
                [2, 111, 48],
                [2, 110, 47],
                [2, 109, 47],
                [1, 108, 46],
                [1, 107, 45],
                [1, 106, 44],
                [1, 105, 43],
                [1, 104, 42],
                [1, 103, 42],
                [1, 102, 41],
                [1, 101, 40],
                [1, 100, 39],
                [1, 99, 38],
                [1, 98, 38],
                [1, 97, 37],
                [1, 96, 36],
                [1, 95, 35],
                [1, 94, 35],
                [1, 93, 34],
                [1, 92, 33],
                [1, 91, 32],
                [0, 90, 32],
                [0, 89, 31],
                [0, 88, 30],
                [0, 87, 30],
                [0, 86, 29],
                [0, 85, 28],
                [0, 84, 28],
                [0, 83, 27],
                [0, 82, 26],
                [0, 81, 26],
                [0, 80, 25],
                [0, 79, 24],
                [0, 78, 24],
                [0, 77, 23],
                [0, 76, 23],
                [0, 75, 22],
                [0, 74, 21],
                [0, 73, 21],
                [0, 72, 20],
                [0, 71, 20],
                [0, 70, 19],
                [0, 69, 19],
                [0, 68, 18],
                [0, 67, 18],
                [0, 66, 17],
                [0, 65, 17],
                [0, 64, 16],
                [0, 63, 16],
                [0, 62, 15],
                [0, 61, 15],
                [0, 60, 14],
                [0, 59, 14],
                [0, 58, 13],
                [0, 57, 13],
                [0, 56, 12],
                [0, 55, 12],
                [0, 54, 11],
                [0, 53, 11],
                [0, 52, 11],
                [0, 51, 10],
                [0, 50, 10],
                [0, 49, 9],
                [0, 48, 9],
                [0, 47, 9],
                [0, 46, 8],
                [0, 45, 8],
                [0, 44, 8],
                [0, 43, 7],
                [0, 42, 7],
                [0, 41, 7],
                [0, 40, 6],
                [0, 39, 6],
                [0, 38, 6],
                [0, 37, 5],
                [0, 36, 5],
                [0, 35, 5],
                [0, 34, 5],
                [0, 33, 4],
                [0, 32, 4],
                [0, 31, 4],
                [0, 30, 4],
                [0, 29, 3],
                [0, 28, 3],
                [0, 27, 3],
                [0, 26, 3],
                [0, 25, 2],
                [0, 24, 2],
                [0, 23, 2],
                [0, 22, 2],
                [0, 21, 2],
                [0, 20, 2],
                [0, 19, 1],
                [0, 18, 1],
                [0, 17, 1],
                [0, 16, 1],
                [0, 15, 1],
                [0, 14, 1],
                [0, 13, 1],
                [0, 12, 1],
                [0, 11, 0],
                [0, 10, 0],
                [0, 9, 0],
                [0, 8, 0],
                [0, 7, 0],
                [0, 6, 0],
                [0, 5, 0],
                [0, 4, 0],
                [0, 3, 0],
                [0, 2, 0],
                [0, 1, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Purple",
            [
                [255, 255, 255],
                [253, 249, 254],
                [251, 243, 253],
                [249, 238, 252],
                [247, 232, 251],
                [245, 226, 250],
                [243, 221, 249],
                [241, 216, 248],
                [239, 211, 247],
                [237, 206, 246],
                [235, 201, 245],
                [233, 196, 244],
                [232, 191, 243],
                [230, 186, 242],
                [228, 182, 241],
                [226, 177, 240],
                [224, 173, 239],
                [222, 169, 238],
                [220, 164, 237],
                [218, 160, 236],
                [217, 156, 235],
                [215, 152, 234],
                [213, 148, 233],
                [211, 145, 232],
                [209, 141, 231],
                [207, 137, 230],
                [206, 134, 229],
                [204, 130, 228],
                [202, 127, 227],
                [200, 124, 226],
                [199, 120, 225],
                [197, 117, 224],
                [195, 114, 223],
                [193, 111, 222],
                [192, 108, 221],
                [190, 105, 220],
                [188, 102, 219],
                [186, 100, 218],
                [185, 97, 217],
                [183, 94, 216],
                [181, 92, 215],
                [180, 89, 214],
                [178, 87, 213],
                [176, 84, 212],
                [175, 82, 211],
                [173, 80, 210],
                [171, 77, 209],
                [170, 75, 208],
                [168, 73, 207],
                [166, 71, 206],
                [165, 69, 205],
                [163, 67, 204],
                [162, 65, 203],
                [160, 63, 202],
                [158, 61, 201],
                [157, 59, 200],
                [155, 58, 199],
                [154, 56, 198],
                [152, 54, 197],
                [151, 53, 196],
                [149, 51, 195],
                [148, 49, 194],
                [146, 48, 193],
                [145, 46, 192],
                [143, 45, 191],
                [142, 44, 190],
                [140, 42, 189],
                [139, 41, 188],
                [137, 40, 187],
                [136, 38, 186],
                [134, 37, 185],
                [133, 36, 184],
                [131, 35, 183],
                [130, 34, 182],
                [128, 33, 181],
                [127, 32, 180],
                [126, 31, 179],
                [124, 29, 178],
                [123, 29, 177],
                [121, 28, 176],
                [120, 27, 175],
                [119, 26, 174],
                [117, 25, 173],
                [116, 24, 172],
                [115, 23, 171],
                [113, 22, 170],
                [112, 22, 169],
                [111, 21, 168],
                [109, 20, 167],
                [108, 19, 166],
                [107, 19, 165],
                [105, 18, 164],
                [104, 17, 163],
                [103, 17, 162],
                [102, 16, 161],
                [100, 16, 160],
                [99, 15, 159],
                [98, 14, 158],
                [97, 14, 157],
                [95, 13, 156],
                [94, 13, 155],
                [93, 12, 154],
                [92, 12, 153],
                [91, 11, 152],
                [89, 11, 151],
                [88, 11, 150],
                [87, 10, 149],
                [86, 10, 148],
                [85, 9, 147],
                [84, 9, 146],
                [82, 9, 145],
                [81, 8, 144],
                [80, 8, 143],
                [79, 8, 142],
                [78, 7, 141],
                [77, 7, 140],
                [76, 7, 139],
                [75, 6, 138],
                [74, 6, 137],
                [73, 6, 136],
                [71, 6, 135],
                [70, 5, 134],
                [69, 5, 133],
                [68, 5, 132],
                [67, 5, 131],
                [66, 4, 130],
                [65, 4, 129],
                [64, 4, 128],
                [63, 4, 127],
                [62, 4, 126],
                [61, 4, 125],
                [60, 3, 124],
                [59, 3, 123],
                [58, 3, 122],
                [57, 3, 121],
                [56, 3, 120],
                [56, 3, 119],
                [55, 3, 118],
                [54, 2, 117],
                [53, 2, 116],
                [52, 2, 115],
                [51, 2, 114],
                [50, 2, 113],
                [49, 2, 112],
                [48, 2, 111],
                [47, 2, 110],
                [47, 2, 109],
                [46, 1, 108],
                [45, 1, 107],
                [44, 1, 106],
                [43, 1, 105],
                [42, 1, 104],
                [42, 1, 103],
                [41, 1, 102],
                [40, 1, 101],
                [39, 1, 100],
                [38, 1, 99],
                [38, 1, 98],
                [37, 1, 97],
                [36, 1, 96],
                [35, 1, 95],
                [35, 1, 94],
                [34, 1, 93],
                [33, 1, 92],
                [32, 1, 91],
                [32, 0, 90],
                [31, 0, 89],
                [30, 0, 88],
                [30, 0, 87],
                [29, 0, 86],
                [28, 0, 85],
                [28, 0, 84],
                [27, 0, 83],
                [26, 0, 82],
                [26, 0, 81],
                [25, 0, 80],
                [24, 0, 79],
                [24, 0, 78],
                [23, 0, 77],
                [23, 0, 76],
                [22, 0, 75],
                [21, 0, 74],
                [21, 0, 73],
                [20, 0, 72],
                [20, 0, 71],
                [19, 0, 70],
                [19, 0, 69],
                [18, 0, 68],
                [18, 0, 67],
                [17, 0, 66],
                [17, 0, 65],
                [16, 0, 64],
                [16, 0, 63],
                [15, 0, 62],
                [15, 0, 61],
                [14, 0, 60],
                [14, 0, 59],
                [13, 0, 58],
                [13, 0, 57],
                [12, 0, 56],
                [12, 0, 55],
                [11, 0, 54],
                [11, 0, 53],
                [11, 0, 52],
                [10, 0, 51],
                [10, 0, 50],
                [9, 0, 49],
                [9, 0, 48],
                [9, 0, 47],
                [8, 0, 46],
                [8, 0, 45],
                [8, 0, 44],
                [7, 0, 43],
                [7, 0, 42],
                [7, 0, 41],
                [6, 0, 40],
                [6, 0, 39],
                [6, 0, 38],
                [5, 0, 37],
                [5, 0, 36],
                [5, 0, 35],
                [5, 0, 34],
                [4, 0, 33],
                [4, 0, 32],
                [4, 0, 31],
                [4, 0, 30],
                [3, 0, 29],
                [3, 0, 28],
                [3, 0, 27],
                [3, 0, 26],
                [2, 0, 25],
                [2, 0, 24],
                [2, 0, 23],
                [2, 0, 22],
                [2, 0, 21],
                [2, 0, 20],
                [1, 0, 19],
                [1, 0, 18],
                [1, 0, 17],
                [1, 0, 16],
                [1, 0, 15],
                [1, 0, 14],
                [1, 0, 13],
                [1, 0, 12],
                [0, 0, 11],
                [0, 0, 10],
                [0, 0, 9],
                [0, 0, 8],
                [0, 0, 7],
                [0, 0, 6],
                [0, 0, 5],
                [0, 0, 4],
                [0, 0, 3],
                [0, 0, 2],
                [0, 0, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Black",
            [
                [255, 255, 255],
                [253, 253, 253],
                [250, 250, 250],
                [248, 248, 248],
                [246, 246, 246],
                [244, 244, 244],
                [241, 241, 241],
                [239, 239, 239],
                [237, 237, 237],
                [235, 235, 235],
                [233, 233, 233],
                [230, 230, 230],
                [228, 228, 228],
                [226, 226, 226],
                [224, 224, 224],
                [222, 222, 222],
                [220, 220, 220],
                [218, 218, 218],
                [216, 216, 216],
                [214, 214, 214],
                [212, 212, 212],
                [210, 210, 210],
                [208, 208, 208],
                [206, 206, 206],
                [204, 204, 204],
                [202, 202, 202],
                [200, 200, 200],
                [198, 198, 198],
                [196, 196, 196],
                [195, 195, 195],
                [193, 193, 193],
                [191, 191, 191],
                [189, 189, 189],
                [187, 187, 187],
                [185, 185, 185],
                [184, 184, 184],
                [182, 182, 182],
                [180, 180, 180],
                [178, 178, 178],
                [177, 177, 177],
                [175, 175, 175],
                [173, 173, 173],
                [172, 172, 172],
                [170, 170, 170],
                [168, 168, 168],
                [167, 167, 167],
                [165, 165, 165],
                [164, 164, 164],
                [162, 162, 162],
                [160, 160, 160],
                [159, 159, 159],
                [157, 157, 157],
                [156, 156, 156],
                [154, 154, 154],
                [153, 153, 153],
                [151, 151, 151],
                [150, 150, 150],
                [148, 148, 148],
                [147, 147, 147],
                [145, 145, 145],
                [144, 144, 144],
                [142, 142, 142],
                [141, 141, 141],
                [140, 140, 140],
                [138, 138, 138],
                [137, 137, 137],
                [135, 135, 135],
                [134, 134, 134],
                [133, 133, 133],
                [131, 131, 131],
                [130, 130, 130],
                [129, 129, 129],
                [127, 127, 127],
                [126, 126, 126],
                [125, 125, 125],
                [123, 123, 123],
                [122, 122, 122],
                [121, 121, 121],
                [120, 120, 120],
                [118, 118, 118],
                [117, 117, 117],
                [116, 116, 116],
                [115, 115, 115],
                [114, 114, 114],
                [112, 112, 112],
                [111, 111, 111],
                [110, 110, 110],
                [109, 109, 109],
                [108, 108, 108],
                [107, 107, 107],
                [105, 105, 105],
                [104, 104, 104],
                [103, 103, 103],
                [102, 102, 102],
                [101, 101, 101],
                [100, 100, 100],
                [99, 99, 99],
                [98, 98, 98],
                [97, 97, 97],
                [96, 96, 96],
                [95, 95, 95],
                [94, 94, 94],
                [93, 93, 93],
                [92, 92, 92],
                [91, 91, 91],
                [90, 90, 90],
                [89, 89, 89],
                [88, 88, 88],
                [87, 87, 87],
                [86, 86, 86],
                [85, 85, 85],
                [84, 84, 84],
                [83, 83, 83],
                [82, 82, 82],
                [81, 81, 81],
                [80, 80, 80],
                [79, 79, 79],
                [78, 78, 78],
                [77, 77, 77],
                [76, 76, 76],
                [76, 76, 76],
                [75, 75, 75],
                [74, 74, 74],
                [73, 73, 73],
                [72, 72, 72],
                [71, 71, 71],
                [70, 70, 70],
                [69, 69, 69],
                [69, 69, 69],
                [68, 68, 68],
                [67, 67, 67],
                [66, 66, 66],
                [65, 65, 65],
                [65, 65, 65],
                [64, 64, 64],
                [63, 63, 63],
                [62, 62, 62],
                [61, 61, 61],
                [61, 61, 61],
                [60, 60, 60],
                [59, 59, 59],
                [58, 58, 58],
                [58, 58, 58],
                [57, 57, 57],
                [56, 56, 56],
                [55, 55, 55],
                [55, 55, 55],
                [54, 54, 54],
                [53, 53, 53],
                [53, 53, 53],
                [52, 52, 52],
                [51, 51, 51],
                [50, 50, 50],
                [50, 50, 50],
                [49, 49, 49],
                [48, 48, 48],
                [48, 48, 48],
                [47, 47, 47],
                [46, 46, 46],
                [46, 46, 46],
                [45, 45, 45],
                [44, 44, 44],
                [44, 44, 44],
                [43, 43, 43],
                [43, 43, 43],
                [42, 42, 42],
                [41, 41, 41],
                [41, 41, 41],
                [40, 40, 40],
                [39, 39, 39],
                [39, 39, 39],
                [38, 38, 38],
                [38, 38, 38],
                [37, 37, 37],
                [36, 36, 36],
                [36, 36, 36],
                [35, 35, 35],
                [35, 35, 35],
                [34, 34, 34],
                [34, 34, 34],
                [33, 33, 33],
                [32, 32, 32],
                [32, 32, 32],
                [31, 31, 31],
                [31, 31, 31],
                [30, 30, 30],
                [30, 30, 30],
                [29, 29, 29],
                [29, 29, 29],
                [28, 28, 28],
                [28, 28, 28],
                [27, 27, 27],
                [27, 27, 27],
                [26, 26, 26],
                [25, 25, 25],
                [25, 25, 25],
                [24, 24, 24],
                [24, 24, 24],
                [23, 23, 23],
                [23, 23, 23],
                [22, 22, 22],
                [22, 22, 22],
                [21, 21, 21],
                [21, 21, 21],
                [21, 21, 21],
                [20, 20, 20],
                [20, 20, 20],
                [19, 19, 19],
                [19, 19, 19],
                [18, 18, 18],
                [18, 18, 18],
                [17, 17, 17],
                [17, 17, 17],
                [16, 16, 16],
                [16, 16, 16],
                [15, 15, 15],
                [15, 15, 15],
                [15, 15, 15],
                [14, 14, 14],
                [14, 14, 14],
                [13, 13, 13],
                [13, 13, 13],
                [12, 12, 12],
                [12, 12, 12],
                [12, 12, 12],
                [11, 11, 11],
                [11, 11, 11],
                [10, 10, 10],
                [10, 10, 10],
                [10, 10, 10],
                [9, 9, 9],
                [9, 9, 9],
                [8, 8, 8],
                [8, 8, 8],
                [8, 8, 8],
                [7, 7, 7],
                [7, 7, 7],
                [6, 6, 6],
                [6, 6, 6],
                [6, 6, 6],
                [5, 5, 5],
                [5, 5, 5],
                [5, 5, 5],
                [4, 4, 4],
                [4, 4, 4],
                [3, 3, 3],
                [3, 3, 3],
                [3, 3, 3],
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [0, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Cherry",
            [
                [255, 255, 255],
                [254, 251, 253],
                [253, 247, 251],
                [252, 243, 249],
                [251, 239, 247],
                [250, 236, 245],
                [249, 232, 243],
                [248, 228, 241],
                [247, 224, 239],
                [246, 221, 237],
                [245, 217, 235],
                [244, 214, 233],
                [243, 210, 232],
                [242, 207, 230],
                [241, 203, 228],
                [240, 200, 226],
                [239, 197, 224],
                [238, 194, 222],
                [237, 190, 220],
                [236, 187, 218],
                [235, 184, 217],
                [234, 181, 215],
                [233, 178, 213],
                [232, 175, 211],
                [231, 172, 209],
                [230, 169, 207],
                [229, 166, 206],
                [228, 163, 204],
                [227, 160, 202],
                [226, 157, 200],
                [225, 155, 199],
                [224, 152, 197],
                [223, 149, 195],
                [222, 146, 193],
                [221, 144, 192],
                [220, 141, 190],
                [219, 139, 188],
                [218, 136, 186],
                [217, 134, 185],
                [216, 131, 183],
                [215, 129, 181],
                [214, 126, 180],
                [213, 124, 178],
                [212, 122, 176],
                [211, 120, 175],
                [210, 117, 173],
                [209, 115, 171],
                [208, 113, 170],
                [207, 111, 168],
                [206, 109, 166],
                [205, 107, 165],
                [204, 104, 163],
                [203, 102, 162],
                [202, 100, 160],
                [201, 98, 158],
                [200, 96, 157],
                [199, 95, 155],
                [198, 93, 154],
                [197, 91, 152],
                [196, 89, 151],
                [195, 87, 149],
                [194, 85, 148],
                [193, 84, 146],
                [192, 82, 145],
                [191, 80, 143],
                [190, 79, 142],
                [189, 77, 140],
                [188, 75, 139],
                [187, 74, 137],
                [186, 72, 136],
                [185, 71, 134],
                [184, 69, 133],
                [183, 68, 131],
                [182, 66, 130],
                [181, 65, 128],
                [180, 63, 127],
                [179, 62, 126],
                [178, 61, 124],
                [177, 59, 123],
                [176, 58, 121],
                [175, 57, 120],
                [174, 55, 119],
                [173, 54, 117],
                [172, 53, 116],
                [171, 52, 115],
                [170, 50, 113],
                [169, 49, 112],
                [168, 48, 111],
                [167, 47, 109],
                [166, 46, 108],
                [165, 45, 107],
                [164, 44, 105],
                [163, 43, 104],
                [162, 42, 103],
                [161, 41, 102],
                [160, 40, 100],
                [159, 39, 99],
                [158, 38, 98],
                [157, 37, 97],
                [156, 36, 95],
                [155, 35, 94],
                [154, 34, 93],
                [153, 33, 92],
                [152, 32, 91],
                [151, 31, 89],
                [150, 31, 88],
                [149, 30, 87],
                [148, 29, 86],
                [147, 28, 85],
                [146, 27, 84],
                [145, 27, 82],
                [144, 26, 81],
                [143, 25, 80],
                [142, 25, 79],
                [141, 24, 78],
                [140, 23, 77],
                [139, 23, 76],
                [138, 22, 75],
                [137, 21, 74],
                [136, 21, 73],
                [135, 20, 71],
                [134, 19, 70],
                [133, 19, 69],
                [132, 18, 68],
                [131, 18, 67],
                [130, 17, 66],
                [129, 17, 65],
                [128, 16, 64],
                [127, 16, 63],
                [126, 15, 62],
                [125, 15, 61],
                [124, 14, 60],
                [123, 14, 59],
                [122, 13, 58],
                [121, 13, 57],
                [120, 13, 56],
                [119, 12, 56],
                [118, 12, 55],
                [117, 11, 54],
                [116, 11, 53],
                [115, 11, 52],
                [114, 10, 51],
                [113, 10, 50],
                [112, 9, 49],
                [111, 9, 48],
                [110, 9, 47],
                [109, 9, 47],
                [108, 8, 46],
                [107, 8, 45],
                [106, 8, 44],
                [105, 7, 43],
                [104, 7, 42],
                [103, 7, 42],
                [102, 7, 41],
                [101, 6, 40],
                [100, 6, 39],
                [99, 6, 38],
                [98, 6, 38],
                [97, 5, 37],
                [96, 5, 36],
                [95, 5, 35],
                [94, 5, 35],
                [93, 5, 34],
                [92, 4, 33],
                [91, 4, 32],
                [90, 4, 32],
                [89, 4, 31],
                [88, 4, 30],
                [87, 3, 30],
                [86, 3, 29],
                [85, 3, 28],
                [84, 3, 28],
                [83, 3, 27],
                [82, 3, 26],
                [81, 3, 26],
                [80, 2, 25],
                [79, 2, 24],
                [78, 2, 24],
                [77, 2, 23],
                [76, 2, 23],
                [75, 2, 22],
                [74, 2, 21],
                [73, 2, 21],
                [72, 2, 20],
                [71, 2, 20],
                [70, 1, 19],
                [69, 1, 19],
                [68, 1, 18],
                [67, 1, 18],
                [66, 1, 17],
                [65, 1, 17],
                [64, 1, 16],
                [63, 1, 16],
                [62, 1, 15],
                [61, 1, 15],
                [60, 1, 14],
                [59, 1, 14],
                [58, 1, 13],
                [57, 1, 13],
                [56, 1, 12],
                [55, 1, 12],
                [54, 1, 11],
                [53, 0, 11],
                [52, 0, 11],
                [51, 0, 10],
                [50, 0, 10],
                [49, 0, 9],
                [48, 0, 9],
                [47, 0, 9],
                [46, 0, 8],
                [45, 0, 8],
                [44, 0, 8],
                [43, 0, 7],
                [42, 0, 7],
                [41, 0, 7],
                [40, 0, 6],
                [39, 0, 6],
                [38, 0, 6],
                [37, 0, 5],
                [36, 0, 5],
                [35, 0, 5],
                [34, 0, 5],
                [33, 0, 4],
                [32, 0, 4],
                [31, 0, 4],
                [30, 0, 4],
                [29, 0, 3],
                [28, 0, 3],
                [27, 0, 3],
                [26, 0, 3],
                [25, 0, 2],
                [24, 0, 2],
                [23, 0, 2],
                [22, 0, 2],
                [21, 0, 2],
                [20, 0, 2],
                [19, 0, 1],
                [18, 0, 1],
                [17, 0, 1],
                [16, 0, 1],
                [15, 0, 1],
                [14, 0, 1],
                [13, 0, 1],
                [12, 0, 1],
                [11, 0, 0],
                [10, 0, 0],
                [9, 0, 0],
                [8, 0, 0],
                [7, 0, 0],
                [6, 0, 0],
                [5, 0, 0],
                [4, 0, 0],
                [3, 0, 0],
                [2, 0, 0],
                [1, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Cyan",
            [
                [255, 255, 255],
                [251, 253, 254],
                [247, 251, 253],
                [243, 249, 252],
                [239, 247, 251],
                [236, 245, 250],
                [232, 243, 249],
                [228, 241, 248],
                [224, 239, 247],
                [221, 237, 246],
                [217, 235, 245],
                [214, 233, 244],
                [210, 232, 243],
                [207, 230, 242],
                [203, 228, 241],
                [200, 226, 240],
                [197, 224, 239],
                [194, 222, 238],
                [190, 220, 237],
                [187, 218, 236],
                [184, 217, 235],
                [181, 215, 234],
                [178, 213, 233],
                [175, 211, 232],
                [172, 209, 231],
                [169, 207, 230],
                [166, 206, 229],
                [163, 204, 228],
                [160, 202, 227],
                [157, 200, 226],
                [155, 199, 225],
                [152, 197, 224],
                [149, 195, 223],
                [146, 193, 222],
                [144, 192, 221],
                [141, 190, 220],
                [139, 188, 219],
                [136, 186, 218],
                [134, 185, 217],
                [131, 183, 216],
                [129, 181, 215],
                [126, 180, 214],
                [124, 178, 213],
                [122, 176, 212],
                [120, 175, 211],
                [117, 173, 210],
                [115, 171, 209],
                [113, 170, 208],
                [111, 168, 207],
                [109, 166, 206],
                [107, 165, 205],
                [104, 163, 204],
                [102, 162, 203],
                [100, 160, 202],
                [98, 158, 201],
                [96, 157, 200],
                [95, 155, 199],
                [93, 154, 198],
                [91, 152, 197],
                [89, 151, 196],
                [87, 149, 195],
                [85, 148, 194],
                [84, 146, 193],
                [82, 145, 192],
                [80, 143, 191],
                [79, 142, 190],
                [77, 140, 189],
                [75, 139, 188],
                [74, 137, 187],
                [72, 136, 186],
                [71, 134, 185],
                [69, 133, 184],
                [68, 131, 183],
                [66, 130, 182],
                [65, 128, 181],
                [63, 127, 180],
                [62, 126, 179],
                [61, 124, 178],
                [59, 123, 177],
                [58, 121, 176],
                [57, 120, 175],
                [55, 119, 174],
                [54, 117, 173],
                [53, 116, 172],
                [52, 115, 171],
                [50, 113, 170],
                [49, 112, 169],
                [48, 111, 168],
                [47, 109, 167],
                [46, 108, 166],
                [45, 107, 165],
                [44, 105, 164],
                [43, 104, 163],
                [42, 103, 162],
                [41, 102, 161],
                [40, 100, 160],
                [39, 99, 159],
                [38, 98, 158],
                [37, 97, 157],
                [36, 95, 156],
                [35, 94, 155],
                [34, 93, 154],
                [33, 92, 153],
                [32, 91, 152],
                [31, 89, 151],
                [31, 88, 150],
                [30, 87, 149],
                [29, 86, 148],
                [28, 85, 147],
                [27, 84, 146],
                [27, 82, 145],
                [26, 81, 144],
                [25, 80, 143],
                [25, 79, 142],
                [24, 78, 141],
                [23, 77, 140],
                [23, 76, 139],
                [22, 75, 138],
                [21, 74, 137],
                [21, 73, 136],
                [20, 71, 135],
                [19, 70, 134],
                [19, 69, 133],
                [18, 68, 132],
                [18, 67, 131],
                [17, 66, 130],
                [17, 65, 129],
                [16, 64, 128],
                [16, 63, 127],
                [15, 62, 126],
                [15, 61, 125],
                [14, 60, 124],
                [14, 59, 123],
                [13, 58, 122],
                [13, 57, 121],
                [13, 56, 120],
                [12, 56, 119],
                [12, 55, 118],
                [11, 54, 117],
                [11, 53, 116],
                [11, 52, 115],
                [10, 51, 114],
                [10, 50, 113],
                [9, 49, 112],
                [9, 48, 111],
                [9, 47, 110],
                [9, 47, 109],
                [8, 46, 108],
                [8, 45, 107],
                [8, 44, 106],
                [7, 43, 105],
                [7, 42, 104],
                [7, 42, 103],
                [7, 41, 102],
                [6, 40, 101],
                [6, 39, 100],
                [6, 38, 99],
                [6, 38, 98],
                [5, 37, 97],
                [5, 36, 96],
                [5, 35, 95],
                [5, 35, 94],
                [5, 34, 93],
                [4, 33, 92],
                [4, 32, 91],
                [4, 32, 90],
                [4, 31, 89],
                [4, 30, 88],
                [3, 30, 87],
                [3, 29, 86],
                [3, 28, 85],
                [3, 28, 84],
                [3, 27, 83],
                [3, 26, 82],
                [3, 26, 81],
                [2, 25, 80],
                [2, 24, 79],
                [2, 24, 78],
                [2, 23, 77],
                [2, 23, 76],
                [2, 22, 75],
                [2, 21, 74],
                [2, 21, 73],
                [2, 20, 72],
                [2, 20, 71],
                [1, 19, 70],
                [1, 19, 69],
                [1, 18, 68],
                [1, 18, 67],
                [1, 17, 66],
                [1, 17, 65],
                [1, 16, 64],
                [1, 16, 63],
                [1, 15, 62],
                [1, 15, 61],
                [1, 14, 60],
                [1, 14, 59],
                [1, 13, 58],
                [1, 13, 57],
                [1, 12, 56],
                [1, 12, 55],
                [1, 11, 54],
                [0, 11, 53],
                [0, 11, 52],
                [0, 10, 51],
                [0, 10, 50],
                [0, 9, 49],
                [0, 9, 48],
                [0, 9, 47],
                [0, 8, 46],
                [0, 8, 45],
                [0, 8, 44],
                [0, 7, 43],
                [0, 7, 42],
                [0, 7, 41],
                [0, 6, 40],
                [0, 6, 39],
                [0, 6, 38],
                [0, 5, 37],
                [0, 5, 36],
                [0, 5, 35],
                [0, 5, 34],
                [0, 4, 33],
                [0, 4, 32],
                [0, 4, 31],
                [0, 4, 30],
                [0, 3, 29],
                [0, 3, 28],
                [0, 3, 27],
                [0, 3, 26],
                [0, 2, 25],
                [0, 2, 24],
                [0, 2, 23],
                [0, 2, 22],
                [0, 2, 21],
                [0, 2, 20],
                [0, 1, 19],
                [0, 1, 18],
                [0, 1, 17],
                [0, 1, 16],
                [0, 1, 15],
                [0, 1, 14],
                [0, 1, 13],
                [0, 1, 12],
                [0, 0, 11],
                [0, 0, 10],
                [0, 0, 9],
                [0, 0, 8],
                [0, 0, 7],
                [0, 0, 6],
                [0, 0, 5],
                [0, 0, 4],
                [0, 0, 3],
                [0, 0, 2],
                [0, 0, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Green",
            [
                [255, 255, 255],
                [253, 254, 251],
                [251, 253, 247],
                [249, 252, 243],
                [247, 251, 239],
                [245, 250, 236],
                [243, 249, 232],
                [241, 248, 228],
                [239, 247, 224],
                [237, 246, 221],
                [235, 245, 217],
                [233, 244, 214],
                [232, 243, 210],
                [230, 242, 207],
                [228, 241, 203],
                [226, 240, 200],
                [224, 239, 197],
                [222, 238, 194],
                [220, 237, 190],
                [218, 236, 187],
                [217, 235, 184],
                [215, 234, 181],
                [213, 233, 178],
                [211, 232, 175],
                [209, 231, 172],
                [207, 230, 169],
                [206, 229, 166],
                [204, 228, 163],
                [202, 227, 160],
                [200, 226, 157],
                [199, 225, 155],
                [197, 224, 152],
                [195, 223, 149],
                [193, 222, 146],
                [192, 221, 144],
                [190, 220, 141],
                [188, 219, 139],
                [186, 218, 136],
                [185, 217, 134],
                [183, 216, 131],
                [181, 215, 129],
                [180, 214, 126],
                [178, 213, 124],
                [176, 212, 122],
                [175, 211, 120],
                [173, 210, 117],
                [171, 209, 115],
                [170, 208, 113],
                [168, 207, 111],
                [166, 206, 109],
                [165, 205, 107],
                [163, 204, 104],
                [162, 203, 102],
                [160, 202, 100],
                [158, 201, 98],
                [157, 200, 96],
                [155, 199, 95],
                [154, 198, 93],
                [152, 197, 91],
                [151, 196, 89],
                [149, 195, 87],
                [148, 194, 85],
                [146, 193, 84],
                [145, 192, 82],
                [143, 191, 80],
                [142, 190, 79],
                [140, 189, 77],
                [139, 188, 75],
                [137, 187, 74],
                [136, 186, 72],
                [134, 185, 71],
                [133, 184, 69],
                [131, 183, 68],
                [130, 182, 66],
                [128, 181, 65],
                [127, 180, 63],
                [126, 179, 62],
                [124, 178, 61],
                [123, 177, 59],
                [121, 176, 58],
                [120, 175, 57],
                [119, 174, 55],
                [117, 173, 54],
                [116, 172, 53],
                [115, 171, 52],
                [113, 170, 50],
                [112, 169, 49],
                [111, 168, 48],
                [109, 167, 47],
                [108, 166, 46],
                [107, 165, 45],
                [105, 164, 44],
                [104, 163, 43],
                [103, 162, 42],
                [102, 161, 41],
                [100, 160, 40],
                [99, 159, 39],
                [98, 158, 38],
                [97, 157, 37],
                [95, 156, 36],
                [94, 155, 35],
                [93, 154, 34],
                [92, 153, 33],
                [91, 152, 32],
                [89, 151, 31],
                [88, 150, 31],
                [87, 149, 30],
                [86, 148, 29],
                [85, 147, 28],
                [84, 146, 27],
                [82, 145, 27],
                [81, 144, 26],
                [80, 143, 25],
                [79, 142, 25],
                [78, 141, 24],
                [77, 140, 23],
                [76, 139, 23],
                [75, 138, 22],
                [74, 137, 21],
                [73, 136, 21],
                [71, 135, 20],
                [70, 134, 19],
                [69, 133, 19],
                [68, 132, 18],
                [67, 131, 18],
                [66, 130, 17],
                [65, 129, 17],
                [64, 128, 16],
                [63, 127, 16],
                [62, 126, 15],
                [61, 125, 15],
                [60, 124, 14],
                [59, 123, 14],
                [58, 122, 13],
                [57, 121, 13],
                [56, 120, 13],
                [56, 119, 12],
                [55, 118, 12],
                [54, 117, 11],
                [53, 116, 11],
                [52, 115, 11],
                [51, 114, 10],
                [50, 113, 10],
                [49, 112, 9],
                [48, 111, 9],
                [47, 110, 9],
                [47, 109, 9],
                [46, 108, 8],
                [45, 107, 8],
                [44, 106, 8],
                [43, 105, 7],
                [42, 104, 7],
                [42, 103, 7],
                [41, 102, 7],
                [40, 101, 6],
                [39, 100, 6],
                [38, 99, 6],
                [38, 98, 6],
                [37, 97, 5],
                [36, 96, 5],
                [35, 95, 5],
                [35, 94, 5],
                [34, 93, 5],
                [33, 92, 4],
                [32, 91, 4],
                [32, 90, 4],
                [31, 89, 4],
                [30, 88, 4],
                [30, 87, 3],
                [29, 86, 3],
                [28, 85, 3],
                [28, 84, 3],
                [27, 83, 3],
                [26, 82, 3],
                [26, 81, 3],
                [25, 80, 2],
                [24, 79, 2],
                [24, 78, 2],
                [23, 77, 2],
                [23, 76, 2],
                [22, 75, 2],
                [21, 74, 2],
                [21, 73, 2],
                [20, 72, 2],
                [20, 71, 2],
                [19, 70, 1],
                [19, 69, 1],
                [18, 68, 1],
                [18, 67, 1],
                [17, 66, 1],
                [17, 65, 1],
                [16, 64, 1],
                [16, 63, 1],
                [15, 62, 1],
                [15, 61, 1],
                [14, 60, 1],
                [14, 59, 1],
                [13, 58, 1],
                [13, 57, 1],
                [12, 56, 1],
                [12, 55, 1],
                [11, 54, 1],
                [11, 53, 0],
                [11, 52, 0],
                [10, 51, 0],
                [10, 50, 0],
                [9, 49, 0],
                [9, 48, 0],
                [9, 47, 0],
                [8, 46, 0],
                [8, 45, 0],
                [8, 44, 0],
                [7, 43, 0],
                [7, 42, 0],
                [7, 41, 0],
                [6, 40, 0],
                [6, 39, 0],
                [6, 38, 0],
                [5, 37, 0],
                [5, 36, 0],
                [5, 35, 0],
                [5, 34, 0],
                [4, 33, 0],
                [4, 32, 0],
                [4, 31, 0],
                [4, 30, 0],
                [3, 29, 0],
                [3, 28, 0],
                [3, 27, 0],
                [3, 26, 0],
                [2, 25, 0],
                [2, 24, 0],
                [2, 23, 0],
                [2, 22, 0],
                [2, 21, 0],
                [2, 20, 0],
                [1, 19, 0],
                [1, 18, 0],
                [1, 17, 0],
                [1, 16, 0],
                [1, 15, 0],
                [1, 14, 0],
                [1, 13, 0],
                [1, 12, 0],
                [0, 11, 0],
                [0, 10, 0],
                [0, 9, 0],
                [0, 8, 0],
                [0, 7, 0],
                [0, 6, 0],
                [0, 5, 0],
                [0, 4, 0],
                [0, 3, 0],
                [0, 2, 0],
                [0, 1, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Mint",
            [
                [255, 255, 255],
                [251, 254, 253],
                [247, 253, 251],
                [243, 252, 249],
                [239, 251, 247],
                [236, 250, 245],
                [232, 249, 243],
                [228, 248, 241],
                [224, 247, 239],
                [221, 246, 237],
                [217, 245, 235],
                [214, 244, 233],
                [210, 243, 232],
                [207, 242, 230],
                [203, 241, 228],
                [200, 240, 226],
                [197, 239, 224],
                [194, 238, 222],
                [190, 237, 220],
                [187, 236, 218],
                [184, 235, 217],
                [181, 234, 215],
                [178, 233, 213],
                [175, 232, 211],
                [172, 231, 209],
                [169, 230, 207],
                [166, 229, 206],
                [163, 228, 204],
                [160, 227, 202],
                [157, 226, 200],
                [155, 225, 199],
                [152, 224, 197],
                [149, 223, 195],
                [146, 222, 193],
                [144, 221, 192],
                [141, 220, 190],
                [139, 219, 188],
                [136, 218, 186],
                [134, 217, 185],
                [131, 216, 183],
                [129, 215, 181],
                [126, 214, 180],
                [124, 213, 178],
                [122, 212, 176],
                [120, 211, 175],
                [117, 210, 173],
                [115, 209, 171],
                [113, 208, 170],
                [111, 207, 168],
                [109, 206, 166],
                [107, 205, 165],
                [104, 204, 163],
                [102, 203, 162],
                [100, 202, 160],
                [98, 201, 158],
                [96, 200, 157],
                [95, 199, 155],
                [93, 198, 154],
                [91, 197, 152],
                [89, 196, 151],
                [87, 195, 149],
                [85, 194, 148],
                [84, 193, 146],
                [82, 192, 145],
                [80, 191, 143],
                [79, 190, 142],
                [77, 189, 140],
                [75, 188, 139],
                [74, 187, 137],
                [72, 186, 136],
                [71, 185, 134],
                [69, 184, 133],
                [68, 183, 131],
                [66, 182, 130],
                [65, 181, 128],
                [63, 180, 127],
                [62, 179, 126],
                [61, 178, 124],
                [59, 177, 123],
                [58, 176, 121],
                [57, 175, 120],
                [55, 174, 119],
                [54, 173, 117],
                [53, 172, 116],
                [52, 171, 115],
                [50, 170, 113],
                [49, 169, 112],
                [48, 168, 111],
                [47, 167, 109],
                [46, 166, 108],
                [45, 165, 107],
                [44, 164, 105],
                [43, 163, 104],
                [42, 162, 103],
                [41, 161, 102],
                [40, 160, 100],
                [39, 159, 99],
                [38, 158, 98],
                [37, 157, 97],
                [36, 156, 95],
                [35, 155, 94],
                [34, 154, 93],
                [33, 153, 92],
                [32, 152, 91],
                [31, 151, 89],
                [31, 150, 88],
                [30, 149, 87],
                [29, 148, 86],
                [28, 147, 85],
                [27, 146, 84],
                [27, 145, 82],
                [26, 144, 81],
                [25, 143, 80],
                [25, 142, 79],
                [24, 141, 78],
                [23, 140, 77],
                [23, 139, 76],
                [22, 138, 75],
                [21, 137, 74],
                [21, 136, 73],
                [20, 135, 71],
                [19, 134, 70],
                [19, 133, 69],
                [18, 132, 68],
                [18, 131, 67],
                [17, 130, 66],
                [17, 129, 65],
                [16, 128, 64],
                [16, 127, 63],
                [15, 126, 62],
                [15, 125, 61],
                [14, 124, 60],
                [14, 123, 59],
                [13, 122, 58],
                [13, 121, 57],
                [13, 120, 56],
                [12, 119, 56],
                [12, 118, 55],
                [11, 117, 54],
                [11, 116, 53],
                [11, 115, 52],
                [10, 114, 51],
                [10, 113, 50],
                [9, 112, 49],
                [9, 111, 48],
                [9, 110, 47],
                [9, 109, 47],
                [8, 108, 46],
                [8, 107, 45],
                [8, 106, 44],
                [7, 105, 43],
                [7, 104, 42],
                [7, 103, 42],
                [7, 102, 41],
                [6, 101, 40],
                [6, 100, 39],
                [6, 99, 38],
                [6, 98, 38],
                [5, 97, 37],
                [5, 96, 36],
                [5, 95, 35],
                [5, 94, 35],
                [5, 93, 34],
                [4, 92, 33],
                [4, 91, 32],
                [4, 90, 32],
                [4, 89, 31],
                [4, 88, 30],
                [3, 87, 30],
                [3, 86, 29],
                [3, 85, 28],
                [3, 84, 28],
                [3, 83, 27],
                [3, 82, 26],
                [3, 81, 26],
                [2, 80, 25],
                [2, 79, 24],
                [2, 78, 24],
                [2, 77, 23],
                [2, 76, 23],
                [2, 75, 22],
                [2, 74, 21],
                [2, 73, 21],
                [2, 72, 20],
                [2, 71, 20],
                [1, 70, 19],
                [1, 69, 19],
                [1, 68, 18],
                [1, 67, 18],
                [1, 66, 17],
                [1, 65, 17],
                [1, 64, 16],
                [1, 63, 16],
                [1, 62, 15],
                [1, 61, 15],
                [1, 60, 14],
                [1, 59, 14],
                [1, 58, 13],
                [1, 57, 13],
                [1, 56, 12],
                [1, 55, 12],
                [1, 54, 11],
                [0, 53, 11],
                [0, 52, 11],
                [0, 51, 10],
                [0, 50, 10],
                [0, 49, 9],
                [0, 48, 9],
                [0, 47, 9],
                [0, 46, 8],
                [0, 45, 8],
                [0, 44, 8],
                [0, 43, 7],
                [0, 42, 7],
                [0, 41, 7],
                [0, 40, 6],
                [0, 39, 6],
                [0, 38, 6],
                [0, 37, 5],
                [0, 36, 5],
                [0, 35, 5],
                [0, 34, 5],
                [0, 33, 4],
                [0, 32, 4],
                [0, 31, 4],
                [0, 30, 4],
                [0, 29, 3],
                [0, 28, 3],
                [0, 27, 3],
                [0, 26, 3],
                [0, 25, 2],
                [0, 24, 2],
                [0, 23, 2],
                [0, 22, 2],
                [0, 21, 2],
                [0, 20, 2],
                [0, 19, 1],
                [0, 18, 1],
                [0, 17, 1],
                [0, 16, 1],
                [0, 15, 1],
                [0, 14, 1],
                [0, 13, 1],
                [0, 12, 1],
                [0, 11, 0],
                [0, 10, 0],
                [0, 9, 0],
                [0, 8, 0],
                [0, 7, 0],
                [0, 6, 0],
                [0, 5, 0],
                [0, 4, 0],
                [0, 3, 0],
                [0, 2, 0],
                [0, 1, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Purple",
            [
                [255, 255, 255],
                [253, 251, 254],
                [251, 247, 253],
                [249, 243, 252],
                [247, 239, 251],
                [245, 236, 250],
                [243, 232, 249],
                [241, 228, 248],
                [239, 224, 247],
                [237, 221, 246],
                [235, 217, 245],
                [233, 214, 244],
                [232, 210, 243],
                [230, 207, 242],
                [228, 203, 241],
                [226, 200, 240],
                [224, 197, 239],
                [222, 194, 238],
                [220, 190, 237],
                [218, 187, 236],
                [217, 184, 235],
                [215, 181, 234],
                [213, 178, 233],
                [211, 175, 232],
                [209, 172, 231],
                [207, 169, 230],
                [206, 166, 229],
                [204, 163, 228],
                [202, 160, 227],
                [200, 157, 226],
                [199, 155, 225],
                [197, 152, 224],
                [195, 149, 223],
                [193, 146, 222],
                [192, 144, 221],
                [190, 141, 220],
                [188, 139, 219],
                [186, 136, 218],
                [185, 134, 217],
                [183, 131, 216],
                [181, 129, 215],
                [180, 126, 214],
                [178, 124, 213],
                [176, 122, 212],
                [175, 120, 211],
                [173, 117, 210],
                [171, 115, 209],
                [170, 113, 208],
                [168, 111, 207],
                [166, 109, 206],
                [165, 107, 205],
                [163, 104, 204],
                [162, 102, 203],
                [160, 100, 202],
                [158, 98, 201],
                [157, 96, 200],
                [155, 95, 199],
                [154, 93, 198],
                [152, 91, 197],
                [151, 89, 196],
                [149, 87, 195],
                [148, 85, 194],
                [146, 84, 193],
                [145, 82, 192],
                [143, 80, 191],
                [142, 79, 190],
                [140, 77, 189],
                [139, 75, 188],
                [137, 74, 187],
                [136, 72, 186],
                [134, 71, 185],
                [133, 69, 184],
                [131, 68, 183],
                [130, 66, 182],
                [128, 65, 181],
                [127, 63, 180],
                [126, 62, 179],
                [124, 61, 178],
                [123, 59, 177],
                [121, 58, 176],
                [120, 57, 175],
                [119, 55, 174],
                [117, 54, 173],
                [116, 53, 172],
                [115, 52, 171],
                [113, 50, 170],
                [112, 49, 169],
                [111, 48, 168],
                [109, 47, 167],
                [108, 46, 166],
                [107, 45, 165],
                [105, 44, 164],
                [104, 43, 163],
                [103, 42, 162],
                [102, 41, 161],
                [100, 40, 160],
                [99, 39, 159],
                [98, 38, 158],
                [97, 37, 157],
                [95, 36, 156],
                [94, 35, 155],
                [93, 34, 154],
                [92, 33, 153],
                [91, 32, 152],
                [89, 31, 151],
                [88, 31, 150],
                [87, 30, 149],
                [86, 29, 148],
                [85, 28, 147],
                [84, 27, 146],
                [82, 27, 145],
                [81, 26, 144],
                [80, 25, 143],
                [79, 25, 142],
                [78, 24, 141],
                [77, 23, 140],
                [76, 23, 139],
                [75, 22, 138],
                [74, 21, 137],
                [73, 21, 136],
                [71, 20, 135],
                [70, 19, 134],
                [69, 19, 133],
                [68, 18, 132],
                [67, 18, 131],
                [66, 17, 130],
                [65, 17, 129],
                [64, 16, 128],
                [63, 16, 127],
                [62, 15, 126],
                [61, 15, 125],
                [60, 14, 124],
                [59, 14, 123],
                [58, 13, 122],
                [57, 13, 121],
                [56, 13, 120],
                [56, 12, 119],
                [55, 12, 118],
                [54, 11, 117],
                [53, 11, 116],
                [52, 11, 115],
                [51, 10, 114],
                [50, 10, 113],
                [49, 9, 112],
                [48, 9, 111],
                [47, 9, 110],
                [47, 9, 109],
                [46, 8, 108],
                [45, 8, 107],
                [44, 8, 106],
                [43, 7, 105],
                [42, 7, 104],
                [42, 7, 103],
                [41, 7, 102],
                [40, 6, 101],
                [39, 6, 100],
                [38, 6, 99],
                [38, 6, 98],
                [37, 5, 97],
                [36, 5, 96],
                [35, 5, 95],
                [35, 5, 94],
                [34, 5, 93],
                [33, 4, 92],
                [32, 4, 91],
                [32, 4, 90],
                [31, 4, 89],
                [30, 4, 88],
                [30, 3, 87],
                [29, 3, 86],
                [28, 3, 85],
                [28, 3, 84],
                [27, 3, 83],
                [26, 3, 82],
                [26, 3, 81],
                [25, 2, 80],
                [24, 2, 79],
                [24, 2, 78],
                [23, 2, 77],
                [23, 2, 76],
                [22, 2, 75],
                [21, 2, 74],
                [21, 2, 73],
                [20, 2, 72],
                [20, 2, 71],
                [19, 1, 70],
                [19, 1, 69],
                [18, 1, 68],
                [18, 1, 67],
                [17, 1, 66],
                [17, 1, 65],
                [16, 1, 64],
                [16, 1, 63],
                [15, 1, 62],
                [15, 1, 61],
                [14, 1, 60],
                [14, 1, 59],
                [13, 1, 58],
                [13, 1, 57],
                [12, 1, 56],
                [12, 1, 55],
                [11, 1, 54],
                [11, 0, 53],
                [11, 0, 52],
                [10, 0, 51],
                [10, 0, 50],
                [9, 0, 49],
                [9, 0, 48],
                [9, 0, 47],
                [8, 0, 46],
                [8, 0, 45],
                [8, 0, 44],
                [7, 0, 43],
                [7, 0, 42],
                [7, 0, 41],
                [6, 0, 40],
                [6, 0, 39],
                [6, 0, 38],
                [5, 0, 37],
                [5, 0, 36],
                [5, 0, 35],
                [5, 0, 34],
                [4, 0, 33],
                [4, 0, 32],
                [4, 0, 31],
                [4, 0, 30],
                [3, 0, 29],
                [3, 0, 28],
                [3, 0, 27],
                [3, 0, 26],
                [2, 0, 25],
                [2, 0, 24],
                [2, 0, 23],
                [2, 0, 22],
                [2, 0, 21],
                [2, 0, 20],
                [1, 0, 19],
                [1, 0, 18],
                [1, 0, 17],
                [1, 0, 16],
                [1, 0, 15],
                [1, 0, 14],
                [1, 0, 13],
                [1, 0, 12],
                [0, 0, 11],
                [0, 0, 10],
                [0, 0, 9],
                [0, 0, 8],
                [0, 0, 7],
                [0, 0, 6],
                [0, 0, 5],
                [0, 0, 4],
                [0, 0, 3],
                [0, 0, 2],
                [0, 0, 1],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Wash Yellow",
            [
                [255, 255, 255],
                [254, 253, 251],
                [253, 251, 247],
                [252, 249, 243],
                [251, 247, 239],
                [250, 245, 236],
                [249, 243, 232],
                [248, 241, 228],
                [247, 239, 224],
                [246, 237, 221],
                [245, 235, 217],
                [244, 233, 214],
                [243, 232, 210],
                [242, 230, 207],
                [241, 228, 203],
                [240, 226, 200],
                [239, 224, 197],
                [238, 222, 194],
                [237, 220, 190],
                [236, 218, 187],
                [235, 217, 184],
                [234, 215, 181],
                [233, 213, 178],
                [232, 211, 175],
                [231, 209, 172],
                [230, 207, 169],
                [229, 206, 166],
                [228, 204, 163],
                [227, 202, 160],
                [226, 200, 157],
                [225, 199, 155],
                [224, 197, 152],
                [223, 195, 149],
                [222, 193, 146],
                [221, 192, 144],
                [220, 190, 141],
                [219, 188, 139],
                [218, 186, 136],
                [217, 185, 134],
                [216, 183, 131],
                [215, 181, 129],
                [214, 180, 126],
                [213, 178, 124],
                [212, 176, 122],
                [211, 175, 120],
                [210, 173, 117],
                [209, 171, 115],
                [208, 170, 113],
                [207, 168, 111],
                [206, 166, 109],
                [205, 165, 107],
                [204, 163, 104],
                [203, 162, 102],
                [202, 160, 100],
                [201, 158, 98],
                [200, 157, 96],
                [199, 155, 95],
                [198, 154, 93],
                [197, 152, 91],
                [196, 151, 89],
                [195, 149, 87],
                [194, 148, 85],
                [193, 146, 84],
                [192, 145, 82],
                [191, 143, 80],
                [190, 142, 79],
                [189, 140, 77],
                [188, 139, 75],
                [187, 137, 74],
                [186, 136, 72],
                [185, 134, 71],
                [184, 133, 69],
                [183, 131, 68],
                [182, 130, 66],
                [181, 128, 65],
                [180, 127, 63],
                [179, 126, 62],
                [178, 124, 61],
                [177, 123, 59],
                [176, 121, 58],
                [175, 120, 57],
                [174, 119, 55],
                [173, 117, 54],
                [172, 116, 53],
                [171, 115, 52],
                [170, 113, 50],
                [169, 112, 49],
                [168, 111, 48],
                [167, 109, 47],
                [166, 108, 46],
                [165, 107, 45],
                [164, 105, 44],
                [163, 104, 43],
                [162, 103, 42],
                [161, 102, 41],
                [160, 100, 40],
                [159, 99, 39],
                [158, 98, 38],
                [157, 97, 37],
                [156, 95, 36],
                [155, 94, 35],
                [154, 93, 34],
                [153, 92, 33],
                [152, 91, 32],
                [151, 89, 31],
                [150, 88, 31],
                [149, 87, 30],
                [148, 86, 29],
                [147, 85, 28],
                [146, 84, 27],
                [145, 82, 27],
                [144, 81, 26],
                [143, 80, 25],
                [142, 79, 25],
                [141, 78, 24],
                [140, 77, 23],
                [139, 76, 23],
                [138, 75, 22],
                [137, 74, 21],
                [136, 73, 21],
                [135, 71, 20],
                [134, 70, 19],
                [133, 69, 19],
                [132, 68, 18],
                [131, 67, 18],
                [130, 66, 17],
                [129, 65, 17],
                [128, 64, 16],
                [127, 63, 16],
                [126, 62, 15],
                [125, 61, 15],
                [124, 60, 14],
                [123, 59, 14],
                [122, 58, 13],
                [121, 57, 13],
                [120, 56, 13],
                [119, 56, 12],
                [118, 55, 12],
                [117, 54, 11],
                [116, 53, 11],
                [115, 52, 11],
                [114, 51, 10],
                [113, 50, 10],
                [112, 49, 9],
                [111, 48, 9],
                [110, 47, 9],
                [109, 47, 9],
                [108, 46, 8],
                [107, 45, 8],
                [106, 44, 8],
                [105, 43, 7],
                [104, 42, 7],
                [103, 42, 7],
                [102, 41, 7],
                [101, 40, 6],
                [100, 39, 6],
                [99, 38, 6],
                [98, 38, 6],
                [97, 37, 5],
                [96, 36, 5],
                [95, 35, 5],
                [94, 35, 5],
                [93, 34, 5],
                [92, 33, 4],
                [91, 32, 4],
                [90, 32, 4],
                [89, 31, 4],
                [88, 30, 4],
                [87, 30, 3],
                [86, 29, 3],
                [85, 28, 3],
                [84, 28, 3],
                [83, 27, 3],
                [82, 26, 3],
                [81, 26, 3],
                [80, 25, 2],
                [79, 24, 2],
                [78, 24, 2],
                [77, 23, 2],
                [76, 23, 2],
                [75, 22, 2],
                [74, 21, 2],
                [73, 21, 2],
                [72, 20, 2],
                [71, 20, 2],
                [70, 19, 1],
                [69, 19, 1],
                [68, 18, 1],
                [67, 18, 1],
                [66, 17, 1],
                [65, 17, 1],
                [64, 16, 1],
                [63, 16, 1],
                [62, 15, 1],
                [61, 15, 1],
                [60, 14, 1],
                [59, 14, 1],
                [58, 13, 1],
                [57, 13, 1],
                [56, 12, 1],
                [55, 12, 1],
                [54, 11, 1],
                [53, 11, 0],
                [52, 11, 0],
                [51, 10, 0],
                [50, 10, 0],
                [49, 9, 0],
                [48, 9, 0],
                [47, 9, 0],
                [46, 8, 0],
                [45, 8, 0],
                [44, 8, 0],
                [43, 7, 0],
                [42, 7, 0],
                [41, 7, 0],
                [40, 6, 0],
                [39, 6, 0],
                [38, 6, 0],
                [37, 5, 0],
                [36, 5, 0],
                [35, 5, 0],
                [34, 5, 0],
                [33, 4, 0],
                [32, 4, 0],
                [31, 4, 0],
                [30, 4, 0],
                [29, 3, 0],
                [28, 3, 0],
                [27, 3, 0],
                [26, 3, 0],
                [25, 2, 0],
                [24, 2, 0],
                [23, 2, 0],
                [22, 2, 0],
                [21, 2, 0],
                [20, 2, 0],
                [19, 1, 0],
                [18, 1, 0],
                [17, 1, 0],
                [16, 1, 0],
                [15, 1, 0],
                [14, 1, 0],
                [13, 1, 0],
                [12, 1, 0],
                [11, 0, 0],
                [10, 0, 0],
                [9, 0, 0],
                [8, 0, 0],
                [7, 0, 0],
                [6, 0, 0],
                [5, 0, 0],
                [4, 0, 0],
                [3, 0, 0],
                [2, 0, 0],
                [1, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Ink Yellow",
            [
                [255, 255, 255],
                [254, 253, 249],
                [253, 251, 243],
                [252, 249, 238],
                [251, 247, 232],
                [250, 245, 226],
                [249, 243, 221],
                [248, 241, 216],
                [247, 239, 211],
                [246, 237, 206],
                [245, 235, 201],
                [244, 233, 196],
                [243, 232, 191],
                [242, 230, 186],
                [241, 228, 182],
                [240, 226, 177],
                [239, 224, 173],
                [238, 222, 169],
                [237, 220, 164],
                [236, 218, 160],
                [235, 217, 156],
                [234, 215, 152],
                [233, 213, 148],
                [232, 211, 145],
                [231, 209, 141],
                [230, 207, 137],
                [229, 206, 134],
                [228, 204, 130],
                [227, 202, 127],
                [226, 200, 124],
                [225, 199, 120],
                [224, 197, 117],
                [223, 195, 114],
                [222, 193, 111],
                [221, 192, 108],
                [220, 190, 105],
                [219, 188, 102],
                [218, 186, 100],
                [217, 185, 97],
                [216, 183, 94],
                [215, 181, 92],
                [214, 180, 89],
                [213, 178, 87],
                [212, 176, 84],
                [211, 175, 82],
                [210, 173, 80],
                [209, 171, 77],
                [208, 170, 75],
                [207, 168, 73],
                [206, 166, 71],
                [205, 165, 69],
                [204, 163, 67],
                [203, 162, 65],
                [202, 160, 63],
                [201, 158, 61],
                [200, 157, 59],
                [199, 155, 58],
                [198, 154, 56],
                [197, 152, 54],
                [196, 151, 53],
                [195, 149, 51],
                [194, 148, 49],
                [193, 146, 48],
                [192, 145, 46],
                [191, 143, 45],
                [190, 142, 44],
                [189, 140, 42],
                [188, 139, 41],
                [187, 137, 40],
                [186, 136, 38],
                [185, 134, 37],
                [184, 133, 36],
                [183, 131, 35],
                [182, 130, 34],
                [181, 128, 33],
                [180, 127, 32],
                [179, 126, 31],
                [178, 124, 29],
                [177, 123, 29],
                [176, 121, 28],
                [175, 120, 27],
                [174, 119, 26],
                [173, 117, 25],
                [172, 116, 24],
                [171, 115, 23],
                [170, 113, 22],
                [169, 112, 22],
                [168, 111, 21],
                [167, 109, 20],
                [166, 108, 19],
                [165, 107, 19],
                [164, 105, 18],
                [163, 104, 17],
                [162, 103, 17],
                [161, 102, 16],
                [160, 100, 16],
                [159, 99, 15],
                [158, 98, 14],
                [157, 97, 14],
                [156, 95, 13],
                [155, 94, 13],
                [154, 93, 12],
                [153, 92, 12],
                [152, 91, 11],
                [151, 89, 11],
                [150, 88, 11],
                [149, 87, 10],
                [148, 86, 10],
                [147, 85, 9],
                [146, 84, 9],
                [145, 82, 9],
                [144, 81, 8],
                [143, 80, 8],
                [142, 79, 8],
                [141, 78, 7],
                [140, 77, 7],
                [139, 76, 7],
                [138, 75, 6],
                [137, 74, 6],
                [136, 73, 6],
                [135, 71, 6],
                [134, 70, 5],
                [133, 69, 5],
                [132, 68, 5],
                [131, 67, 5],
                [130, 66, 4],
                [129, 65, 4],
                [128, 64, 4],
                [127, 63, 4],
                [126, 62, 4],
                [125, 61, 4],
                [124, 60, 3],
                [123, 59, 3],
                [122, 58, 3],
                [121, 57, 3],
                [120, 56, 3],
                [119, 56, 3],
                [118, 55, 3],
                [117, 54, 2],
                [116, 53, 2],
                [115, 52, 2],
                [114, 51, 2],
                [113, 50, 2],
                [112, 49, 2],
                [111, 48, 2],
                [110, 47, 2],
                [109, 47, 2],
                [108, 46, 1],
                [107, 45, 1],
                [106, 44, 1],
                [105, 43, 1],
                [104, 42, 1],
                [103, 42, 1],
                [102, 41, 1],
                [101, 40, 1],
                [100, 39, 1],
                [99, 38, 1],
                [98, 38, 1],
                [97, 37, 1],
                [96, 36, 1],
                [95, 35, 1],
                [94, 35, 1],
                [93, 34, 1],
                [92, 33, 1],
                [91, 32, 1],
                [90, 32, 0],
                [89, 31, 0],
                [88, 30, 0],
                [87, 30, 0],
                [86, 29, 0],
                [85, 28, 0],
                [84, 28, 0],
                [83, 27, 0],
                [82, 26, 0],
                [81, 26, 0],
                [80, 25, 0],
                [79, 24, 0],
                [78, 24, 0],
                [77, 23, 0],
                [76, 23, 0],
                [75, 22, 0],
                [74, 21, 0],
                [73, 21, 0],
                [72, 20, 0],
                [71, 20, 0],
                [70, 19, 0],
                [69, 19, 0],
                [68, 18, 0],
                [67, 18, 0],
                [66, 17, 0],
                [65, 17, 0],
                [64, 16, 0],
                [63, 16, 0],
                [62, 15, 0],
                [61, 15, 0],
                [60, 14, 0],
                [59, 14, 0],
                [58, 13, 0],
                [57, 13, 0],
                [56, 12, 0],
                [55, 12, 0],
                [54, 11, 0],
                [53, 11, 0],
                [52, 11, 0],
                [51, 10, 0],
                [50, 10, 0],
                [49, 9, 0],
                [48, 9, 0],
                [47, 9, 0],
                [46, 8, 0],
                [45, 8, 0],
                [44, 8, 0],
                [43, 7, 0],
                [42, 7, 0],
                [41, 7, 0],
                [40, 6, 0],
                [39, 6, 0],
                [38, 6, 0],
                [37, 5, 0],
                [36, 5, 0],
                [35, 5, 0],
                [34, 5, 0],
                [33, 4, 0],
                [32, 4, 0],
                [31, 4, 0],
                [30, 4, 0],
                [29, 3, 0],
                [28, 3, 0],
                [27, 3, 0],
                [26, 3, 0],
                [25, 2, 0],
                [24, 2, 0],
                [23, 2, 0],
                [22, 2, 0],
                [21, 2, 0],
                [20, 2, 0],
                [19, 1, 0],
                [18, 1, 0],
                [17, 1, 0],
                [16, 1, 0],
                [15, 1, 0],
                [14, 1, 0],
                [13, 1, 0],
                [12, 1, 0],
                [11, 0, 0],
                [10, 0, 0],
                [9, 0, 0],
                [8, 0, 0],
                [7, 0, 0],
                [6, 0, 0],
                [5, 0, 0],
                [4, 0, 0],
                [3, 0, 0],
                [2, 0, 0],
                [1, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Magenta",
            [
                [0, 0, 0],
                [1, 0, 1],
                [2, 0, 2],
                [3, 0, 3],
                [4, 0, 4],
                [5, 0, 5],
                [6, 0, 6],
                [7, 0, 7],
                [8, 0, 8],
                [9, 0, 9],
                [10, 0, 10],
                [11, 0, 11],
                [12, 0, 12],
                [13, 0, 13],
                [14, 0, 14],
                [15, 0, 15],
                [16, 0, 16],
                [17, 0, 17],
                [18, 0, 18],
                [19, 0, 19],
                [20, 0, 20],
                [21, 0, 21],
                [22, 0, 22],
                [23, 0, 23],
                [24, 0, 24],
                [25, 0, 25],
                [26, 0, 26],
                [27, 0, 27],
                [28, 0, 28],
                [29, 0, 29],
                [30, 0, 30],
                [31, 0, 31],
                [32, 0, 32],
                [33, 0, 33],
                [34, 0, 34],
                [35, 0, 35],
                [36, 0, 36],
                [37, 0, 37],
                [38, 0, 38],
                [39, 0, 39],
                [40, 0, 40],
                [41, 0, 41],
                [42, 0, 42],
                [43, 0, 43],
                [44, 0, 44],
                [45, 0, 45],
                [46, 0, 46],
                [47, 0, 47],
                [48, 0, 48],
                [49, 0, 49],
                [50, 0, 50],
                [51, 0, 51],
                [52, 0, 52],
                [53, 0, 53],
                [54, 0, 54],
                [55, 0, 55],
                [56, 0, 56],
                [57, 0, 57],
                [58, 0, 58],
                [59, 0, 59],
                [60, 0, 60],
                [61, 0, 61],
                [62, 0, 62],
                [63, 0, 63],
                [64, 0, 64],
                [65, 0, 65],
                [66, 0, 66],
                [67, 0, 67],
                [68, 0, 68],
                [69, 0, 69],
                [70, 0, 70],
                [71, 0, 71],
                [72, 0, 72],
                [73, 0, 73],
                [74, 0, 74],
                [75, 0, 75],
                [76, 0, 76],
                [77, 0, 77],
                [78, 0, 78],
                [79, 0, 79],
                [80, 0, 80],
                [81, 0, 81],
                [82, 0, 82],
                [83, 0, 83],
                [84, 0, 84],
                [85, 0, 85],
                [86, 0, 86],
                [87, 0, 87],
                [88, 0, 88],
                [89, 0, 89],
                [90, 0, 90],
                [91, 0, 91],
                [92, 0, 92],
                [93, 0, 93],
                [94, 0, 94],
                [95, 0, 95],
                [96, 0, 96],
                [97, 0, 97],
                [98, 0, 98],
                [99, 0, 99],
                [100, 0, 100],
                [101, 0, 101],
                [102, 0, 102],
                [103, 0, 103],
                [104, 0, 104],
                [105, 0, 105],
                [106, 0, 106],
                [107, 0, 107],
                [108, 0, 108],
                [109, 0, 109],
                [110, 0, 110],
                [111, 0, 111],
                [112, 0, 112],
                [113, 0, 113],
                [114, 0, 114],
                [115, 0, 115],
                [116, 0, 116],
                [117, 0, 117],
                [118, 0, 118],
                [119, 0, 119],
                [120, 0, 120],
                [121, 0, 121],
                [122, 0, 122],
                [123, 0, 123],
                [124, 0, 124],
                [125, 0, 125],
                [126, 0, 126],
                [127, 0, 127],
                [128, 0, 128],
                [129, 0, 129],
                [130, 0, 130],
                [131, 0, 131],
                [132, 0, 132],
                [133, 0, 133],
                [134, 0, 134],
                [135, 0, 135],
                [136, 0, 136],
                [137, 0, 137],
                [138, 0, 138],
                [139, 0, 139],
                [140, 0, 140],
                [141, 0, 141],
                [142, 0, 142],
                [143, 0, 143],
                [144, 0, 144],
                [145, 0, 145],
                [146, 0, 146],
                [147, 0, 147],
                [148, 0, 148],
                [149, 0, 149],
                [150, 0, 150],
                [151, 0, 151],
                [152, 0, 152],
                [153, 0, 153],
                [154, 0, 154],
                [155, 0, 155],
                [156, 0, 156],
                [157, 0, 157],
                [158, 0, 158],
                [159, 0, 159],
                [160, 0, 160],
                [161, 0, 161],
                [162, 0, 162],
                [163, 0, 163],
                [164, 0, 164],
                [165, 0, 165],
                [166, 0, 166],
                [167, 0, 167],
                [168, 0, 168],
                [169, 0, 169],
                [170, 0, 170],
                [171, 0, 171],
                [172, 0, 172],
                [173, 0, 173],
                [174, 0, 174],
                [175, 0, 175],
                [176, 0, 176],
                [177, 0, 177],
                [178, 0, 178],
                [179, 0, 179],
                [180, 0, 180],
                [181, 0, 181],
                [182, 0, 182],
                [183, 0, 183],
                [184, 0, 184],
                [185, 0, 185],
                [186, 0, 186],
                [187, 0, 187],
                [188, 0, 188],
                [189, 0, 189],
                [190, 0, 190],
                [191, 0, 191],
                [192, 0, 192],
                [193, 0, 193],
                [194, 0, 194],
                [195, 0, 195],
                [196, 0, 196],
                [197, 0, 197],
                [198, 0, 198],
                [199, 0, 199],
                [200, 0, 200],
                [201, 0, 201],
                [202, 0, 202],
                [203, 0, 203],
                [204, 0, 204],
                [205, 0, 205],
                [206, 0, 206],
                [207, 0, 207],
                [208, 0, 208],
                [209, 0, 209],
                [210, 0, 210],
                [211, 0, 211],
                [212, 0, 212],
                [213, 0, 213],
                [214, 0, 214],
                [215, 0, 215],
                [216, 0, 216],
                [217, 0, 217],
                [218, 0, 218],
                [219, 0, 219],
                [220, 0, 220],
                [221, 0, 221],
                [222, 0, 222],
                [223, 0, 223],
                [224, 0, 224],
                [225, 0, 225],
                [226, 0, 226],
                [227, 0, 227],
                [228, 0, 228],
                [229, 0, 229],
                [230, 0, 230],
                [231, 0, 231],
                [232, 0, 232],
                [233, 0, 233],
                [234, 0, 234],
                [235, 0, 235],
                [236, 0, 236],
                [237, 0, 237],
                [238, 0, 238],
                [239, 0, 239],
                [240, 0, 240],
                [241, 0, 241],
                [242, 0, 242],
                [243, 0, 243],
                [244, 0, 244],
                [245, 0, 245],
                [246, 0, 246],
                [247, 0, 247],
                [248, 0, 248],
                [249, 0, 249],
                [250, 0, 250],
                [251, 0, 251],
                [252, 0, 252],
                [253, 0, 253],
                [254, 0, 254],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Magenta Hot",
            [
                [0, 0, 0],
                [1, 0, 1],
                [3, 0, 3],
                [4, 0, 4],
                [6, 0, 6],
                [7, 0, 7],
                [9, 0, 9],
                [11, 0, 11],
                [12, 0, 12],
                [14, 0, 14],
                [15, 0, 15],
                [17, 0, 17],
                [19, 0, 19],
                [20, 0, 20],
                [22, 0, 22],
                [23, 0, 23],
                [25, 0, 25],
                [27, 0, 27],
                [28, 0, 28],
                [30, 0, 30],
                [31, 0, 31],
                [33, 0, 33],
                [35, 0, 35],
                [36, 0, 36],
                [38, 0, 38],
                [39, 0, 39],
                [41, 0, 41],
                [43, 0, 43],
                [44, 0, 44],
                [46, 0, 46],
                [47, 0, 47],
                [49, 0, 49],
                [51, 0, 51],
                [52, 0, 52],
                [54, 0, 54],
                [55, 0, 55],
                [57, 0, 57],
                [58, 0, 58],
                [60, 0, 60],
                [62, 0, 62],
                [63, 0, 63],
                [65, 0, 65],
                [66, 0, 66],
                [68, 0, 68],
                [70, 0, 70],
                [71, 0, 71],
                [73, 0, 73],
                [74, 0, 74],
                [76, 0, 76],
                [78, 0, 78],
                [79, 0, 79],
                [81, 0, 81],
                [82, 0, 82],
                [84, 0, 84],
                [86, 0, 86],
                [87, 0, 87],
                [89, 0, 89],
                [90, 0, 90],
                [92, 0, 92],
                [94, 0, 94],
                [95, 0, 95],
                [97, 0, 97],
                [98, 0, 98],
                [102, 0, 102],
                [102, 0, 102],
                [104, 0, 104],
                [106, 0, 106],
                [109, 0, 109],
                [111, 0, 111],
                [113, 0, 113],
                [116, 0, 116],
                [118, 0, 118],
                [121, 0, 121],
                [123, 0, 123],
                [125, 0, 125],
                [128, 0, 128],
                [130, 0, 130],
                [133, 0, 133],
                [135, 0, 135],
                [137, 0, 137],
                [140, 0, 140],
                [142, 0, 142],
                [145, 0, 145],
                [147, 0, 147],
                [149, 0, 149],
                [152, 0, 152],
                [154, 0, 154],
                [156, 0, 156],
                [159, 0, 159],
                [161, 0, 161],
                [164, 0, 164],
                [166, 0, 166],
                [168, 0, 168],
                [171, 0, 171],
                [173, 0, 173],
                [176, 0, 176],
                [178, 0, 178],
                [180, 0, 180],
                [183, 0, 183],
                [185, 0, 185],
                [188, 0, 188],
                [190, 0, 190],
                [192, 0, 192],
                [195, 0, 195],
                [197, 0, 197],
                [200, 0, 200],
                [202, 0, 202],
                [204, 0, 204],
                [207, 0, 207],
                [209, 0, 209],
                [211, 0, 211],
                [214, 0, 214],
                [216, 0, 216],
                [219, 0, 219],
                [221, 0, 221],
                [223, 0, 223],
                [226, 0, 226],
                [228, 0, 228],
                [231, 0, 231],
                [233, 0, 233],
                [235, 0, 235],
                [238, 0, 238],
                [240, 0, 240],
                [243, 0, 243],
                [245, 0, 245],
                [247, 0, 247],
                [250, 0, 250],
                [255, 0, 255],
                [255, 0, 255],
                [255, 1, 255],
                [255, 3, 255],
                [255, 4, 255],
                [255, 6, 255],
                [255, 7, 255],
                [255, 9, 255],
                [255, 11, 255],
                [255, 12, 255],
                [255, 14, 255],
                [255, 15, 255],
                [255, 17, 255],
                [255, 19, 255],
                [255, 20, 255],
                [255, 22, 255],
                [255, 23, 255],
                [255, 25, 255],
                [255, 27, 255],
                [255, 28, 255],
                [255, 30, 255],
                [255, 31, 255],
                [255, 33, 255],
                [255, 35, 255],
                [255, 36, 255],
                [255, 38, 255],
                [255, 39, 255],
                [255, 41, 255],
                [255, 43, 255],
                [255, 44, 255],
                [255, 46, 255],
                [255, 47, 255],
                [255, 49, 255],
                [255, 51, 255],
                [255, 52, 255],
                [255, 54, 255],
                [255, 55, 255],
                [255, 57, 255],
                [255, 58, 255],
                [255, 60, 255],
                [255, 62, 255],
                [255, 63, 255],
                [255, 65, 255],
                [255, 66, 255],
                [255, 68, 255],
                [255, 70, 255],
                [255, 71, 255],
                [255, 73, 255],
                [255, 74, 255],
                [255, 76, 255],
                [255, 78, 255],
                [255, 79, 255],
                [255, 81, 255],
                [255, 82, 255],
                [255, 84, 255],
                [255, 86, 255],
                [255, 87, 255],
                [255, 89, 255],
                [255, 90, 255],
                [255, 92, 255],
                [255, 94, 255],
                [255, 95, 255],
                [255, 97, 255],
                [255, 98, 255],
                [255, 102, 255],
                [255, 102, 255],
                [255, 104, 255],
                [255, 106, 255],
                [255, 109, 255],
                [255, 111, 255],
                [255, 113, 255],
                [255, 116, 255],
                [255, 118, 255],
                [255, 121, 255],
                [255, 123, 255],
                [255, 125, 255],
                [255, 128, 255],
                [255, 130, 255],
                [255, 133, 255],
                [255, 135, 255],
                [255, 137, 255],
                [255, 140, 255],
                [255, 142, 255],
                [255, 145, 255],
                [255, 147, 255],
                [255, 149, 255],
                [255, 152, 255],
                [255, 154, 255],
                [255, 156, 255],
                [255, 159, 255],
                [255, 161, 255],
                [255, 164, 255],
                [255, 166, 255],
                [255, 168, 255],
                [255, 171, 255],
                [255, 173, 255],
                [255, 176, 255],
                [255, 178, 255],
                [255, 180, 255],
                [255, 183, 255],
                [255, 185, 255],
                [255, 188, 255],
                [255, 190, 255],
                [255, 192, 255],
                [255, 195, 255],
                [255, 197, 255],
                [255, 200, 255],
                [255, 202, 255],
                [255, 204, 255],
                [255, 207, 255],
                [255, 209, 255],
                [255, 211, 255],
                [255, 214, 255],
                [255, 216, 255],
                [255, 219, 255],
                [255, 221, 255],
                [255, 223, 255],
                [255, 226, 255],
                [255, 228, 255],
                [255, 231, 255],
                [255, 233, 255],
                [255, 235, 255],
                [255, 238, 255],
                [255, 240, 255],
                [255, 243, 255],
                [255, 245, 255],
                [255, 247, 255],
                [255, 250, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "OIMB1",
            [
                [0, 0, 3],
                [1, 1, 5],
                [2, 2, 7],
                [4, 3, 9],
                [5, 4, 11],
                [6, 5, 13],
                [8, 6, 16],
                [9, 7, 18],
                [10, 8, 20],
                [12, 9, 22],
                [13, 10, 24],
                [15, 11, 26],
                [16, 12, 29],
                [17, 13, 31],
                [19, 14, 33],
                [20, 15, 35],
                [21, 16, 37],
                [23, 17, 40],
                [24, 18, 42],
                [25, 19, 44],
                [27, 20, 46],
                [28, 21, 48],
                [30, 22, 50],
                [31, 23, 53],
                [32, 24, 55],
                [34, 25, 57],
                [35, 26, 59],
                [36, 27, 61],
                [38, 28, 63],
                [39, 29, 66],
                [40, 30, 68],
                [42, 31, 70],
                [43, 32, 72],
                [45, 33, 74],
                [46, 34, 77],
                [47, 35, 79],
                [49, 36, 81],
                [50, 37, 83],
                [51, 38, 85],
                [53, 39, 87],
                [54, 40, 90],
                [55, 41, 92],
                [57, 42, 94],
                [58, 43, 96],
                [60, 44, 98],
                [61, 45, 100],
                [62, 46, 103],
                [64, 47, 105],
                [65, 48, 107],
                [66, 49, 109],
                [68, 50, 111],
                [69, 51, 114],
                [70, 52, 116],
                [72, 53, 118],
                [73, 54, 120],
                [75, 55, 122],
                [76, 56, 124],
                [77, 57, 127],
                [79, 58, 129],
                [80, 59, 131],
                [81, 60, 133],
                [83, 61, 135],
                [84, 62, 137],
                [85, 63, 140],
                [87, 64, 142],
                [88, 65, 144],
                [90, 66, 146],
                [91, 67, 148],
                [92, 68, 151],
                [94, 69, 153],
                [95, 70, 155],
                [96, 71, 157],
                [98, 72, 159],
                [99, 73, 161],
                [100, 74, 164],
                [102, 75, 166],
                [103, 76, 168],
                [105, 77, 170],
                [106, 78, 172],
                [107, 79, 174],
                [109, 80, 177],
                [110, 81, 179],
                [111, 82, 181],
                [113, 83, 183],
                [114, 84, 185],
                [116, 86, 188],
                [117, 87, 186],
                [118, 88, 185],
                [120, 90, 183],
                [121, 91, 182],
                [123, 92, 180],
                [124, 94, 179],
                [126, 95, 177],
                [127, 97, 176],
                [129, 98, 175],
                [130, 99, 173],
                [132, 101, 172],
                [133, 102, 170],
                [135, 104, 169],
                [136, 105, 167],
                [138, 106, 166],
                [139, 108, 165],
                [141, 109, 163],
                [142, 110, 162],
                [144, 112, 160],
                [145, 113, 159],
                [147, 115, 157],
                [148, 116, 156],
                [150, 117, 154],
                [151, 119, 153],
                [153, 120, 152],
                [154, 122, 150],
                [156, 123, 149],
                [157, 124, 147],
                [158, 126, 146],
                [160, 127, 144],
                [161, 129, 143],
                [163, 130, 142],
                [164, 131, 140],
                [166, 133, 139],
                [167, 134, 137],
                [169, 135, 136],
                [170, 137, 134],
                [172, 138, 133],
                [173, 140, 132],
                [175, 141, 130],
                [176, 142, 129],
                [178, 144, 127],
                [179, 145, 126],
                [181, 147, 124],
                [182, 148, 123],
                [184, 149, 121],
                [185, 151, 120],
                [187, 152, 119],
                [188, 154, 117],
                [190, 155, 116],
                [191, 156, 114],
                [193, 158, 113],
                [194, 159, 111],
                [196, 160, 110],
                [197, 162, 109],
                [199, 163, 107],
                [200, 165, 106],
                [201, 166, 104],
                [203, 167, 103],
                [204, 169, 101],
                [206, 170, 100],
                [207, 172, 99],
                [209, 173, 97],
                [210, 174, 96],
                [212, 176, 94],
                [213, 177, 93],
                [215, 179, 91],
                [216, 180, 90],
                [218, 181, 88],
                [219, 183, 87],
                [221, 184, 86],
                [222, 185, 84],
                [224, 187, 83],
                [225, 188, 81],
                [227, 190, 80],
                [228, 191, 78],
                [230, 192, 77],
                [231, 194, 76],
                [233, 195, 74],
                [234, 197, 73],
                [236, 198, 71],
                [237, 199, 70],
                [239, 201, 68],
                [240, 202, 67],
                [242, 204, 66],
                [242, 204, 67],
                [242, 205, 69],
                [242, 205, 71],
                [242, 206, 73],
                [242, 207, 75],
                [242, 207, 76],
                [243, 208, 78],
                [243, 208, 80],
                [243, 209, 82],
                [243, 210, 84],
                [243, 210, 85],
                [243, 211, 87],
                [243, 211, 89],
                [244, 212, 91],
                [244, 212, 93],
                [244, 213, 94],
                [244, 214, 96],
                [244, 214, 98],
                [244, 215, 100],
                [245, 216, 102],
                [245, 216, 104],
                [245, 217, 105],
                [245, 217, 107],
                [245, 218, 109],
                [245, 219, 111],
                [245, 219, 113],
                [246, 220, 114],
                [246, 220, 116],
                [246, 221, 118],
                [246, 222, 120],
                [246, 222, 122],
                [246, 223, 123],
                [247, 223, 125],
                [247, 224, 127],
                [247, 225, 129],
                [247, 225, 131],
                [247, 226, 133],
                [247, 226, 134],
                [247, 227, 136],
                [248, 228, 138],
                [248, 228, 140],
                [248, 229, 142],
                [248, 229, 143],
                [248, 230, 145],
                [248, 231, 147],
                [249, 231, 149],
                [249, 232, 151],
                [249, 232, 152],
                [249, 233, 154],
                [249, 234, 156],
                [249, 234, 158],
                [249, 235, 160],
                [250, 235, 162],
                [250, 236, 163],
                [250, 237, 165],
                [250, 237, 167],
                [250, 238, 169],
                [250, 238, 171],
                [251, 239, 172],
                [251, 240, 174],
                [251, 240, 176],
                [251, 241, 178],
                [251, 241, 180],
                [251, 242, 181],
                [251, 243, 183],
                [252, 243, 185],
                [252, 244, 187],
                [252, 244, 189],
                [252, 245, 191],
                [252, 246, 192],
                [252, 246, 194],
                [253, 247, 196],
                [253, 247, 198],
                [253, 248, 200],
                [253, 249, 201],
                [253, 249, 203],
                [253, 250, 205],
                [253, 250, 207],
                [254, 251, 209],
                [254, 252, 210],
                [254, 252, 212],
                [254, 253, 214],
                [254, 253, 216],
                [254, 254, 218],
                [255, 255, 220],
            ],
        );

        m.insert(
            "OIMB2",
            [
                [0, 0, 0],
                [1, 1, 2],
                [2, 1, 4],
                [2, 2, 6],
                [3, 2, 8],
                [4, 3, 11],
                [5, 3, 13],
                [5, 4, 15],
                [6, 4, 17],
                [7, 5, 19],
                [8, 6, 21],
                [8, 6, 23],
                [9, 7, 25],
                [10, 7, 27],
                [11, 8, 29],
                [12, 9, 31],
                [13, 9, 33],
                [13, 10, 35],
                [14, 10, 37],
                [15, 11, 39],
                [16, 11, 41],
                [17, 12, 43],
                [18, 13, 45],
                [19, 13, 47],
                [20, 14, 49],
                [21, 15, 51],
                [22, 15, 52],
                [22, 16, 54],
                [23, 16, 56],
                [24, 17, 58],
                [25, 18, 59],
                [27, 18, 61],
                [28, 19, 63],
                [29, 20, 64],
                [30, 20, 66],
                [31, 21, 68],
                [32, 22, 69],
                [33, 22, 71],
                [34, 23, 72],
                [36, 24, 74],
                [37, 25, 75],
                [38, 25, 76],
                [39, 26, 78],
                [41, 27, 79],
                [42, 28, 80],
                [43, 28, 82],
                [45, 29, 83],
                [46, 30, 84],
                [48, 31, 85],
                [49, 32, 86],
                [51, 32, 87],
                [52, 33, 88],
                [54, 34, 89],
                [55, 35, 90],
                [57, 36, 91],
                [59, 37, 91],
                [60, 37, 92],
                [62, 38, 93],
                [64, 39, 93],
                [65, 40, 94],
                [67, 41, 94],
                [69, 42, 95],
                [71, 43, 95],
                [73, 44, 96],
                [75, 45, 96],
                [77, 46, 96],
                [79, 47, 96],
                [81, 48, 97],
                [83, 49, 97],
                [85, 50, 97],
                [88, 51, 97],
                [90, 52, 97],
                [92, 53, 96],
                [94, 54, 96],
                [97, 56, 96],
                [99, 57, 96],
                [101, 58, 95],
                [104, 59, 95],
                [106, 60, 95],
                [109, 61, 94],
                [111, 62, 94],
                [113, 64, 93],
                [116, 65, 93],
                [118, 66, 92],
                [121, 67, 92],
                [123, 68, 91],
                [126, 70, 90],
                [128, 71, 90],
                [131, 72, 89],
                [133, 73, 88],
                [136, 75, 87],
                [138, 76, 87],
                [141, 77, 86],
                [143, 78, 85],
                [146, 80, 84],
                [148, 81, 83],
                [151, 82, 82],
                [153, 83, 82],
                [156, 85, 81],
                [158, 86, 80],
                [161, 87, 79],
                [163, 89, 78],
                [166, 90, 77],
                [168, 91, 76],
                [171, 93, 75],
                [173, 94, 74],
                [175, 95, 73],
                [178, 97, 72],
                [180, 98, 71],
                [182, 99, 70],
                [185, 101, 70],
                [187, 102, 69],
                [189, 103, 68],
                [191, 105, 67],
                [194, 106, 66],
                [196, 107, 65],
                [198, 109, 64],
                [200, 110, 63],
                [202, 112, 62],
                [204, 113, 62],
                [206, 114, 61],
                [208, 116, 60],
                [210, 117, 59],
                [212, 118, 58],
                [213, 120, 58],
                [215, 121, 57],
                [217, 122, 56],
                [218, 124, 56],
                [220, 125, 55],
                [222, 126, 54],
                [223, 128, 54],
                [224, 129, 53],
                [226, 130, 53],
                [227, 132, 52],
                [228, 133, 52],
                [230, 134, 51],
                [231, 136, 51],
                [232, 137, 51],
                [233, 138, 50],
                [234, 140, 50],
                [235, 141, 50],
                [236, 142, 50],
                [237, 143, 49],
                [238, 145, 49],
                [239, 146, 49],
                [240, 147, 49],
                [240, 149, 49],
                [241, 150, 49],
                [242, 151, 49],
                [243, 152, 49],
                [243, 154, 49],
                [244, 155, 49],
                [244, 156, 49],
                [245, 157, 49],
                [245, 159, 49],
                [246, 160, 49],
                [246, 161, 50],
                [247, 162, 50],
                [247, 163, 50],
                [248, 165, 50],
                [248, 166, 51],
                [248, 167, 51],
                [248, 168, 51],
                [249, 169, 52],
                [249, 171, 52],
                [249, 172, 53],
                [249, 173, 53],
                [250, 174, 54],
                [250, 175, 54],
                [250, 176, 55],
                [250, 177, 55],
                [250, 179, 56],
                [250, 180, 57],
                [250, 181, 57],
                [250, 182, 58],
                [250, 183, 59],
                [250, 184, 59],
                [250, 185, 60],
                [250, 186, 61],
                [250, 187, 62],
                [250, 188, 63],
                [250, 189, 64],
                [250, 190, 65],
                [250, 191, 65],
                [250, 192, 66],
                [250, 193, 67],
                [250, 194, 68],
                [250, 195, 69],
                [250, 196, 70],
                [250, 197, 72],
                [250, 198, 73],
                [250, 199, 74],
                [250, 200, 75],
                [250, 201, 76],
                [250, 202, 77],
                [250, 203, 79],
                [250, 204, 80],
                [250, 204, 81],
                [250, 205, 83],
                [250, 206, 84],
                [250, 207, 85],
                [250, 208, 87],
                [250, 209, 88],
                [250, 209, 89],
                [250, 210, 91],
                [250, 211, 92],
                [250, 212, 94],
                [250, 213, 95],
                [250, 213, 97],
                [250, 214, 98],
                [250, 215, 100],
                [249, 216, 102],
                [249, 216, 103],
                [249, 217, 105],
                [249, 218, 106],
                [249, 219, 108],
                [249, 219, 110],
                [249, 220, 111],
                [249, 221, 113],
                [249, 221, 115],
                [249, 222, 116],
                [249, 223, 118],
                [249, 223, 120],
                [249, 224, 122],
                [249, 225, 124],
                [249, 225, 125],
                [249, 226, 127],
                [249, 227, 129],
                [249, 227, 131],
                [250, 228, 133],
                [250, 229, 134],
                [250, 229, 136],
                [250, 230, 138],
                [250, 230, 140],
                [250, 231, 142],
                [250, 232, 144],
                [250, 232, 146],
                [250, 233, 148],
                [250, 234, 150],
                [250, 234, 152],
                [250, 235, 153],
                [250, 235, 155],
                [250, 236, 157],
                [250, 236, 159],
                [250, 237, 161],
                [250, 238, 163],
                [250, 238, 165],
                [250, 239, 167],
                [250, 239, 169],
                [250, 240, 171],
                [250, 241, 173],
                [250, 241, 175],
                [250, 242, 177],
                [250, 242, 179],
                [250, 243, 181],
                [250, 243, 183],
            ],
        );

        m.insert(
            "OIMB3",
            [
                [0, 0, 0],
                [0, 0, 1],
                [1, 0, 1],
                [1, 0, 2],
                [2, 0, 2],
                [2, 0, 3],
                [3, 1, 3],
                [3, 1, 4],
                [4, 1, 4],
                [4, 1, 5],
                [4, 1, 5],
                [5, 1, 6],
                [5, 1, 6],
                [6, 1, 7],
                [6, 1, 7],
                [7, 2, 8],
                [7, 2, 8],
                [8, 2, 9],
                [8, 2, 9],
                [9, 2, 10],
                [9, 2, 11],
                [10, 2, 11],
                [10, 2, 12],
                [11, 3, 12],
                [11, 3, 13],
                [12, 3, 13],
                [13, 3, 14],
                [13, 3, 14],
                [14, 3, 15],
                [14, 4, 15],
                [15, 4, 16],
                [15, 4, 16],
                [16, 4, 17],
                [17, 4, 18],
                [17, 5, 18],
                [18, 5, 19],
                [19, 5, 19],
                [19, 5, 20],
                [20, 5, 20],
                [21, 6, 21],
                [22, 6, 21],
                [22, 6, 22],
                [23, 7, 22],
                [24, 7, 23],
                [25, 7, 24],
                [26, 7, 24],
                [26, 8, 25],
                [27, 8, 25],
                [28, 8, 26],
                [29, 9, 26],
                [30, 9, 27],
                [31, 9, 27],
                [32, 10, 28],
                [33, 10, 29],
                [34, 10, 29],
                [35, 11, 30],
                [36, 11, 30],
                [37, 12, 31],
                [38, 12, 31],
                [39, 13, 32],
                [40, 13, 33],
                [41, 14, 33],
                [43, 14, 34],
                [44, 14, 34],
                [45, 15, 35],
                [46, 16, 36],
                [48, 16, 36],
                [49, 17, 37],
                [50, 17, 37],
                [51, 18, 38],
                [53, 18, 39],
                [54, 19, 39],
                [56, 20, 40],
                [57, 20, 40],
                [59, 21, 41],
                [60, 21, 42],
                [61, 22, 42],
                [63, 23, 43],
                [64, 23, 43],
                [66, 24, 44],
                [68, 25, 45],
                [69, 25, 45],
                [71, 26, 46],
                [72, 27, 46],
                [74, 28, 47],
                [76, 28, 47],
                [77, 29, 48],
                [79, 30, 49],
                [80, 31, 49],
                [82, 32, 50],
                [84, 32, 50],
                [86, 33, 51],
                [87, 34, 51],
                [89, 35, 52],
                [91, 36, 52],
                [92, 37, 53],
                [94, 37, 53],
                [96, 38, 54],
                [98, 39, 54],
                [99, 40, 55],
                [101, 41, 55],
                [103, 42, 56],
                [105, 43, 56],
                [106, 44, 57],
                [108, 45, 57],
                [110, 46, 58],
                [112, 47, 58],
                [114, 48, 59],
                [115, 49, 59],
                [117, 50, 59],
                [119, 51, 60],
                [121, 52, 60],
                [122, 53, 61],
                [124, 54, 61],
                [126, 55, 61],
                [128, 56, 62],
                [129, 57, 62],
                [131, 58, 62],
                [133, 59, 63],
                [135, 60, 63],
                [136, 61, 63],
                [138, 62, 64],
                [140, 63, 64],
                [142, 64, 64],
                [143, 65, 64],
                [145, 67, 64],
                [147, 68, 65],
                [148, 69, 65],
                [150, 70, 65],
                [152, 71, 65],
                [153, 72, 65],
                [155, 73, 65],
                [157, 75, 66],
                [158, 76, 66],
                [160, 77, 66],
                [161, 78, 66],
                [163, 79, 66],
                [164, 80, 66],
                [166, 82, 66],
                [167, 83, 66],
                [169, 84, 66],
                [170, 85, 66],
                [172, 87, 66],
                [173, 88, 66],
                [175, 89, 66],
                [176, 90, 66],
                [178, 91, 66],
                [179, 93, 66],
                [181, 94, 66],
                [182, 95, 66],
                [183, 96, 65],
                [185, 98, 65],
                [186, 99, 65],
                [187, 100, 65],
                [189, 101, 65],
                [190, 103, 65],
                [191, 104, 65],
                [192, 105, 65],
                [194, 106, 65],
                [195, 108, 64],
                [196, 109, 64],
                [197, 110, 64],
                [198, 112, 64],
                [200, 113, 64],
                [201, 114, 64],
                [202, 115, 64],
                [203, 117, 63],
                [204, 118, 63],
                [205, 119, 63],
                [206, 121, 63],
                [207, 122, 63],
                [208, 123, 63],
                [209, 124, 62],
                [210, 126, 62],
                [211, 127, 62],
                [212, 128, 62],
                [213, 130, 62],
                [214, 131, 62],
                [215, 132, 62],
                [216, 133, 61],
                [216, 135, 61],
                [217, 136, 61],
                [218, 137, 61],
                [219, 139, 61],
                [220, 140, 61],
                [220, 141, 61],
                [221, 142, 61],
                [222, 144, 60],
                [222, 145, 60],
                [223, 146, 60],
                [224, 147, 60],
                [224, 149, 60],
                [225, 150, 60],
                [226, 151, 60],
                [226, 153, 60],
                [227, 154, 60],
                [227, 155, 60],
                [228, 156, 60],
                [228, 158, 60],
                [229, 159, 60],
                [229, 160, 60],
                [229, 161, 60],
                [230, 162, 60],
                [230, 164, 60],
                [231, 165, 60],
                [231, 166, 60],
                [231, 167, 60],
                [232, 169, 60],
                [232, 170, 60],
                [232, 171, 60],
                [232, 172, 60],
                [233, 174, 60],
                [233, 175, 60],
                [233, 176, 60],
                [233, 177, 60],
                [233, 178, 60],
                [234, 180, 60],
                [234, 181, 61],
                [234, 182, 61],
                [234, 183, 61],
                [234, 184, 61],
                [234, 186, 61],
                [234, 187, 61],
                [234, 188, 61],
                [235, 189, 61],
                [235, 190, 62],
                [235, 192, 62],
                [235, 193, 62],
                [235, 194, 62],
                [235, 195, 62],
                [235, 196, 62],
                [235, 198, 62],
                [235, 199, 63],
                [235, 200, 63],
                [235, 201, 63],
                [235, 202, 63],
                [235, 203, 63],
                [235, 205, 63],
                [235, 206, 64],
                [235, 207, 64],
                [234, 208, 64],
                [234, 209, 64],
                [234, 211, 64],
                [234, 212, 64],
                [234, 213, 65],
                [234, 214, 65],
                [234, 215, 65],
                [234, 216, 65],
                [234, 218, 65],
                [234, 219, 66],
                [234, 220, 66],
                [234, 221, 66],
                [233, 222, 66],
                [233, 223, 66],
                [233, 225, 67],
                [233, 226, 67],
            ],
        );

        m.insert(
            "OPF fresh",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 1, 0],
                [0, 2, 1],
                [0, 3, 1],
                [0, 4, 2],
                [0, 5, 2],
                [0, 6, 3],
                [0, 7, 3],
                [0, 8, 4],
                [0, 9, 4],
                [0, 10, 5],
                [0, 11, 5],
                [0, 12, 5],
                [0, 13, 6],
                [0, 14, 6],
                [0, 15, 7],
                [0, 16, 7],
                [0, 17, 8],
                [0, 18, 8],
                [0, 19, 9],
                [0, 20, 9],
                [0, 21, 10],
                [0, 22, 10],
                [0, 23, 10],
                [0, 24, 11],
                [0, 25, 11],
                [0, 26, 12],
                [0, 27, 12],
                [0, 28, 13],
                [0, 29, 13],
                [0, 30, 14],
                [0, 31, 14],
                [0, 32, 15],
                [0, 33, 15],
                [0, 34, 15],
                [0, 35, 16],
                [0, 36, 16],
                [0, 37, 17],
                [0, 38, 17],
                [0, 39, 18],
                [0, 40, 18],
                [0, 41, 19],
                [0, 42, 19],
                [0, 43, 20],
                [0, 44, 20],
                [0, 45, 21],
                [0, 46, 21],
                [0, 47, 21],
                [0, 48, 22],
                [0, 49, 22],
                [0, 50, 23],
                [0, 51, 23],
                [0, 52, 24],
                [0, 53, 24],
                [0, 54, 25],
                [0, 55, 25],
                [0, 56, 26],
                [0, 57, 26],
                [0, 58, 26],
                [0, 59, 27],
                [0, 60, 27],
                [0, 61, 28],
                [0, 62, 28],
                [0, 63, 29],
                [0, 64, 29],
                [0, 65, 30],
                [0, 66, 30],
                [0, 67, 31],
                [0, 68, 31],
                [0, 69, 31],
                [0, 70, 32],
                [0, 71, 32],
                [0, 72, 33],
                [0, 73, 33],
                [0, 74, 34],
                [0, 75, 34],
                [0, 76, 35],
                [0, 77, 35],
                [0, 78, 36],
                [0, 79, 36],
                [0, 80, 37],
                [0, 81, 37],
                [0, 82, 37],
                [0, 83, 38],
                [0, 84, 38],
                [0, 85, 39],
                [0, 86, 39],
                [0, 87, 40],
                [0, 88, 40],
                [0, 89, 41],
                [0, 90, 41],
                [0, 91, 42],
                [0, 92, 42],
                [0, 93, 42],
                [0, 94, 43],
                [0, 95, 43],
                [0, 96, 44],
                [0, 97, 44],
                [0, 98, 45],
                [0, 99, 45],
                [0, 100, 46],
                [0, 101, 46],
                [0, 102, 47],
                [0, 103, 47],
                [0, 104, 47],
                [0, 105, 48],
                [0, 106, 48],
                [0, 107, 49],
                [0, 108, 49],
                [0, 109, 50],
                [0, 110, 50],
                [0, 111, 51],
                [0, 112, 51],
                [0, 113, 52],
                [0, 114, 52],
                [0, 115, 53],
                [0, 116, 53],
                [0, 117, 53],
                [0, 118, 54],
                [0, 119, 54],
                [0, 120, 55],
                [0, 121, 55],
                [0, 122, 56],
                [0, 123, 56],
                [0, 124, 57],
                [0, 125, 57],
                [0, 126, 58],
                [0, 127, 58],
                [0, 128, 58],
                [0, 129, 59],
                [0, 130, 59],
                [0, 131, 60],
                [0, 132, 60],
                [0, 133, 61],
                [0, 134, 61],
                [0, 135, 62],
                [0, 136, 62],
                [0, 137, 63],
                [0, 138, 63],
                [0, 139, 63],
                [0, 140, 64],
                [0, 141, 64],
                [0, 142, 65],
                [0, 143, 65],
                [0, 144, 66],
                [0, 145, 66],
                [0, 146, 67],
                [0, 147, 67],
                [0, 148, 68],
                [0, 149, 68],
                [0, 150, 69],
                [0, 151, 69],
                [0, 152, 69],
                [0, 153, 70],
                [0, 154, 70],
                [0, 155, 71],
                [0, 156, 71],
                [0, 157, 72],
                [0, 158, 72],
                [0, 159, 73],
                [0, 160, 73],
                [0, 161, 74],
                [0, 162, 74],
                [0, 163, 74],
                [0, 164, 75],
                [0, 165, 75],
                [0, 166, 76],
                [0, 167, 76],
                [0, 168, 77],
                [0, 169, 77],
                [0, 170, 78],
                [0, 171, 78],
                [0, 172, 79],
                [0, 173, 79],
                [0, 174, 79],
                [0, 175, 80],
                [0, 176, 80],
                [0, 177, 81],
                [0, 178, 81],
                [0, 179, 82],
                [0, 180, 82],
                [0, 181, 83],
                [0, 182, 83],
                [0, 183, 84],
                [0, 184, 84],
                [0, 185, 85],
                [0, 186, 85],
                [0, 187, 85],
                [0, 188, 86],
                [0, 189, 86],
                [0, 190, 87],
                [0, 191, 87],
                [0, 192, 88],
                [0, 193, 88],
                [0, 194, 89],
                [0, 195, 89],
                [0, 196, 90],
                [0, 197, 90],
                [0, 198, 90],
                [0, 199, 91],
                [0, 200, 91],
                [0, 201, 92],
                [0, 202, 92],
                [0, 203, 93],
                [0, 204, 93],
                [0, 205, 94],
                [0, 206, 94],
                [0, 207, 95],
                [0, 208, 95],
                [0, 209, 95],
                [0, 210, 96],
                [0, 211, 96],
                [0, 212, 97],
                [0, 213, 97],
                [0, 214, 98],
                [0, 215, 98],
                [0, 216, 99],
                [0, 217, 99],
                [0, 218, 100],
                [0, 219, 100],
                [0, 220, 101],
                [0, 221, 101],
                [0, 222, 101],
                [0, 223, 102],
                [0, 224, 102],
                [0, 225, 103],
                [0, 226, 103],
                [0, 227, 104],
                [0, 228, 104],
                [0, 229, 105],
                [0, 230, 105],
                [0, 231, 106],
                [0, 232, 106],
                [0, 233, 106],
                [0, 234, 107],
                [0, 235, 107],
                [0, 236, 108],
                [0, 237, 108],
                [0, 238, 109],
                [0, 239, 109],
                [0, 240, 110],
                [0, 241, 110],
                [0, 242, 111],
                [0, 243, 111],
                [0, 244, 111],
                [0, 245, 112],
                [0, 246, 112],
                [0, 247, 113],
                [0, 248, 113],
                [0, 249, 114],
                [0, 250, 114],
                [0, 251, 115],
                [0, 252, 115],
                [0, 253, 116],
                [0, 255, 117],
            ],
        );

        m.insert(
            "OPF orange",
            [
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [2, 1, 0],
                [3, 1, 0],
                [4, 2, 0],
                [5, 2, 0],
                [6, 3, 0],
                [7, 3, 0],
                [8, 4, 0],
                [9, 4, 0],
                [10, 5, 0],
                [11, 5, 0],
                [12, 5, 0],
                [13, 6, 0],
                [14, 6, 0],
                [15, 7, 0],
                [16, 7, 0],
                [17, 8, 0],
                [18, 8, 0],
                [19, 9, 0],
                [20, 9, 0],
                [21, 10, 0],
                [22, 10, 0],
                [23, 10, 0],
                [24, 11, 0],
                [25, 11, 0],
                [26, 12, 0],
                [27, 12, 0],
                [28, 13, 0],
                [29, 13, 0],
                [30, 14, 0],
                [31, 14, 0],
                [32, 15, 0],
                [33, 15, 0],
                [34, 15, 0],
                [35, 16, 0],
                [36, 16, 0],
                [37, 17, 0],
                [38, 17, 0],
                [39, 18, 0],
                [40, 18, 0],
                [41, 19, 0],
                [42, 19, 0],
                [43, 20, 0],
                [44, 20, 0],
                [45, 21, 0],
                [46, 21, 0],
                [47, 21, 0],
                [48, 22, 0],
                [49, 22, 0],
                [50, 23, 0],
                [51, 23, 0],
                [52, 24, 0],
                [53, 24, 0],
                [54, 25, 0],
                [55, 25, 0],
                [56, 26, 0],
                [57, 26, 0],
                [58, 26, 0],
                [59, 27, 0],
                [60, 27, 0],
                [61, 28, 0],
                [62, 28, 0],
                [63, 29, 0],
                [64, 29, 0],
                [65, 30, 0],
                [66, 30, 0],
                [67, 31, 0],
                [68, 31, 0],
                [69, 31, 0],
                [70, 32, 0],
                [71, 32, 0],
                [72, 33, 0],
                [73, 33, 0],
                [74, 34, 0],
                [75, 34, 0],
                [76, 35, 0],
                [77, 35, 0],
                [78, 36, 0],
                [79, 36, 0],
                [80, 37, 0],
                [81, 37, 0],
                [82, 37, 0],
                [83, 38, 0],
                [84, 38, 0],
                [85, 39, 0],
                [86, 39, 0],
                [87, 40, 0],
                [88, 40, 0],
                [89, 41, 0],
                [90, 41, 0],
                [91, 42, 0],
                [92, 42, 0],
                [93, 42, 0],
                [94, 43, 0],
                [95, 43, 0],
                [96, 44, 0],
                [97, 44, 0],
                [98, 45, 0],
                [99, 45, 0],
                [100, 46, 0],
                [101, 46, 0],
                [102, 47, 0],
                [103, 47, 0],
                [104, 47, 0],
                [105, 48, 0],
                [106, 48, 0],
                [107, 49, 0],
                [108, 49, 0],
                [109, 50, 0],
                [110, 50, 0],
                [111, 51, 0],
                [112, 51, 0],
                [113, 52, 0],
                [114, 52, 0],
                [115, 53, 0],
                [116, 53, 0],
                [117, 53, 0],
                [118, 54, 0],
                [119, 54, 0],
                [120, 55, 0],
                [121, 55, 0],
                [122, 56, 0],
                [123, 56, 0],
                [124, 57, 0],
                [125, 57, 0],
                [126, 58, 0],
                [127, 58, 0],
                [128, 58, 0],
                [129, 59, 0],
                [130, 59, 0],
                [131, 60, 0],
                [132, 60, 0],
                [133, 61, 0],
                [134, 61, 0],
                [135, 62, 0],
                [136, 62, 0],
                [137, 63, 0],
                [138, 63, 0],
                [139, 63, 0],
                [140, 64, 0],
                [141, 64, 0],
                [142, 65, 0],
                [143, 65, 0],
                [144, 66, 0],
                [145, 66, 0],
                [146, 67, 0],
                [147, 67, 0],
                [148, 68, 0],
                [149, 68, 0],
                [150, 69, 0],
                [151, 69, 0],
                [152, 69, 0],
                [153, 70, 0],
                [154, 70, 0],
                [155, 71, 0],
                [156, 71, 0],
                [157, 72, 0],
                [158, 72, 0],
                [159, 73, 0],
                [160, 73, 0],
                [161, 74, 0],
                [162, 74, 0],
                [163, 74, 0],
                [164, 75, 0],
                [165, 75, 0],
                [166, 76, 0],
                [167, 76, 0],
                [168, 77, 0],
                [169, 77, 0],
                [170, 78, 0],
                [171, 78, 0],
                [172, 79, 0],
                [173, 79, 0],
                [174, 79, 0],
                [175, 80, 0],
                [176, 80, 0],
                [177, 81, 0],
                [178, 81, 0],
                [179, 82, 0],
                [180, 82, 0],
                [181, 83, 0],
                [182, 83, 0],
                [183, 84, 0],
                [184, 84, 0],
                [185, 85, 0],
                [186, 85, 0],
                [187, 85, 0],
                [188, 86, 0],
                [189, 86, 0],
                [190, 87, 0],
                [191, 87, 0],
                [192, 88, 0],
                [193, 88, 0],
                [194, 89, 0],
                [195, 89, 0],
                [196, 90, 0],
                [197, 90, 0],
                [198, 90, 0],
                [199, 91, 0],
                [200, 91, 0],
                [201, 92, 0],
                [202, 92, 0],
                [203, 93, 0],
                [204, 93, 0],
                [205, 94, 0],
                [206, 94, 0],
                [207, 95, 0],
                [208, 95, 0],
                [209, 95, 0],
                [210, 96, 0],
                [211, 96, 0],
                [212, 97, 0],
                [213, 97, 0],
                [214, 98, 0],
                [215, 98, 0],
                [216, 99, 0],
                [217, 99, 0],
                [218, 100, 0],
                [219, 100, 0],
                [220, 101, 0],
                [221, 101, 0],
                [222, 101, 0],
                [223, 102, 0],
                [224, 102, 0],
                [225, 103, 0],
                [226, 103, 0],
                [227, 104, 0],
                [228, 104, 0],
                [229, 105, 0],
                [230, 105, 0],
                [231, 106, 0],
                [232, 106, 0],
                [233, 106, 0],
                [234, 107, 0],
                [235, 107, 0],
                [236, 108, 0],
                [237, 108, 0],
                [238, 109, 0],
                [239, 109, 0],
                [240, 110, 0],
                [241, 110, 0],
                [242, 111, 0],
                [243, 111, 0],
                [244, 111, 0],
                [245, 112, 0],
                [246, 112, 0],
                [247, 113, 0],
                [248, 113, 0],
                [249, 114, 0],
                [250, 114, 0],
                [251, 115, 0],
                [252, 115, 0],
                [253, 116, 0],
                [255, 117, 0],
            ],
        );

        m.insert(
            "OPF purple",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 1],
                [1, 0, 2],
                [1, 0, 3],
                [2, 0, 4],
                [2, 0, 5],
                [3, 0, 6],
                [3, 0, 7],
                [4, 0, 8],
                [4, 0, 9],
                [5, 0, 10],
                [5, 0, 11],
                [5, 0, 12],
                [6, 0, 13],
                [6, 0, 14],
                [7, 0, 15],
                [7, 0, 16],
                [8, 0, 17],
                [8, 0, 18],
                [9, 0, 19],
                [9, 0, 20],
                [10, 0, 21],
                [10, 0, 22],
                [10, 0, 23],
                [11, 0, 24],
                [11, 0, 25],
                [12, 0, 26],
                [12, 0, 27],
                [13, 0, 28],
                [13, 0, 29],
                [14, 0, 30],
                [14, 0, 31],
                [15, 0, 32],
                [15, 0, 33],
                [15, 0, 34],
                [16, 0, 35],
                [16, 0, 36],
                [17, 0, 37],
                [17, 0, 38],
                [18, 0, 39],
                [18, 0, 40],
                [19, 0, 41],
                [19, 0, 42],
                [20, 0, 43],
                [20, 0, 44],
                [21, 0, 45],
                [21, 0, 46],
                [21, 0, 47],
                [22, 0, 48],
                [22, 0, 49],
                [23, 0, 50],
                [23, 0, 51],
                [24, 0, 52],
                [24, 0, 53],
                [25, 0, 54],
                [25, 0, 55],
                [26, 0, 56],
                [26, 0, 57],
                [26, 0, 58],
                [27, 0, 59],
                [27, 0, 60],
                [28, 0, 61],
                [28, 0, 62],
                [29, 0, 63],
                [29, 0, 64],
                [30, 0, 65],
                [30, 0, 66],
                [31, 0, 67],
                [31, 0, 68],
                [31, 0, 69],
                [32, 0, 70],
                [32, 0, 71],
                [33, 0, 72],
                [33, 0, 73],
                [34, 0, 74],
                [34, 0, 75],
                [35, 0, 76],
                [35, 0, 77],
                [36, 0, 78],
                [36, 0, 79],
                [37, 0, 80],
                [37, 0, 81],
                [37, 0, 82],
                [38, 0, 83],
                [38, 0, 84],
                [39, 0, 85],
                [39, 0, 86],
                [40, 0, 87],
                [40, 0, 88],
                [41, 0, 89],
                [41, 0, 90],
                [42, 0, 91],
                [42, 0, 92],
                [42, 0, 93],
                [43, 0, 94],
                [43, 0, 95],
                [44, 0, 96],
                [44, 0, 97],
                [45, 0, 98],
                [45, 0, 99],
                [46, 0, 100],
                [46, 0, 101],
                [47, 0, 102],
                [47, 0, 103],
                [47, 0, 104],
                [48, 0, 105],
                [48, 0, 106],
                [49, 0, 107],
                [49, 0, 108],
                [50, 0, 109],
                [50, 0, 110],
                [51, 0, 111],
                [51, 0, 112],
                [52, 0, 113],
                [52, 0, 114],
                [53, 0, 115],
                [53, 0, 116],
                [53, 0, 117],
                [54, 0, 118],
                [54, 0, 119],
                [55, 0, 120],
                [55, 0, 121],
                [56, 0, 122],
                [56, 0, 123],
                [57, 0, 124],
                [57, 0, 125],
                [58, 0, 126],
                [58, 0, 127],
                [58, 0, 128],
                [59, 0, 129],
                [59, 0, 130],
                [60, 0, 131],
                [60, 0, 132],
                [61, 0, 133],
                [61, 0, 134],
                [62, 0, 135],
                [62, 0, 136],
                [63, 0, 137],
                [63, 0, 138],
                [63, 0, 139],
                [64, 0, 140],
                [64, 0, 141],
                [65, 0, 142],
                [65, 0, 143],
                [66, 0, 144],
                [66, 0, 145],
                [67, 0, 146],
                [67, 0, 147],
                [68, 0, 148],
                [68, 0, 149],
                [69, 0, 150],
                [69, 0, 151],
                [69, 0, 152],
                [70, 0, 153],
                [70, 0, 154],
                [71, 0, 155],
                [71, 0, 156],
                [72, 0, 157],
                [72, 0, 158],
                [73, 0, 159],
                [73, 0, 160],
                [74, 0, 161],
                [74, 0, 162],
                [74, 0, 163],
                [75, 0, 164],
                [75, 0, 165],
                [76, 0, 166],
                [76, 0, 167],
                [77, 0, 168],
                [77, 0, 169],
                [78, 0, 170],
                [78, 0, 171],
                [79, 0, 172],
                [79, 0, 173],
                [79, 0, 174],
                [80, 0, 175],
                [80, 0, 176],
                [81, 0, 177],
                [81, 0, 178],
                [82, 0, 179],
                [82, 0, 180],
                [83, 0, 181],
                [83, 0, 182],
                [84, 0, 183],
                [84, 0, 184],
                [85, 0, 185],
                [85, 0, 186],
                [85, 0, 187],
                [86, 0, 188],
                [86, 0, 189],
                [87, 0, 190],
                [87, 0, 191],
                [88, 0, 192],
                [88, 0, 193],
                [89, 0, 194],
                [89, 0, 195],
                [90, 0, 196],
                [90, 0, 197],
                [90, 0, 198],
                [91, 0, 199],
                [91, 0, 200],
                [92, 0, 201],
                [92, 0, 202],
                [93, 0, 203],
                [93, 0, 204],
                [94, 0, 205],
                [94, 0, 206],
                [95, 0, 207],
                [95, 0, 208],
                [95, 0, 209],
                [96, 0, 210],
                [96, 0, 211],
                [97, 0, 212],
                [97, 0, 213],
                [98, 0, 214],
                [98, 0, 215],
                [99, 0, 216],
                [99, 0, 217],
                [100, 0, 218],
                [100, 0, 219],
                [101, 0, 220],
                [101, 0, 221],
                [101, 0, 222],
                [102, 0, 223],
                [102, 0, 224],
                [103, 0, 225],
                [103, 0, 226],
                [104, 0, 227],
                [104, 0, 228],
                [105, 0, 229],
                [105, 0, 230],
                [106, 0, 231],
                [106, 0, 232],
                [106, 0, 233],
                [107, 0, 234],
                [107, 0, 235],
                [108, 0, 236],
                [108, 0, 237],
                [109, 0, 238],
                [109, 0, 239],
                [110, 0, 240],
                [110, 0, 241],
                [111, 0, 242],
                [111, 0, 243],
                [111, 0, 244],
                [112, 0, 245],
                [112, 0, 246],
                [113, 0, 247],
                [113, 0, 248],
                [114, 0, 249],
                [114, 0, 250],
                [115, 0, 251],
                [115, 0, 252],
                [116, 0, 253],
                [117, 0, 255],
            ],
        );

        m.insert(
            "Orange Hot",
            [
                [0, 0, 0],
                [2, 1, 0],
                [5, 3, 0],
                [8, 4, 0],
                [11, 6, 0],
                [14, 7, 0],
                [17, 9, 0],
                [20, 10, 0],
                [23, 12, 0],
                [26, 13, 0],
                [29, 15, 0],
                [32, 16, 0],
                [35, 18, 0],
                [38, 19, 0],
                [41, 21, 0],
                [44, 22, 0],
                [47, 24, 0],
                [50, 25, 0],
                [53, 27, 0],
                [56, 28, 0],
                [59, 30, 0],
                [62, 31, 0],
                [65, 33, 0],
                [68, 34, 0],
                [71, 36, 0],
                [74, 37, 0],
                [77, 39, 0],
                [80, 40, 0],
                [83, 42, 0],
                [86, 43, 0],
                [89, 45, 0],
                [92, 46, 0],
                [95, 48, 0],
                [98, 49, 0],
                [101, 51, 0],
                [104, 52, 0],
                [107, 54, 0],
                [110, 55, 0],
                [113, 57, 0],
                [116, 58, 0],
                [119, 60, 0],
                [122, 61, 0],
                [125, 63, 0],
                [128, 64, 0],
                [131, 66, 0],
                [134, 67, 0],
                [137, 69, 0],
                [140, 70, 0],
                [143, 72, 0],
                [146, 73, 0],
                [149, 75, 0],
                [152, 76, 0],
                [155, 78, 0],
                [158, 79, 0],
                [161, 81, 0],
                [164, 82, 0],
                [167, 84, 0],
                [170, 85, 0],
                [173, 87, 0],
                [176, 88, 0],
                [179, 90, 0],
                [182, 91, 0],
                [185, 93, 0],
                [188, 94, 0],
                [191, 96, 0],
                [194, 97, 0],
                [197, 99, 0],
                [200, 100, 0],
                [203, 102, 0],
                [206, 103, 0],
                [209, 105, 0],
                [212, 106, 0],
                [215, 108, 0],
                [218, 109, 0],
                [221, 111, 0],
                [224, 112, 0],
                [227, 114, 0],
                [230, 115, 0],
                [233, 117, 0],
                [236, 118, 0],
                [239, 120, 0],
                [242, 121, 0],
                [245, 123, 0],
                [248, 124, 0],
                [255, 128, 0],
                [255, 128, 0],
                [255, 129, 0],
                [255, 130, 0],
                [255, 132, 0],
                [255, 133, 0],
                [255, 135, 0],
                [255, 136, 0],
                [255, 138, 0],
                [255, 139, 0],
                [255, 141, 0],
                [255, 142, 0],
                [255, 144, 0],
                [255, 145, 0],
                [255, 147, 0],
                [255, 148, 0],
                [255, 150, 0],
                [255, 151, 0],
                [255, 153, 0],
                [255, 154, 0],
                [255, 156, 0],
                [255, 157, 0],
                [255, 159, 0],
                [255, 160, 0],
                [255, 162, 0],
                [255, 163, 0],
                [255, 165, 0],
                [255, 166, 0],
                [255, 168, 0],
                [255, 169, 0],
                [255, 171, 0],
                [255, 172, 0],
                [255, 174, 0],
                [255, 175, 0],
                [255, 177, 0],
                [255, 178, 0],
                [255, 180, 0],
                [255, 181, 0],
                [255, 183, 0],
                [255, 184, 0],
                [255, 186, 0],
                [255, 187, 0],
                [255, 189, 0],
                [255, 190, 0],
                [255, 191, 0],
                [255, 193, 0],
                [255, 194, 0],
                [255, 196, 0],
                [255, 197, 0],
                [255, 199, 0],
                [255, 200, 0],
                [255, 202, 0],
                [255, 203, 0],
                [255, 205, 0],
                [255, 206, 0],
                [255, 208, 0],
                [255, 209, 0],
                [255, 211, 0],
                [255, 212, 0],
                [255, 214, 0],
                [255, 215, 0],
                [255, 217, 0],
                [255, 218, 0],
                [255, 220, 0],
                [255, 221, 0],
                [255, 223, 0],
                [255, 224, 0],
                [255, 226, 0],
                [255, 227, 0],
                [255, 229, 0],
                [255, 230, 0],
                [255, 232, 0],
                [255, 233, 0],
                [255, 235, 0],
                [255, 236, 0],
                [255, 238, 0],
                [255, 239, 0],
                [255, 241, 0],
                [255, 242, 0],
                [255, 244, 0],
                [255, 245, 0],
                [255, 247, 0],
                [255, 248, 0],
                [255, 250, 0],
                [255, 251, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 2],
                [255, 255, 5],
                [255, 255, 8],
                [255, 255, 11],
                [255, 255, 14],
                [255, 255, 17],
                [255, 255, 20],
                [255, 255, 23],
                [255, 255, 26],
                [255, 255, 29],
                [255, 255, 32],
                [255, 255, 35],
                [255, 255, 38],
                [255, 255, 41],
                [255, 255, 44],
                [255, 255, 47],
                [255, 255, 50],
                [255, 255, 53],
                [255, 255, 56],
                [255, 255, 59],
                [255, 255, 62],
                [255, 255, 65],
                [255, 255, 68],
                [255, 255, 71],
                [255, 255, 74],
                [255, 255, 77],
                [255, 255, 80],
                [255, 255, 83],
                [255, 255, 86],
                [255, 255, 89],
                [255, 255, 92],
                [255, 255, 95],
                [255, 255, 98],
                [255, 255, 101],
                [255, 255, 104],
                [255, 255, 107],
                [255, 255, 110],
                [255, 255, 113],
                [255, 255, 116],
                [255, 255, 119],
                [255, 255, 122],
                [255, 255, 125],
                [255, 255, 128],
                [255, 255, 131],
                [255, 255, 134],
                [255, 255, 137],
                [255, 255, 140],
                [255, 255, 143],
                [255, 255, 146],
                [255, 255, 149],
                [255, 255, 152],
                [255, 255, 155],
                [255, 255, 158],
                [255, 255, 161],
                [255, 255, 164],
                [255, 255, 167],
                [255, 255, 170],
                [255, 255, 173],
                [255, 255, 176],
                [255, 255, 179],
                [255, 255, 182],
                [255, 255, 185],
                [255, 255, 188],
                [255, 255, 191],
                [255, 255, 194],
                [255, 255, 197],
                [255, 255, 200],
                [255, 255, 203],
                [255, 255, 206],
                [255, 255, 209],
                [255, 255, 212],
                [255, 255, 215],
                [255, 255, 218],
                [255, 255, 221],
                [255, 255, 224],
                [255, 255, 227],
                [255, 255, 230],
                [255, 255, 233],
                [255, 255, 236],
                [255, 255, 239],
                [255, 255, 242],
                [255, 255, 245],
                [255, 255, 248],
                [255, 255, 251],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Parabolic RGB",
            [
                [0, 255, 255],
                [2, 255, 251],
                [4, 255, 247],
                [6, 255, 243],
                [8, 255, 239],
                [10, 255, 235],
                [12, 255, 232],
                [14, 255, 228],
                [16, 255, 224],
                [18, 255, 220],
                [20, 255, 217],
                [22, 255, 213],
                [23, 254, 209],
                [25, 254, 206],
                [27, 254, 202],
                [29, 254, 199],
                [31, 254, 195],
                [33, 254, 192],
                [35, 254, 188],
                [37, 254, 185],
                [38, 253, 181],
                [40, 253, 178],
                [42, 253, 175],
                [44, 253, 171],
                [46, 253, 168],
                [48, 253, 165],
                [49, 252, 162],
                [51, 252, 158],
                [53, 252, 155],
                [55, 252, 152],
                [56, 251, 149],
                [58, 251, 146],
                [60, 251, 143],
                [62, 251, 140],
                [63, 250, 137],
                [65, 250, 134],
                [67, 250, 131],
                [69, 250, 128],
                [70, 249, 126],
                [72, 249, 123],
                [74, 249, 120],
                [75, 248, 117],
                [77, 248, 115],
                [79, 248, 112],
                [80, 247, 109],
                [82, 247, 107],
                [84, 247, 104],
                [85, 246, 102],
                [87, 246, 99],
                [89, 246, 97],
                [90, 245, 94],
                [92, 245, 92],
                [93, 244, 89],
                [95, 244, 87],
                [97, 244, 85],
                [98, 243, 82],
                [100, 243, 80],
                [101, 242, 78],
                [103, 242, 76],
                [104, 241, 74],
                [106, 241, 71],
                [107, 240, 69],
                [109, 240, 67],
                [110, 239, 65],
                [112, 239, 63],
                [113, 238, 61],
                [115, 238, 59],
                [116, 237, 57],
                [118, 237, 56],
                [119, 236, 54],
                [121, 236, 52],
                [122, 235, 50],
                [124, 235, 48],
                [125, 234, 47],
                [127, 234, 45],
                [128, 233, 43],
                [129, 232, 42],
                [131, 232, 40],
                [132, 231, 38],
                [134, 231, 37],
                [135, 230, 35],
                [136, 229, 34],
                [138, 229, 32],
                [139, 228, 31],
                [140, 227, 30],
                [142, 227, 28],
                [143, 226, 27],
                [144, 225, 26],
                [146, 225, 24],
                [147, 224, 23],
                [148, 223, 22],
                [150, 223, 21],
                [151, 222, 20],
                [152, 221, 19],
                [153, 220, 18],
                [155, 220, 17],
                [156, 219, 16],
                [157, 218, 15],
                [158, 217, 14],
                [160, 217, 13],
                [161, 216, 12],
                [162, 215, 11],
                [163, 214, 10],
                [164, 213, 9],
                [166, 213, 9],
                [167, 212, 8],
                [168, 211, 7],
                [169, 210, 7],
                [170, 209, 6],
                [171, 208, 5],
                [173, 208, 5],
                [174, 207, 4],
                [175, 206, 4],
                [176, 205, 3],
                [177, 204, 3],
                [178, 203, 2],
                [179, 202, 2],
                [180, 201, 2],
                [181, 200, 1],
                [182, 199, 1],
                [184, 199, 1],
                [185, 198, 1],
                [186, 197, 0],
                [187, 196, 0],
                [188, 195, 0],
                [189, 194, 0],
                [190, 193, 0],
                [191, 192, 0],
                [192, 191, 0],
                [193, 190, 0],
                [194, 189, 0],
                [195, 188, 0],
                [196, 187, 0],
                [197, 186, 0],
                [198, 185, 1],
                [199, 184, 1],
                [199, 182, 1],
                [200, 181, 1],
                [201, 180, 2],
                [202, 179, 2],
                [203, 178, 2],
                [204, 177, 3],
                [205, 176, 3],
                [206, 175, 4],
                [207, 174, 4],
                [208, 173, 5],
                [208, 171, 5],
                [209, 170, 6],
                [210, 169, 7],
                [211, 168, 7],
                [212, 167, 8],
                [213, 166, 9],
                [213, 164, 9],
                [214, 163, 10],
                [215, 162, 11],
                [216, 161, 12],
                [217, 160, 13],
                [217, 158, 14],
                [218, 157, 15],
                [219, 156, 16],
                [220, 155, 17],
                [220, 153, 18],
                [221, 152, 19],
                [222, 151, 20],
                [223, 150, 21],
                [223, 148, 22],
                [224, 147, 23],
                [225, 146, 24],
                [225, 144, 26],
                [226, 143, 27],
                [227, 142, 28],
                [227, 140, 30],
                [228, 139, 31],
                [229, 138, 32],
                [229, 136, 34],
                [230, 135, 35],
                [231, 134, 37],
                [231, 132, 38],
                [232, 131, 40],
                [232, 129, 42],
                [233, 128, 43],
                [234, 127, 45],
                [234, 125, 47],
                [235, 124, 48],
                [235, 122, 50],
                [236, 121, 52],
                [236, 119, 54],
                [237, 118, 56],
                [237, 116, 57],
                [238, 115, 59],
                [238, 113, 61],
                [239, 112, 63],
                [239, 110, 65],
                [240, 109, 67],
                [240, 107, 69],
                [241, 106, 71],
                [241, 104, 74],
                [242, 103, 76],
                [242, 101, 78],
                [243, 100, 80],
                [243, 98, 82],
                [244, 97, 85],
                [244, 95, 87],
                [244, 93, 89],
                [245, 92, 92],
                [245, 90, 94],
                [246, 89, 97],
                [246, 87, 99],
                [246, 85, 102],
                [247, 84, 104],
                [247, 82, 107],
                [247, 80, 109],
                [248, 79, 112],
                [248, 77, 115],
                [248, 75, 117],
                [249, 74, 120],
                [249, 72, 123],
                [249, 70, 126],
                [250, 69, 128],
                [250, 67, 131],
                [250, 65, 134],
                [250, 63, 137],
                [251, 62, 140],
                [251, 60, 143],
                [251, 58, 146],
                [251, 56, 149],
                [252, 55, 152],
                [252, 53, 155],
                [252, 51, 158],
                [252, 49, 162],
                [253, 48, 165],
                [253, 46, 168],
                [253, 44, 171],
                [253, 42, 175],
                [253, 40, 178],
                [253, 38, 181],
                [254, 37, 185],
                [254, 35, 188],
                [254, 33, 192],
                [254, 31, 195],
                [254, 29, 199],
                [254, 27, 202],
                [254, 25, 206],
                [254, 23, 209],
                [255, 22, 213],
                [255, 20, 217],
                [255, 18, 220],
                [255, 16, 224],
                [255, 14, 228],
                [255, 12, 232],
                [255, 10, 235],
                [255, 8, 239],
                [255, 6, 243],
                [255, 4, 247],
                [255, 2, 251],
                [255, 0, 255],
            ],
        );

        m.insert(
            "Phase Bold Green-Magenta",
            [
                [255, 255, 255],
                [253, 255, 223],
                [251, 255, 210],
                [249, 255, 200],
                [247, 255, 192],
                [245, 255, 184],
                [243, 255, 178],
                [241, 255, 172],
                [239, 254, 166],
                [237, 254, 161],
                [235, 254, 156],
                [233, 254, 151],
                [231, 254, 147],
                [229, 254, 143],
                [227, 253, 139],
                [225, 253, 135],
                [223, 253, 131],
                [221, 253, 128],
                [219, 252, 124],
                [217, 252, 121],
                [215, 252, 118],
                [213, 252, 115],
                [211, 251, 112],
                [209, 251, 109],
                [207, 250, 106],
                [205, 250, 103],
                [203, 250, 101],
                [201, 249, 98],
                [199, 249, 96],
                [197, 248, 93],
                [195, 248, 91],
                [193, 247, 88],
                [191, 247, 86],
                [189, 246, 84],
                [187, 246, 82],
                [185, 245, 80],
                [183, 245, 77],
                [181, 244, 75],
                [179, 243, 73],
                [177, 243, 71],
                [175, 242, 70],
                [173, 241, 68],
                [171, 241, 66],
                [169, 240, 64],
                [167, 239, 62],
                [165, 239, 61],
                [163, 238, 59],
                [161, 237, 57],
                [159, 236, 56],
                [157, 235, 54],
                [155, 235, 53],
                [153, 234, 51],
                [151, 233, 50],
                [149, 232, 48],
                [147, 231, 47],
                [145, 230, 45],
                [143, 229, 44],
                [141, 228, 43],
                [139, 227, 41],
                [137, 226, 40],
                [135, 225, 39],
                [133, 224, 37],
                [131, 223, 36],
                [129, 222, 35],
                [127, 221, 34],
                [125, 219, 33],
                [123, 218, 32],
                [121, 217, 31],
                [119, 216, 29],
                [117, 214, 28],
                [115, 213, 27],
                [113, 212, 26],
                [111, 210, 25],
                [109, 209, 24],
                [107, 208, 24],
                [105, 206, 23],
                [103, 205, 22],
                [101, 203, 21],
                [99, 202, 20],
                [97, 200, 19],
                [95, 199, 18],
                [93, 197, 18],
                [91, 195, 17],
                [89, 194, 16],
                [87, 192, 15],
                [85, 190, 15],
                [83, 188, 14],
                [81, 186, 13],
                [79, 185, 13],
                [77, 183, 12],
                [75, 181, 11],
                [73, 179, 11],
                [71, 177, 10],
                [69, 174, 10],
                [67, 172, 9],
                [65, 170, 8],
                [63, 168, 8],
                [61, 165, 7],
                [59, 163, 7],
                [57, 161, 6],
                [55, 158, 6],
                [53, 156, 6],
                [51, 153, 5],
                [49, 150, 5],
                [47, 148, 4],
                [45, 145, 4],
                [43, 142, 4],
                [41, 139, 3],
                [39, 136, 3],
                [37, 132, 3],
                [35, 129, 2],
                [33, 125, 2],
                [31, 122, 2],
                [29, 118, 2],
                [27, 114, 1],
                [25, 110, 1],
                [23, 106, 1],
                [21, 101, 1],
                [19, 97, 1],
                [17, 92, 1],
                [15, 86, 0],
                [13, 80, 0],
                [11, 74, 0],
                [9, 67, 0],
                [7, 59, 0],
                [5, 50, 0],
                [3, 39, 0],
                [1, 23, 0],
                [1, 0, 23],
                [3, 0, 39],
                [5, 0, 50],
                [7, 0, 59],
                [9, 0, 67],
                [11, 0, 74],
                [13, 0, 80],
                [15, 0, 86],
                [17, 1, 92],
                [19, 1, 97],
                [21, 1, 101],
                [23, 1, 106],
                [25, 1, 110],
                [27, 1, 114],
                [29, 2, 118],
                [31, 2, 122],
                [33, 2, 125],
                [35, 2, 129],
                [37, 3, 132],
                [39, 3, 136],
                [41, 3, 139],
                [43, 4, 142],
                [45, 4, 145],
                [47, 4, 148],
                [49, 5, 150],
                [51, 5, 153],
                [53, 6, 156],
                [55, 6, 158],
                [57, 6, 161],
                [59, 7, 163],
                [61, 7, 165],
                [63, 8, 168],
                [65, 8, 170],
                [67, 9, 172],
                [69, 10, 174],
                [71, 10, 177],
                [73, 11, 179],
                [75, 11, 181],
                [77, 12, 183],
                [79, 13, 185],
                [81, 13, 186],
                [83, 14, 188],
                [85, 15, 190],
                [87, 15, 192],
                [89, 16, 194],
                [91, 17, 195],
                [93, 18, 197],
                [95, 18, 199],
                [97, 19, 200],
                [99, 20, 202],
                [101, 21, 203],
                [103, 22, 205],
                [105, 23, 206],
                [107, 24, 208],
                [109, 24, 209],
                [111, 25, 210],
                [113, 26, 212],
                [115, 27, 213],
                [117, 28, 214],
                [119, 29, 216],
                [121, 31, 217],
                [123, 32, 218],
                [125, 33, 219],
                [127, 34, 221],
                [129, 35, 222],
                [131, 36, 223],
                [133, 37, 224],
                [135, 39, 225],
                [137, 40, 226],
                [139, 41, 227],
                [141, 43, 228],
                [143, 44, 229],
                [145, 45, 230],
                [147, 47, 231],
                [149, 48, 232],
                [151, 50, 233],
                [153, 51, 234],
                [155, 53, 235],
                [157, 54, 235],
                [159, 56, 236],
                [161, 57, 237],
                [163, 59, 238],
                [165, 61, 239],
                [167, 62, 239],
                [169, 64, 240],
                [171, 66, 241],
                [173, 68, 241],
                [175, 70, 242],
                [177, 71, 243],
                [179, 73, 243],
                [181, 75, 244],
                [183, 77, 245],
                [185, 80, 245],
                [187, 82, 246],
                [189, 84, 246],
                [191, 86, 247],
                [193, 88, 247],
                [195, 91, 248],
                [197, 93, 248],
                [199, 96, 249],
                [201, 98, 249],
                [203, 101, 250],
                [205, 103, 250],
                [207, 106, 250],
                [209, 109, 251],
                [211, 112, 251],
                [213, 115, 252],
                [215, 118, 252],
                [217, 121, 252],
                [219, 124, 252],
                [221, 128, 253],
                [223, 131, 253],
                [225, 135, 253],
                [227, 139, 253],
                [229, 143, 254],
                [231, 147, 254],
                [233, 151, 254],
                [235, 156, 254],
                [237, 161, 254],
                [239, 166, 254],
                [241, 172, 255],
                [243, 178, 255],
                [245, 184, 255],
                [247, 192, 255],
                [249, 200, 255],
                [251, 210, 255],
                [253, 223, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Phase Bold Ink Green-Magenta",
            [
                [1, 23, 0],
                [3, 39, 0],
                [5, 50, 0],
                [7, 59, 0],
                [9, 67, 0],
                [11, 74, 0],
                [13, 80, 0],
                [15, 86, 0],
                [17, 92, 1],
                [19, 97, 1],
                [21, 101, 1],
                [23, 106, 1],
                [25, 110, 1],
                [27, 114, 1],
                [29, 118, 2],
                [31, 122, 2],
                [33, 125, 2],
                [35, 129, 2],
                [37, 132, 3],
                [39, 136, 3],
                [41, 139, 3],
                [43, 142, 4],
                [45, 145, 4],
                [47, 148, 4],
                [49, 150, 5],
                [51, 153, 5],
                [53, 156, 6],
                [55, 158, 6],
                [57, 161, 6],
                [59, 163, 7],
                [61, 165, 7],
                [63, 168, 8],
                [65, 170, 8],
                [67, 172, 9],
                [69, 174, 10],
                [71, 177, 10],
                [73, 179, 11],
                [75, 181, 11],
                [77, 183, 12],
                [79, 185, 13],
                [81, 186, 13],
                [83, 188, 14],
                [85, 190, 15],
                [87, 192, 15],
                [89, 194, 16],
                [91, 195, 17],
                [93, 197, 18],
                [95, 199, 18],
                [97, 200, 19],
                [99, 202, 20],
                [101, 203, 21],
                [103, 205, 22],
                [105, 206, 23],
                [107, 208, 24],
                [109, 209, 24],
                [111, 210, 25],
                [113, 212, 26],
                [115, 213, 27],
                [117, 214, 28],
                [119, 216, 29],
                [121, 217, 31],
                [123, 218, 32],
                [125, 219, 33],
                [127, 221, 34],
                [129, 222, 35],
                [131, 223, 36],
                [133, 224, 37],
                [135, 225, 39],
                [137, 226, 40],
                [139, 227, 41],
                [141, 228, 43],
                [143, 229, 44],
                [145, 230, 45],
                [147, 231, 47],
                [149, 232, 48],
                [151, 233, 50],
                [153, 234, 51],
                [155, 235, 53],
                [157, 235, 54],
                [159, 236, 56],
                [161, 237, 57],
                [163, 238, 59],
                [165, 239, 61],
                [167, 239, 62],
                [169, 240, 64],
                [171, 241, 66],
                [173, 241, 68],
                [175, 242, 70],
                [177, 243, 71],
                [179, 243, 73],
                [181, 244, 75],
                [183, 245, 77],
                [185, 245, 80],
                [187, 246, 82],
                [189, 246, 84],
                [191, 247, 86],
                [193, 247, 88],
                [195, 248, 91],
                [197, 248, 93],
                [199, 249, 96],
                [201, 249, 98],
                [203, 250, 101],
                [205, 250, 103],
                [207, 250, 106],
                [209, 251, 109],
                [211, 251, 112],
                [213, 252, 115],
                [215, 252, 118],
                [217, 252, 121],
                [219, 252, 124],
                [221, 253, 128],
                [223, 253, 131],
                [225, 253, 135],
                [227, 253, 139],
                [229, 254, 143],
                [231, 254, 147],
                [233, 254, 151],
                [235, 254, 156],
                [237, 254, 161],
                [239, 254, 166],
                [241, 255, 172],
                [243, 255, 178],
                [245, 255, 184],
                [247, 255, 192],
                [249, 255, 200],
                [251, 255, 210],
                [253, 255, 223],
                [255, 255, 255],
                [255, 255, 255],
                [253, 223, 255],
                [251, 210, 255],
                [249, 200, 255],
                [247, 192, 255],
                [245, 184, 255],
                [243, 178, 255],
                [241, 172, 255],
                [239, 166, 254],
                [237, 161, 254],
                [235, 156, 254],
                [233, 151, 254],
                [231, 147, 254],
                [229, 143, 254],
                [227, 139, 253],
                [225, 135, 253],
                [223, 131, 253],
                [221, 128, 253],
                [219, 124, 252],
                [217, 121, 252],
                [215, 118, 252],
                [213, 115, 252],
                [211, 112, 251],
                [209, 109, 251],
                [207, 106, 250],
                [205, 103, 250],
                [203, 101, 250],
                [201, 98, 249],
                [199, 96, 249],
                [197, 93, 248],
                [195, 91, 248],
                [193, 88, 247],
                [191, 86, 247],
                [189, 84, 246],
                [187, 82, 246],
                [185, 80, 245],
                [183, 77, 245],
                [181, 75, 244],
                [179, 73, 243],
                [177, 71, 243],
                [175, 70, 242],
                [173, 68, 241],
                [171, 66, 241],
                [169, 64, 240],
                [167, 62, 239],
                [165, 61, 239],
                [163, 59, 238],
                [161, 57, 237],
                [159, 56, 236],
                [157, 54, 235],
                [155, 53, 235],
                [153, 51, 234],
                [151, 50, 233],
                [149, 48, 232],
                [147, 47, 231],
                [145, 45, 230],
                [143, 44, 229],
                [141, 43, 228],
                [139, 41, 227],
                [137, 40, 226],
                [135, 39, 225],
                [133, 37, 224],
                [131, 36, 223],
                [129, 35, 222],
                [127, 34, 221],
                [125, 33, 219],
                [123, 32, 218],
                [121, 31, 217],
                [119, 29, 216],
                [117, 28, 214],
                [115, 27, 213],
                [113, 26, 212],
                [111, 25, 210],
                [109, 24, 209],
                [107, 24, 208],
                [105, 23, 206],
                [103, 22, 205],
                [101, 21, 203],
                [99, 20, 202],
                [97, 19, 200],
                [95, 18, 199],
                [93, 18, 197],
                [91, 17, 195],
                [89, 16, 194],
                [87, 15, 192],
                [85, 15, 190],
                [83, 14, 188],
                [81, 13, 186],
                [79, 13, 185],
                [77, 12, 183],
                [75, 11, 181],
                [73, 11, 179],
                [71, 10, 177],
                [69, 10, 174],
                [67, 9, 172],
                [65, 8, 170],
                [63, 8, 168],
                [61, 7, 165],
                [59, 7, 163],
                [57, 6, 161],
                [55, 6, 158],
                [53, 6, 156],
                [51, 5, 153],
                [49, 5, 150],
                [47, 4, 148],
                [45, 4, 145],
                [43, 4, 142],
                [41, 3, 139],
                [39, 3, 136],
                [37, 3, 132],
                [35, 2, 129],
                [33, 2, 125],
                [31, 2, 122],
                [29, 2, 118],
                [27, 1, 114],
                [25, 1, 110],
                [23, 1, 106],
                [21, 1, 101],
                [19, 1, 97],
                [17, 1, 92],
                [15, 0, 86],
                [13, 0, 80],
                [11, 0, 74],
                [9, 0, 67],
                [7, 0, 59],
                [5, 0, 50],
                [3, 0, 39],
                [1, 0, 23],
            ],
        );

        m.insert(
            "Phase Bold Ink Mint-Cherry",
            [
                [0, 23, 1],
                [0, 39, 3],
                [0, 50, 5],
                [0, 59, 7],
                [0, 67, 9],
                [0, 74, 11],
                [0, 80, 13],
                [0, 86, 15],
                [1, 92, 17],
                [1, 97, 19],
                [1, 101, 21],
                [1, 106, 23],
                [1, 110, 25],
                [1, 114, 27],
                [2, 118, 29],
                [2, 122, 31],
                [2, 125, 33],
                [2, 129, 35],
                [3, 132, 37],
                [3, 136, 39],
                [3, 139, 41],
                [4, 142, 43],
                [4, 145, 45],
                [4, 148, 47],
                [5, 150, 49],
                [5, 153, 51],
                [6, 156, 53],
                [6, 158, 55],
                [6, 161, 57],
                [7, 163, 59],
                [7, 165, 61],
                [8, 168, 63],
                [8, 170, 65],
                [9, 172, 67],
                [10, 174, 69],
                [10, 177, 71],
                [11, 179, 73],
                [11, 181, 75],
                [12, 183, 77],
                [13, 185, 79],
                [13, 186, 81],
                [14, 188, 83],
                [15, 190, 85],
                [15, 192, 87],
                [16, 194, 89],
                [17, 195, 91],
                [18, 197, 93],
                [18, 199, 95],
                [19, 200, 97],
                [20, 202, 99],
                [21, 203, 101],
                [22, 205, 103],
                [23, 206, 105],
                [24, 208, 107],
                [24, 209, 109],
                [25, 210, 111],
                [26, 212, 113],
                [27, 213, 115],
                [28, 214, 117],
                [29, 216, 119],
                [31, 217, 121],
                [32, 218, 123],
                [33, 219, 125],
                [34, 221, 127],
                [35, 222, 129],
                [36, 223, 131],
                [37, 224, 133],
                [39, 225, 135],
                [40, 226, 137],
                [41, 227, 139],
                [43, 228, 141],
                [44, 229, 143],
                [45, 230, 145],
                [47, 231, 147],
                [48, 232, 149],
                [50, 233, 151],
                [51, 234, 153],
                [53, 235, 155],
                [54, 235, 157],
                [56, 236, 159],
                [57, 237, 161],
                [59, 238, 163],
                [61, 239, 165],
                [62, 239, 167],
                [64, 240, 169],
                [66, 241, 171],
                [68, 241, 173],
                [70, 242, 175],
                [71, 243, 177],
                [73, 243, 179],
                [75, 244, 181],
                [77, 245, 183],
                [80, 245, 185],
                [82, 246, 187],
                [84, 246, 189],
                [86, 247, 191],
                [88, 247, 193],
                [91, 248, 195],
                [93, 248, 197],
                [96, 249, 199],
                [98, 249, 201],
                [101, 250, 203],
                [103, 250, 205],
                [106, 250, 207],
                [109, 251, 209],
                [112, 251, 211],
                [115, 252, 213],
                [118, 252, 215],
                [121, 252, 217],
                [124, 252, 219],
                [128, 253, 221],
                [131, 253, 223],
                [135, 253, 225],
                [139, 253, 227],
                [143, 254, 229],
                [147, 254, 231],
                [151, 254, 233],
                [156, 254, 235],
                [161, 254, 237],
                [166, 254, 239],
                [172, 255, 241],
                [178, 255, 243],
                [184, 255, 245],
                [192, 255, 247],
                [200, 255, 249],
                [210, 255, 251],
                [223, 255, 253],
                [255, 255, 255],
                [255, 255, 255],
                [255, 223, 253],
                [255, 210, 251],
                [255, 200, 249],
                [255, 192, 247],
                [255, 184, 245],
                [255, 178, 243],
                [255, 172, 241],
                [254, 166, 239],
                [254, 161, 237],
                [254, 156, 235],
                [254, 151, 233],
                [254, 147, 231],
                [254, 143, 229],
                [253, 139, 227],
                [253, 135, 225],
                [253, 131, 223],
                [253, 128, 221],
                [252, 124, 219],
                [252, 121, 217],
                [252, 118, 215],
                [252, 115, 213],
                [251, 112, 211],
                [251, 109, 209],
                [250, 106, 207],
                [250, 103, 205],
                [250, 101, 203],
                [249, 98, 201],
                [249, 96, 199],
                [248, 93, 197],
                [248, 91, 195],
                [247, 88, 193],
                [247, 86, 191],
                [246, 84, 189],
                [246, 82, 187],
                [245, 80, 185],
                [245, 77, 183],
                [244, 75, 181],
                [243, 73, 179],
                [243, 71, 177],
                [242, 70, 175],
                [241, 68, 173],
                [241, 66, 171],
                [240, 64, 169],
                [239, 62, 167],
                [239, 61, 165],
                [238, 59, 163],
                [237, 57, 161],
                [236, 56, 159],
                [235, 54, 157],
                [235, 53, 155],
                [234, 51, 153],
                [233, 50, 151],
                [232, 48, 149],
                [231, 47, 147],
                [230, 45, 145],
                [229, 44, 143],
                [228, 43, 141],
                [227, 41, 139],
                [226, 40, 137],
                [225, 39, 135],
                [224, 37, 133],
                [223, 36, 131],
                [222, 35, 129],
                [221, 34, 127],
                [219, 33, 125],
                [218, 32, 123],
                [217, 31, 121],
                [216, 29, 119],
                [214, 28, 117],
                [213, 27, 115],
                [212, 26, 113],
                [210, 25, 111],
                [209, 24, 109],
                [208, 24, 107],
                [206, 23, 105],
                [205, 22, 103],
                [203, 21, 101],
                [202, 20, 99],
                [200, 19, 97],
                [199, 18, 95],
                [197, 18, 93],
                [195, 17, 91],
                [194, 16, 89],
                [192, 15, 87],
                [190, 15, 85],
                [188, 14, 83],
                [186, 13, 81],
                [185, 13, 79],
                [183, 12, 77],
                [181, 11, 75],
                [179, 11, 73],
                [177, 10, 71],
                [174, 10, 69],
                [172, 9, 67],
                [170, 8, 65],
                [168, 8, 63],
                [165, 7, 61],
                [163, 7, 59],
                [161, 6, 57],
                [158, 6, 55],
                [156, 6, 53],
                [153, 5, 51],
                [150, 5, 49],
                [148, 4, 47],
                [145, 4, 45],
                [142, 4, 43],
                [139, 3, 41],
                [136, 3, 39],
                [132, 3, 37],
                [129, 2, 35],
                [125, 2, 33],
                [122, 2, 31],
                [118, 2, 29],
                [114, 1, 27],
                [110, 1, 25],
                [106, 1, 23],
                [101, 1, 21],
                [97, 1, 19],
                [92, 1, 17],
                [86, 0, 15],
                [80, 0, 13],
                [74, 0, 11],
                [67, 0, 9],
                [59, 0, 7],
                [50, 0, 5],
                [39, 0, 3],
                [23, 0, 1],
            ],
        );

        m.insert(
            "Phase Bold Ink Yellow-Cyan",
            [
                [23, 1, 0],
                [39, 3, 0],
                [50, 5, 0],
                [59, 7, 0],
                [67, 9, 0],
                [74, 11, 0],
                [80, 13, 0],
                [86, 15, 0],
                [92, 17, 1],
                [97, 19, 1],
                [101, 21, 1],
                [106, 23, 1],
                [110, 25, 1],
                [114, 27, 1],
                [118, 29, 2],
                [122, 31, 2],
                [125, 33, 2],
                [129, 35, 2],
                [132, 37, 3],
                [136, 39, 3],
                [139, 41, 3],
                [142, 43, 4],
                [145, 45, 4],
                [148, 47, 4],
                [150, 49, 5],
                [153, 51, 5],
                [156, 53, 6],
                [158, 55, 6],
                [161, 57, 6],
                [163, 59, 7],
                [165, 61, 7],
                [168, 63, 8],
                [170, 65, 8],
                [172, 67, 9],
                [174, 69, 10],
                [177, 71, 10],
                [179, 73, 11],
                [181, 75, 11],
                [183, 77, 12],
                [185, 79, 13],
                [186, 81, 13],
                [188, 83, 14],
                [190, 85, 15],
                [192, 87, 15],
                [194, 89, 16],
                [195, 91, 17],
                [197, 93, 18],
                [199, 95, 18],
                [200, 97, 19],
                [202, 99, 20],
                [203, 101, 21],
                [205, 103, 22],
                [206, 105, 23],
                [208, 107, 24],
                [209, 109, 24],
                [210, 111, 25],
                [212, 113, 26],
                [213, 115, 27],
                [214, 117, 28],
                [216, 119, 29],
                [217, 121, 31],
                [218, 123, 32],
                [219, 125, 33],
                [221, 127, 34],
                [222, 129, 35],
                [223, 131, 36],
                [224, 133, 37],
                [225, 135, 39],
                [226, 137, 40],
                [227, 139, 41],
                [228, 141, 43],
                [229, 143, 44],
                [230, 145, 45],
                [231, 147, 47],
                [232, 149, 48],
                [233, 151, 50],
                [234, 153, 51],
                [235, 155, 53],
                [235, 157, 54],
                [236, 159, 56],
                [237, 161, 57],
                [238, 163, 59],
                [239, 165, 61],
                [239, 167, 62],
                [240, 169, 64],
                [241, 171, 66],
                [241, 173, 68],
                [242, 175, 70],
                [243, 177, 71],
                [243, 179, 73],
                [244, 181, 75],
                [245, 183, 77],
                [245, 185, 80],
                [246, 187, 82],
                [246, 189, 84],
                [247, 191, 86],
                [247, 193, 88],
                [248, 195, 91],
                [248, 197, 93],
                [249, 199, 96],
                [249, 201, 98],
                [250, 203, 101],
                [250, 205, 103],
                [250, 207, 106],
                [251, 209, 109],
                [251, 211, 112],
                [252, 213, 115],
                [252, 215, 118],
                [252, 217, 121],
                [252, 219, 124],
                [253, 221, 128],
                [253, 223, 131],
                [253, 225, 135],
                [253, 227, 139],
                [254, 229, 143],
                [254, 231, 147],
                [254, 233, 151],
                [254, 235, 156],
                [254, 237, 161],
                [254, 239, 166],
                [255, 241, 172],
                [255, 243, 178],
                [255, 245, 184],
                [255, 247, 192],
                [255, 249, 200],
                [255, 251, 210],
                [255, 253, 223],
                [255, 255, 255],
                [255, 255, 255],
                [223, 253, 255],
                [210, 251, 255],
                [200, 249, 255],
                [192, 247, 255],
                [184, 245, 255],
                [178, 243, 255],
                [172, 241, 255],
                [166, 239, 254],
                [161, 237, 254],
                [156, 235, 254],
                [151, 233, 254],
                [147, 231, 254],
                [143, 229, 254],
                [139, 227, 253],
                [135, 225, 253],
                [131, 223, 253],
                [128, 221, 253],
                [124, 219, 252],
                [121, 217, 252],
                [118, 215, 252],
                [115, 213, 252],
                [112, 211, 251],
                [109, 209, 251],
                [106, 207, 250],
                [103, 205, 250],
                [101, 203, 250],
                [98, 201, 249],
                [96, 199, 249],
                [93, 197, 248],
                [91, 195, 248],
                [88, 193, 247],
                [86, 191, 247],
                [84, 189, 246],
                [82, 187, 246],
                [80, 185, 245],
                [77, 183, 245],
                [75, 181, 244],
                [73, 179, 243],
                [71, 177, 243],
                [70, 175, 242],
                [68, 173, 241],
                [66, 171, 241],
                [64, 169, 240],
                [62, 167, 239],
                [61, 165, 239],
                [59, 163, 238],
                [57, 161, 237],
                [56, 159, 236],
                [54, 157, 235],
                [53, 155, 235],
                [51, 153, 234],
                [50, 151, 233],
                [48, 149, 232],
                [47, 147, 231],
                [45, 145, 230],
                [44, 143, 229],
                [43, 141, 228],
                [41, 139, 227],
                [40, 137, 226],
                [39, 135, 225],
                [37, 133, 224],
                [36, 131, 223],
                [35, 129, 222],
                [34, 127, 221],
                [33, 125, 219],
                [32, 123, 218],
                [31, 121, 217],
                [29, 119, 216],
                [28, 117, 214],
                [27, 115, 213],
                [26, 113, 212],
                [25, 111, 210],
                [24, 109, 209],
                [24, 107, 208],
                [23, 105, 206],
                [22, 103, 205],
                [21, 101, 203],
                [20, 99, 202],
                [19, 97, 200],
                [18, 95, 199],
                [18, 93, 197],
                [17, 91, 195],
                [16, 89, 194],
                [15, 87, 192],
                [15, 85, 190],
                [14, 83, 188],
                [13, 81, 186],
                [13, 79, 185],
                [12, 77, 183],
                [11, 75, 181],
                [11, 73, 179],
                [10, 71, 177],
                [10, 69, 174],
                [9, 67, 172],
                [8, 65, 170],
                [8, 63, 168],
                [7, 61, 165],
                [7, 59, 163],
                [6, 57, 161],
                [6, 55, 158],
                [6, 53, 156],
                [5, 51, 153],
                [5, 49, 150],
                [4, 47, 148],
                [4, 45, 145],
                [4, 43, 142],
                [3, 41, 139],
                [3, 39, 136],
                [3, 37, 132],
                [2, 35, 129],
                [2, 33, 125],
                [2, 31, 122],
                [2, 29, 118],
                [1, 27, 114],
                [1, 25, 110],
                [1, 23, 106],
                [1, 21, 101],
                [1, 19, 97],
                [1, 17, 92],
                [0, 15, 86],
                [0, 13, 80],
                [0, 11, 74],
                [0, 9, 67],
                [0, 7, 59],
                [0, 5, 50],
                [0, 3, 39],
                [0, 1, 23],
            ],
        );

        m.insert(
            "Phase Bold Mint-Cherry",
            [
                [255, 255, 255],
                [223, 255, 253],
                [210, 255, 251],
                [200, 255, 249],
                [192, 255, 247],
                [184, 255, 245],
                [178, 255, 243],
                [172, 255, 241],
                [166, 254, 239],
                [161, 254, 237],
                [156, 254, 235],
                [151, 254, 233],
                [147, 254, 231],
                [143, 254, 229],
                [139, 253, 227],
                [135, 253, 225],
                [131, 253, 223],
                [128, 253, 221],
                [124, 252, 219],
                [121, 252, 217],
                [118, 252, 215],
                [115, 252, 213],
                [112, 251, 211],
                [109, 251, 209],
                [106, 250, 207],
                [103, 250, 205],
                [101, 250, 203],
                [98, 249, 201],
                [96, 249, 199],
                [93, 248, 197],
                [91, 248, 195],
                [88, 247, 193],
                [86, 247, 191],
                [84, 246, 189],
                [82, 246, 187],
                [80, 245, 185],
                [77, 245, 183],
                [75, 244, 181],
                [73, 243, 179],
                [71, 243, 177],
                [70, 242, 175],
                [68, 241, 173],
                [66, 241, 171],
                [64, 240, 169],
                [62, 239, 167],
                [61, 239, 165],
                [59, 238, 163],
                [57, 237, 161],
                [56, 236, 159],
                [54, 235, 157],
                [53, 235, 155],
                [51, 234, 153],
                [50, 233, 151],
                [48, 232, 149],
                [47, 231, 147],
                [45, 230, 145],
                [44, 229, 143],
                [43, 228, 141],
                [41, 227, 139],
                [40, 226, 137],
                [39, 225, 135],
                [37, 224, 133],
                [36, 223, 131],
                [35, 222, 129],
                [34, 221, 127],
                [33, 219, 125],
                [32, 218, 123],
                [31, 217, 121],
                [29, 216, 119],
                [28, 214, 117],
                [27, 213, 115],
                [26, 212, 113],
                [25, 210, 111],
                [24, 209, 109],
                [24, 208, 107],
                [23, 206, 105],
                [22, 205, 103],
                [21, 203, 101],
                [20, 202, 99],
                [19, 200, 97],
                [18, 199, 95],
                [18, 197, 93],
                [17, 195, 91],
                [16, 194, 89],
                [15, 192, 87],
                [15, 190, 85],
                [14, 188, 83],
                [13, 186, 81],
                [13, 185, 79],
                [12, 183, 77],
                [11, 181, 75],
                [11, 179, 73],
                [10, 177, 71],
                [10, 174, 69],
                [9, 172, 67],
                [8, 170, 65],
                [8, 168, 63],
                [7, 165, 61],
                [7, 163, 59],
                [6, 161, 57],
                [6, 158, 55],
                [6, 156, 53],
                [5, 153, 51],
                [5, 150, 49],
                [4, 148, 47],
                [4, 145, 45],
                [4, 142, 43],
                [3, 139, 41],
                [3, 136, 39],
                [3, 132, 37],
                [2, 129, 35],
                [2, 125, 33],
                [2, 122, 31],
                [2, 118, 29],
                [1, 114, 27],
                [1, 110, 25],
                [1, 106, 23],
                [1, 101, 21],
                [1, 97, 19],
                [1, 92, 17],
                [0, 86, 15],
                [0, 80, 13],
                [0, 74, 11],
                [0, 67, 9],
                [0, 59, 7],
                [0, 50, 5],
                [0, 39, 3],
                [0, 23, 1],
                [23, 0, 1],
                [39, 0, 3],
                [50, 0, 5],
                [59, 0, 7],
                [67, 0, 9],
                [74, 0, 11],
                [80, 0, 13],
                [86, 0, 15],
                [92, 1, 17],
                [97, 1, 19],
                [101, 1, 21],
                [106, 1, 23],
                [110, 1, 25],
                [114, 1, 27],
                [118, 2, 29],
                [122, 2, 31],
                [125, 2, 33],
                [129, 2, 35],
                [132, 3, 37],
                [136, 3, 39],
                [139, 3, 41],
                [142, 4, 43],
                [145, 4, 45],
                [148, 4, 47],
                [150, 5, 49],
                [153, 5, 51],
                [156, 6, 53],
                [158, 6, 55],
                [161, 6, 57],
                [163, 7, 59],
                [165, 7, 61],
                [168, 8, 63],
                [170, 8, 65],
                [172, 9, 67],
                [174, 10, 69],
                [177, 10, 71],
                [179, 11, 73],
                [181, 11, 75],
                [183, 12, 77],
                [185, 13, 79],
                [186, 13, 81],
                [188, 14, 83],
                [190, 15, 85],
                [192, 15, 87],
                [194, 16, 89],
                [195, 17, 91],
                [197, 18, 93],
                [199, 18, 95],
                [200, 19, 97],
                [202, 20, 99],
                [203, 21, 101],
                [205, 22, 103],
                [206, 23, 105],
                [208, 24, 107],
                [209, 24, 109],
                [210, 25, 111],
                [212, 26, 113],
                [213, 27, 115],
                [214, 28, 117],
                [216, 29, 119],
                [217, 31, 121],
                [218, 32, 123],
                [219, 33, 125],
                [221, 34, 127],
                [222, 35, 129],
                [223, 36, 131],
                [224, 37, 133],
                [225, 39, 135],
                [226, 40, 137],
                [227, 41, 139],
                [228, 43, 141],
                [229, 44, 143],
                [230, 45, 145],
                [231, 47, 147],
                [232, 48, 149],
                [233, 50, 151],
                [234, 51, 153],
                [235, 53, 155],
                [235, 54, 157],
                [236, 56, 159],
                [237, 57, 161],
                [238, 59, 163],
                [239, 61, 165],
                [239, 62, 167],
                [240, 64, 169],
                [241, 66, 171],
                [241, 68, 173],
                [242, 70, 175],
                [243, 71, 177],
                [243, 73, 179],
                [244, 75, 181],
                [245, 77, 183],
                [245, 80, 185],
                [246, 82, 187],
                [246, 84, 189],
                [247, 86, 191],
                [247, 88, 193],
                [248, 91, 195],
                [248, 93, 197],
                [249, 96, 199],
                [249, 98, 201],
                [250, 101, 203],
                [250, 103, 205],
                [250, 106, 207],
                [251, 109, 209],
                [251, 112, 211],
                [252, 115, 213],
                [252, 118, 215],
                [252, 121, 217],
                [252, 124, 219],
                [253, 128, 221],
                [253, 131, 223],
                [253, 135, 225],
                [253, 139, 227],
                [254, 143, 229],
                [254, 147, 231],
                [254, 151, 233],
                [254, 156, 235],
                [254, 161, 237],
                [254, 166, 239],
                [255, 172, 241],
                [255, 178, 243],
                [255, 184, 245],
                [255, 192, 247],
                [255, 200, 249],
                [255, 210, 251],
                [255, 223, 253],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Phase Bold Yellow-Cyan",
            [
                [255, 255, 255],
                [255, 253, 223],
                [255, 251, 210],
                [255, 249, 200],
                [255, 247, 192],
                [255, 245, 184],
                [255, 243, 178],
                [255, 241, 172],
                [254, 239, 166],
                [254, 237, 161],
                [254, 235, 156],
                [254, 233, 151],
                [254, 231, 147],
                [254, 229, 143],
                [253, 227, 139],
                [253, 225, 135],
                [253, 223, 131],
                [253, 221, 128],
                [252, 219, 124],
                [252, 217, 121],
                [252, 215, 118],
                [252, 213, 115],
                [251, 211, 112],
                [251, 209, 109],
                [250, 207, 106],
                [250, 205, 103],
                [250, 203, 101],
                [249, 201, 98],
                [249, 199, 96],
                [248, 197, 93],
                [248, 195, 91],
                [247, 193, 88],
                [247, 191, 86],
                [246, 189, 84],
                [246, 187, 82],
                [245, 185, 80],
                [245, 183, 77],
                [244, 181, 75],
                [243, 179, 73],
                [243, 177, 71],
                [242, 175, 70],
                [241, 173, 68],
                [241, 171, 66],
                [240, 169, 64],
                [239, 167, 62],
                [239, 165, 61],
                [238, 163, 59],
                [237, 161, 57],
                [236, 159, 56],
                [235, 157, 54],
                [235, 155, 53],
                [234, 153, 51],
                [233, 151, 50],
                [232, 149, 48],
                [231, 147, 47],
                [230, 145, 45],
                [229, 143, 44],
                [228, 141, 43],
                [227, 139, 41],
                [226, 137, 40],
                [225, 135, 39],
                [224, 133, 37],
                [223, 131, 36],
                [222, 129, 35],
                [221, 127, 34],
                [219, 125, 33],
                [218, 123, 32],
                [217, 121, 31],
                [216, 119, 29],
                [214, 117, 28],
                [213, 115, 27],
                [212, 113, 26],
                [210, 111, 25],
                [209, 109, 24],
                [208, 107, 24],
                [206, 105, 23],
                [205, 103, 22],
                [203, 101, 21],
                [202, 99, 20],
                [200, 97, 19],
                [199, 95, 18],
                [197, 93, 18],
                [195, 91, 17],
                [194, 89, 16],
                [192, 87, 15],
                [190, 85, 15],
                [188, 83, 14],
                [186, 81, 13],
                [185, 79, 13],
                [183, 77, 12],
                [181, 75, 11],
                [179, 73, 11],
                [177, 71, 10],
                [174, 69, 10],
                [172, 67, 9],
                [170, 65, 8],
                [168, 63, 8],
                [165, 61, 7],
                [163, 59, 7],
                [161, 57, 6],
                [158, 55, 6],
                [156, 53, 6],
                [153, 51, 5],
                [150, 49, 5],
                [148, 47, 4],
                [145, 45, 4],
                [142, 43, 4],
                [139, 41, 3],
                [136, 39, 3],
                [132, 37, 3],
                [129, 35, 2],
                [125, 33, 2],
                [122, 31, 2],
                [118, 29, 2],
                [114, 27, 1],
                [110, 25, 1],
                [106, 23, 1],
                [101, 21, 1],
                [97, 19, 1],
                [92, 17, 1],
                [86, 15, 0],
                [80, 13, 0],
                [74, 11, 0],
                [67, 9, 0],
                [59, 7, 0],
                [50, 5, 0],
                [39, 3, 0],
                [23, 1, 0],
                [0, 1, 23],
                [0, 3, 39],
                [0, 5, 50],
                [0, 7, 59],
                [0, 9, 67],
                [0, 11, 74],
                [0, 13, 80],
                [0, 15, 86],
                [1, 17, 92],
                [1, 19, 97],
                [1, 21, 101],
                [1, 23, 106],
                [1, 25, 110],
                [1, 27, 114],
                [2, 29, 118],
                [2, 31, 122],
                [2, 33, 125],
                [2, 35, 129],
                [3, 37, 132],
                [3, 39, 136],
                [3, 41, 139],
                [4, 43, 142],
                [4, 45, 145],
                [4, 47, 148],
                [5, 49, 150],
                [5, 51, 153],
                [6, 53, 156],
                [6, 55, 158],
                [6, 57, 161],
                [7, 59, 163],
                [7, 61, 165],
                [8, 63, 168],
                [8, 65, 170],
                [9, 67, 172],
                [10, 69, 174],
                [10, 71, 177],
                [11, 73, 179],
                [11, 75, 181],
                [12, 77, 183],
                [13, 79, 185],
                [13, 81, 186],
                [14, 83, 188],
                [15, 85, 190],
                [15, 87, 192],
                [16, 89, 194],
                [17, 91, 195],
                [18, 93, 197],
                [18, 95, 199],
                [19, 97, 200],
                [20, 99, 202],
                [21, 101, 203],
                [22, 103, 205],
                [23, 105, 206],
                [24, 107, 208],
                [24, 109, 209],
                [25, 111, 210],
                [26, 113, 212],
                [27, 115, 213],
                [28, 117, 214],
                [29, 119, 216],
                [31, 121, 217],
                [32, 123, 218],
                [33, 125, 219],
                [34, 127, 221],
                [35, 129, 222],
                [36, 131, 223],
                [37, 133, 224],
                [39, 135, 225],
                [40, 137, 226],
                [41, 139, 227],
                [43, 141, 228],
                [44, 143, 229],
                [45, 145, 230],
                [47, 147, 231],
                [48, 149, 232],
                [50, 151, 233],
                [51, 153, 234],
                [53, 155, 235],
                [54, 157, 235],
                [56, 159, 236],
                [57, 161, 237],
                [59, 163, 238],
                [61, 165, 239],
                [62, 167, 239],
                [64, 169, 240],
                [66, 171, 241],
                [68, 173, 241],
                [70, 175, 242],
                [71, 177, 243],
                [73, 179, 243],
                [75, 181, 244],
                [77, 183, 245],
                [80, 185, 245],
                [82, 187, 246],
                [84, 189, 246],
                [86, 191, 247],
                [88, 193, 247],
                [91, 195, 248],
                [93, 197, 248],
                [96, 199, 249],
                [98, 201, 249],
                [101, 203, 250],
                [103, 205, 250],
                [106, 207, 250],
                [109, 209, 251],
                [112, 211, 251],
                [115, 213, 252],
                [118, 215, 252],
                [121, 217, 252],
                [124, 219, 252],
                [128, 221, 253],
                [131, 223, 253],
                [135, 225, 253],
                [139, 227, 253],
                [143, 229, 254],
                [147, 231, 254],
                [151, 233, 254],
                [156, 235, 254],
                [161, 237, 254],
                [166, 239, 254],
                [172, 241, 255],
                [178, 243, 255],
                [184, 245, 255],
                [192, 247, 255],
                [200, 249, 255],
                [210, 251, 255],
                [223, 253, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Phase Green-Magenta",
            [
                [255, 255, 255],
                [253, 254, 251],
                [251, 253, 247],
                [249, 252, 243],
                [247, 251, 239],
                [245, 250, 235],
                [243, 249, 232],
                [241, 248, 228],
                [239, 247, 224],
                [237, 246, 220],
                [235, 245, 217],
                [233, 244, 213],
                [231, 243, 209],
                [229, 242, 206],
                [227, 241, 202],
                [225, 240, 199],
                [223, 238, 195],
                [221, 237, 192],
                [219, 236, 188],
                [217, 235, 185],
                [215, 234, 181],
                [213, 233, 178],
                [211, 232, 175],
                [209, 231, 171],
                [207, 230, 168],
                [205, 229, 165],
                [203, 228, 162],
                [201, 226, 158],
                [199, 225, 155],
                [197, 224, 152],
                [195, 223, 149],
                [193, 222, 146],
                [191, 221, 143],
                [189, 220, 140],
                [187, 218, 137],
                [185, 217, 134],
                [183, 216, 131],
                [181, 215, 128],
                [179, 214, 126],
                [177, 212, 123],
                [175, 211, 120],
                [173, 210, 117],
                [171, 209, 115],
                [169, 208, 112],
                [167, 206, 109],
                [165, 205, 107],
                [163, 204, 104],
                [161, 203, 102],
                [159, 201, 99],
                [157, 200, 97],
                [155, 199, 94],
                [153, 198, 92],
                [151, 196, 89],
                [149, 195, 87],
                [147, 194, 85],
                [145, 192, 82],
                [143, 191, 80],
                [141, 190, 78],
                [139, 188, 76],
                [137, 187, 74],
                [135, 186, 71],
                [133, 184, 69],
                [131, 183, 67],
                [129, 181, 65],
                [127, 180, 63],
                [125, 179, 61],
                [123, 177, 59],
                [121, 176, 57],
                [119, 174, 56],
                [117, 173, 54],
                [115, 171, 52],
                [113, 170, 50],
                [111, 168, 48],
                [109, 167, 47],
                [107, 165, 45],
                [105, 164, 43],
                [103, 162, 42],
                [101, 160, 40],
                [99, 159, 38],
                [97, 157, 37],
                [95, 156, 35],
                [93, 154, 34],
                [91, 152, 32],
                [89, 151, 31],
                [87, 149, 30],
                [85, 147, 28],
                [83, 145, 27],
                [81, 144, 26],
                [79, 142, 24],
                [77, 140, 23],
                [75, 138, 22],
                [73, 136, 21],
                [71, 135, 20],
                [69, 133, 19],
                [67, 131, 18],
                [65, 129, 17],
                [63, 127, 16],
                [61, 125, 15],
                [59, 123, 14],
                [57, 121, 13],
                [55, 118, 12],
                [53, 116, 11],
                [51, 114, 10],
                [49, 112, 9],
                [47, 109, 9],
                [45, 107, 8],
                [43, 105, 7],
                [41, 102, 7],
                [39, 100, 6],
                [37, 97, 5],
                [35, 94, 5],
                [33, 92, 4],
                [31, 89, 4],
                [29, 86, 3],
                [27, 83, 3],
                [25, 80, 2],
                [23, 77, 2],
                [21, 73, 2],
                [19, 70, 1],
                [17, 66, 1],
                [15, 62, 1],
                [13, 58, 1],
                [11, 53, 0],
                [9, 48, 0],
                [7, 42, 0],
                [5, 36, 0],
                [3, 28, 0],
                [1, 16, 0],
                [1, 0, 16],
                [3, 0, 28],
                [5, 0, 36],
                [7, 0, 42],
                [9, 0, 48],
                [11, 0, 53],
                [13, 1, 58],
                [15, 1, 62],
                [17, 1, 66],
                [19, 1, 70],
                [21, 2, 73],
                [23, 2, 77],
                [25, 2, 80],
                [27, 3, 83],
                [29, 3, 86],
                [31, 4, 89],
                [33, 4, 92],
                [35, 5, 94],
                [37, 5, 97],
                [39, 6, 100],
                [41, 7, 102],
                [43, 7, 105],
                [45, 8, 107],
                [47, 9, 109],
                [49, 9, 112],
                [51, 10, 114],
                [53, 11, 116],
                [55, 12, 118],
                [57, 13, 121],
                [59, 14, 123],
                [61, 15, 125],
                [63, 16, 127],
                [65, 17, 129],
                [67, 18, 131],
                [69, 19, 133],
                [71, 20, 135],
                [73, 21, 136],
                [75, 22, 138],
                [77, 23, 140],
                [79, 24, 142],
                [81, 26, 144],
                [83, 27, 145],
                [85, 28, 147],
                [87, 30, 149],
                [89, 31, 151],
                [91, 32, 152],
                [93, 34, 154],
                [95, 35, 156],
                [97, 37, 157],
                [99, 38, 159],
                [101, 40, 160],
                [103, 42, 162],
                [105, 43, 164],
                [107, 45, 165],
                [109, 47, 167],
                [111, 48, 168],
                [113, 50, 170],
                [115, 52, 171],
                [117, 54, 173],
                [119, 56, 174],
                [121, 57, 176],
                [123, 59, 177],
                [125, 61, 179],
                [127, 63, 180],
                [129, 65, 181],
                [131, 67, 183],
                [133, 69, 184],
                [135, 71, 186],
                [137, 74, 187],
                [139, 76, 188],
                [141, 78, 190],
                [143, 80, 191],
                [145, 82, 192],
                [147, 85, 194],
                [149, 87, 195],
                [151, 89, 196],
                [153, 92, 198],
                [155, 94, 199],
                [157, 97, 200],
                [159, 99, 201],
                [161, 102, 203],
                [163, 104, 204],
                [165, 107, 205],
                [167, 109, 206],
                [169, 112, 208],
                [171, 115, 209],
                [173, 117, 210],
                [175, 120, 211],
                [177, 123, 212],
                [179, 126, 214],
                [181, 128, 215],
                [183, 131, 216],
                [185, 134, 217],
                [187, 137, 218],
                [189, 140, 220],
                [191, 143, 221],
                [193, 146, 222],
                [195, 149, 223],
                [197, 152, 224],
                [199, 155, 225],
                [201, 158, 226],
                [203, 162, 228],
                [205, 165, 229],
                [207, 168, 230],
                [209, 171, 231],
                [211, 175, 232],
                [213, 178, 233],
                [215, 181, 234],
                [217, 185, 235],
                [219, 188, 236],
                [221, 192, 237],
                [223, 195, 238],
                [225, 199, 240],
                [227, 202, 241],
                [229, 206, 242],
                [231, 209, 243],
                [233, 213, 244],
                [235, 217, 245],
                [237, 220, 246],
                [239, 224, 247],
                [241, 228, 248],
                [243, 232, 249],
                [245, 235, 250],
                [247, 239, 251],
                [249, 243, 252],
                [251, 247, 253],
                [253, 251, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Phase Ink Green-Magenta",
            [
                [1, 16, 0],
                [3, 28, 0],
                [5, 36, 0],
                [7, 42, 0],
                [9, 48, 0],
                [11, 53, 0],
                [13, 58, 1],
                [15, 62, 1],
                [17, 66, 1],
                [19, 70, 1],
                [21, 73, 2],
                [23, 77, 2],
                [25, 80, 2],
                [27, 83, 3],
                [29, 86, 3],
                [31, 89, 4],
                [33, 92, 4],
                [35, 94, 5],
                [37, 97, 5],
                [39, 100, 6],
                [41, 102, 7],
                [43, 105, 7],
                [45, 107, 8],
                [47, 109, 9],
                [49, 112, 9],
                [51, 114, 10],
                [53, 116, 11],
                [55, 118, 12],
                [57, 121, 13],
                [59, 123, 14],
                [61, 125, 15],
                [63, 127, 16],
                [65, 129, 17],
                [67, 131, 18],
                [69, 133, 19],
                [71, 135, 20],
                [73, 136, 21],
                [75, 138, 22],
                [77, 140, 23],
                [79, 142, 24],
                [81, 144, 26],
                [83, 145, 27],
                [85, 147, 28],
                [87, 149, 30],
                [89, 151, 31],
                [91, 152, 32],
                [93, 154, 34],
                [95, 156, 35],
                [97, 157, 37],
                [99, 159, 38],
                [101, 160, 40],
                [103, 162, 42],
                [105, 164, 43],
                [107, 165, 45],
                [109, 167, 47],
                [111, 168, 48],
                [113, 170, 50],
                [115, 171, 52],
                [117, 173, 54],
                [119, 174, 56],
                [121, 176, 57],
                [123, 177, 59],
                [125, 179, 61],
                [127, 180, 63],
                [129, 181, 65],
                [131, 183, 67],
                [133, 184, 69],
                [135, 186, 71],
                [137, 187, 74],
                [139, 188, 76],
                [141, 190, 78],
                [143, 191, 80],
                [145, 192, 82],
                [147, 194, 85],
                [149, 195, 87],
                [151, 196, 89],
                [153, 198, 92],
                [155, 199, 94],
                [157, 200, 97],
                [159, 201, 99],
                [161, 203, 102],
                [163, 204, 104],
                [165, 205, 107],
                [167, 206, 109],
                [169, 208, 112],
                [171, 209, 115],
                [173, 210, 117],
                [175, 211, 120],
                [177, 212, 123],
                [179, 214, 126],
                [181, 215, 128],
                [183, 216, 131],
                [185, 217, 134],
                [187, 218, 137],
                [189, 220, 140],
                [191, 221, 143],
                [193, 222, 146],
                [195, 223, 149],
                [197, 224, 152],
                [199, 225, 155],
                [201, 226, 158],
                [203, 228, 162],
                [205, 229, 165],
                [207, 230, 168],
                [209, 231, 171],
                [211, 232, 175],
                [213, 233, 178],
                [215, 234, 181],
                [217, 235, 185],
                [219, 236, 188],
                [221, 237, 192],
                [223, 238, 195],
                [225, 240, 199],
                [227, 241, 202],
                [229, 242, 206],
                [231, 243, 209],
                [233, 244, 213],
                [235, 245, 217],
                [237, 246, 220],
                [239, 247, 224],
                [241, 248, 228],
                [243, 249, 232],
                [245, 250, 235],
                [247, 251, 239],
                [249, 252, 243],
                [251, 253, 247],
                [253, 254, 251],
                [255, 255, 255],
                [255, 255, 255],
                [253, 251, 254],
                [251, 247, 253],
                [249, 243, 252],
                [247, 239, 251],
                [245, 235, 250],
                [243, 232, 249],
                [241, 228, 248],
                [239, 224, 247],
                [237, 220, 246],
                [235, 217, 245],
                [233, 213, 244],
                [231, 209, 243],
                [229, 206, 242],
                [227, 202, 241],
                [225, 199, 240],
                [223, 195, 238],
                [221, 192, 237],
                [219, 188, 236],
                [217, 185, 235],
                [215, 181, 234],
                [213, 178, 233],
                [211, 175, 232],
                [209, 171, 231],
                [207, 168, 230],
                [205, 165, 229],
                [203, 162, 228],
                [201, 158, 226],
                [199, 155, 225],
                [197, 152, 224],
                [195, 149, 223],
                [193, 146, 222],
                [191, 143, 221],
                [189, 140, 220],
                [187, 137, 218],
                [185, 134, 217],
                [183, 131, 216],
                [181, 128, 215],
                [179, 126, 214],
                [177, 123, 212],
                [175, 120, 211],
                [173, 117, 210],
                [171, 115, 209],
                [169, 112, 208],
                [167, 109, 206],
                [165, 107, 205],
                [163, 104, 204],
                [161, 102, 203],
                [159, 99, 201],
                [157, 97, 200],
                [155, 94, 199],
                [153, 92, 198],
                [151, 89, 196],
                [149, 87, 195],
                [147, 85, 194],
                [145, 82, 192],
                [143, 80, 191],
                [141, 78, 190],
                [139, 76, 188],
                [137, 74, 187],
                [135, 71, 186],
                [133, 69, 184],
                [131, 67, 183],
                [129, 65, 181],
                [127, 63, 180],
                [125, 61, 179],
                [123, 59, 177],
                [121, 57, 176],
                [119, 56, 174],
                [117, 54, 173],
                [115, 52, 171],
                [113, 50, 170],
                [111, 48, 168],
                [109, 47, 167],
                [107, 45, 165],
                [105, 43, 164],
                [103, 42, 162],
                [101, 40, 160],
                [99, 38, 159],
                [97, 37, 157],
                [95, 35, 156],
                [93, 34, 154],
                [91, 32, 152],
                [89, 31, 151],
                [87, 30, 149],
                [85, 28, 147],
                [83, 27, 145],
                [81, 26, 144],
                [79, 24, 142],
                [77, 23, 140],
                [75, 22, 138],
                [73, 21, 136],
                [71, 20, 135],
                [69, 19, 133],
                [67, 18, 131],
                [65, 17, 129],
                [63, 16, 127],
                [61, 15, 125],
                [59, 14, 123],
                [57, 13, 121],
                [55, 12, 118],
                [53, 11, 116],
                [51, 10, 114],
                [49, 9, 112],
                [47, 9, 109],
                [45, 8, 107],
                [43, 7, 105],
                [41, 7, 102],
                [39, 6, 100],
                [37, 5, 97],
                [35, 5, 94],
                [33, 4, 92],
                [31, 4, 89],
                [29, 3, 86],
                [27, 3, 83],
                [25, 2, 80],
                [23, 2, 77],
                [21, 2, 73],
                [19, 1, 70],
                [17, 1, 66],
                [15, 1, 62],
                [13, 1, 58],
                [11, 0, 53],
                [9, 0, 48],
                [7, 0, 42],
                [5, 0, 36],
                [3, 0, 28],
                [1, 0, 16],
            ],
        );

        m.insert(
            "Phase Ink Mint-Cherry",
            [
                [0, 16, 1],
                [0, 28, 3],
                [0, 36, 5],
                [0, 42, 7],
                [0, 48, 9],
                [0, 53, 11],
                [1, 58, 13],
                [1, 62, 15],
                [1, 66, 17],
                [1, 70, 19],
                [2, 73, 21],
                [2, 77, 23],
                [2, 80, 25],
                [3, 83, 27],
                [3, 86, 29],
                [4, 89, 31],
                [4, 92, 33],
                [5, 94, 35],
                [5, 97, 37],
                [6, 100, 39],
                [7, 102, 41],
                [7, 105, 43],
                [8, 107, 45],
                [9, 109, 47],
                [9, 112, 49],
                [10, 114, 51],
                [11, 116, 53],
                [12, 118, 55],
                [13, 121, 57],
                [14, 123, 59],
                [15, 125, 61],
                [16, 127, 63],
                [17, 129, 65],
                [18, 131, 67],
                [19, 133, 69],
                [20, 135, 71],
                [21, 136, 73],
                [22, 138, 75],
                [23, 140, 77],
                [24, 142, 79],
                [26, 144, 81],
                [27, 145, 83],
                [28, 147, 85],
                [30, 149, 87],
                [31, 151, 89],
                [32, 152, 91],
                [34, 154, 93],
                [35, 156, 95],
                [37, 157, 97],
                [38, 159, 99],
                [40, 160, 101],
                [42, 162, 103],
                [43, 164, 105],
                [45, 165, 107],
                [47, 167, 109],
                [48, 168, 111],
                [50, 170, 113],
                [52, 171, 115],
                [54, 173, 117],
                [56, 174, 119],
                [57, 176, 121],
                [59, 177, 123],
                [61, 179, 125],
                [63, 180, 127],
                [65, 181, 129],
                [67, 183, 131],
                [69, 184, 133],
                [71, 186, 135],
                [74, 187, 137],
                [76, 188, 139],
                [78, 190, 141],
                [80, 191, 143],
                [82, 192, 145],
                [85, 194, 147],
                [87, 195, 149],
                [89, 196, 151],
                [92, 198, 153],
                [94, 199, 155],
                [97, 200, 157],
                [99, 201, 159],
                [102, 203, 161],
                [104, 204, 163],
                [107, 205, 165],
                [109, 206, 167],
                [112, 208, 169],
                [115, 209, 171],
                [117, 210, 173],
                [120, 211, 175],
                [123, 212, 177],
                [126, 214, 179],
                [128, 215, 181],
                [131, 216, 183],
                [134, 217, 185],
                [137, 218, 187],
                [140, 220, 189],
                [143, 221, 191],
                [146, 222, 193],
                [149, 223, 195],
                [152, 224, 197],
                [155, 225, 199],
                [158, 226, 201],
                [162, 228, 203],
                [165, 229, 205],
                [168, 230, 207],
                [171, 231, 209],
                [175, 232, 211],
                [178, 233, 213],
                [181, 234, 215],
                [185, 235, 217],
                [188, 236, 219],
                [192, 237, 221],
                [195, 238, 223],
                [199, 240, 225],
                [202, 241, 227],
                [206, 242, 229],
                [209, 243, 231],
                [213, 244, 233],
                [217, 245, 235],
                [220, 246, 237],
                [224, 247, 239],
                [228, 248, 241],
                [232, 249, 243],
                [235, 250, 245],
                [239, 251, 247],
                [243, 252, 249],
                [247, 253, 251],
                [251, 254, 253],
                [255, 255, 255],
                [255, 255, 255],
                [254, 251, 253],
                [253, 247, 251],
                [252, 243, 249],
                [251, 239, 247],
                [250, 235, 245],
                [249, 232, 243],
                [248, 228, 241],
                [247, 224, 239],
                [246, 220, 237],
                [245, 217, 235],
                [244, 213, 233],
                [243, 209, 231],
                [242, 206, 229],
                [241, 202, 227],
                [240, 199, 225],
                [238, 195, 223],
                [237, 192, 221],
                [236, 188, 219],
                [235, 185, 217],
                [234, 181, 215],
                [233, 178, 213],
                [232, 175, 211],
                [231, 171, 209],
                [230, 168, 207],
                [229, 165, 205],
                [228, 162, 203],
                [226, 158, 201],
                [225, 155, 199],
                [224, 152, 197],
                [223, 149, 195],
                [222, 146, 193],
                [221, 143, 191],
                [220, 140, 189],
                [218, 137, 187],
                [217, 134, 185],
                [216, 131, 183],
                [215, 128, 181],
                [214, 126, 179],
                [212, 123, 177],
                [211, 120, 175],
                [210, 117, 173],
                [209, 115, 171],
                [208, 112, 169],
                [206, 109, 167],
                [205, 107, 165],
                [204, 104, 163],
                [203, 102, 161],
                [201, 99, 159],
                [200, 97, 157],
                [199, 94, 155],
                [198, 92, 153],
                [196, 89, 151],
                [195, 87, 149],
                [194, 85, 147],
                [192, 82, 145],
                [191, 80, 143],
                [190, 78, 141],
                [188, 76, 139],
                [187, 74, 137],
                [186, 71, 135],
                [184, 69, 133],
                [183, 67, 131],
                [181, 65, 129],
                [180, 63, 127],
                [179, 61, 125],
                [177, 59, 123],
                [176, 57, 121],
                [174, 56, 119],
                [173, 54, 117],
                [171, 52, 115],
                [170, 50, 113],
                [168, 48, 111],
                [167, 47, 109],
                [165, 45, 107],
                [164, 43, 105],
                [162, 42, 103],
                [160, 40, 101],
                [159, 38, 99],
                [157, 37, 97],
                [156, 35, 95],
                [154, 34, 93],
                [152, 32, 91],
                [151, 31, 89],
                [149, 30, 87],
                [147, 28, 85],
                [145, 27, 83],
                [144, 26, 81],
                [142, 24, 79],
                [140, 23, 77],
                [138, 22, 75],
                [136, 21, 73],
                [135, 20, 71],
                [133, 19, 69],
                [131, 18, 67],
                [129, 17, 65],
                [127, 16, 63],
                [125, 15, 61],
                [123, 14, 59],
                [121, 13, 57],
                [118, 12, 55],
                [116, 11, 53],
                [114, 10, 51],
                [112, 9, 49],
                [109, 9, 47],
                [107, 8, 45],
                [105, 7, 43],
                [102, 7, 41],
                [100, 6, 39],
                [97, 5, 37],
                [94, 5, 35],
                [92, 4, 33],
                [89, 4, 31],
                [86, 3, 29],
                [83, 3, 27],
                [80, 2, 25],
                [77, 2, 23],
                [73, 2, 21],
                [70, 1, 19],
                [66, 1, 17],
                [62, 1, 15],
                [58, 1, 13],
                [53, 0, 11],
                [48, 0, 9],
                [42, 0, 7],
                [36, 0, 5],
                [28, 0, 3],
                [16, 0, 1],
            ],
        );

        m.insert(
            "Phase Ink Yellow-Cyan",
            [
                [16, 1, 0],
                [28, 3, 0],
                [36, 5, 0],
                [42, 7, 0],
                [48, 9, 0],
                [53, 11, 0],
                [58, 13, 1],
                [62, 15, 1],
                [66, 17, 1],
                [70, 19, 1],
                [73, 21, 2],
                [77, 23, 2],
                [80, 25, 2],
                [83, 27, 3],
                [86, 29, 3],
                [89, 31, 4],
                [92, 33, 4],
                [94, 35, 5],
                [97, 37, 5],
                [100, 39, 6],
                [102, 41, 7],
                [105, 43, 7],
                [107, 45, 8],
                [109, 47, 9],
                [112, 49, 9],
                [114, 51, 10],
                [116, 53, 11],
                [118, 55, 12],
                [121, 57, 13],
                [123, 59, 14],
                [125, 61, 15],
                [127, 63, 16],
                [129, 65, 17],
                [131, 67, 18],
                [133, 69, 19],
                [135, 71, 20],
                [136, 73, 21],
                [138, 75, 22],
                [140, 77, 23],
                [142, 79, 24],
                [144, 81, 26],
                [145, 83, 27],
                [147, 85, 28],
                [149, 87, 30],
                [151, 89, 31],
                [152, 91, 32],
                [154, 93, 34],
                [156, 95, 35],
                [157, 97, 37],
                [159, 99, 38],
                [160, 101, 40],
                [162, 103, 42],
                [164, 105, 43],
                [165, 107, 45],
                [167, 109, 47],
                [168, 111, 48],
                [170, 113, 50],
                [171, 115, 52],
                [173, 117, 54],
                [174, 119, 56],
                [176, 121, 57],
                [177, 123, 59],
                [179, 125, 61],
                [180, 127, 63],
                [181, 129, 65],
                [183, 131, 67],
                [184, 133, 69],
                [186, 135, 71],
                [187, 137, 74],
                [188, 139, 76],
                [190, 141, 78],
                [191, 143, 80],
                [192, 145, 82],
                [194, 147, 85],
                [195, 149, 87],
                [196, 151, 89],
                [198, 153, 92],
                [199, 155, 94],
                [200, 157, 97],
                [201, 159, 99],
                [203, 161, 102],
                [204, 163, 104],
                [205, 165, 107],
                [206, 167, 109],
                [208, 169, 112],
                [209, 171, 115],
                [210, 173, 117],
                [211, 175, 120],
                [212, 177, 123],
                [214, 179, 126],
                [215, 181, 128],
                [216, 183, 131],
                [217, 185, 134],
                [218, 187, 137],
                [220, 189, 140],
                [221, 191, 143],
                [222, 193, 146],
                [223, 195, 149],
                [224, 197, 152],
                [225, 199, 155],
                [226, 201, 158],
                [228, 203, 162],
                [229, 205, 165],
                [230, 207, 168],
                [231, 209, 171],
                [232, 211, 175],
                [233, 213, 178],
                [234, 215, 181],
                [235, 217, 185],
                [236, 219, 188],
                [237, 221, 192],
                [238, 223, 195],
                [240, 225, 199],
                [241, 227, 202],
                [242, 229, 206],
                [243, 231, 209],
                [244, 233, 213],
                [245, 235, 217],
                [246, 237, 220],
                [247, 239, 224],
                [248, 241, 228],
                [249, 243, 232],
                [250, 245, 235],
                [251, 247, 239],
                [252, 249, 243],
                [253, 251, 247],
                [254, 253, 251],
                [255, 255, 255],
                [255, 255, 255],
                [251, 253, 254],
                [247, 251, 253],
                [243, 249, 252],
                [239, 247, 251],
                [235, 245, 250],
                [232, 243, 249],
                [228, 241, 248],
                [224, 239, 247],
                [220, 237, 246],
                [217, 235, 245],
                [213, 233, 244],
                [209, 231, 243],
                [206, 229, 242],
                [202, 227, 241],
                [199, 225, 240],
                [195, 223, 238],
                [192, 221, 237],
                [188, 219, 236],
                [185, 217, 235],
                [181, 215, 234],
                [178, 213, 233],
                [175, 211, 232],
                [171, 209, 231],
                [168, 207, 230],
                [165, 205, 229],
                [162, 203, 228],
                [158, 201, 226],
                [155, 199, 225],
                [152, 197, 224],
                [149, 195, 223],
                [146, 193, 222],
                [143, 191, 221],
                [140, 189, 220],
                [137, 187, 218],
                [134, 185, 217],
                [131, 183, 216],
                [128, 181, 215],
                [126, 179, 214],
                [123, 177, 212],
                [120, 175, 211],
                [117, 173, 210],
                [115, 171, 209],
                [112, 169, 208],
                [109, 167, 206],
                [107, 165, 205],
                [104, 163, 204],
                [102, 161, 203],
                [99, 159, 201],
                [97, 157, 200],
                [94, 155, 199],
                [92, 153, 198],
                [89, 151, 196],
                [87, 149, 195],
                [85, 147, 194],
                [82, 145, 192],
                [80, 143, 191],
                [78, 141, 190],
                [76, 139, 188],
                [74, 137, 187],
                [71, 135, 186],
                [69, 133, 184],
                [67, 131, 183],
                [65, 129, 181],
                [63, 127, 180],
                [61, 125, 179],
                [59, 123, 177],
                [57, 121, 176],
                [56, 119, 174],
                [54, 117, 173],
                [52, 115, 171],
                [50, 113, 170],
                [48, 111, 168],
                [47, 109, 167],
                [45, 107, 165],
                [43, 105, 164],
                [42, 103, 162],
                [40, 101, 160],
                [38, 99, 159],
                [37, 97, 157],
                [35, 95, 156],
                [34, 93, 154],
                [32, 91, 152],
                [31, 89, 151],
                [30, 87, 149],
                [28, 85, 147],
                [27, 83, 145],
                [26, 81, 144],
                [24, 79, 142],
                [23, 77, 140],
                [22, 75, 138],
                [21, 73, 136],
                [20, 71, 135],
                [19, 69, 133],
                [18, 67, 131],
                [17, 65, 129],
                [16, 63, 127],
                [15, 61, 125],
                [14, 59, 123],
                [13, 57, 121],
                [12, 55, 118],
                [11, 53, 116],
                [10, 51, 114],
                [9, 49, 112],
                [9, 47, 109],
                [8, 45, 107],
                [7, 43, 105],
                [7, 41, 102],
                [6, 39, 100],
                [5, 37, 97],
                [5, 35, 94],
                [4, 33, 92],
                [4, 31, 89],
                [3, 29, 86],
                [3, 27, 83],
                [2, 25, 80],
                [2, 23, 77],
                [2, 21, 73],
                [1, 19, 70],
                [1, 17, 66],
                [1, 15, 62],
                [1, 13, 58],
                [0, 11, 53],
                [0, 9, 48],
                [0, 7, 42],
                [0, 5, 36],
                [0, 3, 28],
                [0, 1, 16],
            ],
        );

        m.insert(
            "Phase Mint-Cherry",
            [
                [255, 255, 255],
                [251, 254, 253],
                [247, 253, 251],
                [243, 252, 249],
                [239, 251, 247],
                [235, 250, 245],
                [232, 249, 243],
                [228, 248, 241],
                [224, 247, 239],
                [220, 246, 237],
                [217, 245, 235],
                [213, 244, 233],
                [209, 243, 231],
                [206, 242, 229],
                [202, 241, 227],
                [199, 240, 225],
                [195, 238, 223],
                [192, 237, 221],
                [188, 236, 219],
                [185, 235, 217],
                [181, 234, 215],
                [178, 233, 213],
                [175, 232, 211],
                [171, 231, 209],
                [168, 230, 207],
                [165, 229, 205],
                [162, 228, 203],
                [158, 226, 201],
                [155, 225, 199],
                [152, 224, 197],
                [149, 223, 195],
                [146, 222, 193],
                [143, 221, 191],
                [140, 220, 189],
                [137, 218, 187],
                [134, 217, 185],
                [131, 216, 183],
                [128, 215, 181],
                [126, 214, 179],
                [123, 212, 177],
                [120, 211, 175],
                [117, 210, 173],
                [115, 209, 171],
                [112, 208, 169],
                [109, 206, 167],
                [107, 205, 165],
                [104, 204, 163],
                [102, 203, 161],
                [99, 201, 159],
                [97, 200, 157],
                [94, 199, 155],
                [92, 198, 153],
                [89, 196, 151],
                [87, 195, 149],
                [85, 194, 147],
                [82, 192, 145],
                [80, 191, 143],
                [78, 190, 141],
                [76, 188, 139],
                [74, 187, 137],
                [71, 186, 135],
                [69, 184, 133],
                [67, 183, 131],
                [65, 181, 129],
                [63, 180, 127],
                [61, 179, 125],
                [59, 177, 123],
                [57, 176, 121],
                [56, 174, 119],
                [54, 173, 117],
                [52, 171, 115],
                [50, 170, 113],
                [48, 168, 111],
                [47, 167, 109],
                [45, 165, 107],
                [43, 164, 105],
                [42, 162, 103],
                [40, 160, 101],
                [38, 159, 99],
                [37, 157, 97],
                [35, 156, 95],
                [34, 154, 93],
                [32, 152, 91],
                [31, 151, 89],
                [30, 149, 87],
                [28, 147, 85],
                [27, 145, 83],
                [26, 144, 81],
                [24, 142, 79],
                [23, 140, 77],
                [22, 138, 75],
                [21, 136, 73],
                [20, 135, 71],
                [19, 133, 69],
                [18, 131, 67],
                [17, 129, 65],
                [16, 127, 63],
                [15, 125, 61],
                [14, 123, 59],
                [13, 121, 57],
                [12, 118, 55],
                [11, 116, 53],
                [10, 114, 51],
                [9, 112, 49],
                [9, 109, 47],
                [8, 107, 45],
                [7, 105, 43],
                [7, 102, 41],
                [6, 100, 39],
                [5, 97, 37],
                [5, 94, 35],
                [4, 92, 33],
                [4, 89, 31],
                [3, 86, 29],
                [3, 83, 27],
                [2, 80, 25],
                [2, 77, 23],
                [2, 73, 21],
                [1, 70, 19],
                [1, 66, 17],
                [1, 62, 15],
                [1, 58, 13],
                [0, 53, 11],
                [0, 48, 9],
                [0, 42, 7],
                [0, 36, 5],
                [0, 28, 3],
                [0, 16, 1],
                [16, 0, 1],
                [28, 0, 3],
                [36, 0, 5],
                [42, 0, 7],
                [48, 0, 9],
                [53, 0, 11],
                [58, 1, 13],
                [62, 1, 15],
                [66, 1, 17],
                [70, 1, 19],
                [73, 2, 21],
                [77, 2, 23],
                [80, 2, 25],
                [83, 3, 27],
                [86, 3, 29],
                [89, 4, 31],
                [92, 4, 33],
                [94, 5, 35],
                [97, 5, 37],
                [100, 6, 39],
                [102, 7, 41],
                [105, 7, 43],
                [107, 8, 45],
                [109, 9, 47],
                [112, 9, 49],
                [114, 10, 51],
                [116, 11, 53],
                [118, 12, 55],
                [121, 13, 57],
                [123, 14, 59],
                [125, 15, 61],
                [127, 16, 63],
                [129, 17, 65],
                [131, 18, 67],
                [133, 19, 69],
                [135, 20, 71],
                [136, 21, 73],
                [138, 22, 75],
                [140, 23, 77],
                [142, 24, 79],
                [144, 26, 81],
                [145, 27, 83],
                [147, 28, 85],
                [149, 30, 87],
                [151, 31, 89],
                [152, 32, 91],
                [154, 34, 93],
                [156, 35, 95],
                [157, 37, 97],
                [159, 38, 99],
                [160, 40, 101],
                [162, 42, 103],
                [164, 43, 105],
                [165, 45, 107],
                [167, 47, 109],
                [168, 48, 111],
                [170, 50, 113],
                [171, 52, 115],
                [173, 54, 117],
                [174, 56, 119],
                [176, 57, 121],
                [177, 59, 123],
                [179, 61, 125],
                [180, 63, 127],
                [181, 65, 129],
                [183, 67, 131],
                [184, 69, 133],
                [186, 71, 135],
                [187, 74, 137],
                [188, 76, 139],
                [190, 78, 141],
                [191, 80, 143],
                [192, 82, 145],
                [194, 85, 147],
                [195, 87, 149],
                [196, 89, 151],
                [198, 92, 153],
                [199, 94, 155],
                [200, 97, 157],
                [201, 99, 159],
                [203, 102, 161],
                [204, 104, 163],
                [205, 107, 165],
                [206, 109, 167],
                [208, 112, 169],
                [209, 115, 171],
                [210, 117, 173],
                [211, 120, 175],
                [212, 123, 177],
                [214, 126, 179],
                [215, 128, 181],
                [216, 131, 183],
                [217, 134, 185],
                [218, 137, 187],
                [220, 140, 189],
                [221, 143, 191],
                [222, 146, 193],
                [223, 149, 195],
                [224, 152, 197],
                [225, 155, 199],
                [226, 158, 201],
                [228, 162, 203],
                [229, 165, 205],
                [230, 168, 207],
                [231, 171, 209],
                [232, 175, 211],
                [233, 178, 213],
                [234, 181, 215],
                [235, 185, 217],
                [236, 188, 219],
                [237, 192, 221],
                [238, 195, 223],
                [240, 199, 225],
                [241, 202, 227],
                [242, 206, 229],
                [243, 209, 231],
                [244, 213, 233],
                [245, 217, 235],
                [246, 220, 237],
                [247, 224, 239],
                [248, 228, 241],
                [249, 232, 243],
                [250, 235, 245],
                [251, 239, 247],
                [252, 243, 249],
                [253, 247, 251],
                [254, 251, 253],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Phase Yellow-Cyan",
            [
                [255, 255, 255],
                [254, 253, 251],
                [253, 251, 247],
                [252, 249, 243],
                [251, 247, 239],
                [250, 245, 235],
                [249, 243, 232],
                [248, 241, 228],
                [247, 239, 224],
                [246, 237, 220],
                [245, 235, 217],
                [244, 233, 213],
                [243, 231, 209],
                [242, 229, 206],
                [241, 227, 202],
                [240, 225, 199],
                [238, 223, 195],
                [237, 221, 192],
                [236, 219, 188],
                [235, 217, 185],
                [234, 215, 181],
                [233, 213, 178],
                [232, 211, 175],
                [231, 209, 171],
                [230, 207, 168],
                [229, 205, 165],
                [228, 203, 162],
                [226, 201, 158],
                [225, 199, 155],
                [224, 197, 152],
                [223, 195, 149],
                [222, 193, 146],
                [221, 191, 143],
                [220, 189, 140],
                [218, 187, 137],
                [217, 185, 134],
                [216, 183, 131],
                [215, 181, 128],
                [214, 179, 126],
                [212, 177, 123],
                [211, 175, 120],
                [210, 173, 117],
                [209, 171, 115],
                [208, 169, 112],
                [206, 167, 109],
                [205, 165, 107],
                [204, 163, 104],
                [203, 161, 102],
                [201, 159, 99],
                [200, 157, 97],
                [199, 155, 94],
                [198, 153, 92],
                [196, 151, 89],
                [195, 149, 87],
                [194, 147, 85],
                [192, 145, 82],
                [191, 143, 80],
                [190, 141, 78],
                [188, 139, 76],
                [187, 137, 74],
                [186, 135, 71],
                [184, 133, 69],
                [183, 131, 67],
                [181, 129, 65],
                [180, 127, 63],
                [179, 125, 61],
                [177, 123, 59],
                [176, 121, 57],
                [174, 119, 56],
                [173, 117, 54],
                [171, 115, 52],
                [170, 113, 50],
                [168, 111, 48],
                [167, 109, 47],
                [165, 107, 45],
                [164, 105, 43],
                [162, 103, 42],
                [160, 101, 40],
                [159, 99, 38],
                [157, 97, 37],
                [156, 95, 35],
                [154, 93, 34],
                [152, 91, 32],
                [151, 89, 31],
                [149, 87, 30],
                [147, 85, 28],
                [145, 83, 27],
                [144, 81, 26],
                [142, 79, 24],
                [140, 77, 23],
                [138, 75, 22],
                [136, 73, 21],
                [135, 71, 20],
                [133, 69, 19],
                [131, 67, 18],
                [129, 65, 17],
                [127, 63, 16],
                [125, 61, 15],
                [123, 59, 14],
                [121, 57, 13],
                [118, 55, 12],
                [116, 53, 11],
                [114, 51, 10],
                [112, 49, 9],
                [109, 47, 9],
                [107, 45, 8],
                [105, 43, 7],
                [102, 41, 7],
                [100, 39, 6],
                [97, 37, 5],
                [94, 35, 5],
                [92, 33, 4],
                [89, 31, 4],
                [86, 29, 3],
                [83, 27, 3],
                [80, 25, 2],
                [77, 23, 2],
                [73, 21, 2],
                [70, 19, 1],
                [66, 17, 1],
                [62, 15, 1],
                [58, 13, 1],
                [53, 11, 0],
                [48, 9, 0],
                [42, 7, 0],
                [36, 5, 0],
                [28, 3, 0],
                [16, 1, 0],
                [0, 1, 16],
                [0, 3, 28],
                [0, 5, 36],
                [0, 7, 42],
                [0, 9, 48],
                [0, 11, 53],
                [1, 13, 58],
                [1, 15, 62],
                [1, 17, 66],
                [1, 19, 70],
                [2, 21, 73],
                [2, 23, 77],
                [2, 25, 80],
                [3, 27, 83],
                [3, 29, 86],
                [4, 31, 89],
                [4, 33, 92],
                [5, 35, 94],
                [5, 37, 97],
                [6, 39, 100],
                [7, 41, 102],
                [7, 43, 105],
                [8, 45, 107],
                [9, 47, 109],
                [9, 49, 112],
                [10, 51, 114],
                [11, 53, 116],
                [12, 55, 118],
                [13, 57, 121],
                [14, 59, 123],
                [15, 61, 125],
                [16, 63, 127],
                [17, 65, 129],
                [18, 67, 131],
                [19, 69, 133],
                [20, 71, 135],
                [21, 73, 136],
                [22, 75, 138],
                [23, 77, 140],
                [24, 79, 142],
                [26, 81, 144],
                [27, 83, 145],
                [28, 85, 147],
                [30, 87, 149],
                [31, 89, 151],
                [32, 91, 152],
                [34, 93, 154],
                [35, 95, 156],
                [37, 97, 157],
                [38, 99, 159],
                [40, 101, 160],
                [42, 103, 162],
                [43, 105, 164],
                [45, 107, 165],
                [47, 109, 167],
                [48, 111, 168],
                [50, 113, 170],
                [52, 115, 171],
                [54, 117, 173],
                [56, 119, 174],
                [57, 121, 176],
                [59, 123, 177],
                [61, 125, 179],
                [63, 127, 180],
                [65, 129, 181],
                [67, 131, 183],
                [69, 133, 184],
                [71, 135, 186],
                [74, 137, 187],
                [76, 139, 188],
                [78, 141, 190],
                [80, 143, 191],
                [82, 145, 192],
                [85, 147, 194],
                [87, 149, 195],
                [89, 151, 196],
                [92, 153, 198],
                [94, 155, 199],
                [97, 157, 200],
                [99, 159, 201],
                [102, 161, 203],
                [104, 163, 204],
                [107, 165, 205],
                [109, 167, 206],
                [112, 169, 208],
                [115, 171, 209],
                [117, 173, 210],
                [120, 175, 211],
                [123, 177, 212],
                [126, 179, 214],
                [128, 181, 215],
                [131, 183, 216],
                [134, 185, 217],
                [137, 187, 218],
                [140, 189, 220],
                [143, 191, 221],
                [146, 193, 222],
                [149, 195, 223],
                [152, 197, 224],
                [155, 199, 225],
                [158, 201, 226],
                [162, 203, 228],
                [165, 205, 229],
                [168, 207, 230],
                [171, 209, 231],
                [175, 211, 232],
                [178, 213, 233],
                [181, 215, 234],
                [185, 217, 235],
                [188, 219, 236],
                [192, 221, 237],
                [195, 223, 238],
                [199, 225, 240],
                [202, 227, 241],
                [206, 229, 242],
                [209, 231, 243],
                [213, 233, 244],
                [217, 235, 245],
                [220, 237, 246],
                [224, 239, 247],
                [228, 241, 248],
                [232, 243, 249],
                [235, 245, 250],
                [239, 247, 251],
                [243, 249, 252],
                [247, 251, 253],
                [251, 253, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop blue",
            [
                [0, 0, 0],
                [0, 0, 4],
                [0, 0, 8],
                [0, 0, 12],
                [0, 0, 16],
                [0, 0, 19],
                [0, 0, 23],
                [0, 0, 27],
                [0, 0, 31],
                [0, 0, 34],
                [0, 0, 38],
                [0, 0, 41],
                [0, 0, 45],
                [0, 0, 48],
                [0, 0, 52],
                [0, 0, 55],
                [0, 0, 58],
                [0, 0, 61],
                [0, 0, 65],
                [0, 0, 68],
                [0, 0, 71],
                [0, 0, 74],
                [0, 0, 77],
                [0, 0, 80],
                [0, 0, 83],
                [0, 0, 86],
                [0, 0, 89],
                [0, 0, 92],
                [0, 0, 95],
                [0, 0, 98],
                [0, 0, 100],
                [0, 0, 103],
                [0, 0, 106],
                [0, 0, 109],
                [0, 0, 111],
                [0, 0, 114],
                [0, 0, 116],
                [0, 0, 119],
                [0, 0, 121],
                [0, 0, 124],
                [0, 0, 126],
                [0, 0, 129],
                [0, 0, 131],
                [0, 0, 133],
                [0, 0, 135],
                [0, 0, 138],
                [0, 0, 140],
                [0, 0, 142],
                [0, 0, 144],
                [0, 0, 146],
                [0, 0, 148],
                [0, 0, 151],
                [0, 0, 153],
                [0, 0, 155],
                [0, 0, 157],
                [0, 0, 159],
                [0, 0, 160],
                [0, 0, 162],
                [0, 0, 164],
                [0, 0, 166],
                [0, 0, 168],
                [0, 0, 170],
                [0, 0, 171],
                [0, 0, 173],
                [0, 0, 175],
                [0, 2, 176],
                [0, 3, 178],
                [0, 4, 180],
                [0, 6, 181],
                [0, 7, 183],
                [0, 8, 184],
                [0, 10, 186],
                [0, 11, 187],
                [0, 12, 189],
                [0, 14, 190],
                [0, 15, 192],
                [0, 16, 193],
                [0, 18, 194],
                [0, 19, 196],
                [0, 20, 197],
                [0, 22, 198],
                [0, 23, 200],
                [0, 24, 201],
                [0, 26, 202],
                [0, 27, 203],
                [0, 28, 205],
                [0, 30, 206],
                [0, 31, 207],
                [0, 32, 208],
                [0, 34, 209],
                [0, 35, 210],
                [0, 36, 211],
                [0, 38, 212],
                [1, 39, 213],
                [1, 40, 214],
                [1, 42, 215],
                [1, 43, 216],
                [1, 44, 217],
                [1, 46, 218],
                [2, 47, 219],
                [2, 48, 220],
                [2, 50, 221],
                [3, 51, 222],
                [3, 52, 223],
                [3, 54, 224],
                [4, 55, 224],
                [4, 56, 225],
                [4, 58, 226],
                [5, 59, 227],
                [5, 60, 228],
                [6, 62, 228],
                [6, 63, 229],
                [6, 64, 230],
                [7, 66, 230],
                [7, 67, 231],
                [8, 68, 232],
                [8, 70, 232],
                [9, 71, 233],
                [10, 72, 234],
                [10, 74, 234],
                [11, 75, 235],
                [11, 76, 236],
                [12, 78, 236],
                [13, 79, 237],
                [13, 80, 237],
                [14, 82, 238],
                [15, 83, 238],
                [16, 84, 239],
                [16, 86, 239],
                [17, 87, 240],
                [18, 88, 240],
                [19, 90, 241],
                [19, 91, 241],
                [20, 92, 242],
                [21, 94, 242],
                [22, 95, 242],
                [23, 96, 243],
                [24, 98, 243],
                [25, 99, 244],
                [26, 100, 244],
                [27, 102, 244],
                [28, 103, 245],
                [29, 104, 245],
                [30, 106, 246],
                [31, 107, 246],
                [32, 108, 246],
                [33, 110, 246],
                [34, 111, 247],
                [35, 112, 247],
                [36, 114, 247],
                [37, 115, 248],
                [38, 116, 248],
                [40, 118, 248],
                [41, 119, 248],
                [42, 120, 249],
                [43, 122, 249],
                [44, 123, 249],
                [46, 124, 249],
                [47, 126, 250],
                [48, 127, 250],
                [50, 128, 250],
                [51, 130, 250],
                [52, 131, 250],
                [54, 132, 251],
                [55, 134, 251],
                [56, 135, 251],
                [58, 136, 251],
                [59, 138, 251],
                [61, 139, 252],
                [62, 140, 252],
                [64, 142, 252],
                [65, 143, 252],
                [67, 144, 252],
                [68, 146, 252],
                [70, 147, 252],
                [71, 148, 253],
                [73, 150, 253],
                [75, 151, 253],
                [76, 152, 253],
                [78, 154, 253],
                [80, 155, 253],
                [81, 156, 253],
                [83, 158, 253],
                [85, 159, 253],
                [86, 160, 253],
                [88, 162, 254],
                [90, 163, 254],
                [92, 164, 254],
                [94, 166, 254],
                [95, 167, 254],
                [97, 168, 254],
                [99, 170, 254],
                [101, 171, 254],
                [103, 172, 254],
                [105, 174, 254],
                [107, 175, 254],
                [109, 176, 254],
                [111, 178, 254],
                [113, 179, 254],
                [115, 180, 254],
                [117, 182, 254],
                [119, 183, 254],
                [121, 184, 255],
                [123, 186, 255],
                [125, 187, 255],
                [127, 188, 255],
                [129, 190, 255],
                [131, 191, 255],
                [133, 192, 255],
                [136, 194, 255],
                [138, 195, 255],
                [140, 196, 255],
                [142, 198, 255],
                [145, 199, 255],
                [147, 200, 255],
                [149, 202, 255],
                [151, 203, 255],
                [154, 204, 255],
                [156, 206, 255],
                [158, 207, 255],
                [161, 208, 255],
                [163, 210, 255],
                [166, 211, 255],
                [168, 212, 255],
                [170, 214, 255],
                [173, 215, 255],
                [175, 216, 255],
                [178, 218, 255],
                [180, 219, 255],
                [183, 220, 255],
                [186, 222, 255],
                [188, 223, 255],
                [191, 224, 255],
                [193, 226, 255],
                [196, 227, 255],
                [199, 228, 255],
                [201, 230, 255],
                [204, 231, 255],
                [207, 232, 255],
                [209, 234, 255],
                [212, 235, 255],
                [215, 236, 255],
                [217, 238, 255],
                [220, 239, 255],
                [223, 240, 255],
                [226, 242, 255],
                [229, 243, 255],
                [232, 244, 255],
                [234, 246, 255],
                [237, 247, 255],
                [240, 248, 255],
                [243, 250, 255],
                [246, 251, 255],
                [249, 252, 255],
                [252, 254, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop blue inverted",
            [
                [255, 255, 255],
                [252, 254, 255],
                [249, 252, 255],
                [246, 251, 255],
                [243, 250, 255],
                [240, 248, 255],
                [237, 247, 255],
                [234, 246, 255],
                [232, 244, 255],
                [229, 243, 255],
                [226, 242, 255],
                [223, 240, 255],
                [220, 239, 255],
                [217, 238, 255],
                [215, 236, 255],
                [212, 235, 255],
                [209, 234, 255],
                [207, 232, 255],
                [204, 231, 255],
                [201, 230, 255],
                [199, 228, 255],
                [196, 227, 255],
                [193, 226, 255],
                [191, 224, 255],
                [188, 223, 255],
                [186, 222, 255],
                [183, 220, 255],
                [180, 219, 255],
                [178, 218, 255],
                [175, 216, 255],
                [173, 215, 255],
                [170, 214, 255],
                [168, 212, 255],
                [166, 211, 255],
                [163, 210, 255],
                [161, 208, 255],
                [158, 207, 255],
                [156, 206, 255],
                [154, 204, 255],
                [151, 203, 255],
                [149, 202, 255],
                [147, 200, 255],
                [145, 199, 255],
                [142, 198, 255],
                [140, 196, 255],
                [138, 195, 255],
                [136, 194, 255],
                [133, 192, 255],
                [131, 191, 255],
                [129, 190, 255],
                [127, 188, 255],
                [125, 187, 255],
                [123, 186, 255],
                [121, 184, 255],
                [119, 183, 254],
                [117, 182, 254],
                [115, 180, 254],
                [113, 179, 254],
                [111, 178, 254],
                [109, 176, 254],
                [107, 175, 254],
                [105, 174, 254],
                [103, 172, 254],
                [101, 171, 254],
                [99, 170, 254],
                [97, 168, 254],
                [95, 167, 254],
                [94, 166, 254],
                [92, 164, 254],
                [90, 163, 254],
                [88, 162, 254],
                [86, 160, 253],
                [85, 159, 253],
                [83, 158, 253],
                [81, 156, 253],
                [80, 155, 253],
                [78, 154, 253],
                [76, 152, 253],
                [75, 151, 253],
                [73, 150, 253],
                [71, 148, 253],
                [70, 147, 252],
                [68, 146, 252],
                [67, 144, 252],
                [65, 143, 252],
                [64, 142, 252],
                [62, 140, 252],
                [61, 139, 252],
                [59, 138, 251],
                [58, 136, 251],
                [56, 135, 251],
                [55, 134, 251],
                [54, 132, 251],
                [52, 131, 250],
                [51, 130, 250],
                [50, 128, 250],
                [48, 127, 250],
                [47, 126, 250],
                [46, 124, 249],
                [44, 123, 249],
                [43, 122, 249],
                [42, 120, 249],
                [41, 119, 248],
                [40, 118, 248],
                [38, 116, 248],
                [37, 115, 248],
                [36, 114, 247],
                [35, 112, 247],
                [34, 111, 247],
                [33, 110, 246],
                [32, 108, 246],
                [31, 107, 246],
                [30, 106, 246],
                [29, 104, 245],
                [28, 103, 245],
                [27, 102, 244],
                [26, 100, 244],
                [25, 99, 244],
                [24, 98, 243],
                [23, 96, 243],
                [22, 95, 242],
                [21, 94, 242],
                [20, 92, 242],
                [19, 91, 241],
                [19, 90, 241],
                [18, 88, 240],
                [17, 87, 240],
                [16, 86, 239],
                [16, 84, 239],
                [15, 83, 238],
                [14, 82, 238],
                [13, 80, 237],
                [13, 79, 237],
                [12, 78, 236],
                [11, 76, 236],
                [11, 75, 235],
                [10, 74, 234],
                [10, 72, 234],
                [9, 71, 233],
                [8, 70, 232],
                [8, 68, 232],
                [7, 67, 231],
                [7, 66, 230],
                [6, 64, 230],
                [6, 63, 229],
                [6, 62, 228],
                [5, 60, 228],
                [5, 59, 227],
                [4, 58, 226],
                [4, 56, 225],
                [4, 55, 224],
                [3, 54, 224],
                [3, 52, 223],
                [3, 51, 222],
                [2, 50, 221],
                [2, 48, 220],
                [2, 47, 219],
                [1, 46, 218],
                [1, 44, 217],
                [1, 43, 216],
                [1, 42, 215],
                [1, 40, 214],
                [1, 39, 213],
                [0, 38, 212],
                [0, 36, 211],
                [0, 35, 210],
                [0, 34, 209],
                [0, 32, 208],
                [0, 31, 207],
                [0, 30, 206],
                [0, 28, 205],
                [0, 27, 203],
                [0, 26, 202],
                [0, 24, 201],
                [0, 23, 200],
                [0, 22, 198],
                [0, 20, 197],
                [0, 19, 196],
                [0, 18, 194],
                [0, 16, 193],
                [0, 15, 192],
                [0, 14, 190],
                [0, 12, 189],
                [0, 11, 187],
                [0, 10, 186],
                [0, 8, 184],
                [0, 7, 183],
                [0, 6, 181],
                [0, 4, 180],
                [0, 3, 178],
                [0, 2, 176],
                [0, 0, 175],
                [0, 0, 173],
                [0, 0, 171],
                [0, 0, 170],
                [0, 0, 168],
                [0, 0, 166],
                [0, 0, 164],
                [0, 0, 162],
                [0, 0, 160],
                [0, 0, 159],
                [0, 0, 157],
                [0, 0, 155],
                [0, 0, 153],
                [0, 0, 151],
                [0, 0, 148],
                [0, 0, 146],
                [0, 0, 144],
                [0, 0, 142],
                [0, 0, 140],
                [0, 0, 138],
                [0, 0, 135],
                [0, 0, 133],
                [0, 0, 131],
                [0, 0, 129],
                [0, 0, 126],
                [0, 0, 124],
                [0, 0, 121],
                [0, 0, 119],
                [0, 0, 116],
                [0, 0, 114],
                [0, 0, 111],
                [0, 0, 109],
                [0, 0, 106],
                [0, 0, 103],
                [0, 0, 100],
                [0, 0, 98],
                [0, 0, 95],
                [0, 0, 92],
                [0, 0, 89],
                [0, 0, 86],
                [0, 0, 83],
                [0, 0, 80],
                [0, 0, 77],
                [0, 0, 74],
                [0, 0, 71],
                [0, 0, 68],
                [0, 0, 65],
                [0, 0, 61],
                [0, 0, 58],
                [0, 0, 55],
                [0, 0, 52],
                [0, 0, 48],
                [0, 0, 45],
                [0, 0, 41],
                [0, 0, 38],
                [0, 0, 34],
                [0, 0, 31],
                [0, 0, 27],
                [0, 0, 23],
                [0, 0, 19],
                [0, 0, 16],
                [0, 0, 12],
                [0, 0, 8],
                [0, 0, 4],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop cherry",
            [
                [0, 0, 0],
                [4, 0, 0],
                [8, 0, 0],
                [12, 0, 0],
                [16, 0, 0],
                [19, 0, 0],
                [23, 0, 0],
                [27, 0, 0],
                [31, 0, 0],
                [34, 0, 0],
                [38, 0, 0],
                [41, 0, 0],
                [45, 0, 0],
                [48, 0, 0],
                [52, 0, 0],
                [55, 0, 0],
                [58, 0, 0],
                [61, 0, 0],
                [65, 0, 0],
                [68, 0, 0],
                [71, 0, 0],
                [74, 0, 0],
                [77, 0, 0],
                [80, 0, 0],
                [83, 0, 0],
                [86, 0, 0],
                [89, 0, 0],
                [92, 0, 0],
                [95, 0, 0],
                [98, 0, 0],
                [100, 0, 0],
                [103, 0, 0],
                [106, 0, 0],
                [109, 0, 0],
                [111, 0, 0],
                [114, 0, 0],
                [116, 0, 0],
                [119, 0, 0],
                [121, 0, 0],
                [124, 0, 0],
                [126, 0, 0],
                [129, 0, 0],
                [131, 0, 0],
                [133, 0, 0],
                [135, 0, 0],
                [138, 0, 0],
                [140, 0, 0],
                [142, 0, 0],
                [144, 0, 0],
                [146, 0, 0],
                [148, 0, 0],
                [151, 0, 0],
                [153, 0, 0],
                [155, 0, 0],
                [157, 0, 0],
                [159, 0, 0],
                [160, 0, 0],
                [162, 0, 0],
                [164, 0, 0],
                [166, 0, 0],
                [168, 0, 0],
                [170, 0, 0],
                [171, 0, 0],
                [173, 0, 0],
                [175, 0, 0],
                [176, 0, 2],
                [178, 0, 3],
                [180, 0, 4],
                [181, 0, 6],
                [183, 0, 7],
                [184, 0, 8],
                [186, 0, 10],
                [187, 0, 11],
                [189, 0, 12],
                [190, 0, 14],
                [192, 0, 15],
                [193, 0, 16],
                [194, 0, 18],
                [196, 0, 19],
                [197, 0, 20],
                [198, 0, 22],
                [200, 0, 23],
                [201, 0, 24],
                [202, 0, 26],
                [203, 0, 27],
                [205, 0, 28],
                [206, 0, 30],
                [207, 0, 31],
                [208, 0, 32],
                [209, 0, 34],
                [210, 0, 35],
                [211, 0, 36],
                [212, 0, 38],
                [213, 1, 39],
                [214, 1, 40],
                [215, 1, 42],
                [216, 1, 43],
                [217, 1, 44],
                [218, 1, 46],
                [219, 2, 47],
                [220, 2, 48],
                [221, 2, 50],
                [222, 3, 51],
                [223, 3, 52],
                [224, 3, 54],
                [224, 4, 55],
                [225, 4, 56],
                [226, 4, 58],
                [227, 5, 59],
                [228, 5, 60],
                [228, 6, 62],
                [229, 6, 63],
                [230, 6, 64],
                [230, 7, 66],
                [231, 7, 67],
                [232, 8, 68],
                [232, 8, 70],
                [233, 9, 71],
                [234, 10, 72],
                [234, 10, 74],
                [235, 11, 75],
                [236, 11, 76],
                [236, 12, 78],
                [237, 13, 79],
                [237, 13, 80],
                [238, 14, 82],
                [238, 15, 83],
                [239, 16, 84],
                [239, 16, 86],
                [240, 17, 87],
                [240, 18, 88],
                [241, 19, 90],
                [241, 19, 91],
                [242, 20, 92],
                [242, 21, 94],
                [242, 22, 95],
                [243, 23, 96],
                [243, 24, 98],
                [244, 25, 99],
                [244, 26, 100],
                [244, 27, 102],
                [245, 28, 103],
                [245, 29, 104],
                [246, 30, 106],
                [246, 31, 107],
                [246, 32, 108],
                [246, 33, 110],
                [247, 34, 111],
                [247, 35, 112],
                [247, 36, 114],
                [248, 37, 115],
                [248, 38, 116],
                [248, 40, 118],
                [248, 41, 119],
                [249, 42, 120],
                [249, 43, 122],
                [249, 44, 123],
                [249, 46, 124],
                [250, 47, 126],
                [250, 48, 127],
                [250, 50, 128],
                [250, 51, 130],
                [250, 52, 131],
                [251, 54, 132],
                [251, 55, 134],
                [251, 56, 135],
                [251, 58, 136],
                [251, 59, 138],
                [252, 61, 139],
                [252, 62, 140],
                [252, 64, 142],
                [252, 65, 143],
                [252, 67, 144],
                [252, 68, 146],
                [252, 70, 147],
                [253, 71, 148],
                [253, 73, 150],
                [253, 75, 151],
                [253, 76, 152],
                [253, 78, 154],
                [253, 80, 155],
                [253, 81, 156],
                [253, 83, 158],
                [253, 85, 159],
                [253, 86, 160],
                [254, 88, 162],
                [254, 90, 163],
                [254, 92, 164],
                [254, 94, 166],
                [254, 95, 167],
                [254, 97, 168],
                [254, 99, 170],
                [254, 101, 171],
                [254, 103, 172],
                [254, 105, 174],
                [254, 107, 175],
                [254, 109, 176],
                [254, 111, 178],
                [254, 113, 179],
                [254, 115, 180],
                [254, 117, 182],
                [254, 119, 183],
                [255, 121, 184],
                [255, 123, 186],
                [255, 125, 187],
                [255, 127, 188],
                [255, 129, 190],
                [255, 131, 191],
                [255, 133, 192],
                [255, 136, 194],
                [255, 138, 195],
                [255, 140, 196],
                [255, 142, 198],
                [255, 145, 199],
                [255, 147, 200],
                [255, 149, 202],
                [255, 151, 203],
                [255, 154, 204],
                [255, 156, 206],
                [255, 158, 207],
                [255, 161, 208],
                [255, 163, 210],
                [255, 166, 211],
                [255, 168, 212],
                [255, 170, 214],
                [255, 173, 215],
                [255, 175, 216],
                [255, 178, 218],
                [255, 180, 219],
                [255, 183, 220],
                [255, 186, 222],
                [255, 188, 223],
                [255, 191, 224],
                [255, 193, 226],
                [255, 196, 227],
                [255, 199, 228],
                [255, 201, 230],
                [255, 204, 231],
                [255, 207, 232],
                [255, 209, 234],
                [255, 212, 235],
                [255, 215, 236],
                [255, 217, 238],
                [255, 220, 239],
                [255, 223, 240],
                [255, 226, 242],
                [255, 229, 243],
                [255, 232, 244],
                [255, 234, 246],
                [255, 237, 247],
                [255, 240, 248],
                [255, 243, 250],
                [255, 246, 251],
                [255, 249, 252],
                [255, 252, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop cherry inverted",
            [
                [255, 255, 255],
                [255, 252, 254],
                [255, 249, 252],
                [255, 246, 251],
                [255, 243, 250],
                [255, 240, 248],
                [255, 237, 247],
                [255, 234, 246],
                [255, 232, 244],
                [255, 229, 243],
                [255, 226, 242],
                [255, 223, 240],
                [255, 220, 239],
                [255, 217, 238],
                [255, 215, 236],
                [255, 212, 235],
                [255, 209, 234],
                [255, 207, 232],
                [255, 204, 231],
                [255, 201, 230],
                [255, 199, 228],
                [255, 196, 227],
                [255, 193, 226],
                [255, 191, 224],
                [255, 188, 223],
                [255, 186, 222],
                [255, 183, 220],
                [255, 180, 219],
                [255, 178, 218],
                [255, 175, 216],
                [255, 173, 215],
                [255, 170, 214],
                [255, 168, 212],
                [255, 166, 211],
                [255, 163, 210],
                [255, 161, 208],
                [255, 158, 207],
                [255, 156, 206],
                [255, 154, 204],
                [255, 151, 203],
                [255, 149, 202],
                [255, 147, 200],
                [255, 145, 199],
                [255, 142, 198],
                [255, 140, 196],
                [255, 138, 195],
                [255, 136, 194],
                [255, 133, 192],
                [255, 131, 191],
                [255, 129, 190],
                [255, 127, 188],
                [255, 125, 187],
                [255, 123, 186],
                [255, 121, 184],
                [254, 119, 183],
                [254, 117, 182],
                [254, 115, 180],
                [254, 113, 179],
                [254, 111, 178],
                [254, 109, 176],
                [254, 107, 175],
                [254, 105, 174],
                [254, 103, 172],
                [254, 101, 171],
                [254, 99, 170],
                [254, 97, 168],
                [254, 95, 167],
                [254, 94, 166],
                [254, 92, 164],
                [254, 90, 163],
                [254, 88, 162],
                [253, 86, 160],
                [253, 85, 159],
                [253, 83, 158],
                [253, 81, 156],
                [253, 80, 155],
                [253, 78, 154],
                [253, 76, 152],
                [253, 75, 151],
                [253, 73, 150],
                [253, 71, 148],
                [252, 70, 147],
                [252, 68, 146],
                [252, 67, 144],
                [252, 65, 143],
                [252, 64, 142],
                [252, 62, 140],
                [252, 61, 139],
                [251, 59, 138],
                [251, 58, 136],
                [251, 56, 135],
                [251, 55, 134],
                [251, 54, 132],
                [250, 52, 131],
                [250, 51, 130],
                [250, 50, 128],
                [250, 48, 127],
                [250, 47, 126],
                [249, 46, 124],
                [249, 44, 123],
                [249, 43, 122],
                [249, 42, 120],
                [248, 41, 119],
                [248, 40, 118],
                [248, 38, 116],
                [248, 37, 115],
                [247, 36, 114],
                [247, 35, 112],
                [247, 34, 111],
                [246, 33, 110],
                [246, 32, 108],
                [246, 31, 107],
                [246, 30, 106],
                [245, 29, 104],
                [245, 28, 103],
                [244, 27, 102],
                [244, 26, 100],
                [244, 25, 99],
                [243, 24, 98],
                [243, 23, 96],
                [242, 22, 95],
                [242, 21, 94],
                [242, 20, 92],
                [241, 19, 91],
                [241, 19, 90],
                [240, 18, 88],
                [240, 17, 87],
                [239, 16, 86],
                [239, 16, 84],
                [238, 15, 83],
                [238, 14, 82],
                [237, 13, 80],
                [237, 13, 79],
                [236, 12, 78],
                [236, 11, 76],
                [235, 11, 75],
                [234, 10, 74],
                [234, 10, 72],
                [233, 9, 71],
                [232, 8, 70],
                [232, 8, 68],
                [231, 7, 67],
                [230, 7, 66],
                [230, 6, 64],
                [229, 6, 63],
                [228, 6, 62],
                [228, 5, 60],
                [227, 5, 59],
                [226, 4, 58],
                [225, 4, 56],
                [224, 4, 55],
                [224, 3, 54],
                [223, 3, 52],
                [222, 3, 51],
                [221, 2, 50],
                [220, 2, 48],
                [219, 2, 47],
                [218, 1, 46],
                [217, 1, 44],
                [216, 1, 43],
                [215, 1, 42],
                [214, 1, 40],
                [213, 1, 39],
                [212, 0, 38],
                [211, 0, 36],
                [210, 0, 35],
                [209, 0, 34],
                [208, 0, 32],
                [207, 0, 31],
                [206, 0, 30],
                [205, 0, 28],
                [203, 0, 27],
                [202, 0, 26],
                [201, 0, 24],
                [200, 0, 23],
                [198, 0, 22],
                [197, 0, 20],
                [196, 0, 19],
                [194, 0, 18],
                [193, 0, 16],
                [192, 0, 15],
                [190, 0, 14],
                [189, 0, 12],
                [187, 0, 11],
                [186, 0, 10],
                [184, 0, 8],
                [183, 0, 7],
                [181, 0, 6],
                [180, 0, 4],
                [178, 0, 3],
                [176, 0, 2],
                [175, 0, 0],
                [173, 0, 0],
                [171, 0, 0],
                [170, 0, 0],
                [168, 0, 0],
                [166, 0, 0],
                [164, 0, 0],
                [162, 0, 0],
                [160, 0, 0],
                [159, 0, 0],
                [157, 0, 0],
                [155, 0, 0],
                [153, 0, 0],
                [151, 0, 0],
                [148, 0, 0],
                [146, 0, 0],
                [144, 0, 0],
                [142, 0, 0],
                [140, 0, 0],
                [138, 0, 0],
                [135, 0, 0],
                [133, 0, 0],
                [131, 0, 0],
                [129, 0, 0],
                [126, 0, 0],
                [124, 0, 0],
                [121, 0, 0],
                [119, 0, 0],
                [116, 0, 0],
                [114, 0, 0],
                [111, 0, 0],
                [109, 0, 0],
                [106, 0, 0],
                [103, 0, 0],
                [100, 0, 0],
                [98, 0, 0],
                [95, 0, 0],
                [92, 0, 0],
                [89, 0, 0],
                [86, 0, 0],
                [83, 0, 0],
                [80, 0, 0],
                [77, 0, 0],
                [74, 0, 0],
                [71, 0, 0],
                [68, 0, 0],
                [65, 0, 0],
                [61, 0, 0],
                [58, 0, 0],
                [55, 0, 0],
                [52, 0, 0],
                [48, 0, 0],
                [45, 0, 0],
                [41, 0, 0],
                [38, 0, 0],
                [34, 0, 0],
                [31, 0, 0],
                [27, 0, 0],
                [23, 0, 0],
                [19, 0, 0],
                [16, 0, 0],
                [12, 0, 0],
                [8, 0, 0],
                [4, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop cyan",
            [
                [0, 0, 0],
                [0, 2, 2],
                [0, 5, 5],
                [0, 7, 7],
                [0, 10, 10],
                [0, 12, 12],
                [0, 15, 15],
                [0, 17, 17],
                [0, 19, 19],
                [0, 22, 22],
                [0, 24, 24],
                [0, 26, 26],
                [0, 29, 29],
                [0, 31, 31],
                [0, 33, 33],
                [0, 35, 35],
                [0, 38, 38],
                [0, 40, 40],
                [0, 42, 42],
                [0, 44, 44],
                [0, 46, 46],
                [0, 48, 48],
                [0, 51, 51],
                [0, 53, 53],
                [0, 55, 55],
                [0, 57, 57],
                [0, 59, 59],
                [0, 61, 61],
                [0, 63, 63],
                [0, 65, 65],
                [0, 67, 67],
                [0, 69, 69],
                [0, 71, 71],
                [0, 73, 73],
                [0, 75, 75],
                [0, 77, 77],
                [0, 79, 79],
                [0, 80, 80],
                [0, 82, 82],
                [0, 84, 84],
                [0, 86, 86],
                [0, 88, 88],
                [0, 90, 90],
                [0, 91, 91],
                [0, 93, 93],
                [0, 95, 95],
                [0, 97, 97],
                [0, 99, 99],
                [0, 100, 100],
                [0, 102, 102],
                [0, 104, 104],
                [0, 105, 105],
                [0, 107, 107],
                [0, 109, 109],
                [0, 110, 110],
                [0, 112, 112],
                [0, 114, 114],
                [0, 115, 115],
                [0, 117, 117],
                [0, 118, 118],
                [0, 120, 120],
                [0, 121, 121],
                [0, 123, 123],
                [0, 124, 124],
                [0, 126, 126],
                [0, 127, 127],
                [0, 129, 129],
                [0, 130, 130],
                [0, 132, 132],
                [0, 133, 133],
                [0, 135, 135],
                [0, 136, 136],
                [0, 137, 137],
                [0, 139, 139],
                [0, 140, 140],
                [0, 142, 142],
                [0, 143, 143],
                [0, 144, 144],
                [0, 146, 146],
                [0, 147, 147],
                [0, 148, 148],
                [0, 150, 150],
                [0, 151, 151],
                [0, 152, 152],
                [0, 153, 153],
                [0, 155, 155],
                [0, 156, 156],
                [0, 157, 157],
                [0, 158, 158],
                [0, 159, 159],
                [0, 161, 161],
                [0, 162, 162],
                [0, 163, 163],
                [0, 164, 164],
                [0, 165, 165],
                [0, 166, 166],
                [0, 168, 168],
                [0, 169, 169],
                [0, 170, 170],
                [0, 171, 171],
                [0, 172, 172],
                [0, 173, 173],
                [0, 174, 174],
                [1, 175, 175],
                [3, 176, 176],
                [5, 177, 177],
                [6, 178, 178],
                [8, 179, 179],
                [10, 180, 180],
                [11, 181, 181],
                [13, 182, 182],
                [15, 183, 183],
                [16, 184, 184],
                [18, 185, 185],
                [20, 186, 186],
                [21, 187, 187],
                [23, 188, 188],
                [25, 189, 189],
                [26, 190, 190],
                [28, 191, 191],
                [30, 191, 191],
                [31, 192, 192],
                [33, 193, 193],
                [35, 194, 194],
                [36, 195, 195],
                [38, 196, 196],
                [40, 197, 197],
                [41, 197, 197],
                [43, 198, 198],
                [44, 199, 199],
                [46, 200, 200],
                [48, 201, 201],
                [49, 201, 201],
                [51, 202, 202],
                [53, 203, 203],
                [54, 204, 204],
                [56, 204, 204],
                [58, 205, 205],
                [59, 206, 206],
                [61, 207, 207],
                [63, 207, 207],
                [64, 208, 208],
                [66, 209, 209],
                [68, 210, 210],
                [69, 210, 210],
                [71, 211, 211],
                [73, 212, 212],
                [74, 212, 212],
                [76, 213, 213],
                [78, 214, 214],
                [79, 215, 215],
                [81, 215, 215],
                [83, 216, 216],
                [84, 217, 217],
                [86, 217, 217],
                [88, 218, 218],
                [89, 219, 219],
                [91, 220, 220],
                [93, 220, 220],
                [94, 221, 221],
                [96, 222, 222],
                [98, 222, 222],
                [99, 223, 223],
                [101, 224, 224],
                [103, 225, 225],
                [104, 225, 225],
                [106, 226, 226],
                [108, 227, 227],
                [109, 227, 227],
                [111, 228, 228],
                [113, 229, 229],
                [114, 229, 229],
                [116, 230, 230],
                [118, 231, 231],
                [119, 232, 232],
                [121, 232, 232],
                [123, 233, 233],
                [124, 234, 234],
                [126, 234, 234],
                [128, 235, 235],
                [129, 236, 236],
                [131, 236, 236],
                [133, 237, 237],
                [134, 238, 238],
                [136, 239, 239],
                [138, 239, 239],
                [139, 240, 240],
                [141, 241, 241],
                [143, 241, 241],
                [144, 242, 242],
                [146, 243, 243],
                [148, 244, 244],
                [149, 244, 244],
                [151, 245, 245],
                [153, 246, 246],
                [154, 246, 246],
                [156, 247, 247],
                [158, 248, 248],
                [159, 249, 249],
                [161, 249, 249],
                [163, 250, 250],
                [164, 251, 251],
                [166, 251, 251],
                [168, 252, 252],
                [169, 253, 253],
                [171, 254, 254],
                [173, 254, 254],
                [174, 255, 255],
                [176, 255, 255],
                [178, 255, 255],
                [179, 255, 255],
                [181, 255, 255],
                [183, 255, 255],
                [184, 255, 255],
                [186, 255, 255],
                [187, 255, 255],
                [189, 255, 255],
                [191, 255, 255],
                [192, 255, 255],
                [194, 255, 255],
                [196, 255, 255],
                [197, 255, 255],
                [199, 255, 255],
                [201, 255, 255],
                [202, 255, 255],
                [204, 255, 255],
                [206, 255, 255],
                [207, 255, 255],
                [209, 255, 255],
                [211, 255, 255],
                [212, 255, 255],
                [214, 255, 255],
                [216, 255, 255],
                [217, 255, 255],
                [219, 255, 255],
                [221, 255, 255],
                [222, 255, 255],
                [224, 255, 255],
                [226, 255, 255],
                [227, 255, 255],
                [229, 255, 255],
                [231, 255, 255],
                [232, 255, 255],
                [234, 255, 255],
                [236, 255, 255],
                [237, 255, 255],
                [239, 255, 255],
                [241, 255, 255],
                [242, 255, 255],
                [244, 255, 255],
                [246, 255, 255],
                [247, 255, 255],
                [249, 255, 255],
                [251, 255, 255],
                [252, 255, 255],
                [254, 255, 255],
            ],
        );

        m.insert(
            "Pop cyan inverted",
            [
                [254, 255, 255],
                [252, 255, 255],
                [251, 255, 255],
                [249, 255, 255],
                [247, 255, 255],
                [246, 255, 255],
                [244, 255, 255],
                [242, 255, 255],
                [241, 255, 255],
                [239, 255, 255],
                [237, 255, 255],
                [236, 255, 255],
                [234, 255, 255],
                [232, 255, 255],
                [231, 255, 255],
                [229, 255, 255],
                [227, 255, 255],
                [226, 255, 255],
                [224, 255, 255],
                [222, 255, 255],
                [221, 255, 255],
                [219, 255, 255],
                [217, 255, 255],
                [216, 255, 255],
                [214, 255, 255],
                [212, 255, 255],
                [211, 255, 255],
                [209, 255, 255],
                [207, 255, 255],
                [206, 255, 255],
                [204, 255, 255],
                [202, 255, 255],
                [201, 255, 255],
                [199, 255, 255],
                [197, 255, 255],
                [196, 255, 255],
                [194, 255, 255],
                [192, 255, 255],
                [191, 255, 255],
                [189, 255, 255],
                [187, 255, 255],
                [186, 255, 255],
                [184, 255, 255],
                [183, 255, 255],
                [181, 255, 255],
                [179, 255, 255],
                [178, 255, 255],
                [176, 255, 255],
                [174, 255, 255],
                [173, 254, 254],
                [171, 254, 254],
                [169, 253, 253],
                [168, 252, 252],
                [166, 251, 251],
                [164, 251, 251],
                [163, 250, 250],
                [161, 249, 249],
                [159, 249, 249],
                [158, 248, 248],
                [156, 247, 247],
                [154, 246, 246],
                [153, 246, 246],
                [151, 245, 245],
                [149, 244, 244],
                [148, 244, 244],
                [146, 243, 243],
                [144, 242, 242],
                [143, 241, 241],
                [141, 241, 241],
                [139, 240, 240],
                [138, 239, 239],
                [136, 239, 239],
                [134, 238, 238],
                [133, 237, 237],
                [131, 236, 236],
                [129, 236, 236],
                [128, 235, 235],
                [126, 234, 234],
                [124, 234, 234],
                [123, 233, 233],
                [121, 232, 232],
                [119, 232, 232],
                [118, 231, 231],
                [116, 230, 230],
                [114, 229, 229],
                [113, 229, 229],
                [111, 228, 228],
                [109, 227, 227],
                [108, 227, 227],
                [106, 226, 226],
                [104, 225, 225],
                [103, 225, 225],
                [101, 224, 224],
                [99, 223, 223],
                [98, 222, 222],
                [96, 222, 222],
                [94, 221, 221],
                [93, 220, 220],
                [91, 220, 220],
                [89, 219, 219],
                [88, 218, 218],
                [86, 217, 217],
                [84, 217, 217],
                [83, 216, 216],
                [81, 215, 215],
                [79, 215, 215],
                [78, 214, 214],
                [76, 213, 213],
                [74, 212, 212],
                [73, 212, 212],
                [71, 211, 211],
                [69, 210, 210],
                [68, 210, 210],
                [66, 209, 209],
                [64, 208, 208],
                [63, 207, 207],
                [61, 207, 207],
                [59, 206, 206],
                [58, 205, 205],
                [56, 204, 204],
                [54, 204, 204],
                [53, 203, 203],
                [51, 202, 202],
                [49, 201, 201],
                [48, 201, 201],
                [46, 200, 200],
                [44, 199, 199],
                [43, 198, 198],
                [41, 197, 197],
                [40, 197, 197],
                [38, 196, 196],
                [36, 195, 195],
                [35, 194, 194],
                [33, 193, 193],
                [31, 192, 192],
                [30, 191, 191],
                [28, 191, 191],
                [26, 190, 190],
                [25, 189, 189],
                [23, 188, 188],
                [21, 187, 187],
                [20, 186, 186],
                [18, 185, 185],
                [16, 184, 184],
                [15, 183, 183],
                [13, 182, 182],
                [11, 181, 181],
                [10, 180, 180],
                [8, 179, 179],
                [6, 178, 178],
                [5, 177, 177],
                [3, 176, 176],
                [1, 175, 175],
                [0, 174, 174],
                [0, 173, 173],
                [0, 172, 172],
                [0, 171, 171],
                [0, 170, 170],
                [0, 169, 169],
                [0, 168, 168],
                [0, 166, 166],
                [0, 165, 165],
                [0, 164, 164],
                [0, 163, 163],
                [0, 162, 162],
                [0, 161, 161],
                [0, 159, 159],
                [0, 158, 158],
                [0, 157, 157],
                [0, 156, 156],
                [0, 155, 155],
                [0, 153, 153],
                [0, 152, 152],
                [0, 151, 151],
                [0, 150, 150],
                [0, 148, 148],
                [0, 147, 147],
                [0, 146, 146],
                [0, 144, 144],
                [0, 143, 143],
                [0, 142, 142],
                [0, 140, 140],
                [0, 139, 139],
                [0, 137, 137],
                [0, 136, 136],
                [0, 135, 135],
                [0, 133, 133],
                [0, 132, 132],
                [0, 130, 130],
                [0, 129, 129],
                [0, 127, 127],
                [0, 126, 126],
                [0, 124, 124],
                [0, 123, 123],
                [0, 121, 121],
                [0, 120, 120],
                [0, 118, 118],
                [0, 117, 117],
                [0, 115, 115],
                [0, 114, 114],
                [0, 112, 112],
                [0, 110, 110],
                [0, 109, 109],
                [0, 107, 107],
                [0, 105, 105],
                [0, 104, 104],
                [0, 102, 102],
                [0, 100, 100],
                [0, 99, 99],
                [0, 97, 97],
                [0, 95, 95],
                [0, 93, 93],
                [0, 91, 91],
                [0, 90, 90],
                [0, 88, 88],
                [0, 86, 86],
                [0, 84, 84],
                [0, 82, 82],
                [0, 80, 80],
                [0, 79, 79],
                [0, 77, 77],
                [0, 75, 75],
                [0, 73, 73],
                [0, 71, 71],
                [0, 69, 69],
                [0, 67, 67],
                [0, 65, 65],
                [0, 63, 63],
                [0, 61, 61],
                [0, 59, 59],
                [0, 57, 57],
                [0, 55, 55],
                [0, 53, 53],
                [0, 51, 51],
                [0, 48, 48],
                [0, 46, 46],
                [0, 44, 44],
                [0, 42, 42],
                [0, 40, 40],
                [0, 38, 38],
                [0, 35, 35],
                [0, 33, 33],
                [0, 31, 31],
                [0, 29, 29],
                [0, 26, 26],
                [0, 24, 24],
                [0, 22, 22],
                [0, 19, 19],
                [0, 17, 17],
                [0, 15, 15],
                [0, 12, 12],
                [0, 10, 10],
                [0, 7, 7],
                [0, 5, 5],
                [0, 2, 2],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop green",
            [
                [0, 0, 0],
                [0, 4, 0],
                [0, 8, 0],
                [0, 12, 0],
                [0, 16, 0],
                [0, 19, 0],
                [0, 23, 0],
                [0, 27, 0],
                [0, 31, 0],
                [0, 34, 0],
                [0, 38, 0],
                [0, 41, 0],
                [0, 45, 0],
                [0, 48, 0],
                [0, 52, 0],
                [0, 55, 0],
                [0, 58, 0],
                [0, 61, 0],
                [0, 65, 0],
                [0, 68, 0],
                [0, 71, 0],
                [0, 74, 0],
                [0, 77, 0],
                [0, 80, 0],
                [0, 83, 0],
                [0, 86, 0],
                [0, 89, 0],
                [0, 92, 0],
                [0, 95, 0],
                [0, 98, 0],
                [0, 100, 0],
                [0, 103, 0],
                [0, 106, 0],
                [0, 109, 0],
                [0, 111, 0],
                [0, 114, 0],
                [0, 116, 0],
                [0, 119, 0],
                [0, 121, 0],
                [0, 124, 0],
                [0, 126, 0],
                [0, 129, 0],
                [0, 131, 0],
                [0, 133, 0],
                [0, 135, 0],
                [0, 138, 0],
                [0, 140, 0],
                [0, 142, 0],
                [0, 144, 0],
                [0, 146, 0],
                [0, 148, 0],
                [0, 151, 0],
                [0, 153, 0],
                [0, 155, 0],
                [0, 157, 0],
                [0, 159, 0],
                [0, 160, 0],
                [0, 162, 0],
                [0, 164, 0],
                [0, 166, 0],
                [0, 168, 0],
                [0, 170, 0],
                [0, 171, 0],
                [0, 173, 0],
                [0, 175, 0],
                [2, 176, 0],
                [3, 178, 0],
                [4, 180, 0],
                [6, 181, 0],
                [7, 183, 0],
                [8, 184, 0],
                [10, 186, 0],
                [11, 187, 0],
                [12, 189, 0],
                [14, 190, 0],
                [15, 192, 0],
                [16, 193, 0],
                [18, 194, 0],
                [19, 196, 0],
                [20, 197, 0],
                [22, 198, 0],
                [23, 200, 0],
                [24, 201, 0],
                [26, 202, 0],
                [27, 203, 0],
                [28, 205, 0],
                [30, 206, 0],
                [31, 207, 0],
                [32, 208, 0],
                [34, 209, 0],
                [35, 210, 0],
                [36, 211, 0],
                [38, 212, 0],
                [39, 213, 1],
                [40, 214, 1],
                [42, 215, 1],
                [43, 216, 1],
                [44, 217, 1],
                [46, 218, 1],
                [47, 219, 2],
                [48, 220, 2],
                [50, 221, 2],
                [51, 222, 3],
                [52, 223, 3],
                [54, 224, 3],
                [55, 224, 4],
                [56, 225, 4],
                [58, 226, 4],
                [59, 227, 5],
                [60, 228, 5],
                [62, 228, 6],
                [63, 229, 6],
                [64, 230, 6],
                [66, 230, 7],
                [67, 231, 7],
                [68, 232, 8],
                [70, 232, 8],
                [71, 233, 9],
                [72, 234, 10],
                [74, 234, 10],
                [75, 235, 11],
                [76, 236, 11],
                [78, 236, 12],
                [79, 237, 13],
                [80, 237, 13],
                [82, 238, 14],
                [83, 238, 15],
                [84, 239, 16],
                [86, 239, 16],
                [87, 240, 17],
                [88, 240, 18],
                [90, 241, 19],
                [91, 241, 19],
                [92, 242, 20],
                [94, 242, 21],
                [95, 242, 22],
                [96, 243, 23],
                [98, 243, 24],
                [99, 244, 25],
                [100, 244, 26],
                [102, 244, 27],
                [103, 245, 28],
                [104, 245, 29],
                [106, 246, 30],
                [107, 246, 31],
                [108, 246, 32],
                [110, 246, 33],
                [111, 247, 34],
                [112, 247, 35],
                [114, 247, 36],
                [115, 248, 37],
                [116, 248, 38],
                [118, 248, 40],
                [119, 248, 41],
                [120, 249, 42],
                [122, 249, 43],
                [123, 249, 44],
                [124, 249, 46],
                [126, 250, 47],
                [127, 250, 48],
                [128, 250, 50],
                [130, 250, 51],
                [131, 250, 52],
                [132, 251, 54],
                [134, 251, 55],
                [135, 251, 56],
                [136, 251, 58],
                [138, 251, 59],
                [139, 252, 61],
                [140, 252, 62],
                [142, 252, 64],
                [143, 252, 65],
                [144, 252, 67],
                [146, 252, 68],
                [147, 252, 70],
                [148, 253, 71],
                [150, 253, 73],
                [151, 253, 75],
                [152, 253, 76],
                [154, 253, 78],
                [155, 253, 80],
                [156, 253, 81],
                [158, 253, 83],
                [159, 253, 85],
                [160, 253, 86],
                [162, 254, 88],
                [163, 254, 90],
                [164, 254, 92],
                [166, 254, 94],
                [167, 254, 95],
                [168, 254, 97],
                [170, 254, 99],
                [171, 254, 101],
                [172, 254, 103],
                [174, 254, 105],
                [175, 254, 107],
                [176, 254, 109],
                [178, 254, 111],
                [179, 254, 113],
                [180, 254, 115],
                [182, 254, 117],
                [183, 254, 119],
                [184, 255, 121],
                [186, 255, 123],
                [187, 255, 125],
                [188, 255, 127],
                [190, 255, 129],
                [191, 255, 131],
                [192, 255, 133],
                [194, 255, 136],
                [195, 255, 138],
                [196, 255, 140],
                [198, 255, 142],
                [199, 255, 145],
                [200, 255, 147],
                [202, 255, 149],
                [203, 255, 151],
                [204, 255, 154],
                [206, 255, 156],
                [207, 255, 158],
                [208, 255, 161],
                [210, 255, 163],
                [211, 255, 166],
                [212, 255, 168],
                [214, 255, 170],
                [215, 255, 173],
                [216, 255, 175],
                [218, 255, 178],
                [219, 255, 180],
                [220, 255, 183],
                [222, 255, 186],
                [223, 255, 188],
                [224, 255, 191],
                [226, 255, 193],
                [227, 255, 196],
                [228, 255, 199],
                [230, 255, 201],
                [231, 255, 204],
                [232, 255, 207],
                [234, 255, 209],
                [235, 255, 212],
                [236, 255, 215],
                [238, 255, 217],
                [239, 255, 220],
                [240, 255, 223],
                [242, 255, 226],
                [243, 255, 229],
                [244, 255, 232],
                [246, 255, 234],
                [247, 255, 237],
                [248, 255, 240],
                [250, 255, 243],
                [251, 255, 246],
                [252, 255, 249],
                [254, 255, 252],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop green inverted",
            [
                [255, 255, 255],
                [254, 255, 252],
                [252, 255, 249],
                [251, 255, 246],
                [250, 255, 243],
                [248, 255, 240],
                [247, 255, 237],
                [246, 255, 234],
                [244, 255, 232],
                [243, 255, 229],
                [242, 255, 226],
                [240, 255, 223],
                [239, 255, 220],
                [238, 255, 217],
                [236, 255, 215],
                [235, 255, 212],
                [234, 255, 209],
                [232, 255, 207],
                [231, 255, 204],
                [230, 255, 201],
                [228, 255, 199],
                [227, 255, 196],
                [226, 255, 193],
                [224, 255, 191],
                [223, 255, 188],
                [222, 255, 186],
                [220, 255, 183],
                [219, 255, 180],
                [218, 255, 178],
                [216, 255, 175],
                [215, 255, 173],
                [214, 255, 170],
                [212, 255, 168],
                [211, 255, 166],
                [210, 255, 163],
                [208, 255, 161],
                [207, 255, 158],
                [206, 255, 156],
                [204, 255, 154],
                [203, 255, 151],
                [202, 255, 149],
                [200, 255, 147],
                [199, 255, 145],
                [198, 255, 142],
                [196, 255, 140],
                [195, 255, 138],
                [194, 255, 136],
                [192, 255, 133],
                [191, 255, 131],
                [190, 255, 129],
                [188, 255, 127],
                [187, 255, 125],
                [186, 255, 123],
                [184, 255, 121],
                [183, 254, 119],
                [182, 254, 117],
                [180, 254, 115],
                [179, 254, 113],
                [178, 254, 111],
                [176, 254, 109],
                [175, 254, 107],
                [174, 254, 105],
                [172, 254, 103],
                [171, 254, 101],
                [170, 254, 99],
                [168, 254, 97],
                [167, 254, 95],
                [166, 254, 94],
                [164, 254, 92],
                [163, 254, 90],
                [162, 254, 88],
                [160, 253, 86],
                [159, 253, 85],
                [158, 253, 83],
                [156, 253, 81],
                [155, 253, 80],
                [154, 253, 78],
                [152, 253, 76],
                [151, 253, 75],
                [150, 253, 73],
                [148, 253, 71],
                [147, 252, 70],
                [146, 252, 68],
                [144, 252, 67],
                [143, 252, 65],
                [142, 252, 64],
                [140, 252, 62],
                [139, 252, 61],
                [138, 251, 59],
                [136, 251, 58],
                [135, 251, 56],
                [134, 251, 55],
                [132, 251, 54],
                [131, 250, 52],
                [130, 250, 51],
                [128, 250, 50],
                [127, 250, 48],
                [126, 250, 47],
                [124, 249, 46],
                [123, 249, 44],
                [122, 249, 43],
                [120, 249, 42],
                [119, 248, 41],
                [118, 248, 40],
                [116, 248, 38],
                [115, 248, 37],
                [114, 247, 36],
                [112, 247, 35],
                [111, 247, 34],
                [110, 246, 33],
                [108, 246, 32],
                [107, 246, 31],
                [106, 246, 30],
                [104, 245, 29],
                [103, 245, 28],
                [102, 244, 27],
                [100, 244, 26],
                [99, 244, 25],
                [98, 243, 24],
                [96, 243, 23],
                [95, 242, 22],
                [94, 242, 21],
                [92, 242, 20],
                [91, 241, 19],
                [90, 241, 19],
                [88, 240, 18],
                [87, 240, 17],
                [86, 239, 16],
                [84, 239, 16],
                [83, 238, 15],
                [82, 238, 14],
                [80, 237, 13],
                [79, 237, 13],
                [78, 236, 12],
                [76, 236, 11],
                [75, 235, 11],
                [74, 234, 10],
                [72, 234, 10],
                [71, 233, 9],
                [70, 232, 8],
                [68, 232, 8],
                [67, 231, 7],
                [66, 230, 7],
                [64, 230, 6],
                [63, 229, 6],
                [62, 228, 6],
                [60, 228, 5],
                [59, 227, 5],
                [58, 226, 4],
                [56, 225, 4],
                [55, 224, 4],
                [54, 224, 3],
                [52, 223, 3],
                [51, 222, 3],
                [50, 221, 2],
                [48, 220, 2],
                [47, 219, 2],
                [46, 218, 1],
                [44, 217, 1],
                [43, 216, 1],
                [42, 215, 1],
                [40, 214, 1],
                [39, 213, 1],
                [38, 212, 0],
                [36, 211, 0],
                [35, 210, 0],
                [34, 209, 0],
                [32, 208, 0],
                [31, 207, 0],
                [30, 206, 0],
                [28, 205, 0],
                [27, 203, 0],
                [26, 202, 0],
                [24, 201, 0],
                [23, 200, 0],
                [22, 198, 0],
                [20, 197, 0],
                [19, 196, 0],
                [18, 194, 0],
                [16, 193, 0],
                [15, 192, 0],
                [14, 190, 0],
                [12, 189, 0],
                [11, 187, 0],
                [10, 186, 0],
                [8, 184, 0],
                [7, 183, 0],
                [6, 181, 0],
                [4, 180, 0],
                [3, 178, 0],
                [2, 176, 0],
                [0, 175, 0],
                [0, 173, 0],
                [0, 171, 0],
                [0, 170, 0],
                [0, 168, 0],
                [0, 166, 0],
                [0, 164, 0],
                [0, 162, 0],
                [0, 160, 0],
                [0, 159, 0],
                [0, 157, 0],
                [0, 155, 0],
                [0, 153, 0],
                [0, 151, 0],
                [0, 148, 0],
                [0, 146, 0],
                [0, 144, 0],
                [0, 142, 0],
                [0, 140, 0],
                [0, 138, 0],
                [0, 135, 0],
                [0, 133, 0],
                [0, 131, 0],
                [0, 129, 0],
                [0, 126, 0],
                [0, 124, 0],
                [0, 121, 0],
                [0, 119, 0],
                [0, 116, 0],
                [0, 114, 0],
                [0, 111, 0],
                [0, 109, 0],
                [0, 106, 0],
                [0, 103, 0],
                [0, 100, 0],
                [0, 98, 0],
                [0, 95, 0],
                [0, 92, 0],
                [0, 89, 0],
                [0, 86, 0],
                [0, 83, 0],
                [0, 80, 0],
                [0, 77, 0],
                [0, 74, 0],
                [0, 71, 0],
                [0, 68, 0],
                [0, 65, 0],
                [0, 61, 0],
                [0, 58, 0],
                [0, 55, 0],
                [0, 52, 0],
                [0, 48, 0],
                [0, 45, 0],
                [0, 41, 0],
                [0, 38, 0],
                [0, 34, 0],
                [0, 31, 0],
                [0, 27, 0],
                [0, 23, 0],
                [0, 19, 0],
                [0, 16, 0],
                [0, 12, 0],
                [0, 8, 0],
                [0, 4, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop lavender inverted",
            [
                [255, 227, 255],
                [254, 224, 255],
                [252, 221, 255],
                [251, 219, 255],
                [250, 216, 255],
                [248, 214, 255],
                [247, 211, 255],
                [246, 208, 255],
                [244, 206, 255],
                [243, 203, 255],
                [242, 201, 255],
                [240, 198, 255],
                [239, 196, 255],
                [238, 193, 255],
                [236, 191, 255],
                [235, 188, 255],
                [234, 186, 255],
                [232, 184, 255],
                [231, 181, 255],
                [230, 179, 255],
                [228, 176, 255],
                [227, 174, 255],
                [226, 172, 255],
                [224, 169, 255],
                [223, 167, 255],
                [222, 165, 255],
                [220, 163, 255],
                [219, 160, 255],
                [218, 158, 255],
                [216, 156, 255],
                [215, 154, 255],
                [214, 152, 255],
                [212, 149, 255],
                [211, 147, 255],
                [210, 145, 255],
                [208, 143, 255],
                [207, 141, 255],
                [206, 139, 255],
                [204, 137, 255],
                [203, 135, 255],
                [202, 133, 255],
                [200, 131, 255],
                [199, 129, 255],
                [198, 127, 255],
                [196, 125, 255],
                [195, 123, 255],
                [194, 121, 255],
                [192, 119, 255],
                [191, 117, 255],
                [190, 115, 255],
                [188, 113, 255],
                [187, 111, 255],
                [186, 109, 255],
                [184, 107, 255],
                [183, 106, 254],
                [182, 104, 254],
                [180, 102, 254],
                [179, 100, 254],
                [178, 98, 254],
                [176, 97, 254],
                [175, 95, 254],
                [174, 93, 254],
                [172, 91, 254],
                [171, 90, 254],
                [170, 88, 254],
                [168, 86, 254],
                [167, 85, 254],
                [166, 83, 254],
                [164, 82, 254],
                [163, 80, 254],
                [162, 78, 254],
                [160, 77, 253],
                [159, 75, 253],
                [158, 74, 253],
                [156, 72, 253],
                [155, 71, 253],
                [154, 69, 253],
                [152, 68, 253],
                [151, 66, 253],
                [150, 65, 253],
                [148, 64, 253],
                [147, 62, 252],
                [146, 61, 252],
                [144, 59, 252],
                [143, 58, 252],
                [142, 57, 252],
                [140, 55, 252],
                [139, 54, 252],
                [138, 53, 251],
                [136, 51, 251],
                [135, 50, 251],
                [134, 49, 251],
                [132, 48, 251],
                [131, 47, 250],
                [130, 45, 250],
                [128, 44, 250],
                [127, 43, 250],
                [126, 42, 250],
                [124, 41, 249],
                [123, 40, 249],
                [122, 38, 249],
                [120, 37, 249],
                [119, 36, 248],
                [118, 35, 248],
                [116, 34, 248],
                [115, 33, 248],
                [114, 32, 247],
                [112, 31, 247],
                [111, 30, 247],
                [110, 29, 246],
                [108, 28, 246],
                [107, 27, 246],
                [106, 26, 246],
                [104, 25, 245],
                [103, 25, 245],
                [102, 24, 244],
                [100, 23, 244],
                [99, 22, 244],
                [98, 21, 243],
                [96, 20, 243],
                [95, 20, 242],
                [94, 19, 242],
                [92, 18, 242],
                [91, 17, 241],
                [90, 17, 241],
                [88, 16, 240],
                [87, 15, 240],
                [86, 15, 239],
                [84, 14, 239],
                [83, 13, 238],
                [82, 13, 238],
                [80, 12, 237],
                [79, 11, 237],
                [78, 11, 236],
                [76, 10, 236],
                [75, 10, 235],
                [74, 9, 234],
                [72, 9, 234],
                [71, 8, 233],
                [70, 8, 232],
                [68, 7, 232],
                [67, 7, 231],
                [66, 6, 230],
                [64, 6, 230],
                [63, 5, 229],
                [62, 5, 228],
                [60, 5, 228],
                [59, 4, 227],
                [58, 4, 226],
                [56, 3, 225],
                [55, 3, 224],
                [54, 3, 224],
                [52, 3, 223],
                [51, 2, 222],
                [50, 2, 221],
                [48, 2, 220],
                [47, 2, 219],
                [46, 1, 218],
                [44, 1, 217],
                [43, 1, 216],
                [42, 1, 215],
                [40, 1, 214],
                [39, 1, 213],
                [38, 0, 212],
                [36, 0, 211],
                [35, 0, 210],
                [34, 0, 209],
                [32, 0, 208],
                [31, 0, 207],
                [30, 0, 206],
                [28, 0, 205],
                [27, 0, 203],
                [26, 0, 202],
                [24, 0, 201],
                [23, 0, 200],
                [22, 0, 198],
                [20, 0, 197],
                [19, 0, 196],
                [18, 0, 194],
                [16, 0, 193],
                [15, 0, 192],
                [14, 0, 190],
                [12, 0, 189],
                [11, 0, 187],
                [10, 0, 186],
                [8, 0, 184],
                [7, 0, 183],
                [6, 0, 181],
                [4, 0, 180],
                [3, 0, 178],
                [2, 0, 176],
                [0, 0, 175],
                [0, 0, 173],
                [0, 0, 171],
                [0, 0, 170],
                [0, 0, 168],
                [0, 0, 166],
                [0, 0, 164],
                [0, 0, 162],
                [0, 0, 160],
                [0, 0, 159],
                [0, 0, 157],
                [0, 0, 155],
                [0, 0, 153],
                [0, 0, 151],
                [0, 0, 148],
                [0, 0, 146],
                [0, 0, 144],
                [0, 0, 142],
                [0, 0, 140],
                [0, 0, 138],
                [0, 0, 135],
                [0, 0, 133],
                [0, 0, 131],
                [0, 0, 129],
                [0, 0, 126],
                [0, 0, 124],
                [0, 0, 121],
                [0, 0, 119],
                [0, 0, 116],
                [0, 0, 114],
                [0, 0, 111],
                [0, 0, 109],
                [0, 0, 106],
                [0, 0, 103],
                [0, 0, 100],
                [0, 0, 98],
                [0, 0, 95],
                [0, 0, 92],
                [0, 0, 89],
                [0, 0, 86],
                [0, 0, 83],
                [0, 0, 80],
                [0, 0, 77],
                [0, 0, 74],
                [0, 0, 71],
                [0, 0, 68],
                [0, 0, 65],
                [0, 0, 61],
                [0, 0, 58],
                [0, 0, 55],
                [0, 0, 52],
                [0, 0, 48],
                [0, 0, 45],
                [0, 0, 41],
                [0, 0, 38],
                [0, 0, 34],
                [0, 0, 31],
                [0, 0, 27],
                [0, 0, 23],
                [0, 0, 19],
                [0, 0, 16],
                [0, 0, 12],
                [0, 0, 8],
                [0, 0, 4],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop magenta",
            [
                [0, 0, 0],
                [2, 0, 2],
                [5, 0, 5],
                [7, 0, 7],
                [10, 0, 10],
                [12, 0, 12],
                [15, 0, 15],
                [17, 0, 17],
                [19, 0, 19],
                [22, 0, 22],
                [24, 0, 24],
                [26, 0, 26],
                [29, 0, 29],
                [31, 0, 31],
                [33, 0, 33],
                [35, 0, 35],
                [38, 0, 38],
                [40, 0, 40],
                [42, 0, 42],
                [44, 0, 44],
                [46, 0, 46],
                [48, 0, 48],
                [51, 0, 51],
                [53, 0, 53],
                [55, 0, 55],
                [57, 0, 57],
                [59, 0, 59],
                [61, 0, 61],
                [63, 0, 63],
                [65, 0, 65],
                [67, 0, 67],
                [69, 0, 69],
                [71, 0, 71],
                [73, 0, 73],
                [75, 0, 75],
                [77, 0, 77],
                [79, 0, 79],
                [80, 0, 80],
                [82, 0, 82],
                [84, 0, 84],
                [86, 0, 86],
                [88, 0, 88],
                [90, 0, 90],
                [91, 0, 91],
                [93, 0, 93],
                [95, 0, 95],
                [97, 0, 97],
                [99, 0, 99],
                [100, 0, 100],
                [102, 0, 102],
                [104, 0, 104],
                [105, 0, 105],
                [107, 0, 107],
                [109, 0, 109],
                [110, 0, 110],
                [112, 0, 112],
                [114, 0, 114],
                [115, 0, 115],
                [117, 0, 117],
                [118, 0, 118],
                [120, 0, 120],
                [121, 0, 121],
                [123, 0, 123],
                [124, 0, 124],
                [126, 0, 126],
                [127, 0, 127],
                [129, 0, 129],
                [130, 0, 130],
                [132, 0, 132],
                [133, 0, 133],
                [135, 0, 135],
                [136, 0, 136],
                [137, 0, 137],
                [139, 0, 139],
                [140, 0, 140],
                [142, 0, 142],
                [143, 0, 143],
                [144, 0, 144],
                [146, 0, 146],
                [147, 0, 147],
                [148, 0, 148],
                [150, 0, 150],
                [151, 0, 151],
                [152, 0, 152],
                [153, 0, 153],
                [155, 0, 155],
                [156, 0, 156],
                [157, 0, 157],
                [158, 0, 158],
                [159, 0, 159],
                [161, 0, 161],
                [162, 0, 162],
                [163, 0, 163],
                [164, 0, 164],
                [165, 0, 165],
                [166, 0, 166],
                [168, 0, 168],
                [169, 0, 169],
                [170, 0, 170],
                [171, 0, 171],
                [172, 0, 172],
                [173, 0, 173],
                [174, 0, 174],
                [175, 1, 175],
                [176, 3, 176],
                [177, 5, 177],
                [178, 6, 178],
                [179, 8, 179],
                [180, 10, 180],
                [181, 11, 181],
                [182, 13, 182],
                [183, 15, 183],
                [184, 16, 184],
                [185, 18, 185],
                [186, 20, 186],
                [187, 21, 187],
                [188, 23, 188],
                [189, 25, 189],
                [190, 26, 190],
                [191, 28, 191],
                [191, 30, 191],
                [192, 31, 192],
                [193, 33, 193],
                [194, 35, 194],
                [195, 36, 195],
                [196, 38, 196],
                [197, 40, 197],
                [197, 41, 197],
                [198, 43, 198],
                [199, 44, 199],
                [200, 46, 200],
                [201, 48, 201],
                [201, 49, 201],
                [202, 51, 202],
                [203, 53, 203],
                [204, 54, 204],
                [204, 56, 204],
                [205, 58, 205],
                [206, 59, 206],
                [207, 61, 207],
                [207, 63, 207],
                [208, 64, 208],
                [209, 66, 209],
                [210, 68, 210],
                [210, 69, 210],
                [211, 71, 211],
                [212, 73, 212],
                [212, 74, 212],
                [213, 76, 213],
                [214, 78, 214],
                [215, 79, 215],
                [215, 81, 215],
                [216, 83, 216],
                [217, 84, 217],
                [217, 86, 217],
                [218, 88, 218],
                [219, 89, 219],
                [220, 91, 220],
                [220, 93, 220],
                [221, 94, 221],
                [222, 96, 222],
                [222, 98, 222],
                [223, 99, 223],
                [224, 101, 224],
                [225, 103, 225],
                [225, 104, 225],
                [226, 106, 226],
                [227, 108, 227],
                [227, 109, 227],
                [228, 111, 228],
                [229, 113, 229],
                [229, 114, 229],
                [230, 116, 230],
                [231, 118, 231],
                [232, 119, 232],
                [232, 121, 232],
                [233, 123, 233],
                [234, 124, 234],
                [234, 126, 234],
                [235, 128, 235],
                [236, 129, 236],
                [236, 131, 236],
                [237, 133, 237],
                [238, 134, 238],
                [239, 136, 239],
                [239, 138, 239],
                [240, 139, 240],
                [241, 141, 241],
                [241, 143, 241],
                [242, 144, 242],
                [243, 146, 243],
                [244, 148, 244],
                [244, 149, 244],
                [245, 151, 245],
                [246, 153, 246],
                [246, 154, 246],
                [247, 156, 247],
                [248, 158, 248],
                [249, 159, 249],
                [249, 161, 249],
                [250, 163, 250],
                [251, 164, 251],
                [251, 166, 251],
                [252, 168, 252],
                [253, 169, 253],
                [254, 171, 254],
                [254, 173, 254],
                [255, 174, 255],
                [255, 176, 255],
                [255, 178, 255],
                [255, 179, 255],
                [255, 181, 255],
                [255, 183, 255],
                [255, 184, 255],
                [255, 186, 255],
                [255, 187, 255],
                [255, 189, 255],
                [255, 191, 255],
                [255, 192, 255],
                [255, 194, 255],
                [255, 196, 255],
                [255, 197, 255],
                [255, 199, 255],
                [255, 201, 255],
                [255, 202, 255],
                [255, 204, 255],
                [255, 206, 255],
                [255, 207, 255],
                [255, 209, 255],
                [255, 211, 255],
                [255, 212, 255],
                [255, 214, 255],
                [255, 216, 255],
                [255, 217, 255],
                [255, 219, 255],
                [255, 221, 255],
                [255, 222, 255],
                [255, 224, 255],
                [255, 226, 255],
                [255, 227, 255],
                [255, 229, 255],
                [255, 231, 255],
                [255, 232, 255],
                [255, 234, 255],
                [255, 236, 255],
                [255, 237, 255],
                [255, 239, 255],
                [255, 241, 255],
                [255, 242, 255],
                [255, 244, 255],
                [255, 246, 255],
                [255, 247, 255],
                [255, 249, 255],
                [255, 251, 255],
                [255, 252, 255],
                [255, 254, 255],
            ],
        );

        m.insert(
            "Pop magenta inverted",
            [
                [255, 254, 255],
                [255, 252, 255],
                [255, 251, 255],
                [255, 249, 255],
                [255, 247, 255],
                [255, 246, 255],
                [255, 244, 255],
                [255, 242, 255],
                [255, 241, 255],
                [255, 239, 255],
                [255, 237, 255],
                [255, 236, 255],
                [255, 234, 255],
                [255, 232, 255],
                [255, 231, 255],
                [255, 229, 255],
                [255, 227, 255],
                [255, 226, 255],
                [255, 224, 255],
                [255, 222, 255],
                [255, 221, 255],
                [255, 219, 255],
                [255, 217, 255],
                [255, 216, 255],
                [255, 214, 255],
                [255, 212, 255],
                [255, 211, 255],
                [255, 209, 255],
                [255, 207, 255],
                [255, 206, 255],
                [255, 204, 255],
                [255, 202, 255],
                [255, 201, 255],
                [255, 199, 255],
                [255, 197, 255],
                [255, 196, 255],
                [255, 194, 255],
                [255, 192, 255],
                [255, 191, 255],
                [255, 189, 255],
                [255, 187, 255],
                [255, 186, 255],
                [255, 184, 255],
                [255, 183, 255],
                [255, 181, 255],
                [255, 179, 255],
                [255, 178, 255],
                [255, 176, 255],
                [255, 174, 255],
                [254, 173, 254],
                [254, 171, 254],
                [253, 169, 253],
                [252, 168, 252],
                [251, 166, 251],
                [251, 164, 251],
                [250, 163, 250],
                [249, 161, 249],
                [249, 159, 249],
                [248, 158, 248],
                [247, 156, 247],
                [246, 154, 246],
                [246, 153, 246],
                [245, 151, 245],
                [244, 149, 244],
                [244, 148, 244],
                [243, 146, 243],
                [242, 144, 242],
                [241, 143, 241],
                [241, 141, 241],
                [240, 139, 240],
                [239, 138, 239],
                [239, 136, 239],
                [238, 134, 238],
                [237, 133, 237],
                [236, 131, 236],
                [236, 129, 236],
                [235, 128, 235],
                [234, 126, 234],
                [234, 124, 234],
                [233, 123, 233],
                [232, 121, 232],
                [232, 119, 232],
                [231, 118, 231],
                [230, 116, 230],
                [229, 114, 229],
                [229, 113, 229],
                [228, 111, 228],
                [227, 109, 227],
                [227, 108, 227],
                [226, 106, 226],
                [225, 104, 225],
                [225, 103, 225],
                [224, 101, 224],
                [223, 99, 223],
                [222, 98, 222],
                [222, 96, 222],
                [221, 94, 221],
                [220, 93, 220],
                [220, 91, 220],
                [219, 89, 219],
                [218, 88, 218],
                [217, 86, 217],
                [217, 84, 217],
                [216, 83, 216],
                [215, 81, 215],
                [215, 79, 215],
                [214, 78, 214],
                [213, 76, 213],
                [212, 74, 212],
                [212, 73, 212],
                [211, 71, 211],
                [210, 69, 210],
                [210, 68, 210],
                [209, 66, 209],
                [208, 64, 208],
                [207, 63, 207],
                [207, 61, 207],
                [206, 59, 206],
                [205, 58, 205],
                [204, 56, 204],
                [204, 54, 204],
                [203, 53, 203],
                [202, 51, 202],
                [201, 49, 201],
                [201, 48, 201],
                [200, 46, 200],
                [199, 44, 199],
                [198, 43, 198],
                [197, 41, 197],
                [197, 40, 197],
                [196, 38, 196],
                [195, 36, 195],
                [194, 35, 194],
                [193, 33, 193],
                [192, 31, 192],
                [191, 30, 191],
                [191, 28, 191],
                [190, 26, 190],
                [189, 25, 189],
                [188, 23, 188],
                [187, 21, 187],
                [186, 20, 186],
                [185, 18, 185],
                [184, 16, 184],
                [183, 15, 183],
                [182, 13, 182],
                [181, 11, 181],
                [180, 10, 180],
                [179, 8, 179],
                [178, 6, 178],
                [177, 5, 177],
                [176, 3, 176],
                [175, 1, 175],
                [174, 0, 174],
                [173, 0, 173],
                [172, 0, 172],
                [171, 0, 171],
                [170, 0, 170],
                [169, 0, 169],
                [168, 0, 168],
                [166, 0, 166],
                [165, 0, 165],
                [164, 0, 164],
                [163, 0, 163],
                [162, 0, 162],
                [161, 0, 161],
                [159, 0, 159],
                [158, 0, 158],
                [157, 0, 157],
                [156, 0, 156],
                [155, 0, 155],
                [153, 0, 153],
                [152, 0, 152],
                [151, 0, 151],
                [150, 0, 150],
                [148, 0, 148],
                [147, 0, 147],
                [146, 0, 146],
                [144, 0, 144],
                [143, 0, 143],
                [142, 0, 142],
                [140, 0, 140],
                [139, 0, 139],
                [137, 0, 137],
                [136, 0, 136],
                [135, 0, 135],
                [133, 0, 133],
                [132, 0, 132],
                [130, 0, 130],
                [129, 0, 129],
                [127, 0, 127],
                [126, 0, 126],
                [124, 0, 124],
                [123, 0, 123],
                [121, 0, 121],
                [120, 0, 120],
                [118, 0, 118],
                [117, 0, 117],
                [115, 0, 115],
                [114, 0, 114],
                [112, 0, 112],
                [110, 0, 110],
                [109, 0, 109],
                [107, 0, 107],
                [105, 0, 105],
                [104, 0, 104],
                [102, 0, 102],
                [100, 0, 100],
                [99, 0, 99],
                [97, 0, 97],
                [95, 0, 95],
                [93, 0, 93],
                [91, 0, 91],
                [90, 0, 90],
                [88, 0, 88],
                [86, 0, 86],
                [84, 0, 84],
                [82, 0, 82],
                [80, 0, 80],
                [79, 0, 79],
                [77, 0, 77],
                [75, 0, 75],
                [73, 0, 73],
                [71, 0, 71],
                [69, 0, 69],
                [67, 0, 67],
                [65, 0, 65],
                [63, 0, 63],
                [61, 0, 61],
                [59, 0, 59],
                [57, 0, 57],
                [55, 0, 55],
                [53, 0, 53],
                [51, 0, 51],
                [48, 0, 48],
                [46, 0, 46],
                [44, 0, 44],
                [42, 0, 42],
                [40, 0, 40],
                [38, 0, 38],
                [35, 0, 35],
                [33, 0, 33],
                [31, 0, 31],
                [29, 0, 29],
                [26, 0, 26],
                [24, 0, 24],
                [22, 0, 22],
                [19, 0, 19],
                [17, 0, 17],
                [15, 0, 15],
                [12, 0, 12],
                [10, 0, 10],
                [7, 0, 7],
                [5, 0, 5],
                [2, 0, 2],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop mint",
            [
                [0, 0, 0],
                [0, 4, 0],
                [0, 8, 0],
                [0, 12, 0],
                [0, 16, 0],
                [0, 19, 0],
                [0, 23, 0],
                [0, 27, 0],
                [0, 31, 0],
                [0, 34, 0],
                [0, 38, 0],
                [0, 41, 0],
                [0, 45, 0],
                [0, 48, 0],
                [0, 52, 0],
                [0, 55, 0],
                [0, 58, 0],
                [0, 61, 0],
                [0, 65, 0],
                [0, 68, 0],
                [0, 71, 0],
                [0, 74, 0],
                [0, 77, 0],
                [0, 80, 0],
                [0, 83, 0],
                [0, 86, 0],
                [0, 89, 0],
                [0, 92, 0],
                [0, 95, 0],
                [0, 98, 0],
                [0, 100, 0],
                [0, 103, 0],
                [0, 106, 0],
                [0, 109, 0],
                [0, 111, 0],
                [0, 114, 0],
                [0, 116, 0],
                [0, 119, 0],
                [0, 121, 0],
                [0, 124, 0],
                [0, 126, 0],
                [0, 129, 0],
                [0, 131, 0],
                [0, 133, 0],
                [0, 135, 0],
                [0, 138, 0],
                [0, 140, 0],
                [0, 142, 0],
                [0, 144, 0],
                [0, 146, 0],
                [0, 148, 0],
                [0, 151, 0],
                [0, 153, 0],
                [0, 155, 0],
                [0, 157, 0],
                [0, 159, 0],
                [0, 160, 0],
                [0, 162, 0],
                [0, 164, 0],
                [0, 166, 0],
                [0, 168, 0],
                [0, 170, 0],
                [0, 171, 0],
                [0, 173, 0],
                [0, 175, 0],
                [0, 176, 2],
                [0, 178, 3],
                [0, 180, 4],
                [0, 181, 6],
                [0, 183, 7],
                [0, 184, 8],
                [0, 186, 10],
                [0, 187, 11],
                [0, 189, 12],
                [0, 190, 14],
                [0, 192, 15],
                [0, 193, 16],
                [0, 194, 18],
                [0, 196, 19],
                [0, 197, 20],
                [0, 198, 22],
                [0, 200, 23],
                [0, 201, 24],
                [0, 202, 26],
                [0, 203, 27],
                [0, 205, 28],
                [0, 206, 30],
                [0, 207, 31],
                [0, 208, 32],
                [0, 209, 34],
                [0, 210, 35],
                [0, 211, 36],
                [0, 212, 38],
                [1, 213, 39],
                [1, 214, 40],
                [1, 215, 42],
                [1, 216, 43],
                [1, 217, 44],
                [1, 218, 46],
                [2, 219, 47],
                [2, 220, 48],
                [2, 221, 50],
                [3, 222, 51],
                [3, 223, 52],
                [3, 224, 54],
                [4, 224, 55],
                [4, 225, 56],
                [4, 226, 58],
                [5, 227, 59],
                [5, 228, 60],
                [6, 228, 62],
                [6, 229, 63],
                [6, 230, 64],
                [7, 230, 66],
                [7, 231, 67],
                [8, 232, 68],
                [8, 232, 70],
                [9, 233, 71],
                [10, 234, 72],
                [10, 234, 74],
                [11, 235, 75],
                [11, 236, 76],
                [12, 236, 78],
                [13, 237, 79],
                [13, 237, 80],
                [14, 238, 82],
                [15, 238, 83],
                [16, 239, 84],
                [16, 239, 86],
                [17, 240, 87],
                [18, 240, 88],
                [19, 241, 90],
                [19, 241, 91],
                [20, 242, 92],
                [21, 242, 94],
                [22, 242, 95],
                [23, 243, 96],
                [24, 243, 98],
                [25, 244, 99],
                [26, 244, 100],
                [27, 244, 102],
                [28, 245, 103],
                [29, 245, 104],
                [30, 246, 106],
                [31, 246, 107],
                [32, 246, 108],
                [33, 246, 110],
                [34, 247, 111],
                [35, 247, 112],
                [36, 247, 114],
                [37, 248, 115],
                [38, 248, 116],
                [40, 248, 118],
                [41, 248, 119],
                [42, 249, 120],
                [43, 249, 122],
                [44, 249, 123],
                [46, 249, 124],
                [47, 250, 126],
                [48, 250, 127],
                [50, 250, 128],
                [51, 250, 130],
                [52, 250, 131],
                [54, 251, 132],
                [55, 251, 134],
                [56, 251, 135],
                [58, 251, 136],
                [59, 251, 138],
                [61, 252, 139],
                [62, 252, 140],
                [64, 252, 142],
                [65, 252, 143],
                [67, 252, 144],
                [68, 252, 146],
                [70, 252, 147],
                [71, 253, 148],
                [73, 253, 150],
                [75, 253, 151],
                [76, 253, 152],
                [78, 253, 154],
                [80, 253, 155],
                [81, 253, 156],
                [83, 253, 158],
                [85, 253, 159],
                [86, 253, 160],
                [88, 254, 162],
                [90, 254, 163],
                [92, 254, 164],
                [94, 254, 166],
                [95, 254, 167],
                [97, 254, 168],
                [99, 254, 170],
                [101, 254, 171],
                [103, 254, 172],
                [105, 254, 174],
                [107, 254, 175],
                [109, 254, 176],
                [111, 254, 178],
                [113, 254, 179],
                [115, 254, 180],
                [117, 254, 182],
                [119, 254, 183],
                [121, 255, 184],
                [123, 255, 186],
                [125, 255, 187],
                [127, 255, 188],
                [129, 255, 190],
                [131, 255, 191],
                [133, 255, 192],
                [136, 255, 194],
                [138, 255, 195],
                [140, 255, 196],
                [142, 255, 198],
                [145, 255, 199],
                [147, 255, 200],
                [149, 255, 202],
                [151, 255, 203],
                [154, 255, 204],
                [156, 255, 206],
                [158, 255, 207],
                [161, 255, 208],
                [163, 255, 210],
                [166, 255, 211],
                [168, 255, 212],
                [170, 255, 214],
                [173, 255, 215],
                [175, 255, 216],
                [178, 255, 218],
                [180, 255, 219],
                [183, 255, 220],
                [186, 255, 222],
                [188, 255, 223],
                [191, 255, 224],
                [193, 255, 226],
                [196, 255, 227],
                [199, 255, 228],
                [201, 255, 230],
                [204, 255, 231],
                [207, 255, 232],
                [209, 255, 234],
                [212, 255, 235],
                [215, 255, 236],
                [217, 255, 238],
                [220, 255, 239],
                [223, 255, 240],
                [226, 255, 242],
                [229, 255, 243],
                [232, 255, 244],
                [234, 255, 246],
                [237, 255, 247],
                [240, 255, 248],
                [243, 255, 250],
                [246, 255, 251],
                [249, 255, 252],
                [252, 255, 254],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop mint inverted",
            [
                [255, 255, 255],
                [252, 255, 254],
                [249, 255, 252],
                [246, 255, 251],
                [243, 255, 250],
                [240, 255, 248],
                [237, 255, 247],
                [234, 255, 246],
                [232, 255, 244],
                [229, 255, 243],
                [226, 255, 242],
                [223, 255, 240],
                [220, 255, 239],
                [217, 255, 238],
                [215, 255, 236],
                [212, 255, 235],
                [209, 255, 234],
                [207, 255, 232],
                [204, 255, 231],
                [201, 255, 230],
                [199, 255, 228],
                [196, 255, 227],
                [193, 255, 226],
                [191, 255, 224],
                [188, 255, 223],
                [186, 255, 222],
                [183, 255, 220],
                [180, 255, 219],
                [178, 255, 218],
                [175, 255, 216],
                [173, 255, 215],
                [170, 255, 214],
                [168, 255, 212],
                [166, 255, 211],
                [163, 255, 210],
                [161, 255, 208],
                [158, 255, 207],
                [156, 255, 206],
                [154, 255, 204],
                [151, 255, 203],
                [149, 255, 202],
                [147, 255, 200],
                [145, 255, 199],
                [142, 255, 198],
                [140, 255, 196],
                [138, 255, 195],
                [136, 255, 194],
                [133, 255, 192],
                [131, 255, 191],
                [129, 255, 190],
                [127, 255, 188],
                [125, 255, 187],
                [123, 255, 186],
                [121, 255, 184],
                [119, 254, 183],
                [117, 254, 182],
                [115, 254, 180],
                [113, 254, 179],
                [111, 254, 178],
                [109, 254, 176],
                [107, 254, 175],
                [105, 254, 174],
                [103, 254, 172],
                [101, 254, 171],
                [99, 254, 170],
                [97, 254, 168],
                [95, 254, 167],
                [94, 254, 166],
                [92, 254, 164],
                [90, 254, 163],
                [88, 254, 162],
                [86, 253, 160],
                [85, 253, 159],
                [83, 253, 158],
                [81, 253, 156],
                [80, 253, 155],
                [78, 253, 154],
                [76, 253, 152],
                [75, 253, 151],
                [73, 253, 150],
                [71, 253, 148],
                [70, 252, 147],
                [68, 252, 146],
                [67, 252, 144],
                [65, 252, 143],
                [64, 252, 142],
                [62, 252, 140],
                [61, 252, 139],
                [59, 251, 138],
                [58, 251, 136],
                [56, 251, 135],
                [55, 251, 134],
                [54, 251, 132],
                [52, 250, 131],
                [51, 250, 130],
                [50, 250, 128],
                [48, 250, 127],
                [47, 250, 126],
                [46, 249, 124],
                [44, 249, 123],
                [43, 249, 122],
                [42, 249, 120],
                [41, 248, 119],
                [40, 248, 118],
                [38, 248, 116],
                [37, 248, 115],
                [36, 247, 114],
                [35, 247, 112],
                [34, 247, 111],
                [33, 246, 110],
                [32, 246, 108],
                [31, 246, 107],
                [30, 246, 106],
                [29, 245, 104],
                [28, 245, 103],
                [27, 244, 102],
                [26, 244, 100],
                [25, 244, 99],
                [24, 243, 98],
                [23, 243, 96],
                [22, 242, 95],
                [21, 242, 94],
                [20, 242, 92],
                [19, 241, 91],
                [19, 241, 90],
                [18, 240, 88],
                [17, 240, 87],
                [16, 239, 86],
                [16, 239, 84],
                [15, 238, 83],
                [14, 238, 82],
                [13, 237, 80],
                [13, 237, 79],
                [12, 236, 78],
                [11, 236, 76],
                [11, 235, 75],
                [10, 234, 74],
                [10, 234, 72],
                [9, 233, 71],
                [8, 232, 70],
                [8, 232, 68],
                [7, 231, 67],
                [7, 230, 66],
                [6, 230, 64],
                [6, 229, 63],
                [6, 228, 62],
                [5, 228, 60],
                [5, 227, 59],
                [4, 226, 58],
                [4, 225, 56],
                [4, 224, 55],
                [3, 224, 54],
                [3, 223, 52],
                [3, 222, 51],
                [2, 221, 50],
                [2, 220, 48],
                [2, 219, 47],
                [1, 218, 46],
                [1, 217, 44],
                [1, 216, 43],
                [1, 215, 42],
                [1, 214, 40],
                [1, 213, 39],
                [0, 212, 38],
                [0, 211, 36],
                [0, 210, 35],
                [0, 209, 34],
                [0, 208, 32],
                [0, 207, 31],
                [0, 206, 30],
                [0, 205, 28],
                [0, 203, 27],
                [0, 202, 26],
                [0, 201, 24],
                [0, 200, 23],
                [0, 198, 22],
                [0, 197, 20],
                [0, 196, 19],
                [0, 194, 18],
                [0, 193, 16],
                [0, 192, 15],
                [0, 190, 14],
                [0, 189, 12],
                [0, 187, 11],
                [0, 186, 10],
                [0, 184, 8],
                [0, 183, 7],
                [0, 181, 6],
                [0, 180, 4],
                [0, 178, 3],
                [0, 176, 2],
                [0, 175, 0],
                [0, 173, 0],
                [0, 171, 0],
                [0, 170, 0],
                [0, 168, 0],
                [0, 166, 0],
                [0, 164, 0],
                [0, 162, 0],
                [0, 160, 0],
                [0, 159, 0],
                [0, 157, 0],
                [0, 155, 0],
                [0, 153, 0],
                [0, 151, 0],
                [0, 148, 0],
                [0, 146, 0],
                [0, 144, 0],
                [0, 142, 0],
                [0, 140, 0],
                [0, 138, 0],
                [0, 135, 0],
                [0, 133, 0],
                [0, 131, 0],
                [0, 129, 0],
                [0, 126, 0],
                [0, 124, 0],
                [0, 121, 0],
                [0, 119, 0],
                [0, 116, 0],
                [0, 114, 0],
                [0, 111, 0],
                [0, 109, 0],
                [0, 106, 0],
                [0, 103, 0],
                [0, 100, 0],
                [0, 98, 0],
                [0, 95, 0],
                [0, 92, 0],
                [0, 89, 0],
                [0, 86, 0],
                [0, 83, 0],
                [0, 80, 0],
                [0, 77, 0],
                [0, 74, 0],
                [0, 71, 0],
                [0, 68, 0],
                [0, 65, 0],
                [0, 61, 0],
                [0, 58, 0],
                [0, 55, 0],
                [0, 52, 0],
                [0, 48, 0],
                [0, 45, 0],
                [0, 41, 0],
                [0, 38, 0],
                [0, 34, 0],
                [0, 31, 0],
                [0, 27, 0],
                [0, 23, 0],
                [0, 19, 0],
                [0, 16, 0],
                [0, 12, 0],
                [0, 8, 0],
                [0, 4, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop purple",
            [
                [0, 0, 0],
                [0, 0, 4],
                [0, 0, 8],
                [0, 0, 12],
                [0, 0, 16],
                [0, 0, 19],
                [0, 0, 23],
                [0, 0, 27],
                [0, 0, 31],
                [0, 0, 34],
                [0, 0, 38],
                [0, 0, 41],
                [0, 0, 45],
                [0, 0, 48],
                [0, 0, 52],
                [0, 0, 55],
                [0, 0, 58],
                [0, 0, 61],
                [0, 0, 65],
                [0, 0, 68],
                [0, 0, 71],
                [0, 0, 74],
                [0, 0, 77],
                [0, 0, 80],
                [0, 0, 83],
                [0, 0, 86],
                [0, 0, 89],
                [0, 0, 92],
                [0, 0, 95],
                [0, 0, 98],
                [0, 0, 100],
                [0, 0, 103],
                [0, 0, 106],
                [0, 0, 109],
                [0, 0, 111],
                [0, 0, 114],
                [0, 0, 116],
                [0, 0, 119],
                [0, 0, 121],
                [0, 0, 124],
                [0, 0, 126],
                [0, 0, 129],
                [0, 0, 131],
                [0, 0, 133],
                [0, 0, 135],
                [0, 0, 138],
                [0, 0, 140],
                [0, 0, 142],
                [0, 0, 144],
                [0, 0, 146],
                [0, 0, 148],
                [0, 0, 151],
                [0, 0, 153],
                [0, 0, 155],
                [0, 0, 157],
                [0, 0, 159],
                [0, 0, 160],
                [0, 0, 162],
                [0, 0, 164],
                [0, 0, 166],
                [0, 0, 168],
                [0, 0, 170],
                [0, 0, 171],
                [0, 0, 173],
                [0, 0, 175],
                [2, 0, 176],
                [3, 0, 178],
                [4, 0, 180],
                [6, 0, 181],
                [7, 0, 183],
                [8, 0, 184],
                [10, 0, 186],
                [11, 0, 187],
                [12, 0, 189],
                [14, 0, 190],
                [15, 0, 192],
                [16, 0, 193],
                [18, 0, 194],
                [19, 0, 196],
                [20, 0, 197],
                [22, 0, 198],
                [23, 0, 200],
                [24, 0, 201],
                [26, 0, 202],
                [27, 0, 203],
                [28, 0, 205],
                [30, 0, 206],
                [31, 0, 207],
                [32, 0, 208],
                [34, 0, 209],
                [35, 0, 210],
                [36, 0, 211],
                [38, 0, 212],
                [39, 1, 213],
                [40, 1, 214],
                [42, 1, 215],
                [43, 1, 216],
                [44, 1, 217],
                [46, 1, 218],
                [47, 2, 219],
                [48, 2, 220],
                [50, 2, 221],
                [51, 3, 222],
                [52, 3, 223],
                [54, 3, 224],
                [55, 4, 224],
                [56, 4, 225],
                [58, 4, 226],
                [59, 5, 227],
                [60, 5, 228],
                [62, 6, 228],
                [63, 6, 229],
                [64, 6, 230],
                [66, 7, 230],
                [67, 7, 231],
                [68, 8, 232],
                [70, 8, 232],
                [71, 9, 233],
                [72, 10, 234],
                [74, 10, 234],
                [75, 11, 235],
                [76, 11, 236],
                [78, 12, 236],
                [79, 13, 237],
                [80, 13, 237],
                [82, 14, 238],
                [83, 15, 238],
                [84, 16, 239],
                [86, 16, 239],
                [87, 17, 240],
                [88, 18, 240],
                [90, 19, 241],
                [91, 19, 241],
                [92, 20, 242],
                [94, 21, 242],
                [95, 22, 242],
                [96, 23, 243],
                [98, 24, 243],
                [99, 25, 244],
                [100, 26, 244],
                [102, 27, 244],
                [103, 28, 245],
                [104, 29, 245],
                [106, 30, 246],
                [107, 31, 246],
                [108, 32, 246],
                [110, 33, 246],
                [111, 34, 247],
                [112, 35, 247],
                [114, 36, 247],
                [115, 37, 248],
                [116, 38, 248],
                [118, 40, 248],
                [119, 41, 248],
                [120, 42, 249],
                [122, 43, 249],
                [123, 44, 249],
                [124, 46, 249],
                [126, 47, 250],
                [127, 48, 250],
                [128, 50, 250],
                [130, 51, 250],
                [131, 52, 250],
                [132, 54, 251],
                [134, 55, 251],
                [135, 56, 251],
                [136, 58, 251],
                [138, 59, 251],
                [139, 61, 252],
                [140, 62, 252],
                [142, 64, 252],
                [143, 65, 252],
                [144, 67, 252],
                [146, 68, 252],
                [147, 70, 252],
                [148, 71, 253],
                [150, 73, 253],
                [151, 75, 253],
                [152, 76, 253],
                [154, 78, 253],
                [155, 80, 253],
                [156, 81, 253],
                [158, 83, 253],
                [159, 85, 253],
                [160, 86, 253],
                [162, 88, 254],
                [163, 90, 254],
                [164, 92, 254],
                [166, 94, 254],
                [167, 95, 254],
                [168, 97, 254],
                [170, 99, 254],
                [171, 101, 254],
                [172, 103, 254],
                [174, 105, 254],
                [175, 107, 254],
                [176, 109, 254],
                [178, 111, 254],
                [179, 113, 254],
                [180, 115, 254],
                [182, 117, 254],
                [183, 119, 254],
                [184, 121, 255],
                [186, 123, 255],
                [187, 125, 255],
                [188, 127, 255],
                [190, 129, 255],
                [191, 131, 255],
                [192, 133, 255],
                [194, 136, 255],
                [195, 138, 255],
                [196, 140, 255],
                [198, 142, 255],
                [199, 145, 255],
                [200, 147, 255],
                [202, 149, 255],
                [203, 151, 255],
                [204, 154, 255],
                [206, 156, 255],
                [207, 158, 255],
                [208, 161, 255],
                [210, 163, 255],
                [211, 166, 255],
                [212, 168, 255],
                [214, 170, 255],
                [215, 173, 255],
                [216, 175, 255],
                [218, 178, 255],
                [219, 180, 255],
                [220, 183, 255],
                [222, 186, 255],
                [223, 188, 255],
                [224, 191, 255],
                [226, 193, 255],
                [227, 196, 255],
                [228, 199, 255],
                [230, 201, 255],
                [231, 204, 255],
                [232, 207, 255],
                [234, 209, 255],
                [235, 212, 255],
                [236, 215, 255],
                [238, 217, 255],
                [239, 220, 255],
                [240, 223, 255],
                [242, 226, 255],
                [243, 229, 255],
                [244, 232, 255],
                [246, 234, 255],
                [247, 237, 255],
                [248, 240, 255],
                [250, 243, 255],
                [251, 246, 255],
                [252, 249, 255],
                [254, 252, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop purple inverted",
            [
                [255, 255, 255],
                [254, 252, 255],
                [252, 249, 255],
                [251, 246, 255],
                [250, 243, 255],
                [248, 240, 255],
                [247, 237, 255],
                [246, 234, 255],
                [244, 232, 255],
                [243, 229, 255],
                [242, 226, 255],
                [240, 223, 255],
                [239, 220, 255],
                [238, 217, 255],
                [236, 215, 255],
                [235, 212, 255],
                [234, 209, 255],
                [232, 207, 255],
                [231, 204, 255],
                [230, 201, 255],
                [228, 199, 255],
                [227, 196, 255],
                [226, 193, 255],
                [224, 191, 255],
                [223, 188, 255],
                [222, 186, 255],
                [220, 183, 255],
                [219, 180, 255],
                [218, 178, 255],
                [216, 175, 255],
                [215, 173, 255],
                [214, 170, 255],
                [212, 168, 255],
                [211, 166, 255],
                [210, 163, 255],
                [208, 161, 255],
                [207, 158, 255],
                [206, 156, 255],
                [204, 154, 255],
                [203, 151, 255],
                [202, 149, 255],
                [200, 147, 255],
                [199, 145, 255],
                [198, 142, 255],
                [196, 140, 255],
                [195, 138, 255],
                [194, 136, 255],
                [192, 133, 255],
                [191, 131, 255],
                [190, 129, 255],
                [188, 127, 255],
                [187, 125, 255],
                [186, 123, 255],
                [184, 121, 255],
                [183, 119, 254],
                [182, 117, 254],
                [180, 115, 254],
                [179, 113, 254],
                [178, 111, 254],
                [176, 109, 254],
                [175, 107, 254],
                [174, 105, 254],
                [172, 103, 254],
                [171, 101, 254],
                [170, 99, 254],
                [168, 97, 254],
                [167, 95, 254],
                [166, 94, 254],
                [164, 92, 254],
                [163, 90, 254],
                [162, 88, 254],
                [160, 86, 253],
                [159, 85, 253],
                [158, 83, 253],
                [156, 81, 253],
                [155, 80, 253],
                [154, 78, 253],
                [152, 76, 253],
                [151, 75, 253],
                [150, 73, 253],
                [148, 71, 253],
                [147, 70, 252],
                [146, 68, 252],
                [144, 67, 252],
                [143, 65, 252],
                [142, 64, 252],
                [140, 62, 252],
                [139, 61, 252],
                [138, 59, 251],
                [136, 58, 251],
                [135, 56, 251],
                [134, 55, 251],
                [132, 54, 251],
                [131, 52, 250],
                [130, 51, 250],
                [128, 50, 250],
                [127, 48, 250],
                [126, 47, 250],
                [124, 46, 249],
                [123, 44, 249],
                [122, 43, 249],
                [120, 42, 249],
                [119, 41, 248],
                [118, 40, 248],
                [116, 38, 248],
                [115, 37, 248],
                [114, 36, 247],
                [112, 35, 247],
                [111, 34, 247],
                [110, 33, 246],
                [108, 32, 246],
                [107, 31, 246],
                [106, 30, 246],
                [104, 29, 245],
                [103, 28, 245],
                [102, 27, 244],
                [100, 26, 244],
                [99, 25, 244],
                [98, 24, 243],
                [96, 23, 243],
                [95, 22, 242],
                [94, 21, 242],
                [92, 20, 242],
                [91, 19, 241],
                [90, 19, 241],
                [88, 18, 240],
                [87, 17, 240],
                [86, 16, 239],
                [84, 16, 239],
                [83, 15, 238],
                [82, 14, 238],
                [80, 13, 237],
                [79, 13, 237],
                [78, 12, 236],
                [76, 11, 236],
                [75, 11, 235],
                [74, 10, 234],
                [72, 10, 234],
                [71, 9, 233],
                [70, 8, 232],
                [68, 8, 232],
                [67, 7, 231],
                [66, 7, 230],
                [64, 6, 230],
                [63, 6, 229],
                [62, 6, 228],
                [60, 5, 228],
                [59, 5, 227],
                [58, 4, 226],
                [56, 4, 225],
                [55, 4, 224],
                [54, 3, 224],
                [52, 3, 223],
                [51, 3, 222],
                [50, 2, 221],
                [48, 2, 220],
                [47, 2, 219],
                [46, 1, 218],
                [44, 1, 217],
                [43, 1, 216],
                [42, 1, 215],
                [40, 1, 214],
                [39, 1, 213],
                [38, 0, 212],
                [36, 0, 211],
                [35, 0, 210],
                [34, 0, 209],
                [32, 0, 208],
                [31, 0, 207],
                [30, 0, 206],
                [28, 0, 205],
                [27, 0, 203],
                [26, 0, 202],
                [24, 0, 201],
                [23, 0, 200],
                [22, 0, 198],
                [20, 0, 197],
                [19, 0, 196],
                [18, 0, 194],
                [16, 0, 193],
                [15, 0, 192],
                [14, 0, 190],
                [12, 0, 189],
                [11, 0, 187],
                [10, 0, 186],
                [8, 0, 184],
                [7, 0, 183],
                [6, 0, 181],
                [4, 0, 180],
                [3, 0, 178],
                [2, 0, 176],
                [0, 0, 175],
                [0, 0, 173],
                [0, 0, 171],
                [0, 0, 170],
                [0, 0, 168],
                [0, 0, 166],
                [0, 0, 164],
                [0, 0, 162],
                [0, 0, 160],
                [0, 0, 159],
                [0, 0, 157],
                [0, 0, 155],
                [0, 0, 153],
                [0, 0, 151],
                [0, 0, 148],
                [0, 0, 146],
                [0, 0, 144],
                [0, 0, 142],
                [0, 0, 140],
                [0, 0, 138],
                [0, 0, 135],
                [0, 0, 133],
                [0, 0, 131],
                [0, 0, 129],
                [0, 0, 126],
                [0, 0, 124],
                [0, 0, 121],
                [0, 0, 119],
                [0, 0, 116],
                [0, 0, 114],
                [0, 0, 111],
                [0, 0, 109],
                [0, 0, 106],
                [0, 0, 103],
                [0, 0, 100],
                [0, 0, 98],
                [0, 0, 95],
                [0, 0, 92],
                [0, 0, 89],
                [0, 0, 86],
                [0, 0, 83],
                [0, 0, 80],
                [0, 0, 77],
                [0, 0, 74],
                [0, 0, 71],
                [0, 0, 68],
                [0, 0, 65],
                [0, 0, 61],
                [0, 0, 58],
                [0, 0, 55],
                [0, 0, 52],
                [0, 0, 48],
                [0, 0, 45],
                [0, 0, 41],
                [0, 0, 38],
                [0, 0, 34],
                [0, 0, 31],
                [0, 0, 27],
                [0, 0, 23],
                [0, 0, 19],
                [0, 0, 16],
                [0, 0, 12],
                [0, 0, 8],
                [0, 0, 4],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop red",
            [
                [0, 0, 0],
                [4, 0, 0],
                [8, 0, 0],
                [12, 0, 0],
                [16, 0, 0],
                [19, 0, 0],
                [23, 0, 0],
                [27, 0, 0],
                [31, 0, 0],
                [34, 0, 0],
                [38, 0, 0],
                [41, 0, 0],
                [45, 0, 0],
                [48, 0, 0],
                [52, 0, 0],
                [55, 0, 0],
                [58, 0, 0],
                [61, 0, 0],
                [65, 0, 0],
                [68, 0, 0],
                [71, 0, 0],
                [74, 0, 0],
                [77, 0, 0],
                [80, 0, 0],
                [83, 0, 0],
                [86, 0, 0],
                [89, 0, 0],
                [92, 0, 0],
                [95, 0, 0],
                [98, 0, 0],
                [100, 0, 0],
                [103, 0, 0],
                [106, 0, 0],
                [109, 0, 0],
                [111, 0, 0],
                [114, 0, 0],
                [116, 0, 0],
                [119, 0, 0],
                [121, 0, 0],
                [124, 0, 0],
                [126, 0, 0],
                [129, 0, 0],
                [131, 0, 0],
                [133, 0, 0],
                [135, 0, 0],
                [138, 0, 0],
                [140, 0, 0],
                [142, 0, 0],
                [144, 0, 0],
                [146, 0, 0],
                [148, 0, 0],
                [151, 0, 0],
                [153, 0, 0],
                [155, 0, 0],
                [157, 0, 0],
                [159, 0, 0],
                [160, 0, 0],
                [162, 0, 0],
                [164, 0, 0],
                [166, 0, 0],
                [168, 0, 0],
                [170, 0, 0],
                [171, 0, 0],
                [173, 0, 0],
                [175, 0, 0],
                [176, 2, 0],
                [178, 3, 0],
                [180, 4, 0],
                [181, 6, 0],
                [183, 7, 0],
                [184, 8, 0],
                [186, 10, 0],
                [187, 11, 0],
                [189, 12, 0],
                [190, 14, 0],
                [192, 15, 0],
                [193, 16, 0],
                [194, 18, 0],
                [196, 19, 0],
                [197, 20, 0],
                [198, 22, 0],
                [200, 23, 0],
                [201, 24, 0],
                [202, 26, 0],
                [203, 27, 0],
                [205, 28, 0],
                [206, 30, 0],
                [207, 31, 0],
                [208, 32, 0],
                [209, 34, 0],
                [210, 35, 0],
                [211, 36, 0],
                [212, 38, 0],
                [213, 39, 1],
                [214, 40, 1],
                [215, 42, 1],
                [216, 43, 1],
                [217, 44, 1],
                [218, 46, 1],
                [219, 47, 2],
                [220, 48, 2],
                [221, 50, 2],
                [222, 51, 3],
                [223, 52, 3],
                [224, 54, 3],
                [224, 55, 4],
                [225, 56, 4],
                [226, 58, 4],
                [227, 59, 5],
                [228, 60, 5],
                [228, 62, 6],
                [229, 63, 6],
                [230, 64, 6],
                [230, 66, 7],
                [231, 67, 7],
                [232, 68, 8],
                [232, 70, 8],
                [233, 71, 9],
                [234, 72, 10],
                [234, 74, 10],
                [235, 75, 11],
                [236, 76, 11],
                [236, 78, 12],
                [237, 79, 13],
                [237, 80, 13],
                [238, 82, 14],
                [238, 83, 15],
                [239, 84, 16],
                [239, 86, 16],
                [240, 87, 17],
                [240, 88, 18],
                [241, 90, 19],
                [241, 91, 19],
                [242, 92, 20],
                [242, 94, 21],
                [242, 95, 22],
                [243, 96, 23],
                [243, 98, 24],
                [244, 99, 25],
                [244, 100, 26],
                [244, 102, 27],
                [245, 103, 28],
                [245, 104, 29],
                [246, 106, 30],
                [246, 107, 31],
                [246, 108, 32],
                [246, 110, 33],
                [247, 111, 34],
                [247, 112, 35],
                [247, 114, 36],
                [248, 115, 37],
                [248, 116, 38],
                [248, 118, 40],
                [248, 119, 41],
                [249, 120, 42],
                [249, 122, 43],
                [249, 123, 44],
                [249, 124, 46],
                [250, 126, 47],
                [250, 127, 48],
                [250, 128, 50],
                [250, 130, 51],
                [250, 131, 52],
                [251, 132, 54],
                [251, 134, 55],
                [251, 135, 56],
                [251, 136, 58],
                [251, 138, 59],
                [252, 139, 61],
                [252, 140, 62],
                [252, 142, 64],
                [252, 143, 65],
                [252, 144, 67],
                [252, 146, 68],
                [252, 147, 70],
                [253, 148, 71],
                [253, 150, 73],
                [253, 151, 75],
                [253, 152, 76],
                [253, 154, 78],
                [253, 155, 80],
                [253, 156, 81],
                [253, 158, 83],
                [253, 159, 85],
                [253, 160, 86],
                [254, 162, 88],
                [254, 163, 90],
                [254, 164, 92],
                [254, 166, 94],
                [254, 167, 95],
                [254, 168, 97],
                [254, 170, 99],
                [254, 171, 101],
                [254, 172, 103],
                [254, 174, 105],
                [254, 175, 107],
                [254, 176, 109],
                [254, 178, 111],
                [254, 179, 113],
                [254, 180, 115],
                [254, 182, 117],
                [254, 183, 119],
                [255, 184, 121],
                [255, 186, 123],
                [255, 187, 125],
                [255, 188, 127],
                [255, 190, 129],
                [255, 191, 131],
                [255, 192, 133],
                [255, 194, 136],
                [255, 195, 138],
                [255, 196, 140],
                [255, 198, 142],
                [255, 199, 145],
                [255, 200, 147],
                [255, 202, 149],
                [255, 203, 151],
                [255, 204, 154],
                [255, 206, 156],
                [255, 207, 158],
                [255, 208, 161],
                [255, 210, 163],
                [255, 211, 166],
                [255, 212, 168],
                [255, 214, 170],
                [255, 215, 173],
                [255, 216, 175],
                [255, 218, 178],
                [255, 219, 180],
                [255, 220, 183],
                [255, 222, 186],
                [255, 223, 188],
                [255, 224, 191],
                [255, 226, 193],
                [255, 227, 196],
                [255, 228, 199],
                [255, 230, 201],
                [255, 231, 204],
                [255, 232, 207],
                [255, 234, 209],
                [255, 235, 212],
                [255, 236, 215],
                [255, 238, 217],
                [255, 239, 220],
                [255, 240, 223],
                [255, 242, 226],
                [255, 243, 229],
                [255, 244, 232],
                [255, 246, 234],
                [255, 247, 237],
                [255, 248, 240],
                [255, 250, 243],
                [255, 251, 246],
                [255, 252, 249],
                [255, 254, 252],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Pop red inverted",
            [
                [255, 255, 255],
                [255, 254, 252],
                [255, 252, 249],
                [255, 251, 246],
                [255, 250, 243],
                [255, 248, 240],
                [255, 247, 237],
                [255, 246, 234],
                [255, 244, 232],
                [255, 243, 229],
                [255, 242, 226],
                [255, 240, 223],
                [255, 239, 220],
                [255, 238, 217],
                [255, 236, 215],
                [255, 235, 212],
                [255, 234, 209],
                [255, 232, 207],
                [255, 231, 204],
                [255, 230, 201],
                [255, 228, 199],
                [255, 227, 196],
                [255, 226, 193],
                [255, 224, 191],
                [255, 223, 188],
                [255, 222, 186],
                [255, 220, 183],
                [255, 219, 180],
                [255, 218, 178],
                [255, 216, 175],
                [255, 215, 173],
                [255, 214, 170],
                [255, 212, 168],
                [255, 211, 166],
                [255, 210, 163],
                [255, 208, 161],
                [255, 207, 158],
                [255, 206, 156],
                [255, 204, 154],
                [255, 203, 151],
                [255, 202, 149],
                [255, 200, 147],
                [255, 199, 145],
                [255, 198, 142],
                [255, 196, 140],
                [255, 195, 138],
                [255, 194, 136],
                [255, 192, 133],
                [255, 191, 131],
                [255, 190, 129],
                [255, 188, 127],
                [255, 187, 125],
                [255, 186, 123],
                [255, 184, 121],
                [254, 183, 119],
                [254, 182, 117],
                [254, 180, 115],
                [254, 179, 113],
                [254, 178, 111],
                [254, 176, 109],
                [254, 175, 107],
                [254, 174, 105],
                [254, 172, 103],
                [254, 171, 101],
                [254, 170, 99],
                [254, 168, 97],
                [254, 167, 95],
                [254, 166, 94],
                [254, 164, 92],
                [254, 163, 90],
                [254, 162, 88],
                [253, 160, 86],
                [253, 159, 85],
                [253, 158, 83],
                [253, 156, 81],
                [253, 155, 80],
                [253, 154, 78],
                [253, 152, 76],
                [253, 151, 75],
                [253, 150, 73],
                [253, 148, 71],
                [252, 147, 70],
                [252, 146, 68],
                [252, 144, 67],
                [252, 143, 65],
                [252, 142, 64],
                [252, 140, 62],
                [252, 139, 61],
                [251, 138, 59],
                [251, 136, 58],
                [251, 135, 56],
                [251, 134, 55],
                [251, 132, 54],
                [250, 131, 52],
                [250, 130, 51],
                [250, 128, 50],
                [250, 127, 48],
                [250, 126, 47],
                [249, 124, 46],
                [249, 123, 44],
                [249, 122, 43],
                [249, 120, 42],
                [248, 119, 41],
                [248, 118, 40],
                [248, 116, 38],
                [248, 115, 37],
                [247, 114, 36],
                [247, 112, 35],
                [247, 111, 34],
                [246, 110, 33],
                [246, 108, 32],
                [246, 107, 31],
                [246, 106, 30],
                [245, 104, 29],
                [245, 103, 28],
                [244, 102, 27],
                [244, 100, 26],
                [244, 99, 25],
                [243, 98, 24],
                [243, 96, 23],
                [242, 95, 22],
                [242, 94, 21],
                [242, 92, 20],
                [241, 91, 19],
                [241, 90, 19],
                [240, 88, 18],
                [240, 87, 17],
                [239, 86, 16],
                [239, 84, 16],
                [238, 83, 15],
                [238, 82, 14],
                [237, 80, 13],
                [237, 79, 13],
                [236, 78, 12],
                [236, 76, 11],
                [235, 75, 11],
                [234, 74, 10],
                [234, 72, 10],
                [233, 71, 9],
                [232, 70, 8],
                [232, 68, 8],
                [231, 67, 7],
                [230, 66, 7],
                [230, 64, 6],
                [229, 63, 6],
                [228, 62, 6],
                [228, 60, 5],
                [227, 59, 5],
                [226, 58, 4],
                [225, 56, 4],
                [224, 55, 4],
                [224, 54, 3],
                [223, 52, 3],
                [222, 51, 3],
                [221, 50, 2],
                [220, 48, 2],
                [219, 47, 2],
                [218, 46, 1],
                [217, 44, 1],
                [216, 43, 1],
                [215, 42, 1],
                [214, 40, 1],
                [213, 39, 1],
                [212, 38, 0],
                [211, 36, 0],
                [210, 35, 0],
                [209, 34, 0],
                [208, 32, 0],
                [207, 31, 0],
                [206, 30, 0],
                [205, 28, 0],
                [203, 27, 0],
                [202, 26, 0],
                [201, 24, 0],
                [200, 23, 0],
                [198, 22, 0],
                [197, 20, 0],
                [196, 19, 0],
                [194, 18, 0],
                [193, 16, 0],
                [192, 15, 0],
                [190, 14, 0],
                [189, 12, 0],
                [187, 11, 0],
                [186, 10, 0],
                [184, 8, 0],
                [183, 7, 0],
                [181, 6, 0],
                [180, 4, 0],
                [178, 3, 0],
                [176, 2, 0],
                [175, 0, 0],
                [173, 0, 0],
                [171, 0, 0],
                [170, 0, 0],
                [168, 0, 0],
                [166, 0, 0],
                [164, 0, 0],
                [162, 0, 0],
                [160, 0, 0],
                [159, 0, 0],
                [157, 0, 0],
                [155, 0, 0],
                [153, 0, 0],
                [151, 0, 0],
                [148, 0, 0],
                [146, 0, 0],
                [144, 0, 0],
                [142, 0, 0],
                [140, 0, 0],
                [138, 0, 0],
                [135, 0, 0],
                [133, 0, 0],
                [131, 0, 0],
                [129, 0, 0],
                [126, 0, 0],
                [124, 0, 0],
                [121, 0, 0],
                [119, 0, 0],
                [116, 0, 0],
                [114, 0, 0],
                [111, 0, 0],
                [109, 0, 0],
                [106, 0, 0],
                [103, 0, 0],
                [100, 0, 0],
                [98, 0, 0],
                [95, 0, 0],
                [92, 0, 0],
                [89, 0, 0],
                [86, 0, 0],
                [83, 0, 0],
                [80, 0, 0],
                [77, 0, 0],
                [74, 0, 0],
                [71, 0, 0],
                [68, 0, 0],
                [65, 0, 0],
                [61, 0, 0],
                [58, 0, 0],
                [55, 0, 0],
                [52, 0, 0],
                [48, 0, 0],
                [45, 0, 0],
                [41, 0, 0],
                [38, 0, 0],
                [34, 0, 0],
                [31, 0, 0],
                [27, 0, 0],
                [23, 0, 0],
                [19, 0, 0],
                [16, 0, 0],
                [12, 0, 0],
                [8, 0, 0],
                [4, 0, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Pop yellow",
            [
                [0, 0, 0],
                [2, 2, 0],
                [5, 5, 0],
                [7, 7, 0],
                [10, 10, 0],
                [12, 12, 0],
                [15, 15, 0],
                [17, 17, 0],
                [19, 19, 0],
                [22, 22, 0],
                [24, 24, 0],
                [26, 26, 0],
                [29, 29, 0],
                [31, 31, 0],
                [33, 33, 0],
                [35, 35, 0],
                [38, 38, 0],
                [40, 40, 0],
                [42, 42, 0],
                [44, 44, 0],
                [46, 46, 0],
                [48, 48, 0],
                [51, 51, 0],
                [53, 53, 0],
                [55, 55, 0],
                [57, 57, 0],
                [59, 59, 0],
                [61, 61, 0],
                [63, 63, 0],
                [65, 65, 0],
                [67, 67, 0],
                [69, 69, 0],
                [71, 71, 0],
                [73, 73, 0],
                [75, 75, 0],
                [77, 77, 0],
                [79, 79, 0],
                [80, 80, 0],
                [82, 82, 0],
                [84, 84, 0],
                [86, 86, 0],
                [88, 88, 0],
                [90, 90, 0],
                [91, 91, 0],
                [93, 93, 0],
                [95, 95, 0],
                [97, 97, 0],
                [99, 99, 0],
                [100, 100, 0],
                [102, 102, 0],
                [104, 104, 0],
                [105, 105, 0],
                [107, 107, 0],
                [109, 109, 0],
                [110, 110, 0],
                [112, 112, 0],
                [114, 114, 0],
                [115, 115, 0],
                [117, 117, 0],
                [118, 118, 0],
                [120, 120, 0],
                [121, 121, 0],
                [123, 123, 0],
                [124, 124, 0],
                [126, 126, 0],
                [127, 127, 0],
                [129, 129, 0],
                [130, 130, 0],
                [132, 132, 0],
                [133, 133, 0],
                [135, 135, 0],
                [136, 136, 0],
                [137, 137, 0],
                [139, 139, 0],
                [140, 140, 0],
                [142, 142, 0],
                [143, 143, 0],
                [144, 144, 0],
                [146, 146, 0],
                [147, 147, 0],
                [148, 148, 0],
                [150, 150, 0],
                [151, 151, 0],
                [152, 152, 0],
                [153, 153, 0],
                [155, 155, 0],
                [156, 156, 0],
                [157, 157, 0],
                [158, 158, 0],
                [159, 159, 0],
                [161, 161, 0],
                [162, 162, 0],
                [163, 163, 0],
                [164, 164, 0],
                [165, 165, 0],
                [166, 166, 0],
                [168, 168, 0],
                [169, 169, 0],
                [170, 170, 0],
                [171, 171, 0],
                [172, 172, 0],
                [173, 173, 0],
                [174, 174, 0],
                [175, 175, 1],
                [176, 176, 3],
                [177, 177, 5],
                [178, 178, 6],
                [179, 179, 8],
                [180, 180, 10],
                [181, 181, 11],
                [182, 182, 13],
                [183, 183, 15],
                [184, 184, 16],
                [185, 185, 18],
                [186, 186, 20],
                [187, 187, 21],
                [188, 188, 23],
                [189, 189, 25],
                [190, 190, 26],
                [191, 191, 28],
                [191, 191, 30],
                [192, 192, 31],
                [193, 193, 33],
                [194, 194, 35],
                [195, 195, 36],
                [196, 196, 38],
                [197, 197, 40],
                [197, 197, 41],
                [198, 198, 43],
                [199, 199, 44],
                [200, 200, 46],
                [201, 201, 48],
                [201, 201, 49],
                [202, 202, 51],
                [203, 203, 53],
                [204, 204, 54],
                [204, 204, 56],
                [205, 205, 58],
                [206, 206, 59],
                [207, 207, 61],
                [207, 207, 63],
                [208, 208, 64],
                [209, 209, 66],
                [210, 210, 68],
                [210, 210, 69],
                [211, 211, 71],
                [212, 212, 73],
                [212, 212, 74],
                [213, 213, 76],
                [214, 214, 78],
                [215, 215, 79],
                [215, 215, 81],
                [216, 216, 83],
                [217, 217, 84],
                [217, 217, 86],
                [218, 218, 88],
                [219, 219, 89],
                [220, 220, 91],
                [220, 220, 93],
                [221, 221, 94],
                [222, 222, 96],
                [222, 222, 98],
                [223, 223, 99],
                [224, 224, 101],
                [225, 225, 103],
                [225, 225, 104],
                [226, 226, 106],
                [227, 227, 108],
                [227, 227, 109],
                [228, 228, 111],
                [229, 229, 113],
                [229, 229, 114],
                [230, 230, 116],
                [231, 231, 118],
                [232, 232, 119],
                [232, 232, 121],
                [233, 233, 123],
                [234, 234, 124],
                [234, 234, 126],
                [235, 235, 128],
                [236, 236, 129],
                [236, 236, 131],
                [237, 237, 133],
                [238, 238, 134],
                [239, 239, 136],
                [239, 239, 138],
                [240, 240, 139],
                [241, 241, 141],
                [241, 241, 143],
                [242, 242, 144],
                [243, 243, 146],
                [244, 244, 148],
                [244, 244, 149],
                [245, 245, 151],
                [246, 246, 153],
                [246, 246, 154],
                [247, 247, 156],
                [248, 248, 158],
                [249, 249, 159],
                [249, 249, 161],
                [250, 250, 163],
                [251, 251, 164],
                [251, 251, 166],
                [252, 252, 168],
                [253, 253, 169],
                [254, 254, 171],
                [254, 254, 173],
                [255, 255, 174],
                [255, 255, 176],
                [255, 255, 178],
                [255, 255, 179],
                [255, 255, 181],
                [255, 255, 183],
                [255, 255, 184],
                [255, 255, 186],
                [255, 255, 187],
                [255, 255, 189],
                [255, 255, 191],
                [255, 255, 192],
                [255, 255, 194],
                [255, 255, 196],
                [255, 255, 197],
                [255, 255, 199],
                [255, 255, 201],
                [255, 255, 202],
                [255, 255, 204],
                [255, 255, 206],
                [255, 255, 207],
                [255, 255, 209],
                [255, 255, 211],
                [255, 255, 212],
                [255, 255, 214],
                [255, 255, 216],
                [255, 255, 217],
                [255, 255, 219],
                [255, 255, 221],
                [255, 255, 222],
                [255, 255, 224],
                [255, 255, 226],
                [255, 255, 227],
                [255, 255, 229],
                [255, 255, 231],
                [255, 255, 232],
                [255, 255, 234],
                [255, 255, 236],
                [255, 255, 237],
                [255, 255, 239],
                [255, 255, 241],
                [255, 255, 242],
                [255, 255, 244],
                [255, 255, 246],
                [255, 255, 247],
                [255, 255, 249],
                [255, 255, 251],
                [255, 255, 252],
                [255, 255, 254],
            ],
        );

        m.insert(
            "Pop yellow inverted",
            [
                [255, 255, 254],
                [255, 255, 252],
                [255, 255, 251],
                [255, 255, 249],
                [255, 255, 247],
                [255, 255, 246],
                [255, 255, 244],
                [255, 255, 242],
                [255, 255, 241],
                [255, 255, 239],
                [255, 255, 237],
                [255, 255, 236],
                [255, 255, 234],
                [255, 255, 232],
                [255, 255, 231],
                [255, 255, 229],
                [255, 255, 227],
                [255, 255, 226],
                [255, 255, 224],
                [255, 255, 222],
                [255, 255, 221],
                [255, 255, 219],
                [255, 255, 217],
                [255, 255, 216],
                [255, 255, 214],
                [255, 255, 212],
                [255, 255, 211],
                [255, 255, 209],
                [255, 255, 207],
                [255, 255, 206],
                [255, 255, 204],
                [255, 255, 202],
                [255, 255, 201],
                [255, 255, 199],
                [255, 255, 197],
                [255, 255, 196],
                [255, 255, 194],
                [255, 255, 192],
                [255, 255, 191],
                [255, 255, 189],
                [255, 255, 187],
                [255, 255, 186],
                [255, 255, 184],
                [255, 255, 183],
                [255, 255, 181],
                [255, 255, 179],
                [255, 255, 178],
                [255, 255, 176],
                [255, 255, 174],
                [254, 254, 173],
                [254, 254, 171],
                [253, 253, 169],
                [252, 252, 168],
                [251, 251, 166],
                [251, 251, 164],
                [250, 250, 163],
                [249, 249, 161],
                [249, 249, 159],
                [248, 248, 158],
                [247, 247, 156],
                [246, 246, 154],
                [246, 246, 153],
                [245, 245, 151],
                [244, 244, 149],
                [244, 244, 148],
                [243, 243, 146],
                [242, 242, 144],
                [241, 241, 143],
                [241, 241, 141],
                [240, 240, 139],
                [239, 239, 138],
                [239, 239, 136],
                [238, 238, 134],
                [237, 237, 133],
                [236, 236, 131],
                [236, 236, 129],
                [235, 235, 128],
                [234, 234, 126],
                [234, 234, 124],
                [233, 233, 123],
                [232, 232, 121],
                [232, 232, 119],
                [231, 231, 118],
                [230, 230, 116],
                [229, 229, 114],
                [229, 229, 113],
                [228, 228, 111],
                [227, 227, 109],
                [227, 227, 108],
                [226, 226, 106],
                [225, 225, 104],
                [225, 225, 103],
                [224, 224, 101],
                [223, 223, 99],
                [222, 222, 98],
                [222, 222, 96],
                [221, 221, 94],
                [220, 220, 93],
                [220, 220, 91],
                [219, 219, 89],
                [218, 218, 88],
                [217, 217, 86],
                [217, 217, 84],
                [216, 216, 83],
                [215, 215, 81],
                [215, 215, 79],
                [214, 214, 78],
                [213, 213, 76],
                [212, 212, 74],
                [212, 212, 73],
                [211, 211, 71],
                [210, 210, 69],
                [210, 210, 68],
                [209, 209, 66],
                [208, 208, 64],
                [207, 207, 63],
                [207, 207, 61],
                [206, 206, 59],
                [205, 205, 58],
                [204, 204, 56],
                [204, 204, 54],
                [203, 203, 53],
                [202, 202, 51],
                [201, 201, 49],
                [201, 201, 48],
                [200, 200, 46],
                [199, 199, 44],
                [198, 198, 43],
                [197, 197, 41],
                [197, 197, 40],
                [196, 196, 38],
                [195, 195, 36],
                [194, 194, 35],
                [193, 193, 33],
                [192, 192, 31],
                [191, 191, 30],
                [191, 191, 28],
                [190, 190, 26],
                [189, 189, 25],
                [188, 188, 23],
                [187, 187, 21],
                [186, 186, 20],
                [185, 185, 18],
                [184, 184, 16],
                [183, 183, 15],
                [182, 182, 13],
                [181, 181, 11],
                [180, 180, 10],
                [179, 179, 8],
                [178, 178, 6],
                [177, 177, 5],
                [176, 176, 3],
                [175, 175, 1],
                [174, 174, 0],
                [173, 173, 0],
                [172, 172, 0],
                [171, 171, 0],
                [170, 170, 0],
                [169, 169, 0],
                [168, 168, 0],
                [166, 166, 0],
                [165, 165, 0],
                [164, 164, 0],
                [163, 163, 0],
                [162, 162, 0],
                [161, 161, 0],
                [159, 159, 0],
                [158, 158, 0],
                [157, 157, 0],
                [156, 156, 0],
                [155, 155, 0],
                [153, 153, 0],
                [152, 152, 0],
                [151, 151, 0],
                [150, 150, 0],
                [148, 148, 0],
                [147, 147, 0],
                [146, 146, 0],
                [144, 144, 0],
                [143, 143, 0],
                [142, 142, 0],
                [140, 140, 0],
                [139, 139, 0],
                [137, 137, 0],
                [136, 136, 0],
                [135, 135, 0],
                [133, 133, 0],
                [132, 132, 0],
                [130, 130, 0],
                [129, 129, 0],
                [127, 127, 0],
                [126, 126, 0],
                [124, 124, 0],
                [123, 123, 0],
                [121, 121, 0],
                [120, 120, 0],
                [118, 118, 0],
                [117, 117, 0],
                [115, 115, 0],
                [114, 114, 0],
                [112, 112, 0],
                [110, 110, 0],
                [109, 109, 0],
                [107, 107, 0],
                [105, 105, 0],
                [104, 104, 0],
                [102, 102, 0],
                [100, 100, 0],
                [99, 99, 0],
                [97, 97, 0],
                [95, 95, 0],
                [93, 93, 0],
                [91, 91, 0],
                [90, 90, 0],
                [88, 88, 0],
                [86, 86, 0],
                [84, 84, 0],
                [82, 82, 0],
                [80, 80, 0],
                [79, 79, 0],
                [77, 77, 0],
                [75, 75, 0],
                [73, 73, 0],
                [71, 71, 0],
                [69, 69, 0],
                [67, 67, 0],
                [65, 65, 0],
                [63, 63, 0],
                [61, 61, 0],
                [59, 59, 0],
                [57, 57, 0],
                [55, 55, 0],
                [53, 53, 0],
                [51, 51, 0],
                [48, 48, 0],
                [46, 46, 0],
                [44, 44, 0],
                [42, 42, 0],
                [40, 40, 0],
                [38, 38, 0],
                [35, 35, 0],
                [33, 33, 0],
                [31, 31, 0],
                [29, 29, 0],
                [26, 26, 0],
                [24, 24, 0],
                [22, 22, 0],
                [19, 19, 0],
                [17, 17, 0],
                [15, 15, 0],
                [12, 12, 0],
                [10, 10, 0],
                [7, 7, 0],
                [5, 5, 0],
                [2, 2, 0],
                [0, 0, 0],
            ],
        );

        m.insert(
            "Quartetto MYGB Blue",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 1],
                [0, 0, 1],
                [0, 0, 2],
                [0, 0, 2],
                [0, 1, 3],
                [0, 1, 3],
                [0, 1, 4],
                [0, 1, 4],
                [0, 1, 5],
                [0, 1, 5],
                [0, 2, 6],
                [1, 2, 6],
                [1, 2, 7],
                [1, 2, 7],
                [1, 2, 8],
                [1, 2, 8],
                [1, 3, 9],
                [1, 3, 9],
                [1, 3, 10],
                [1, 3, 10],
                [1, 3, 11],
                [1, 3, 11],
                [1, 4, 12],
                [1, 4, 12],
                [2, 4, 13],
                [2, 4, 13],
                [2, 4, 14],
                [2, 4, 14],
                [2, 5, 15],
                [2, 5, 15],
                [2, 5, 16],
                [2, 5, 16],
                [2, 5, 17],
                [2, 5, 17],
                [2, 6, 18],
                [2, 6, 18],
                [2, 6, 19],
                [3, 6, 19],
                [3, 6, 20],
                [3, 6, 20],
                [3, 7, 21],
                [3, 7, 21],
                [3, 7, 22],
                [3, 7, 22],
                [3, 7, 23],
                [3, 7, 23],
                [3, 8, 24],
                [3, 8, 24],
                [3, 8, 25],
                [4, 8, 25],
                [4, 8, 26],
                [4, 8, 26],
                [4, 9, 27],
                [4, 9, 27],
                [4, 9, 28],
                [4, 9, 28],
                [4, 9, 29],
                [4, 9, 29],
                [4, 10, 30],
                [4, 10, 30],
                [4, 10, 31],
                [4, 10, 31],
                [5, 10, 32],
                [5, 10, 32],
                [5, 11, 33],
                [5, 11, 33],
                [5, 11, 34],
                [5, 11, 34],
                [5, 11, 35],
                [5, 11, 35],
                [5, 12, 36],
                [5, 12, 36],
                [5, 12, 37],
                [5, 12, 37],
                [5, 12, 38],
                [6, 12, 38],
                [6, 13, 39],
                [6, 13, 39],
                [6, 13, 40],
                [6, 13, 40],
                [6, 13, 41],
                [6, 13, 41],
                [6, 14, 42],
                [6, 14, 43],
                [6, 14, 43],
                [6, 14, 44],
                [6, 14, 44],
                [6, 15, 45],
                [7, 15, 45],
                [7, 15, 46],
                [7, 15, 46],
                [7, 15, 47],
                [7, 15, 47],
                [7, 16, 48],
                [7, 16, 48],
                [7, 16, 49],
                [7, 16, 49],
                [7, 16, 50],
                [7, 16, 50],
                [7, 17, 51],
                [8, 17, 51],
                [8, 17, 52],
                [8, 17, 52],
                [8, 17, 53],
                [8, 17, 53],
                [8, 18, 54],
                [8, 18, 54],
                [8, 18, 55],
                [8, 18, 55],
                [8, 18, 56],
                [8, 18, 56],
                [8, 19, 57],
                [8, 19, 57],
                [9, 19, 58],
                [9, 19, 58],
                [9, 19, 59],
                [9, 19, 59],
                [9, 20, 60],
                [9, 20, 60],
                [9, 20, 61],
                [9, 20, 61],
                [9, 20, 62],
                [9, 20, 62],
                [9, 21, 63],
                [9, 21, 63],
                [9, 21, 64],
                [10, 21, 64],
                [10, 21, 65],
                [10, 21, 65],
                [10, 22, 66],
                [10, 22, 66],
                [10, 22, 67],
                [10, 22, 67],
                [10, 22, 68],
                [10, 22, 68],
                [10, 23, 69],
                [10, 23, 69],
                [10, 23, 70],
                [10, 23, 70],
                [11, 23, 71],
                [11, 23, 71],
                [11, 24, 72],
                [11, 24, 72],
                [11, 24, 73],
                [11, 24, 73],
                [11, 24, 74],
                [11, 24, 74],
                [11, 25, 75],
                [11, 25, 75],
                [11, 25, 76],
                [11, 25, 76],
                [12, 25, 77],
                [12, 25, 77],
                [12, 26, 78],
                [12, 26, 78],
                [12, 26, 79],
                [12, 26, 79],
                [12, 26, 80],
                [12, 26, 80],
                [12, 27, 81],
                [12, 27, 81],
                [12, 27, 82],
                [12, 27, 82],
                [12, 27, 83],
                [13, 27, 83],
                [13, 28, 84],
                [13, 28, 84],
                [13, 28, 85],
                [13, 28, 86],
                [13, 28, 86],
                [13, 29, 87],
                [13, 29, 87],
                [13, 29, 88],
                [13, 29, 88],
                [13, 29, 89],
                [13, 29, 89],
                [13, 30, 90],
                [14, 30, 90],
                [14, 30, 91],
                [14, 30, 91],
                [14, 30, 92],
                [14, 30, 92],
                [14, 31, 93],
                [14, 31, 93],
                [14, 31, 94],
                [14, 31, 94],
                [14, 31, 95],
                [14, 31, 95],
                [14, 32, 96],
                [14, 32, 96],
                [15, 32, 97],
                [15, 32, 97],
                [15, 32, 98],
                [15, 32, 98],
                [15, 33, 99],
                [15, 33, 99],
                [15, 33, 100],
                [15, 33, 100],
                [15, 33, 101],
                [15, 33, 101],
                [15, 34, 102],
                [15, 34, 102],
                [16, 34, 103],
                [16, 34, 103],
                [16, 34, 104],
                [16, 34, 104],
                [16, 35, 105],
                [16, 35, 105],
                [16, 35, 106],
                [16, 35, 106],
                [16, 35, 107],
                [16, 35, 107],
                [16, 36, 108],
                [16, 36, 108],
                [16, 36, 109],
                [17, 36, 109],
                [17, 36, 110],
                [17, 36, 110],
                [17, 37, 111],
                [17, 37, 111],
                [17, 37, 112],
                [17, 37, 112],
                [17, 37, 113],
                [17, 37, 113],
                [17, 38, 114],
                [17, 38, 114],
                [17, 38, 115],
                [17, 38, 115],
                [18, 38, 116],
                [18, 38, 116],
                [18, 39, 117],
                [18, 39, 117],
                [18, 39, 118],
                [18, 39, 118],
                [18, 39, 119],
                [18, 39, 119],
                [18, 40, 120],
                [18, 40, 120],
                [18, 40, 121],
                [18, 40, 121],
                [18, 40, 122],
                [19, 40, 122],
                [19, 41, 123],
                [19, 41, 123],
                [19, 41, 124],
                [19, 41, 124],
                [19, 41, 125],
                [19, 41, 125],
                [19, 42, 126],
                [19, 42, 126],
                [19, 42, 127],
                [19, 42, 127],
                [19, 42, 128],
                [20, 43, 129],
            ],
        );

        m.insert(
            "Quartetto MYGB Green",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 1, 0],
                [0, 1, 0],
                [0, 2, 0],
                [0, 2, 0],
                [0, 3, 1],
                [0, 3, 1],
                [0, 4, 1],
                [0, 4, 1],
                [0, 5, 1],
                [0, 5, 1],
                [0, 6, 2],
                [1, 6, 2],
                [1, 7, 2],
                [1, 7, 2],
                [1, 8, 2],
                [1, 8, 2],
                [1, 9, 3],
                [1, 9, 3],
                [1, 10, 3],
                [1, 10, 3],
                [1, 11, 3],
                [1, 11, 3],
                [1, 12, 4],
                [1, 12, 4],
                [2, 13, 4],
                [2, 13, 4],
                [2, 14, 4],
                [2, 14, 4],
                [2, 15, 5],
                [2, 15, 5],
                [2, 16, 5],
                [2, 16, 5],
                [2, 17, 5],
                [2, 17, 5],
                [2, 18, 6],
                [2, 18, 6],
                [2, 19, 6],
                [3, 19, 6],
                [3, 20, 6],
                [3, 20, 6],
                [3, 21, 7],
                [3, 21, 7],
                [3, 22, 7],
                [3, 22, 7],
                [3, 23, 7],
                [3, 23, 7],
                [3, 24, 8],
                [3, 24, 8],
                [3, 25, 8],
                [4, 25, 8],
                [4, 26, 8],
                [4, 26, 8],
                [4, 27, 9],
                [4, 27, 9],
                [4, 28, 9],
                [4, 28, 9],
                [4, 29, 9],
                [4, 29, 9],
                [4, 30, 10],
                [4, 30, 10],
                [4, 31, 10],
                [4, 31, 10],
                [5, 32, 10],
                [5, 32, 10],
                [5, 33, 11],
                [5, 33, 11],
                [5, 34, 11],
                [5, 34, 11],
                [5, 35, 11],
                [5, 35, 11],
                [5, 36, 12],
                [5, 36, 12],
                [5, 37, 12],
                [5, 37, 12],
                [5, 38, 12],
                [6, 38, 12],
                [6, 39, 13],
                [6, 39, 13],
                [6, 40, 13],
                [6, 40, 13],
                [6, 41, 13],
                [6, 41, 13],
                [6, 42, 14],
                [6, 43, 14],
                [6, 43, 14],
                [6, 44, 14],
                [6, 44, 14],
                [6, 45, 15],
                [7, 45, 15],
                [7, 46, 15],
                [7, 46, 15],
                [7, 47, 15],
                [7, 47, 15],
                [7, 48, 16],
                [7, 48, 16],
                [7, 49, 16],
                [7, 49, 16],
                [7, 50, 16],
                [7, 50, 16],
                [7, 51, 17],
                [8, 51, 17],
                [8, 52, 17],
                [8, 52, 17],
                [8, 53, 17],
                [8, 53, 17],
                [8, 54, 18],
                [8, 54, 18],
                [8, 55, 18],
                [8, 55, 18],
                [8, 56, 18],
                [8, 56, 18],
                [8, 57, 19],
                [8, 57, 19],
                [9, 58, 19],
                [9, 58, 19],
                [9, 59, 19],
                [9, 59, 19],
                [9, 60, 20],
                [9, 60, 20],
                [9, 61, 20],
                [9, 61, 20],
                [9, 62, 20],
                [9, 62, 20],
                [9, 63, 21],
                [9, 63, 21],
                [9, 64, 21],
                [10, 64, 21],
                [10, 65, 21],
                [10, 65, 21],
                [10, 66, 22],
                [10, 66, 22],
                [10, 67, 22],
                [10, 67, 22],
                [10, 68, 22],
                [10, 68, 22],
                [10, 69, 23],
                [10, 69, 23],
                [10, 70, 23],
                [10, 70, 23],
                [11, 71, 23],
                [11, 71, 23],
                [11, 72, 24],
                [11, 72, 24],
                [11, 73, 24],
                [11, 73, 24],
                [11, 74, 24],
                [11, 74, 24],
                [11, 75, 25],
                [11, 75, 25],
                [11, 76, 25],
                [11, 76, 25],
                [12, 77, 25],
                [12, 77, 25],
                [12, 78, 26],
                [12, 78, 26],
                [12, 79, 26],
                [12, 79, 26],
                [12, 80, 26],
                [12, 80, 26],
                [12, 81, 27],
                [12, 81, 27],
                [12, 82, 27],
                [12, 82, 27],
                [12, 83, 27],
                [13, 83, 27],
                [13, 84, 28],
                [13, 84, 28],
                [13, 85, 28],
                [13, 86, 28],
                [13, 86, 28],
                [13, 87, 29],
                [13, 87, 29],
                [13, 88, 29],
                [13, 88, 29],
                [13, 89, 29],
                [13, 89, 29],
                [13, 90, 30],
                [14, 90, 30],
                [14, 91, 30],
                [14, 91, 30],
                [14, 92, 30],
                [14, 92, 30],
                [14, 93, 31],
                [14, 93, 31],
                [14, 94, 31],
                [14, 94, 31],
                [14, 95, 31],
                [14, 95, 31],
                [14, 96, 32],
                [14, 96, 32],
                [15, 97, 32],
                [15, 97, 32],
                [15, 98, 32],
                [15, 98, 32],
                [15, 99, 33],
                [15, 99, 33],
                [15, 100, 33],
                [15, 100, 33],
                [15, 101, 33],
                [15, 101, 33],
                [15, 102, 34],
                [15, 102, 34],
                [16, 103, 34],
                [16, 103, 34],
                [16, 104, 34],
                [16, 104, 34],
                [16, 105, 35],
                [16, 105, 35],
                [16, 106, 35],
                [16, 106, 35],
                [16, 107, 35],
                [16, 107, 35],
                [16, 108, 36],
                [16, 108, 36],
                [16, 109, 36],
                [17, 109, 36],
                [17, 110, 36],
                [17, 110, 36],
                [17, 111, 37],
                [17, 111, 37],
                [17, 112, 37],
                [17, 112, 37],
                [17, 113, 37],
                [17, 113, 37],
                [17, 114, 38],
                [17, 114, 38],
                [17, 115, 38],
                [17, 115, 38],
                [18, 116, 38],
                [18, 116, 38],
                [18, 117, 39],
                [18, 117, 39],
                [18, 118, 39],
                [18, 118, 39],
                [18, 119, 39],
                [18, 119, 39],
                [18, 120, 40],
                [18, 120, 40],
                [18, 121, 40],
                [18, 121, 40],
                [18, 122, 40],
                [19, 122, 40],
                [19, 123, 41],
                [19, 123, 41],
                [19, 124, 41],
                [19, 124, 41],
                [19, 125, 41],
                [19, 125, 41],
                [19, 126, 42],
                [19, 126, 42],
                [19, 127, 42],
                [19, 127, 42],
                [19, 128, 42],
                [20, 129, 43],
            ],
        );

        m.insert(
            "Quartetto MYGB Magenta",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [1, 0, 1],
                [2, 0, 1],
                [2, 0, 1],
                [2, 0, 1],
                [3, 0, 2],
                [3, 0, 2],
                [4, 0, 2],
                [4, 0, 3],
                [4, 0, 3],
                [5, 0, 3],
                [5, 0, 3],
                [6, 1, 4],
                [6, 1, 4],
                [6, 1, 4],
                [7, 1, 5],
                [7, 1, 5],
                [8, 1, 5],
                [8, 1, 5],
                [8, 1, 6],
                [9, 1, 6],
                [9, 1, 6],
                [10, 1, 6],
                [10, 1, 7],
                [10, 1, 7],
                [11, 1, 7],
                [11, 2, 8],
                [12, 2, 8],
                [12, 2, 8],
                [12, 2, 8],
                [13, 2, 9],
                [13, 2, 9],
                [14, 2, 9],
                [14, 2, 10],
                [14, 2, 10],
                [15, 2, 10],
                [15, 2, 10],
                [16, 2, 11],
                [16, 2, 11],
                [16, 2, 11],
                [17, 3, 11],
                [17, 3, 12],
                [18, 3, 12],
                [18, 3, 12],
                [18, 3, 13],
                [19, 3, 13],
                [19, 3, 13],
                [20, 3, 13],
                [20, 3, 14],
                [21, 3, 14],
                [21, 3, 14],
                [21, 3, 15],
                [22, 3, 15],
                [22, 3, 15],
                [23, 4, 15],
                [23, 4, 16],
                [23, 4, 16],
                [24, 4, 16],
                [24, 4, 16],
                [25, 4, 17],
                [25, 4, 17],
                [25, 4, 17],
                [26, 4, 18],
                [26, 4, 18],
                [27, 4, 18],
                [27, 4, 18],
                [27, 4, 19],
                [28, 4, 19],
                [28, 5, 19],
                [29, 5, 20],
                [29, 5, 20],
                [29, 5, 20],
                [30, 5, 20],
                [30, 5, 21],
                [31, 5, 21],
                [31, 5, 21],
                [31, 5, 21],
                [32, 5, 22],
                [32, 5, 22],
                [33, 5, 22],
                [33, 5, 23],
                [33, 5, 23],
                [34, 6, 23],
                [34, 6, 23],
                [35, 6, 24],
                [35, 6, 24],
                [35, 6, 24],
                [36, 6, 25],
                [36, 6, 25],
                [37, 6, 25],
                [37, 6, 25],
                [37, 6, 26],
                [38, 6, 26],
                [38, 6, 26],
                [39, 6, 27],
                [39, 6, 27],
                [39, 6, 27],
                [40, 7, 27],
                [40, 7, 28],
                [41, 7, 28],
                [41, 7, 28],
                [42, 7, 28],
                [42, 7, 29],
                [42, 7, 29],
                [43, 7, 29],
                [43, 7, 30],
                [44, 7, 30],
                [44, 7, 30],
                [44, 7, 30],
                [45, 7, 31],
                [45, 7, 31],
                [46, 8, 31],
                [46, 8, 32],
                [46, 8, 32],
                [47, 8, 32],
                [47, 8, 32],
                [48, 8, 33],
                [48, 8, 33],
                [48, 8, 33],
                [49, 8, 33],
                [49, 8, 34],
                [50, 8, 34],
                [50, 8, 34],
                [50, 8, 35],
                [51, 8, 35],
                [51, 9, 35],
                [52, 9, 35],
                [52, 9, 36],
                [52, 9, 36],
                [53, 9, 36],
                [53, 9, 37],
                [54, 9, 37],
                [54, 9, 37],
                [54, 9, 37],
                [55, 9, 38],
                [55, 9, 38],
                [56, 9, 38],
                [56, 9, 38],
                [56, 9, 39],
                [57, 10, 39],
                [57, 10, 39],
                [58, 10, 40],
                [58, 10, 40],
                [58, 10, 40],
                [59, 10, 40],
                [59, 10, 41],
                [60, 10, 41],
                [60, 10, 41],
                [60, 10, 42],
                [61, 10, 42],
                [61, 10, 42],
                [62, 10, 42],
                [62, 10, 43],
                [63, 11, 43],
                [63, 11, 43],
                [63, 11, 43],
                [64, 11, 44],
                [64, 11, 44],
                [65, 11, 44],
                [65, 11, 45],
                [65, 11, 45],
                [66, 11, 45],
                [66, 11, 45],
                [67, 11, 46],
                [67, 11, 46],
                [67, 11, 46],
                [68, 11, 47],
                [68, 12, 47],
                [69, 12, 47],
                [69, 12, 47],
                [69, 12, 48],
                [70, 12, 48],
                [70, 12, 48],
                [71, 12, 49],
                [71, 12, 49],
                [71, 12, 49],
                [72, 12, 49],
                [72, 12, 50],
                [73, 12, 50],
                [73, 12, 50],
                [73, 12, 50],
                [74, 12, 51],
                [74, 13, 51],
                [75, 13, 51],
                [75, 13, 52],
                [75, 13, 52],
                [76, 13, 52],
                [76, 13, 52],
                [77, 13, 53],
                [77, 13, 53],
                [77, 13, 53],
                [78, 13, 54],
                [78, 13, 54],
                [79, 13, 54],
                [79, 13, 54],
                [79, 13, 55],
                [80, 14, 55],
                [80, 14, 55],
                [81, 14, 55],
                [81, 14, 56],
                [81, 14, 56],
                [82, 14, 56],
                [82, 14, 57],
                [83, 14, 57],
                [83, 14, 57],
                [84, 14, 57],
                [84, 14, 58],
                [84, 14, 58],
                [85, 14, 58],
                [85, 14, 59],
                [86, 15, 59],
                [86, 15, 59],
                [86, 15, 59],
                [87, 15, 60],
                [87, 15, 60],
                [88, 15, 60],
                [88, 15, 60],
                [88, 15, 61],
                [89, 15, 61],
                [89, 15, 61],
                [90, 15, 62],
                [90, 15, 62],
                [90, 15, 62],
                [91, 15, 62],
                [91, 16, 63],
                [92, 16, 63],
                [92, 16, 63],
                [92, 16, 64],
                [93, 16, 64],
                [93, 16, 64],
                [94, 16, 64],
                [94, 16, 65],
                [94, 16, 65],
                [95, 16, 65],
                [95, 16, 65],
                [96, 16, 66],
                [96, 16, 66],
                [96, 16, 66],
                [97, 17, 67],
                [97, 17, 67],
                [98, 17, 67],
                [98, 17, 67],
                [98, 17, 68],
                [99, 17, 68],
                [99, 17, 68],
                [100, 17, 69],
                [100, 17, 69],
                [100, 17, 69],
                [101, 17, 69],
                [101, 17, 70],
                [102, 17, 70],
                [102, 17, 70],
                [103, 18, 71],
            ],
        );

        m.insert(
            "Quartetto MYGB Yellow",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [1, 1, 0],
                [2, 1, 0],
                [2, 1, 0],
                [3, 1, 0],
                [3, 2, 0],
                [3, 2, 0],
                [4, 2, 0],
                [4, 2, 0],
                [5, 3, 0],
                [5, 3, 0],
                [6, 3, 0],
                [6, 3, 0],
                [7, 4, 0],
                [7, 4, 0],
                [7, 4, 0],
                [8, 4, 0],
                [8, 5, 1],
                [9, 5, 1],
                [9, 5, 1],
                [10, 5, 1],
                [10, 6, 1],
                [11, 6, 1],
                [11, 6, 1],
                [11, 6, 1],
                [12, 7, 1],
                [12, 7, 1],
                [13, 7, 1],
                [13, 8, 1],
                [14, 8, 1],
                [14, 8, 1],
                [15, 8, 1],
                [15, 9, 1],
                [15, 9, 1],
                [16, 9, 1],
                [16, 9, 1],
                [17, 10, 1],
                [17, 10, 2],
                [18, 10, 2],
                [18, 10, 2],
                [19, 11, 2],
                [19, 11, 2],
                [19, 11, 2],
                [20, 11, 2],
                [20, 12, 2],
                [21, 12, 2],
                [21, 12, 2],
                [22, 12, 2],
                [22, 13, 2],
                [23, 13, 2],
                [23, 13, 2],
                [23, 13, 2],
                [24, 14, 2],
                [24, 14, 2],
                [25, 14, 2],
                [25, 15, 2],
                [26, 15, 3],
                [26, 15, 3],
                [27, 15, 3],
                [27, 16, 3],
                [27, 16, 3],
                [28, 16, 3],
                [28, 16, 3],
                [29, 17, 3],
                [29, 17, 3],
                [30, 17, 3],
                [30, 17, 3],
                [31, 18, 3],
                [31, 18, 3],
                [31, 18, 3],
                [32, 18, 3],
                [32, 19, 3],
                [33, 19, 3],
                [33, 19, 3],
                [34, 19, 3],
                [34, 20, 3],
                [35, 20, 4],
                [35, 20, 4],
                [35, 20, 4],
                [36, 21, 4],
                [36, 21, 4],
                [37, 21, 4],
                [37, 22, 4],
                [38, 22, 4],
                [38, 22, 4],
                [38, 22, 4],
                [39, 23, 4],
                [39, 23, 4],
                [40, 23, 4],
                [40, 23, 4],
                [41, 24, 4],
                [41, 24, 4],
                [42, 24, 4],
                [42, 24, 4],
                [42, 25, 4],
                [43, 25, 4],
                [43, 25, 5],
                [44, 25, 5],
                [44, 26, 5],
                [45, 26, 5],
                [45, 26, 5],
                [46, 26, 5],
                [46, 27, 5],
                [46, 27, 5],
                [47, 27, 5],
                [47, 27, 5],
                [48, 28, 5],
                [48, 28, 5],
                [49, 28, 5],
                [49, 28, 5],
                [50, 29, 5],
                [50, 29, 5],
                [50, 29, 5],
                [51, 30, 5],
                [51, 30, 5],
                [52, 30, 6],
                [52, 30, 6],
                [53, 31, 6],
                [53, 31, 6],
                [54, 31, 6],
                [54, 31, 6],
                [54, 32, 6],
                [55, 32, 6],
                [55, 32, 6],
                [56, 32, 6],
                [56, 33, 6],
                [57, 33, 6],
                [57, 33, 6],
                [58, 33, 6],
                [58, 34, 6],
                [58, 34, 6],
                [59, 34, 6],
                [59, 34, 6],
                [60, 35, 6],
                [60, 35, 6],
                [61, 35, 7],
                [61, 35, 7],
                [62, 36, 7],
                [62, 36, 7],
                [62, 36, 7],
                [63, 37, 7],
                [63, 37, 7],
                [64, 37, 7],
                [64, 37, 7],
                [65, 38, 7],
                [65, 38, 7],
                [66, 38, 7],
                [66, 38, 7],
                [66, 39, 7],
                [67, 39, 7],
                [67, 39, 7],
                [68, 39, 7],
                [68, 40, 7],
                [69, 40, 7],
                [69, 40, 8],
                [70, 40, 8],
                [70, 41, 8],
                [70, 41, 8],
                [71, 41, 8],
                [71, 41, 8],
                [72, 42, 8],
                [72, 42, 8],
                [73, 42, 8],
                [73, 42, 8],
                [74, 43, 8],
                [74, 43, 8],
                [74, 43, 8],
                [75, 44, 8],
                [75, 44, 8],
                [76, 44, 8],
                [76, 44, 8],
                [77, 45, 8],
                [77, 45, 8],
                [77, 45, 8],
                [78, 45, 9],
                [78, 46, 9],
                [79, 46, 9],
                [79, 46, 9],
                [80, 46, 9],
                [80, 47, 9],
                [81, 47, 9],
                [81, 47, 9],
                [81, 47, 9],
                [82, 48, 9],
                [82, 48, 9],
                [83, 48, 9],
                [83, 48, 9],
                [84, 49, 9],
                [84, 49, 9],
                [85, 49, 9],
                [85, 49, 9],
                [85, 50, 9],
                [86, 50, 9],
                [86, 50, 9],
                [87, 50, 10],
                [87, 51, 10],
                [88, 51, 10],
                [88, 51, 10],
                [89, 52, 10],
                [89, 52, 10],
                [89, 52, 10],
                [90, 52, 10],
                [90, 53, 10],
                [91, 53, 10],
                [91, 53, 10],
                [92, 53, 10],
                [92, 54, 10],
                [93, 54, 10],
                [93, 54, 10],
                [93, 54, 10],
                [94, 55, 10],
                [94, 55, 10],
                [95, 55, 10],
                [95, 55, 11],
                [96, 56, 11],
                [96, 56, 11],
                [97, 56, 11],
                [97, 56, 11],
                [97, 57, 11],
                [98, 57, 11],
                [98, 57, 11],
                [99, 57, 11],
                [99, 58, 11],
                [100, 58, 11],
                [100, 58, 11],
                [101, 59, 11],
                [101, 59, 11],
                [101, 59, 11],
                [102, 59, 11],
                [102, 60, 11],
                [103, 60, 11],
                [103, 60, 11],
                [104, 60, 11],
                [104, 61, 12],
                [105, 61, 12],
                [105, 61, 12],
                [105, 61, 12],
                [106, 62, 12],
                [106, 62, 12],
                [107, 62, 12],
                [107, 62, 12],
                [108, 63, 12],
                [108, 63, 12],
                [109, 63, 12],
                [109, 63, 12],
                [109, 64, 12],
                [110, 64, 12],
                [110, 64, 12],
                [111, 64, 12],
                [111, 65, 12],
                [112, 65, 12],
                [112, 65, 12],
                [113, 66, 13],
            ],
        );

        m.insert(
            "Quartetto RYGB Blue",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 1],
                [0, 0, 1],
                [0, 0, 2],
                [0, 0, 2],
                [0, 0, 3],
                [0, 1, 3],
                [0, 1, 4],
                [0, 1, 4],
                [0, 1, 5],
                [0, 1, 5],
                [0, 1, 6],
                [0, 1, 7],
                [0, 2, 7],
                [0, 2, 8],
                [0, 2, 8],
                [1, 2, 9],
                [1, 2, 9],
                [1, 2, 10],
                [1, 3, 10],
                [1, 3, 11],
                [1, 3, 11],
                [1, 3, 12],
                [1, 3, 12],
                [1, 3, 13],
                [1, 3, 14],
                [1, 4, 14],
                [1, 4, 15],
                [1, 4, 15],
                [1, 4, 16],
                [1, 4, 16],
                [1, 4, 17],
                [1, 5, 17],
                [2, 5, 18],
                [2, 5, 18],
                [2, 5, 19],
                [2, 5, 20],
                [2, 5, 20],
                [2, 5, 21],
                [2, 6, 21],
                [2, 6, 22],
                [2, 6, 22],
                [2, 6, 23],
                [2, 6, 23],
                [2, 6, 24],
                [2, 7, 24],
                [2, 7, 25],
                [2, 7, 25],
                [2, 7, 26],
                [2, 7, 27],
                [3, 7, 27],
                [3, 7, 28],
                [3, 8, 28],
                [3, 8, 29],
                [3, 8, 29],
                [3, 8, 30],
                [3, 8, 30],
                [3, 8, 31],
                [3, 9, 31],
                [3, 9, 32],
                [3, 9, 33],
                [3, 9, 33],
                [3, 9, 34],
                [3, 9, 34],
                [3, 9, 35],
                [3, 10, 35],
                [3, 10, 36],
                [4, 10, 36],
                [4, 10, 37],
                [4, 10, 37],
                [4, 10, 38],
                [4, 11, 38],
                [4, 11, 39],
                [4, 11, 40],
                [4, 11, 40],
                [4, 11, 41],
                [4, 11, 41],
                [4, 11, 42],
                [4, 12, 42],
                [4, 12, 43],
                [4, 12, 43],
                [4, 12, 44],
                [4, 12, 44],
                [4, 12, 45],
                [5, 13, 46],
                [5, 13, 46],
                [5, 13, 47],
                [5, 13, 47],
                [5, 13, 48],
                [5, 13, 48],
                [5, 13, 49],
                [5, 14, 49],
                [5, 14, 50],
                [5, 14, 50],
                [5, 14, 51],
                [5, 14, 51],
                [5, 14, 52],
                [5, 14, 53],
                [5, 15, 53],
                [5, 15, 54],
                [5, 15, 54],
                [6, 15, 55],
                [6, 15, 55],
                [6, 15, 56],
                [6, 16, 56],
                [6, 16, 57],
                [6, 16, 57],
                [6, 16, 58],
                [6, 16, 58],
                [6, 16, 59],
                [6, 16, 60],
                [6, 17, 60],
                [6, 17, 61],
                [6, 17, 61],
                [6, 17, 62],
                [6, 17, 62],
                [6, 17, 63],
                [6, 18, 63],
                [7, 18, 64],
                [7, 18, 64],
                [7, 18, 65],
                [7, 18, 66],
                [7, 18, 66],
                [7, 18, 67],
                [7, 19, 67],
                [7, 19, 68],
                [7, 19, 68],
                [7, 19, 69],
                [7, 19, 69],
                [7, 19, 70],
                [7, 20, 70],
                [7, 20, 71],
                [7, 20, 71],
                [7, 20, 72],
                [7, 20, 73],
                [8, 20, 73],
                [8, 20, 74],
                [8, 21, 74],
                [8, 21, 75],
                [8, 21, 75],
                [8, 21, 76],
                [8, 21, 76],
                [8, 21, 77],
                [8, 22, 77],
                [8, 22, 78],
                [8, 22, 79],
                [8, 22, 79],
                [8, 22, 80],
                [8, 22, 80],
                [8, 22, 81],
                [8, 23, 81],
                [8, 23, 82],
                [9, 23, 82],
                [9, 23, 83],
                [9, 23, 83],
                [9, 23, 84],
                [9, 24, 84],
                [9, 24, 85],
                [9, 24, 86],
                [9, 24, 86],
                [9, 24, 87],
                [9, 24, 87],
                [9, 24, 88],
                [9, 25, 88],
                [9, 25, 89],
                [9, 25, 89],
                [9, 25, 90],
                [9, 25, 90],
                [9, 25, 91],
                [10, 26, 92],
                [10, 26, 92],
                [10, 26, 93],
                [10, 26, 93],
                [10, 26, 94],
                [10, 26, 94],
                [10, 26, 95],
                [10, 27, 95],
                [10, 27, 96],
                [10, 27, 96],
                [10, 27, 97],
                [10, 27, 97],
                [10, 27, 98],
                [10, 27, 99],
                [10, 28, 99],
                [10, 28, 100],
                [10, 28, 100],
                [11, 28, 101],
                [11, 28, 101],
                [11, 28, 102],
                [11, 29, 102],
                [11, 29, 103],
                [11, 29, 103],
                [11, 29, 104],
                [11, 29, 104],
                [11, 29, 105],
                [11, 29, 106],
                [11, 30, 106],
                [11, 30, 107],
                [11, 30, 107],
                [11, 30, 108],
                [11, 30, 108],
                [11, 30, 109],
                [11, 31, 109],
                [12, 31, 110],
                [12, 31, 110],
                [12, 31, 111],
                [12, 31, 112],
                [12, 31, 112],
                [12, 31, 113],
                [12, 32, 113],
                [12, 32, 114],
                [12, 32, 114],
                [12, 32, 115],
                [12, 32, 115],
                [12, 32, 116],
                [12, 33, 116],
                [12, 33, 117],
                [12, 33, 117],
                [12, 33, 118],
                [12, 33, 119],
                [13, 33, 119],
                [13, 33, 120],
                [13, 34, 120],
                [13, 34, 121],
                [13, 34, 121],
                [13, 34, 122],
                [13, 34, 122],
                [13, 34, 123],
                [13, 35, 123],
                [13, 35, 124],
                [13, 35, 125],
                [13, 35, 125],
                [13, 35, 126],
                [13, 35, 126],
                [13, 35, 127],
                [13, 36, 127],
                [13, 36, 128],
                [14, 36, 128],
                [14, 36, 129],
                [14, 36, 129],
                [14, 36, 130],
                [14, 37, 130],
                [14, 37, 131],
                [14, 37, 132],
                [14, 37, 132],
                [14, 37, 133],
                [14, 37, 133],
                [14, 37, 134],
                [14, 38, 134],
                [14, 38, 135],
                [14, 38, 135],
                [14, 38, 136],
                [14, 38, 136],
                [14, 38, 137],
                [15, 39, 138],
            ],
        );

        m.insert(
            "Quartetto RYGB Green",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 1, 0],
                [0, 1, 0],
                [0, 2, 0],
                [0, 2, 1],
                [0, 3, 1],
                [0, 3, 1],
                [0, 4, 1],
                [0, 4, 1],
                [0, 5, 2],
                [0, 5, 2],
                [0, 6, 2],
                [0, 6, 2],
                [0, 7, 2],
                [1, 7, 3],
                [1, 8, 3],
                [1, 8, 3],
                [1, 9, 3],
                [1, 9, 3],
                [1, 10, 4],
                [1, 10, 4],
                [1, 11, 4],
                [1, 11, 4],
                [1, 12, 4],
                [1, 12, 5],
                [1, 13, 5],
                [1, 13, 5],
                [1, 14, 5],
                [1, 14, 5],
                [1, 15, 6],
                [2, 15, 6],
                [2, 16, 6],
                [2, 16, 6],
                [2, 17, 6],
                [2, 17, 7],
                [2, 18, 7],
                [2, 18, 7],
                [2, 19, 7],
                [2, 19, 7],
                [2, 20, 8],
                [2, 20, 8],
                [2, 21, 8],
                [2, 21, 8],
                [2, 22, 8],
                [2, 22, 9],
                [2, 23, 9],
                [3, 23, 9],
                [3, 24, 9],
                [3, 24, 9],
                [3, 25, 10],
                [3, 25, 10],
                [3, 26, 10],
                [3, 26, 10],
                [3, 27, 10],
                [3, 27, 10],
                [3, 28, 11],
                [3, 28, 11],
                [3, 29, 11],
                [3, 29, 11],
                [3, 30, 11],
                [3, 30, 12],
                [3, 31, 12],
                [4, 31, 12],
                [4, 32, 12],
                [4, 32, 12],
                [4, 33, 13],
                [4, 33, 13],
                [4, 34, 13],
                [4, 34, 13],
                [4, 35, 13],
                [4, 35, 14],
                [4, 36, 14],
                [4, 36, 14],
                [4, 37, 14],
                [4, 37, 14],
                [4, 38, 15],
                [4, 38, 15],
                [4, 39, 15],
                [5, 39, 15],
                [5, 40, 15],
                [5, 40, 16],
                [5, 41, 16],
                [5, 41, 16],
                [5, 42, 16],
                [5, 42, 16],
                [5, 42, 17],
                [5, 43, 17],
                [5, 43, 17],
                [5, 44, 17],
                [5, 44, 17],
                [5, 45, 18],
                [5, 45, 18],
                [5, 46, 18],
                [5, 46, 18],
                [6, 47, 18],
                [6, 47, 19],
                [6, 48, 19],
                [6, 48, 19],
                [6, 49, 19],
                [6, 49, 19],
                [6, 50, 20],
                [6, 50, 20],
                [6, 51, 20],
                [6, 51, 20],
                [6, 52, 20],
                [6, 52, 20],
                [6, 53, 21],
                [6, 53, 21],
                [6, 54, 21],
                [6, 54, 21],
                [7, 55, 21],
                [7, 55, 22],
                [7, 56, 22],
                [7, 56, 22],
                [7, 57, 22],
                [7, 57, 22],
                [7, 58, 23],
                [7, 58, 23],
                [7, 59, 23],
                [7, 59, 23],
                [7, 60, 23],
                [7, 60, 24],
                [7, 61, 24],
                [7, 61, 24],
                [7, 62, 24],
                [7, 62, 24],
                [8, 63, 25],
                [8, 63, 25],
                [8, 64, 25],
                [8, 64, 25],
                [8, 65, 25],
                [8, 65, 26],
                [8, 66, 26],
                [8, 66, 26],
                [8, 67, 26],
                [8, 67, 26],
                [8, 68, 27],
                [8, 68, 27],
                [8, 69, 27],
                [8, 69, 27],
                [8, 70, 27],
                [8, 70, 28],
                [9, 71, 28],
                [9, 71, 28],
                [9, 72, 28],
                [9, 72, 28],
                [9, 73, 29],
                [9, 73, 29],
                [9, 74, 29],
                [9, 74, 29],
                [9, 75, 29],
                [9, 75, 30],
                [9, 76, 30],
                [9, 76, 30],
                [9, 77, 30],
                [9, 77, 30],
                [9, 78, 30],
                [9, 78, 31],
                [10, 79, 31],
                [10, 79, 31],
                [10, 80, 31],
                [10, 80, 31],
                [10, 81, 32],
                [10, 81, 32],
                [10, 82, 32],
                [10, 82, 32],
                [10, 83, 32],
                [10, 83, 33],
                [10, 84, 33],
                [10, 84, 33],
                [10, 84, 33],
                [10, 85, 33],
                [10, 85, 34],
                [10, 86, 34],
                [11, 86, 34],
                [11, 87, 34],
                [11, 87, 34],
                [11, 88, 35],
                [11, 88, 35],
                [11, 89, 35],
                [11, 89, 35],
                [11, 90, 35],
                [11, 90, 36],
                [11, 91, 36],
                [11, 91, 36],
                [11, 92, 36],
                [11, 92, 36],
                [11, 93, 37],
                [11, 93, 37],
                [11, 94, 37],
                [12, 94, 37],
                [12, 95, 37],
                [12, 95, 38],
                [12, 96, 38],
                [12, 96, 38],
                [12, 97, 38],
                [12, 97, 38],
                [12, 98, 39],
                [12, 98, 39],
                [12, 99, 39],
                [12, 99, 39],
                [12, 100, 39],
                [12, 100, 40],
                [12, 101, 40],
                [12, 101, 40],
                [12, 102, 40],
                [13, 102, 40],
                [13, 103, 40],
                [13, 103, 41],
                [13, 104, 41],
                [13, 104, 41],
                [13, 105, 41],
                [13, 105, 41],
                [13, 106, 42],
                [13, 106, 42],
                [13, 107, 42],
                [13, 107, 42],
                [13, 108, 42],
                [13, 108, 43],
                [13, 109, 43],
                [13, 109, 43],
                [13, 110, 43],
                [14, 110, 43],
                [14, 111, 44],
                [14, 111, 44],
                [14, 112, 44],
                [14, 112, 44],
                [14, 113, 44],
                [14, 113, 45],
                [14, 114, 45],
                [14, 114, 45],
                [14, 115, 45],
                [14, 115, 45],
                [14, 116, 46],
                [14, 116, 46],
                [14, 117, 46],
                [14, 117, 46],
                [14, 118, 46],
                [15, 118, 47],
                [15, 119, 47],
                [15, 119, 47],
                [15, 120, 47],
                [15, 120, 47],
                [15, 121, 48],
                [15, 121, 48],
                [15, 122, 48],
                [15, 122, 48],
                [15, 123, 48],
                [15, 123, 49],
                [15, 124, 49],
                [15, 124, 49],
                [15, 125, 49],
                [15, 125, 49],
                [16, 126, 50],
            ],
        );

        m.insert(
            "Quartetto RYGB Red",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [1, 0, 0],
                [2, 0, 1],
                [2, 0, 1],
                [3, 0, 1],
                [3, 0, 1],
                [4, 0, 1],
                [4, 0, 2],
                [5, 0, 2],
                [5, 0, 2],
                [6, 0, 2],
                [6, 0, 2],
                [7, 1, 3],
                [7, 1, 3],
                [8, 1, 3],
                [8, 1, 3],
                [9, 1, 3],
                [9, 1, 4],
                [10, 1, 4],
                [10, 1, 4],
                [11, 1, 4],
                [11, 1, 4],
                [12, 1, 5],
                [12, 1, 5],
                [13, 1, 5],
                [13, 1, 5],
                [13, 2, 5],
                [14, 2, 6],
                [14, 2, 6],
                [15, 2, 6],
                [15, 2, 6],
                [16, 2, 6],
                [16, 2, 7],
                [17, 2, 7],
                [17, 2, 7],
                [18, 2, 7],
                [18, 2, 7],
                [19, 2, 8],
                [19, 2, 8],
                [20, 2, 8],
                [20, 3, 8],
                [21, 3, 8],
                [21, 3, 9],
                [22, 3, 9],
                [22, 3, 9],
                [23, 3, 9],
                [23, 3, 9],
                [24, 3, 10],
                [24, 3, 10],
                [25, 3, 10],
                [25, 3, 10],
                [26, 3, 10],
                [26, 3, 11],
                [27, 3, 11],
                [27, 4, 11],
                [27, 4, 11],
                [28, 4, 11],
                [28, 4, 12],
                [29, 4, 12],
                [29, 4, 12],
                [30, 4, 12],
                [30, 4, 12],
                [31, 4, 13],
                [31, 4, 13],
                [32, 4, 13],
                [32, 4, 13],
                [33, 4, 13],
                [33, 4, 14],
                [34, 5, 14],
                [34, 5, 14],
                [35, 5, 14],
                [35, 5, 14],
                [36, 5, 15],
                [36, 5, 15],
                [37, 5, 15],
                [37, 5, 15],
                [38, 5, 15],
                [38, 5, 16],
                [39, 5, 16],
                [39, 5, 16],
                [40, 5, 16],
                [40, 5, 16],
                [41, 6, 17],
                [41, 6, 17],
                [41, 6, 17],
                [42, 6, 17],
                [42, 6, 17],
                [43, 6, 18],
                [43, 6, 18],
                [44, 6, 18],
                [44, 6, 18],
                [45, 6, 18],
                [45, 6, 19],
                [46, 6, 19],
                [46, 6, 19],
                [47, 6, 19],
                [47, 6, 19],
                [48, 7, 20],
                [48, 7, 20],
                [49, 7, 20],
                [49, 7, 20],
                [50, 7, 20],
                [50, 7, 21],
                [51, 7, 21],
                [51, 7, 21],
                [52, 7, 21],
                [52, 7, 21],
                [53, 7, 22],
                [53, 7, 22],
                [54, 7, 22],
                [54, 7, 22],
                [54, 8, 22],
                [55, 8, 23],
                [55, 8, 23],
                [56, 8, 23],
                [56, 8, 23],
                [57, 8, 23],
                [57, 8, 24],
                [58, 8, 24],
                [58, 8, 24],
                [59, 8, 24],
                [59, 8, 24],
                [60, 8, 25],
                [60, 8, 25],
                [61, 8, 25],
                [61, 9, 25],
                [62, 9, 25],
                [62, 9, 26],
                [63, 9, 26],
                [63, 9, 26],
                [64, 9, 26],
                [64, 9, 26],
                [65, 9, 27],
                [65, 9, 27],
                [66, 9, 27],
                [66, 9, 27],
                [67, 9, 27],
                [67, 9, 28],
                [68, 9, 28],
                [68, 10, 28],
                [68, 10, 28],
                [69, 10, 28],
                [69, 10, 29],
                [70, 10, 29],
                [70, 10, 29],
                [71, 10, 29],
                [71, 10, 29],
                [72, 10, 30],
                [72, 10, 30],
                [73, 10, 30],
                [73, 10, 30],
                [74, 10, 30],
                [74, 10, 30],
                [75, 11, 31],
                [75, 11, 31],
                [76, 11, 31],
                [76, 11, 31],
                [77, 11, 32],
                [77, 11, 32],
                [78, 11, 32],
                [78, 11, 32],
                [79, 11, 32],
                [79, 11, 33],
                [80, 11, 33],
                [80, 11, 33],
                [81, 11, 33],
                [81, 11, 33],
                [82, 12, 34],
                [82, 12, 34],
                [82, 12, 34],
                [83, 12, 34],
                [83, 12, 34],
                [84, 12, 35],
                [84, 12, 35],
                [85, 12, 35],
                [85, 12, 35],
                [86, 12, 35],
                [86, 12, 36],
                [87, 12, 36],
                [87, 12, 36],
                [88, 12, 36],
                [88, 12, 36],
                [89, 13, 37],
                [89, 13, 37],
                [90, 13, 37],
                [90, 13, 37],
                [91, 13, 37],
                [91, 13, 38],
                [92, 13, 38],
                [92, 13, 38],
                [93, 13, 38],
                [93, 13, 38],
                [94, 13, 39],
                [94, 13, 39],
                [95, 13, 39],
                [95, 13, 39],
                [95, 14, 39],
                [96, 14, 40],
                [96, 14, 40],
                [97, 14, 40],
                [97, 14, 40],
                [98, 14, 40],
                [98, 14, 41],
                [99, 14, 41],
                [99, 14, 41],
                [100, 14, 41],
                [100, 14, 41],
                [101, 14, 42],
                [101, 14, 42],
                [102, 14, 42],
                [102, 15, 42],
                [103, 15, 42],
                [103, 15, 43],
                [104, 15, 43],
                [104, 15, 43],
                [105, 15, 43],
                [105, 15, 43],
                [106, 15, 44],
                [106, 15, 44],
                [107, 15, 44],
                [107, 15, 44],
                [108, 15, 44],
                [108, 15, 45],
                [109, 15, 45],
                [109, 16, 45],
                [109, 16, 45],
                [110, 16, 45],
                [110, 16, 46],
                [111, 16, 46],
                [111, 16, 46],
                [112, 16, 46],
                [112, 16, 46],
                [113, 16, 47],
                [113, 16, 47],
                [114, 16, 47],
                [114, 16, 47],
                [115, 16, 47],
                [115, 16, 48],
                [116, 17, 48],
                [116, 17, 48],
                [117, 17, 48],
                [117, 17, 48],
                [118, 17, 49],
                [118, 17, 49],
                [119, 17, 49],
                [119, 17, 49],
                [120, 17, 49],
                [120, 17, 50],
                [121, 17, 50],
                [121, 17, 50],
                [122, 17, 50],
                [122, 17, 50],
                [123, 18, 51],
            ],
        );

        m.insert(
            "Quartetto RYGB Yellow",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [1, 1, 0],
                [2, 1, 0],
                [2, 1, 0],
                [2, 2, 0],
                [3, 2, 0],
                [3, 2, 0],
                [4, 2, 0],
                [4, 3, 0],
                [4, 3, 0],
                [5, 3, 0],
                [5, 4, 0],
                [6, 4, 1],
                [6, 4, 1],
                [6, 4, 1],
                [7, 5, 1],
                [7, 5, 1],
                [8, 5, 1],
                [8, 6, 1],
                [8, 6, 1],
                [9, 6, 1],
                [9, 6, 1],
                [10, 7, 1],
                [10, 7, 1],
                [10, 7, 1],
                [11, 8, 1],
                [11, 8, 1],
                [12, 8, 2],
                [12, 8, 2],
                [12, 9, 2],
                [13, 9, 2],
                [13, 9, 2],
                [14, 10, 2],
                [14, 10, 2],
                [14, 10, 2],
                [15, 10, 2],
                [15, 11, 2],
                [16, 11, 2],
                [16, 11, 2],
                [16, 12, 2],
                [17, 12, 2],
                [17, 12, 2],
                [18, 12, 2],
                [18, 13, 3],
                [18, 13, 3],
                [19, 13, 3],
                [19, 14, 3],
                [20, 14, 3],
                [20, 14, 3],
                [20, 14, 3],
                [21, 15, 3],
                [21, 15, 3],
                [22, 15, 3],
                [22, 16, 3],
                [22, 16, 3],
                [23, 16, 3],
                [23, 16, 3],
                [24, 17, 4],
                [24, 17, 4],
                [24, 17, 4],
                [25, 18, 4],
                [25, 18, 4],
                [26, 18, 4],
                [26, 18, 4],
                [26, 19, 4],
                [27, 19, 4],
                [27, 19, 4],
                [28, 20, 4],
                [28, 20, 4],
                [28, 20, 4],
                [29, 20, 4],
                [29, 21, 4],
                [30, 21, 5],
                [30, 21, 5],
                [30, 22, 5],
                [31, 22, 5],
                [31, 22, 5],
                [32, 22, 5],
                [32, 23, 5],
                [32, 23, 5],
                [33, 23, 5],
                [33, 24, 5],
                [34, 24, 5],
                [34, 24, 5],
                [34, 24, 5],
                [35, 25, 5],
                [35, 25, 5],
                [36, 25, 5],
                [36, 26, 6],
                [36, 26, 6],
                [37, 26, 6],
                [37, 26, 6],
                [38, 27, 6],
                [38, 27, 6],
                [38, 27, 6],
                [39, 28, 6],
                [39, 28, 6],
                [40, 28, 6],
                [40, 28, 6],
                [40, 29, 6],
                [41, 29, 6],
                [41, 29, 6],
                [42, 30, 7],
                [42, 30, 7],
                [42, 30, 7],
                [43, 30, 7],
                [43, 31, 7],
                [44, 31, 7],
                [44, 31, 7],
                [44, 32, 7],
                [45, 32, 7],
                [45, 32, 7],
                [46, 32, 7],
                [46, 33, 7],
                [46, 33, 7],
                [47, 33, 7],
                [47, 34, 7],
                [48, 34, 8],
                [48, 34, 8],
                [48, 34, 8],
                [49, 35, 8],
                [49, 35, 8],
                [50, 35, 8],
                [50, 36, 8],
                [50, 36, 8],
                [51, 36, 8],
                [51, 36, 8],
                [52, 37, 8],
                [52, 37, 8],
                [52, 37, 8],
                [53, 38, 8],
                [53, 38, 8],
                [54, 38, 9],
                [54, 38, 9],
                [54, 39, 9],
                [55, 39, 9],
                [55, 39, 9],
                [56, 40, 9],
                [56, 40, 9],
                [56, 40, 9],
                [57, 40, 9],
                [57, 41, 9],
                [58, 41, 9],
                [58, 41, 9],
                [58, 42, 9],
                [59, 42, 9],
                [59, 42, 9],
                [60, 42, 10],
                [60, 43, 10],
                [60, 43, 10],
                [61, 43, 10],
                [61, 44, 10],
                [61, 44, 10],
                [62, 44, 10],
                [62, 44, 10],
                [63, 45, 10],
                [63, 45, 10],
                [64, 45, 10],
                [64, 46, 10],
                [64, 46, 10],
                [65, 46, 10],
                [65, 46, 10],
                [66, 47, 11],
                [66, 47, 11],
                [66, 47, 11],
                [67, 48, 11],
                [67, 48, 11],
                [68, 48, 11],
                [68, 48, 11],
                [68, 49, 11],
                [69, 49, 11],
                [69, 49, 11],
                [70, 50, 11],
                [70, 50, 11],
                [70, 50, 11],
                [71, 50, 11],
                [71, 51, 11],
                [72, 51, 11],
                [72, 51, 12],
                [72, 52, 12],
                [73, 52, 12],
                [73, 52, 12],
                [74, 52, 12],
                [74, 53, 12],
                [74, 53, 12],
                [75, 53, 12],
                [75, 54, 12],
                [76, 54, 12],
                [76, 54, 12],
                [76, 54, 12],
                [77, 55, 12],
                [77, 55, 12],
                [78, 55, 13],
                [78, 56, 13],
                [78, 56, 13],
                [79, 56, 13],
                [79, 56, 13],
                [80, 57, 13],
                [80, 57, 13],
                [80, 57, 13],
                [81, 58, 13],
                [81, 58, 13],
                [82, 58, 13],
                [82, 58, 13],
                [82, 59, 13],
                [83, 59, 13],
                [83, 59, 13],
                [84, 60, 14],
                [84, 60, 14],
                [84, 60, 14],
                [85, 60, 14],
                [85, 61, 14],
                [86, 61, 14],
                [86, 61, 14],
                [86, 62, 14],
                [87, 62, 14],
                [87, 62, 14],
                [88, 62, 14],
                [88, 63, 14],
                [88, 63, 14],
                [89, 63, 14],
                [89, 64, 14],
                [90, 64, 15],
                [90, 64, 15],
                [90, 64, 15],
                [91, 65, 15],
                [91, 65, 15],
                [92, 65, 15],
                [92, 66, 15],
                [92, 66, 15],
                [93, 66, 15],
                [93, 66, 15],
                [94, 67, 15],
                [94, 67, 15],
                [94, 67, 15],
                [95, 68, 15],
                [95, 68, 15],
                [96, 68, 16],
                [96, 68, 16],
                [96, 69, 16],
                [97, 69, 16],
                [97, 69, 16],
                [98, 70, 16],
                [98, 70, 16],
                [98, 70, 16],
                [99, 70, 16],
                [99, 71, 16],
                [100, 71, 16],
                [100, 71, 16],
                [100, 72, 16],
                [101, 72, 16],
                [101, 72, 16],
                [102, 73, 17],
            ],
        );

        m.insert(
            "Rainbow RGB",
            [
                [0, 0, 0],
                [0, 0, 5],
                [0, 0, 10],
                [0, 1, 15],
                [0, 1, 20],
                [0, 1, 25],
                [1, 1, 30],
                [1, 1, 35],
                [1, 2, 40],
                [1, 2, 45],
                [1, 2, 50],
                [1, 2, 55],
                [1, 2, 60],
                [1, 3, 65],
                [1, 3, 70],
                [2, 3, 75],
                [2, 3, 80],
                [2, 3, 85],
                [2, 4, 90],
                [2, 4, 95],
                [2, 4, 100],
                [2, 4, 105],
                [2, 4, 110],
                [2, 5, 115],
                [2, 5, 120],
                [3, 5, 125],
                [3, 5, 129],
                [3, 5, 134],
                [3, 6, 139],
                [3, 6, 144],
                [3, 6, 149],
                [3, 6, 154],
                [3, 6, 159],
                [3, 7, 164],
                [3, 7, 169],
                [4, 7, 174],
                [4, 7, 179],
                [4, 7, 184],
                [4, 8, 189],
                [4, 8, 194],
                [4, 8, 199],
                [4, 8, 204],
                [4, 8, 209],
                [4, 9, 214],
                [4, 9, 219],
                [4, 9, 224],
                [5, 9, 229],
                [5, 9, 234],
                [5, 10, 239],
                [5, 10, 244],
                [5, 10, 249],
                [5, 15, 244],
                [5, 20, 239],
                [5, 24, 235],
                [5, 29, 230],
                [5, 34, 225],
                [6, 39, 220],
                [6, 44, 215],
                [6, 48, 211],
                [6, 53, 206],
                [6, 58, 201],
                [6, 63, 196],
                [6, 68, 191],
                [6, 72, 187],
                [6, 77, 182],
                [6, 82, 177],
                [7, 87, 172],
                [7, 92, 167],
                [7, 96, 163],
                [7, 101, 158],
                [7, 106, 153],
                [7, 111, 148],
                [7, 116, 143],
                [7, 120, 139],
                [7, 125, 134],
                [7, 129, 129],
                [8, 134, 125],
                [8, 139, 120],
                [8, 143, 116],
                [8, 148, 111],
                [8, 153, 106],
                [8, 158, 101],
                [8, 163, 96],
                [8, 167, 92],
                [8, 172, 87],
                [8, 177, 82],
                [9, 182, 77],
                [9, 187, 72],
                [9, 191, 68],
                [9, 196, 63],
                [9, 201, 58],
                [9, 206, 53],
                [9, 211, 48],
                [9, 215, 44],
                [9, 220, 39],
                [9, 225, 34],
                [10, 230, 29],
                [10, 235, 24],
                [10, 239, 20],
                [10, 244, 15],
                [10, 249, 10],
                [12, 247, 10],
                [15, 244, 10],
                [17, 242, 10],
                [20, 239, 10],
                [22, 237, 10],
                [24, 235, 10],
                [27, 232, 10],
                [29, 230, 10],
                [32, 227, 10],
                [34, 225, 10],
                [36, 223, 10],
                [39, 220, 10],
                [41, 218, 10],
                [44, 215, 10],
                [46, 213, 10],
                [48, 211, 10],
                [51, 208, 10],
                [53, 206, 10],
                [56, 203, 10],
                [58, 201, 10],
                [60, 199, 10],
                [63, 196, 10],
                [65, 194, 10],
                [68, 191, 10],
                [70, 189, 10],
                [72, 187, 10],
                [75, 184, 10],
                [77, 182, 10],
                [77, 182, 10],
                [80, 179, 10],
                [82, 177, 10],
                [84, 175, 10],
                [87, 172, 10],
                [89, 170, 10],
                [92, 167, 10],
                [94, 165, 10],
                [96, 163, 10],
                [99, 160, 10],
                [101, 158, 10],
                [104, 155, 10],
                [106, 153, 10],
                [108, 151, 10],
                [111, 148, 10],
                [113, 146, 10],
                [116, 143, 10],
                [118, 141, 10],
                [120, 139, 10],
                [123, 136, 10],
                [125, 134, 10],
                [128, 131, 10],
                [129, 129, 10],
                [131, 128, 10],
                [134, 125, 10],
                [136, 123, 10],
                [139, 120, 10],
                [141, 118, 10],
                [143, 116, 10],
                [146, 113, 10],
                [148, 111, 10],
                [151, 108, 10],
                [153, 106, 10],
                [155, 104, 10],
                [158, 101, 10],
                [160, 99, 10],
                [163, 96, 10],
                [165, 94, 10],
                [167, 92, 10],
                [170, 89, 10],
                [172, 87, 10],
                [175, 84, 10],
                [177, 82, 10],
                [179, 80, 10],
                [182, 77, 10],
                [184, 75, 10],
                [187, 72, 10],
                [189, 70, 10],
                [191, 68, 10],
                [194, 65, 10],
                [196, 63, 10],
                [199, 60, 10],
                [201, 58, 10],
                [203, 56, 10],
                [206, 53, 10],
                [208, 51, 10],
                [211, 48, 10],
                [213, 46, 10],
                [215, 44, 10],
                [218, 41, 10],
                [220, 39, 10],
                [223, 36, 10],
                [225, 34, 10],
                [227, 32, 10],
                [230, 29, 10],
                [232, 27, 10],
                [235, 24, 10],
                [237, 22, 10],
                [239, 20, 10],
                [242, 17, 10],
                [244, 15, 10],
                [247, 12, 10],
                [249, 10, 10],
                [247, 10, 13],
                [245, 10, 15],
                [244, 10, 18],
                [242, 10, 20],
                [240, 10, 23],
                [238, 10, 25],
                [236, 10, 28],
                [234, 10, 30],
                [233, 10, 33],
                [231, 10, 35],
                [229, 10, 38],
                [227, 10, 41],
                [225, 10, 43],
                [224, 10, 46],
                [222, 10, 48],
                [220, 10, 51],
                [218, 10, 53],
                [216, 10, 56],
                [214, 10, 58],
                [213, 10, 61],
                [211, 10, 63],
                [209, 10, 66],
                [207, 10, 69],
                [205, 10, 71],
                [204, 10, 74],
                [202, 10, 76],
                [200, 10, 79],
                [198, 10, 81],
                [196, 10, 84],
                [194, 10, 86],
                [193, 16, 89],
                [191, 21, 91],
                [189, 27, 94],
                [187, 32, 97],
                [185, 38, 99],
                [184, 44, 102],
                [182, 49, 104],
                [180, 55, 107],
                [178, 60, 109],
                [176, 66, 112],
                [174, 72, 114],
                [173, 77, 117],
                [171, 83, 119],
                [169, 88, 122],
                [167, 94, 125],
                [165, 100, 127],
                [164, 105, 129],
                [162, 111, 131],
                [160, 116, 134],
                [158, 122, 136],
                [156, 128, 139],
                [154, 132, 141],
                [153, 138, 144],
                [151, 143, 146],
            ],
        );

        m.insert(
            "Red",
            [
                [0, 0, 0],
                [1, 0, 0],
                [2, 0, 0],
                [3, 0, 0],
                [4, 0, 0],
                [5, 0, 0],
                [6, 0, 0],
                [7, 0, 0],
                [8, 0, 0],
                [9, 0, 0],
                [10, 0, 0],
                [11, 0, 0],
                [12, 0, 0],
                [13, 0, 0],
                [14, 0, 0],
                [15, 0, 0],
                [16, 0, 0],
                [17, 0, 0],
                [18, 0, 0],
                [19, 0, 0],
                [20, 0, 0],
                [21, 0, 0],
                [22, 0, 0],
                [23, 0, 0],
                [24, 0, 0],
                [25, 0, 0],
                [26, 0, 0],
                [27, 0, 0],
                [28, 0, 0],
                [29, 0, 0],
                [30, 0, 0],
                [31, 0, 0],
                [32, 0, 0],
                [33, 0, 0],
                [34, 0, 0],
                [35, 0, 0],
                [36, 0, 0],
                [37, 0, 0],
                [38, 0, 0],
                [39, 0, 0],
                [40, 0, 0],
                [41, 0, 0],
                [42, 0, 0],
                [43, 0, 0],
                [44, 0, 0],
                [45, 0, 0],
                [46, 0, 0],
                [47, 0, 0],
                [48, 0, 0],
                [49, 0, 0],
                [50, 0, 0],
                [51, 0, 0],
                [52, 0, 0],
                [53, 0, 0],
                [54, 0, 0],
                [55, 0, 0],
                [56, 0, 0],
                [57, 0, 0],
                [58, 0, 0],
                [59, 0, 0],
                [60, 0, 0],
                [61, 0, 0],
                [62, 0, 0],
                [63, 0, 0],
                [64, 0, 0],
                [65, 0, 0],
                [66, 0, 0],
                [67, 0, 0],
                [68, 0, 0],
                [69, 0, 0],
                [70, 0, 0],
                [71, 0, 0],
                [72, 0, 0],
                [73, 0, 0],
                [74, 0, 0],
                [75, 0, 0],
                [76, 0, 0],
                [77, 0, 0],
                [78, 0, 0],
                [79, 0, 0],
                [80, 0, 0],
                [81, 0, 0],
                [82, 0, 0],
                [83, 0, 0],
                [84, 0, 0],
                [85, 0, 0],
                [86, 0, 0],
                [87, 0, 0],
                [88, 0, 0],
                [89, 0, 0],
                [90, 0, 0],
                [91, 0, 0],
                [92, 0, 0],
                [93, 0, 0],
                [94, 0, 0],
                [95, 0, 0],
                [96, 0, 0],
                [97, 0, 0],
                [98, 0, 0],
                [99, 0, 0],
                [100, 0, 0],
                [101, 0, 0],
                [102, 0, 0],
                [103, 0, 0],
                [104, 0, 0],
                [105, 0, 0],
                [106, 0, 0],
                [107, 0, 0],
                [108, 0, 0],
                [109, 0, 0],
                [110, 0, 0],
                [111, 0, 0],
                [112, 0, 0],
                [113, 0, 0],
                [114, 0, 0],
                [115, 0, 0],
                [116, 0, 0],
                [117, 0, 0],
                [118, 0, 0],
                [119, 0, 0],
                [120, 0, 0],
                [121, 0, 0],
                [122, 0, 0],
                [123, 0, 0],
                [124, 0, 0],
                [125, 0, 0],
                [126, 0, 0],
                [127, 0, 0],
                [128, 0, 0],
                [129, 0, 0],
                [130, 0, 0],
                [131, 0, 0],
                [132, 0, 0],
                [133, 0, 0],
                [134, 0, 0],
                [135, 0, 0],
                [136, 0, 0],
                [137, 0, 0],
                [138, 0, 0],
                [139, 0, 0],
                [140, 0, 0],
                [141, 0, 0],
                [142, 0, 0],
                [143, 0, 0],
                [144, 0, 0],
                [145, 0, 0],
                [146, 0, 0],
                [147, 0, 0],
                [148, 0, 0],
                [149, 0, 0],
                [150, 0, 0],
                [151, 0, 0],
                [152, 0, 0],
                [153, 0, 0],
                [154, 0, 0],
                [155, 0, 0],
                [156, 0, 0],
                [157, 0, 0],
                [158, 0, 0],
                [159, 0, 0],
                [160, 0, 0],
                [161, 0, 0],
                [162, 0, 0],
                [163, 0, 0],
                [164, 0, 0],
                [165, 0, 0],
                [166, 0, 0],
                [167, 0, 0],
                [168, 0, 0],
                [169, 0, 0],
                [170, 0, 0],
                [171, 0, 0],
                [172, 0, 0],
                [173, 0, 0],
                [174, 0, 0],
                [175, 0, 0],
                [176, 0, 0],
                [177, 0, 0],
                [178, 0, 0],
                [179, 0, 0],
                [180, 0, 0],
                [181, 0, 0],
                [182, 0, 0],
                [183, 0, 0],
                [184, 0, 0],
                [185, 0, 0],
                [186, 0, 0],
                [187, 0, 0],
                [188, 0, 0],
                [189, 0, 0],
                [190, 0, 0],
                [191, 0, 0],
                [192, 0, 0],
                [193, 0, 0],
                [194, 0, 0],
                [195, 0, 0],
                [196, 0, 0],
                [197, 0, 0],
                [198, 0, 0],
                [199, 0, 0],
                [200, 0, 0],
                [201, 0, 0],
                [202, 0, 0],
                [203, 0, 0],
                [204, 0, 0],
                [205, 0, 0],
                [206, 0, 0],
                [207, 0, 0],
                [208, 0, 0],
                [209, 0, 0],
                [210, 0, 0],
                [211, 0, 0],
                [212, 0, 0],
                [213, 0, 0],
                [214, 0, 0],
                [215, 0, 0],
                [216, 0, 0],
                [217, 0, 0],
                [218, 0, 0],
                [219, 0, 0],
                [220, 0, 0],
                [221, 0, 0],
                [222, 0, 0],
                [223, 0, 0],
                [224, 0, 0],
                [225, 0, 0],
                [226, 0, 0],
                [227, 0, 0],
                [228, 0, 0],
                [229, 0, 0],
                [230, 0, 0],
                [231, 0, 0],
                [232, 0, 0],
                [233, 0, 0],
                [234, 0, 0],
                [235, 0, 0],
                [236, 0, 0],
                [237, 0, 0],
                [238, 0, 0],
                [239, 0, 0],
                [240, 0, 0],
                [241, 0, 0],
                [242, 0, 0],
                [243, 0, 0],
                [244, 0, 0],
                [245, 0, 0],
                [246, 0, 0],
                [247, 0, 0],
                [248, 0, 0],
                [249, 0, 0],
                [250, 0, 0],
                [251, 0, 0],
                [252, 0, 0],
                [253, 0, 0],
                [254, 0, 0],
                [255, 0, 0],
            ],
        );

        m.insert(
            "Red Hot",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [4, 0, 0],
                [7, 0, 0],
                [10, 0, 0],
                [13, 0, 0],
                [16, 0, 0],
                [20, 0, 0],
                [23, 0, 0],
                [27, 0, 0],
                [30, 0, 0],
                [33, 0, 0],
                [36, 0, 0],
                [39, 0, 0],
                [42, 0, 0],
                [45, 0, 0],
                [48, 0, 0],
                [52, 0, 0],
                [55, 0, 0],
                [58, 0, 0],
                [61, 0, 0],
                [65, 0, 0],
                [68, 0, 0],
                [71, 0, 0],
                [74, 0, 0],
                [78, 0, 0],
                [81, 0, 0],
                [84, 0, 0],
                [87, 0, 0],
                [90, 0, 0],
                [93, 0, 0],
                [96, 0, 0],
                [99, 0, 0],
                [103, 0, 0],
                [106, 0, 0],
                [110, 0, 0],
                [113, 0, 0],
                [117, 0, 0],
                [120, 0, 0],
                [123, 0, 0],
                [126, 0, 0],
                [130, 0, 0],
                [133, 0, 0],
                [136, 0, 0],
                [139, 0, 0],
                [142, 0, 0],
                [145, 0, 0],
                [148, 0, 0],
                [151, 0, 0],
                [155, 0, 0],
                [158, 0, 0],
                [161, 0, 0],
                [164, 0, 0],
                [168, 0, 0],
                [171, 0, 0],
                [174, 0, 0],
                [177, 0, 0],
                [181, 0, 0],
                [184, 0, 0],
                [187, 0, 0],
                [190, 0, 0],
                [193, 0, 0],
                [196, 0, 0],
                [200, 0, 0],
                [203, 0, 0],
                [207, 0, 0],
                [210, 0, 0],
                [213, 0, 0],
                [216, 0, 0],
                [220, 0, 0],
                [223, 0, 0],
                [226, 0, 0],
                [229, 0, 0],
                [233, 0, 0],
                [236, 0, 0],
                [239, 0, 0],
                [242, 0, 0],
                [245, 0, 0],
                [247, 0, 0],
                [250, 1, 0],
                [252, 2, 0],
                [255, 3, 0],
                [255, 6, 0],
                [255, 9, 0],
                [255, 12, 0],
                [255, 16, 0],
                [255, 19, 0],
                [255, 22, 0],
                [255, 25, 0],
                [255, 29, 0],
                [255, 32, 0],
                [255, 35, 0],
                [255, 38, 0],
                [255, 42, 0],
                [255, 45, 0],
                [255, 48, 0],
                [255, 51, 0],
                [255, 55, 0],
                [255, 58, 0],
                [255, 61, 0],
                [255, 64, 0],
                [255, 68, 0],
                [255, 71, 0],
                [255, 74, 0],
                [255, 77, 0],
                [255, 81, 0],
                [255, 84, 0],
                [255, 87, 0],
                [255, 90, 0],
                [255, 94, 0],
                [255, 97, 0],
                [255, 100, 0],
                [255, 103, 0],
                [255, 106, 0],
                [255, 109, 0],
                [255, 112, 0],
                [255, 115, 0],
                [255, 119, 0],
                [255, 122, 0],
                [255, 126, 0],
                [255, 129, 0],
                [255, 133, 0],
                [255, 136, 0],
                [255, 139, 0],
                [255, 142, 0],
                [255, 145, 0],
                [255, 148, 0],
                [255, 151, 0],
                [255, 154, 0],
                [255, 158, 0],
                [255, 161, 0],
                [255, 164, 0],
                [255, 167, 0],
                [255, 171, 0],
                [255, 174, 0],
                [255, 177, 0],
                [255, 180, 0],
                [255, 184, 0],
                [255, 187, 0],
                [255, 190, 0],
                [255, 193, 0],
                [255, 197, 0],
                [255, 200, 0],
                [255, 203, 0],
                [255, 206, 0],
                [255, 209, 0],
                [255, 212, 0],
                [255, 216, 0],
                [255, 219, 0],
                [255, 223, 0],
                [255, 226, 0],
                [255, 229, 0],
                [255, 232, 0],
                [255, 236, 0],
                [255, 239, 0],
                [255, 242, 0],
                [255, 245, 0],
                [255, 249, 0],
                [255, 250, 1],
                [255, 252, 3],
                [255, 253, 4],
                [255, 255, 6],
                [255, 255, 9],
                [255, 255, 12],
                [255, 255, 15],
                [255, 255, 19],
                [255, 255, 22],
                [255, 255, 25],
                [255, 255, 28],
                [255, 255, 32],
                [255, 255, 35],
                [255, 255, 38],
                [255, 255, 41],
                [255, 255, 45],
                [255, 255, 48],
                [255, 255, 51],
                [255, 255, 54],
                [255, 255, 58],
                [255, 255, 61],
                [255, 255, 64],
                [255, 255, 67],
                [255, 255, 71],
                [255, 255, 74],
                [255, 255, 77],
                [255, 255, 80],
                [255, 255, 84],
                [255, 255, 87],
                [255, 255, 90],
                [255, 255, 93],
                [255, 255, 97],
                [255, 255, 100],
                [255, 255, 103],
                [255, 255, 106],
                [255, 255, 110],
                [255, 255, 113],
                [255, 255, 116],
                [255, 255, 119],
                [255, 255, 122],
                [255, 255, 125],
                [255, 255, 128],
                [255, 255, 131],
                [255, 255, 135],
                [255, 255, 138],
                [255, 255, 142],
                [255, 255, 145],
                [255, 255, 149],
                [255, 255, 152],
                [255, 255, 155],
                [255, 255, 158],
                [255, 255, 161],
                [255, 255, 164],
                [255, 255, 167],
                [255, 255, 170],
                [255, 255, 174],
                [255, 255, 177],
                [255, 255, 180],
                [255, 255, 183],
                [255, 255, 187],
                [255, 255, 190],
                [255, 255, 193],
                [255, 255, 196],
                [255, 255, 200],
                [255, 255, 203],
                [255, 255, 206],
                [255, 255, 209],
                [255, 255, 213],
                [255, 255, 216],
                [255, 255, 219],
                [255, 255, 222],
                [255, 255, 225],
                [255, 255, 228],
                [255, 255, 232],
                [255, 255, 235],
                [255, 255, 239],
                [255, 255, 242],
                [255, 255, 245],
                [255, 255, 248],
                [255, 255, 252],
                [255, 255, 252],
                [255, 255, 253],
                [255, 255, 254],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "Red/Green",
            [
                [0, 0, 0],
                [2, 0, 0],
                [4, 0, 0],
                [6, 0, 0],
                [8, 0, 0],
                [10, 0, 0],
                [12, 0, 0],
                [14, 0, 0],
                [16, 0, 0],
                [18, 0, 0],
                [20, 0, 0],
                [22, 0, 0],
                [24, 0, 0],
                [26, 0, 0],
                [28, 0, 0],
                [30, 0, 0],
                [32, 0, 0],
                [34, 0, 0],
                [36, 0, 0],
                [38, 0, 0],
                [40, 0, 0],
                [42, 0, 0],
                [44, 0, 0],
                [46, 0, 0],
                [48, 0, 0],
                [50, 0, 0],
                [52, 0, 0],
                [54, 0, 0],
                [56, 0, 0],
                [58, 0, 0],
                [60, 0, 0],
                [62, 0, 0],
                [64, 0, 0],
                [66, 0, 0],
                [68, 0, 0],
                [70, 0, 0],
                [72, 0, 0],
                [74, 0, 0],
                [76, 0, 0],
                [78, 0, 0],
                [80, 0, 0],
                [82, 0, 0],
                [84, 0, 0],
                [86, 0, 0],
                [88, 0, 0],
                [90, 0, 0],
                [92, 0, 0],
                [94, 0, 0],
                [96, 0, 0],
                [98, 0, 0],
                [100, 0, 0],
                [102, 0, 0],
                [104, 0, 0],
                [106, 0, 0],
                [108, 0, 0],
                [110, 0, 0],
                [112, 0, 0],
                [114, 0, 0],
                [116, 0, 0],
                [118, 0, 0],
                [120, 0, 0],
                [122, 0, 0],
                [124, 0, 0],
                [126, 0, 0],
                [128, 0, 0],
                [130, 0, 0],
                [132, 0, 0],
                [134, 0, 0],
                [136, 0, 0],
                [138, 0, 0],
                [140, 0, 0],
                [142, 0, 0],
                [144, 0, 0],
                [146, 0, 0],
                [148, 0, 0],
                [150, 0, 0],
                [152, 0, 0],
                [154, 0, 0],
                [156, 0, 0],
                [158, 0, 0],
                [160, 0, 0],
                [162, 0, 0],
                [164, 0, 0],
                [166, 0, 0],
                [168, 0, 0],
                [170, 0, 0],
                [172, 0, 0],
                [174, 0, 0],
                [176, 0, 0],
                [178, 0, 0],
                [180, 0, 0],
                [182, 0, 0],
                [184, 0, 0],
                [186, 0, 0],
                [188, 0, 0],
                [190, 0, 0],
                [192, 0, 0],
                [194, 0, 0],
                [196, 0, 0],
                [198, 0, 0],
                [200, 0, 0],
                [202, 0, 0],
                [204, 0, 0],
                [206, 0, 0],
                [208, 0, 0],
                [210, 0, 0],
                [212, 0, 0],
                [214, 0, 0],
                [216, 0, 0],
                [218, 0, 0],
                [220, 0, 0],
                [222, 0, 0],
                [224, 0, 0],
                [226, 0, 0],
                [228, 0, 0],
                [230, 0, 0],
                [232, 0, 0],
                [234, 0, 0],
                [236, 0, 0],
                [238, 0, 0],
                [240, 0, 0],
                [242, 0, 0],
                [244, 0, 0],
                [246, 0, 0],
                [248, 0, 0],
                [250, 0, 0],
                [252, 0, 0],
                [254, 0, 0],
                [0, 0, 0],
                [0, 2, 0],
                [0, 4, 0],
                [0, 6, 0],
                [0, 8, 0],
                [0, 10, 0],
                [0, 12, 0],
                [0, 14, 0],
                [0, 16, 0],
                [0, 18, 0],
                [0, 20, 0],
                [0, 22, 0],
                [0, 24, 0],
                [0, 26, 0],
                [0, 28, 0],
                [0, 30, 0],
                [0, 32, 0],
                [0, 34, 0],
                [0, 36, 0],
                [0, 38, 0],
                [0, 40, 0],
                [0, 42, 0],
                [0, 44, 0],
                [0, 46, 0],
                [0, 48, 0],
                [0, 50, 0],
                [0, 52, 0],
                [0, 54, 0],
                [0, 56, 0],
                [0, 58, 0],
                [0, 60, 0],
                [0, 62, 0],
                [0, 64, 0],
                [0, 66, 0],
                [0, 68, 0],
                [0, 70, 0],
                [0, 72, 0],
                [0, 74, 0],
                [0, 76, 0],
                [0, 78, 0],
                [0, 80, 0],
                [0, 82, 0],
                [0, 84, 0],
                [0, 86, 0],
                [0, 88, 0],
                [0, 90, 0],
                [0, 92, 0],
                [0, 94, 0],
                [0, 96, 0],
                [0, 98, 0],
                [0, 100, 0],
                [0, 102, 0],
                [0, 104, 0],
                [0, 106, 0],
                [0, 108, 0],
                [0, 110, 0],
                [0, 112, 0],
                [0, 114, 0],
                [0, 116, 0],
                [0, 118, 0],
                [0, 120, 0],
                [0, 122, 0],
                [0, 124, 0],
                [0, 126, 0],
                [0, 128, 0],
                [0, 130, 0],
                [0, 132, 0],
                [0, 134, 0],
                [0, 136, 0],
                [0, 138, 0],
                [0, 140, 0],
                [0, 142, 0],
                [0, 144, 0],
                [0, 146, 0],
                [0, 148, 0],
                [0, 150, 0],
                [0, 152, 0],
                [0, 154, 0],
                [0, 156, 0],
                [0, 158, 0],
                [0, 160, 0],
                [0, 162, 0],
                [0, 164, 0],
                [0, 166, 0],
                [0, 168, 0],
                [0, 170, 0],
                [0, 172, 0],
                [0, 174, 0],
                [0, 176, 0],
                [0, 178, 0],
                [0, 180, 0],
                [0, 182, 0],
                [0, 184, 0],
                [0, 186, 0],
                [0, 188, 0],
                [0, 190, 0],
                [0, 192, 0],
                [0, 194, 0],
                [0, 196, 0],
                [0, 198, 0],
                [0, 200, 0],
                [0, 202, 0],
                [0, 204, 0],
                [0, 206, 0],
                [0, 208, 0],
                [0, 210, 0],
                [0, 212, 0],
                [0, 214, 0],
                [0, 216, 0],
                [0, 218, 0],
                [0, 220, 0],
                [0, 222, 0],
                [0, 224, 0],
                [0, 226, 0],
                [0, 228, 0],
                [0, 230, 0],
                [0, 232, 0],
                [0, 234, 0],
                [0, 236, 0],
                [0, 238, 0],
                [0, 240, 0],
                [0, 242, 0],
                [0, 244, 0],
                [0, 246, 0],
                [0, 248, 0],
                [0, 250, 0],
                [0, 252, 0],
                [0, 254, 0],
            ],
        );

        m.insert(
            "Spectrum",
            [
                [255, 0, 0],
                [255, 6, 0],
                [255, 12, 0],
                [255, 18, 0],
                [255, 24, 0],
                [255, 30, 0],
                [255, 36, 0],
                [255, 42, 0],
                [255, 48, 0],
                [255, 54, 0],
                [255, 60, 0],
                [255, 66, 0],
                [255, 72, 0],
                [255, 78, 0],
                [255, 84, 0],
                [255, 90, 0],
                [255, 96, 0],
                [255, 102, 0],
                [255, 108, 0],
                [255, 114, 0],
                [255, 120, 0],
                [255, 126, 0],
                [255, 132, 0],
                [255, 138, 0],
                [255, 144, 0],
                [255, 150, 0],
                [255, 156, 0],
                [255, 162, 0],
                [255, 168, 0],
                [255, 174, 0],
                [255, 180, 0],
                [255, 186, 0],
                [255, 192, 0],
                [255, 198, 0],
                [255, 204, 0],
                [255, 210, 0],
                [255, 216, 0],
                [255, 222, 0],
                [255, 228, 0],
                [255, 234, 0],
                [255, 240, 0],
                [255, 246, 0],
                [255, 252, 0],
                [252, 255, 0],
                [246, 255, 0],
                [240, 255, 0],
                [234, 255, 0],
                [228, 255, 0],
                [222, 255, 0],
                [216, 255, 0],
                [210, 255, 0],
                [204, 255, 0],
                [198, 255, 0],
                [192, 255, 0],
                [186, 255, 0],
                [180, 255, 0],
                [174, 255, 0],
                [168, 255, 0],
                [162, 255, 0],
                [156, 255, 0],
                [150, 255, 0],
                [144, 255, 0],
                [138, 255, 0],
                [132, 255, 0],
                [126, 255, 0],
                [120, 255, 0],
                [114, 255, 0],
                [108, 255, 0],
                [102, 255, 0],
                [96, 255, 0],
                [90, 255, 0],
                [84, 255, 0],
                [78, 255, 0],
                [72, 255, 0],
                [66, 255, 0],
                [60, 255, 0],
                [54, 255, 0],
                [48, 255, 0],
                [42, 255, 0],
                [36, 255, 0],
                [30, 255, 0],
                [24, 255, 0],
                [18, 255, 0],
                [12, 255, 0],
                [6, 255, 0],
                [0, 255, 0],
                [0, 255, 6],
                [0, 255, 12],
                [0, 255, 18],
                [0, 255, 24],
                [0, 255, 30],
                [0, 255, 36],
                [0, 255, 42],
                [0, 255, 48],
                [0, 255, 54],
                [0, 255, 60],
                [0, 255, 66],
                [0, 255, 72],
                [0, 255, 78],
                [0, 255, 84],
                [0, 255, 90],
                [0, 255, 96],
                [0, 255, 102],
                [0, 255, 108],
                [0, 255, 114],
                [0, 255, 120],
                [0, 255, 126],
                [0, 255, 132],
                [0, 255, 138],
                [0, 255, 144],
                [0, 255, 150],
                [0, 255, 156],
                [0, 255, 162],
                [0, 255, 168],
                [0, 255, 174],
                [0, 255, 180],
                [0, 255, 186],
                [0, 255, 192],
                [0, 255, 198],
                [0, 255, 204],
                [0, 255, 210],
                [0, 255, 216],
                [0, 255, 222],
                [0, 255, 228],
                [0, 255, 234],
                [0, 255, 240],
                [0, 255, 246],
                [0, 255, 252],
                [0, 252, 255],
                [0, 246, 255],
                [0, 240, 255],
                [0, 234, 255],
                [0, 228, 255],
                [0, 222, 255],
                [0, 216, 255],
                [0, 210, 255],
                [0, 204, 255],
                [0, 198, 255],
                [0, 192, 255],
                [0, 186, 255],
                [0, 180, 255],
                [0, 174, 255],
                [0, 168, 255],
                [0, 162, 255],
                [0, 156, 255],
                [0, 150, 255],
                [0, 144, 255],
                [0, 138, 255],
                [0, 132, 255],
                [0, 126, 255],
                [0, 120, 255],
                [0, 114, 255],
                [0, 108, 255],
                [0, 102, 255],
                [0, 96, 255],
                [0, 90, 255],
                [0, 84, 255],
                [0, 78, 255],
                [0, 72, 255],
                [0, 66, 255],
                [0, 60, 255],
                [0, 54, 255],
                [0, 48, 255],
                [0, 42, 255],
                [0, 36, 255],
                [0, 30, 255],
                [0, 24, 255],
                [0, 18, 255],
                [0, 12, 255],
                [0, 6, 255],
                [0, 0, 255],
                [6, 0, 255],
                [12, 0, 255],
                [18, 0, 255],
                [24, 0, 255],
                [30, 0, 255],
                [36, 0, 255],
                [42, 0, 255],
                [48, 0, 255],
                [54, 0, 255],
                [60, 0, 255],
                [66, 0, 255],
                [72, 0, 255],
                [78, 0, 255],
                [84, 0, 255],
                [90, 0, 255],
                [96, 0, 255],
                [102, 0, 255],
                [108, 0, 255],
                [114, 0, 255],
                [120, 0, 255],
                [126, 0, 255],
                [132, 0, 255],
                [138, 0, 255],
                [144, 0, 255],
                [150, 0, 255],
                [156, 0, 255],
                [162, 0, 255],
                [168, 0, 255],
                [174, 0, 255],
                [180, 0, 255],
                [186, 0, 255],
                [192, 0, 255],
                [198, 0, 255],
                [204, 0, 255],
                [210, 0, 255],
                [216, 0, 255],
                [222, 0, 255],
                [228, 0, 255],
                [234, 0, 255],
                [240, 0, 255],
                [246, 0, 255],
                [252, 0, 255],
                [255, 0, 252],
                [255, 0, 246],
                [255, 0, 240],
                [255, 0, 234],
                [255, 0, 228],
                [255, 0, 222],
                [255, 0, 216],
                [255, 0, 210],
                [255, 0, 204],
                [255, 0, 198],
                [255, 0, 192],
                [255, 0, 186],
                [255, 0, 180],
                [255, 0, 174],
                [255, 0, 168],
                [255, 0, 162],
                [255, 0, 156],
                [255, 0, 150],
                [255, 0, 144],
                [255, 0, 138],
                [255, 0, 132],
                [255, 0, 126],
                [255, 0, 120],
                [255, 0, 114],
                [255, 0, 108],
                [255, 0, 102],
                [255, 0, 96],
                [255, 0, 90],
                [255, 0, 84],
                [255, 0, 78],
                [255, 0, 72],
                [255, 0, 66],
                [255, 0, 60],
                [255, 0, 54],
                [255, 0, 48],
                [255, 0, 42],
                [255, 0, 36],
                [255, 0, 30],
                [255, 0, 24],
                [255, 0, 18],
                [255, 0, 12],
                [255, 0, 6],
                [255, 0, 0],
            ],
        );

        m.insert(
            "Thermal",
            [
                [70, 0, 115],
                [70, 0, 115],
                [70, 0, 116],
                [70, 0, 118],
                [70, 0, 120],
                [70, 0, 122],
                [70, 0, 124],
                [70, 0, 126],
                [70, 0, 128],
                [70, 0, 131],
                [70, 0, 133],
                [70, 0, 136],
                [70, 0, 139],
                [70, 0, 141],
                [70, 0, 144],
                [70, 0, 147],
                [70, 0, 151],
                [70, 0, 154],
                [70, 0, 157],
                [70, 0, 160],
                [70, 0, 164],
                [70, 0, 167],
                [70, 0, 170],
                [70, 0, 174],
                [70, 0, 177],
                [70, 0, 181],
                [70, 0, 184],
                [70, 0, 188],
                [70, 0, 194],
                [70, 0, 200],
                [70, 0, 206],
                [70, 0, 211],
                [70, 0, 217],
                [70, 0, 222],
                [70, 0, 227],
                [70, 0, 232],
                [70, 0, 236],
                [70, 0, 240],
                [70, 0, 244],
                [69, 0, 248],
                [69, 0, 251],
                [68, 0, 253],
                [67, 2, 255],
                [66, 5, 255],
                [64, 9, 255],
                [63, 13, 255],
                [61, 17, 255],
                [59, 22, 255],
                [57, 27, 255],
                [55, 32, 255],
                [53, 38, 255],
                [51, 44, 255],
                [48, 50, 255],
                [45, 57, 255],
                [43, 63, 255],
                [40, 70, 255],
                [37, 77, 255],
                [34, 84, 255],
                [31, 91, 255],
                [28, 98, 255],
                [26, 106, 255],
                [23, 113, 254],
                [20, 121, 253],
                [17, 128, 252],
                [14, 136, 251],
                [12, 144, 250],
                [9, 152, 248],
                [6, 160, 247],
                [4, 168, 246],
                [2, 176, 245],
                [0, 183, 243],
                [0, 191, 242],
                [0, 198, 241],
                [0, 205, 240],
                [0, 212, 239],
                [0, 218, 238],
                [0, 224, 237],
                [0, 230, 236],
                [0, 235, 235],
                [0, 240, 235],
                [0, 245, 235],
                [0, 249, 234],
                [0, 253, 234],
                [1, 255, 234],
                [4, 255, 234],
                [7, 255, 234],
                [11, 255, 235],
                [16, 255, 236],
                [21, 255, 237],
                [27, 255, 238],
                [32, 255, 239],
                [39, 255, 240],
                [45, 255, 241],
                [52, 255, 243],
                [60, 255, 244],
                [68, 255, 246],
                [76, 255, 247],
                [84, 255, 249],
                [92, 255, 250],
                [101, 255, 252],
                [109, 255, 253],
                [117, 255, 254],
                [126, 255, 254],
                [134, 255, 254],
                [143, 255, 254],
                [152, 255, 254],
                [160, 255, 254],
                [168, 255, 254],
                [176, 255, 254],
                [184, 255, 254],
                [192, 255, 254],
                [199, 255, 254],
                [206, 255, 254],
                [213, 255, 254],
                [219, 255, 254],
                [225, 255, 254],
                [231, 255, 254],
                [236, 255, 254],
                [240, 255, 254],
                [244, 255, 254],
                [247, 255, 254],
                [250, 255, 254],
                [252, 254, 254],
                [253, 254, 254],
                [254, 254, 254],
                [254, 254, 252],
                [253, 254, 249],
                [252, 254, 246],
                [251, 254, 243],
                [249, 254, 239],
                [246, 254, 236],
                [243, 254, 231],
                [240, 254, 227],
                [237, 254, 223],
                [233, 254, 218],
                [228, 254, 213],
                [223, 255, 208],
                [219, 255, 203],
                [214, 255, 198],
                [208, 255, 192],
                [203, 255, 187],
                [196, 255, 181],
                [190, 255, 175],
                [184, 255, 169],
                [178, 255, 163],
                [171, 255, 157],
                [165, 255, 151],
                [158, 255, 145],
                [151, 255, 138],
                [144, 255, 132],
                [138, 255, 126],
                [129, 255, 118],
                [120, 255, 110],
                [112, 255, 102],
                [103, 255, 94],
                [95, 255, 87],
                [87, 255, 79],
                [79, 255, 72],
                [71, 255, 65],
                [64, 255, 58],
                [57, 255, 51],
                [51, 255, 45],
                [45, 255, 38],
                [39, 255, 32],
                [35, 255, 27],
                [30, 255, 22],
                [27, 255, 17],
                [24, 255, 13],
                [21, 255, 8],
                [20, 255, 5],
                [19, 255, 2],
                [19, 255, 1],
                [21, 255, 1],
                [23, 255, 1],
                [27, 255, 1],
                [32, 255, 1],
                [37, 255, 1],
                [44, 255, 1],
                [51, 255, 1],
                [59, 255, 1],
                [68, 255, 1],
                [77, 255, 1],
                [86, 255, 1],
                [97, 255, 3],
                [107, 255, 5],
                [118, 255, 8],
                [125, 255, 10],
                [131, 255, 12],
                [137, 255, 14],
                [144, 255, 16],
                [150, 255, 17],
                [156, 255, 19],
                [162, 255, 21],
                [168, 255, 23],
                [174, 255, 25],
                [180, 255, 26],
                [185, 255, 28],
                [191, 255, 30],
                [197, 254, 31],
                [202, 254, 33],
                [207, 252, 34],
                [212, 252, 36],
                [217, 250, 37],
                [222, 249, 38],
                [227, 248, 39],
                [231, 246, 40],
                [235, 245, 41],
                [238, 243, 42],
                [242, 241, 43],
                [245, 239, 43],
                [248, 237, 43],
                [251, 235, 44],
                [253, 233, 44],
                [255, 229, 44],
                [255, 226, 44],
                [255, 222, 43],
                [255, 218, 43],
                [255, 213, 42],
                [255, 208, 42],
                [255, 203, 41],
                [255, 198, 40],
                [255, 192, 40],
                [255, 187, 39],
                [255, 181, 38],
                [255, 175, 37],
                [255, 169, 36],
                [255, 162, 34],
                [255, 156, 33],
                [255, 149, 32],
                [255, 143, 31],
                [255, 136, 30],
                [255, 129, 28],
                [255, 122, 27],
                [255, 116, 25],
                [255, 109, 24],
                [255, 102, 23],
                [255, 95, 21],
                [255, 89, 20],
                [255, 82, 19],
                [255, 76, 17],
                [255, 70, 16],
                [255, 63, 15],
                [255, 57, 13],
                [255, 51, 12],
                [255, 45, 11],
                [255, 40, 10],
                [255, 35, 9],
                [255, 29, 7],
                [255, 25, 6],
                [255, 20, 6],
                [255, 16, 5],
                [255, 12, 4],
                [255, 8, 3],
                [255, 5, 3],
                [255, 2, 2],
                [255, 2, 2],
            ],
        );

        m.insert(
            "Turbo",
            [
                [48, 18, 59],
                [50, 21, 67],
                [51, 24, 74],
                [52, 27, 81],
                [53, 30, 88],
                [54, 33, 95],
                [55, 36, 102],
                [56, 39, 109],
                [57, 42, 115],
                [58, 45, 121],
                [59, 47, 128],
                [60, 50, 134],
                [61, 53, 139],
                [62, 56, 145],
                [63, 59, 151],
                [63, 62, 156],
                [64, 64, 162],
                [65, 67, 167],
                [65, 70, 172],
                [66, 73, 177],
                [66, 75, 181],
                [67, 78, 186],
                [68, 81, 191],
                [68, 84, 195],
                [68, 86, 199],
                [69, 89, 203],
                [69, 92, 207],
                [69, 94, 211],
                [70, 97, 214],
                [70, 100, 218],
                [70, 102, 221],
                [70, 105, 224],
                [70, 107, 227],
                [71, 110, 230],
                [71, 113, 233],
                [71, 115, 235],
                [71, 118, 238],
                [71, 120, 240],
                [71, 123, 242],
                [70, 125, 244],
                [70, 128, 246],
                [70, 130, 248],
                [70, 133, 250],
                [70, 135, 251],
                [69, 138, 252],
                [69, 140, 253],
                [68, 143, 254],
                [67, 145, 254],
                [66, 148, 255],
                [65, 150, 255],
                [64, 153, 255],
                [62, 155, 254],
                [61, 158, 254],
                [59, 160, 253],
                [58, 163, 252],
                [56, 165, 251],
                [55, 168, 250],
                [53, 171, 248],
                [51, 173, 247],
                [49, 175, 245],
                [47, 178, 244],
                [46, 180, 242],
                [44, 183, 240],
                [42, 185, 238],
                [40, 188, 235],
                [39, 190, 233],
                [37, 192, 231],
                [35, 195, 228],
                [34, 197, 226],
                [32, 199, 223],
                [31, 201, 221],
                [30, 203, 218],
                [28, 205, 216],
                [27, 208, 213],
                [26, 210, 210],
                [26, 212, 208],
                [25, 213, 205],
                [24, 215, 202],
                [24, 217, 200],
                [24, 219, 197],
                [24, 221, 194],
                [24, 222, 192],
                [24, 224, 189],
                [25, 226, 187],
                [25, 227, 185],
                [26, 228, 182],
                [28, 230, 180],
                [29, 231, 178],
                [31, 233, 175],
                [32, 234, 172],
                [34, 235, 170],
                [37, 236, 167],
                [39, 238, 164],
                [42, 239, 161],
                [44, 240, 158],
                [47, 241, 155],
                [50, 242, 152],
                [53, 243, 148],
                [56, 244, 145],
                [60, 245, 142],
                [63, 246, 138],
                [67, 247, 135],
                [70, 248, 132],
                [74, 248, 128],
                [78, 249, 125],
                [82, 250, 122],
                [85, 250, 118],
                [89, 251, 115],
                [93, 252, 111],
                [97, 252, 108],
                [101, 253, 105],
                [105, 253, 102],
                [109, 254, 98],
                [113, 254, 95],
                [117, 254, 92],
                [121, 254, 89],
                [125, 255, 86],
                [128, 255, 83],
                [132, 255, 81],
                [136, 255, 78],
                [139, 255, 75],
                [143, 255, 73],
                [146, 255, 71],
                [150, 254, 68],
                [153, 254, 66],
                [156, 254, 64],
                [159, 253, 63],
                [161, 253, 61],
                [164, 252, 60],
                [167, 252, 58],
                [169, 251, 57],
                [172, 251, 56],
                [175, 250, 55],
                [177, 249, 54],
                [180, 248, 54],
                [183, 247, 53],
                [185, 246, 53],
                [188, 245, 52],
                [190, 244, 52],
                [193, 243, 52],
                [195, 241, 52],
                [198, 240, 52],
                [200, 239, 52],
                [203, 237, 52],
                [205, 236, 52],
                [208, 234, 52],
                [210, 233, 53],
                [212, 231, 53],
                [215, 229, 53],
                [217, 228, 54],
                [219, 226, 54],
                [221, 224, 55],
                [223, 223, 55],
                [225, 221, 55],
                [227, 219, 56],
                [229, 217, 56],
                [231, 215, 57],
                [233, 213, 57],
                [235, 211, 57],
                [236, 209, 58],
                [238, 207, 58],
                [239, 205, 58],
                [241, 203, 58],
                [242, 201, 58],
                [244, 199, 58],
                [245, 197, 58],
                [246, 195, 58],
                [247, 193, 58],
                [248, 190, 57],
                [249, 188, 57],
                [250, 186, 57],
                [251, 184, 56],
                [251, 182, 55],
                [252, 179, 54],
                [252, 177, 54],
                [253, 174, 53],
                [253, 172, 52],
                [254, 169, 51],
                [254, 167, 50],
                [254, 164, 49],
                [254, 161, 48],
                [254, 158, 47],
                [254, 155, 45],
                [254, 153, 44],
                [254, 150, 43],
                [254, 147, 42],
                [254, 144, 41],
                [253, 141, 39],
                [253, 138, 38],
                [252, 135, 37],
                [252, 132, 35],
                [251, 129, 34],
                [251, 126, 33],
                [250, 123, 31],
                [249, 120, 30],
                [249, 117, 29],
                [248, 114, 28],
                [247, 111, 26],
                [246, 108, 25],
                [245, 105, 24],
                [244, 102, 23],
                [243, 99, 21],
                [242, 96, 20],
                [241, 93, 19],
                [240, 91, 18],
                [239, 88, 17],
                [237, 85, 16],
                [236, 83, 15],
                [235, 80, 14],
                [234, 78, 13],
                [232, 75, 12],
                [231, 73, 12],
                [229, 71, 11],
                [228, 69, 10],
                [226, 67, 10],
                [225, 65, 9],
                [223, 63, 8],
                [221, 61, 8],
                [220, 59, 7],
                [218, 57, 7],
                [216, 55, 6],
                [214, 53, 6],
                [212, 51, 5],
                [210, 49, 5],
                [208, 47, 5],
                [206, 45, 4],
                [204, 43, 4],
                [202, 42, 4],
                [200, 40, 3],
                [197, 38, 3],
                [195, 37, 3],
                [193, 35, 2],
                [190, 33, 2],
                [188, 32, 2],
                [185, 30, 2],
                [183, 29, 2],
                [180, 27, 1],
                [178, 26, 1],
                [175, 24, 1],
                [172, 23, 1],
                [169, 22, 1],
                [167, 20, 1],
                [164, 19, 1],
                [161, 18, 1],
                [158, 16, 1],
                [155, 15, 1],
                [152, 14, 1],
                [149, 13, 1],
                [146, 11, 1],
                [142, 10, 1],
                [139, 9, 2],
                [136, 8, 2],
                [133, 7, 2],
                [129, 6, 2],
                [126, 5, 2],
                [122, 4, 3],
            ],
        );

        m.insert(
            "Yellow",
            [
                [0, 0, 0],
                [1, 1, 0],
                [2, 2, 0],
                [3, 3, 0],
                [4, 4, 0],
                [5, 5, 0],
                [6, 6, 0],
                [7, 7, 0],
                [8, 8, 0],
                [9, 9, 0],
                [10, 10, 0],
                [11, 11, 0],
                [12, 12, 0],
                [13, 13, 0],
                [14, 14, 0],
                [15, 15, 0],
                [16, 16, 0],
                [17, 17, 0],
                [18, 18, 0],
                [19, 19, 0],
                [20, 20, 0],
                [21, 21, 0],
                [22, 22, 0],
                [23, 23, 0],
                [24, 24, 0],
                [25, 25, 0],
                [26, 26, 0],
                [27, 27, 0],
                [28, 28, 0],
                [29, 29, 0],
                [30, 30, 0],
                [31, 31, 0],
                [32, 32, 0],
                [33, 33, 0],
                [34, 34, 0],
                [35, 35, 0],
                [36, 36, 0],
                [37, 37, 0],
                [38, 38, 0],
                [39, 39, 0],
                [40, 40, 0],
                [41, 41, 0],
                [42, 42, 0],
                [43, 43, 0],
                [44, 44, 0],
                [45, 45, 0],
                [46, 46, 0],
                [47, 47, 0],
                [48, 48, 0],
                [49, 49, 0],
                [50, 50, 0],
                [51, 51, 0],
                [52, 52, 0],
                [53, 53, 0],
                [54, 54, 0],
                [55, 55, 0],
                [56, 56, 0],
                [57, 57, 0],
                [58, 58, 0],
                [59, 59, 0],
                [60, 60, 0],
                [61, 61, 0],
                [62, 62, 0],
                [63, 63, 0],
                [64, 64, 0],
                [65, 65, 0],
                [66, 66, 0],
                [67, 67, 0],
                [68, 68, 0],
                [69, 69, 0],
                [70, 70, 0],
                [71, 71, 0],
                [72, 72, 0],
                [73, 73, 0],
                [74, 74, 0],
                [75, 75, 0],
                [76, 76, 0],
                [77, 77, 0],
                [78, 78, 0],
                [79, 79, 0],
                [80, 80, 0],
                [81, 81, 0],
                [82, 82, 0],
                [83, 83, 0],
                [84, 84, 0],
                [85, 85, 0],
                [86, 86, 0],
                [87, 87, 0],
                [88, 88, 0],
                [89, 89, 0],
                [90, 90, 0],
                [91, 91, 0],
                [92, 92, 0],
                [93, 93, 0],
                [94, 94, 0],
                [95, 95, 0],
                [96, 96, 0],
                [97, 97, 0],
                [98, 98, 0],
                [99, 99, 0],
                [100, 100, 0],
                [101, 101, 0],
                [102, 102, 0],
                [103, 103, 0],
                [104, 104, 0],
                [105, 105, 0],
                [106, 106, 0],
                [107, 107, 0],
                [108, 108, 0],
                [109, 109, 0],
                [110, 110, 0],
                [111, 111, 0],
                [112, 112, 0],
                [113, 113, 0],
                [114, 114, 0],
                [115, 115, 0],
                [116, 116, 0],
                [117, 117, 0],
                [118, 118, 0],
                [119, 119, 0],
                [120, 120, 0],
                [121, 121, 0],
                [122, 122, 0],
                [123, 123, 0],
                [124, 124, 0],
                [125, 125, 0],
                [126, 126, 0],
                [127, 127, 0],
                [128, 128, 0],
                [129, 129, 0],
                [130, 130, 0],
                [131, 131, 0],
                [132, 132, 0],
                [133, 133, 0],
                [134, 134, 0],
                [135, 135, 0],
                [136, 136, 0],
                [137, 137, 0],
                [138, 138, 0],
                [139, 139, 0],
                [140, 140, 0],
                [141, 141, 0],
                [142, 142, 0],
                [143, 143, 0],
                [144, 144, 0],
                [145, 145, 0],
                [146, 146, 0],
                [147, 147, 0],
                [148, 148, 0],
                [149, 149, 0],
                [150, 150, 0],
                [151, 151, 0],
                [152, 152, 0],
                [153, 153, 0],
                [154, 154, 0],
                [155, 155, 0],
                [156, 156, 0],
                [157, 157, 0],
                [158, 158, 0],
                [159, 159, 0],
                [160, 160, 0],
                [161, 161, 0],
                [162, 162, 0],
                [163, 163, 0],
                [164, 164, 0],
                [165, 165, 0],
                [166, 166, 0],
                [167, 167, 0],
                [168, 168, 0],
                [169, 169, 0],
                [170, 170, 0],
                [171, 171, 0],
                [172, 172, 0],
                [173, 173, 0],
                [174, 174, 0],
                [175, 175, 0],
                [176, 176, 0],
                [177, 177, 0],
                [178, 178, 0],
                [179, 179, 0],
                [180, 180, 0],
                [181, 181, 0],
                [182, 182, 0],
                [183, 183, 0],
                [184, 184, 0],
                [185, 185, 0],
                [186, 186, 0],
                [187, 187, 0],
                [188, 188, 0],
                [189, 189, 0],
                [190, 190, 0],
                [191, 191, 0],
                [192, 192, 0],
                [193, 193, 0],
                [194, 194, 0],
                [195, 195, 0],
                [196, 196, 0],
                [197, 197, 0],
                [198, 198, 0],
                [199, 199, 0],
                [200, 200, 0],
                [201, 201, 0],
                [202, 202, 0],
                [203, 203, 0],
                [204, 204, 0],
                [205, 205, 0],
                [206, 206, 0],
                [207, 207, 0],
                [208, 208, 0],
                [209, 209, 0],
                [210, 210, 0],
                [211, 211, 0],
                [212, 212, 0],
                [213, 213, 0],
                [214, 214, 0],
                [215, 215, 0],
                [216, 216, 0],
                [217, 217, 0],
                [218, 218, 0],
                [219, 219, 0],
                [220, 220, 0],
                [221, 221, 0],
                [222, 222, 0],
                [223, 223, 0],
                [224, 224, 0],
                [225, 225, 0],
                [226, 226, 0],
                [227, 227, 0],
                [228, 228, 0],
                [229, 229, 0],
                [230, 230, 0],
                [231, 231, 0],
                [232, 232, 0],
                [233, 233, 0],
                [234, 234, 0],
                [235, 235, 0],
                [236, 236, 0],
                [237, 237, 0],
                [238, 238, 0],
                [239, 239, 0],
                [240, 240, 0],
                [241, 241, 0],
                [242, 242, 0],
                [243, 243, 0],
                [244, 244, 0],
                [245, 245, 0],
                [246, 246, 0],
                [247, 247, 0],
                [248, 248, 0],
                [249, 249, 0],
                [250, 250, 0],
                [251, 251, 0],
                [252, 252, 0],
                [253, 253, 0],
                [254, 254, 0],
                [255, 255, 0],
            ],
        );

        m.insert(
            "Yellow Hot",
            [
                [0, 0, 0],
                [2, 1, 0],
                [4, 3, 0],
                [7, 5, 0],
                [9, 7, 0],
                [11, 8, 0],
                [14, 10, 0],
                [16, 12, 0],
                [19, 14, 0],
                [21, 16, 0],
                [23, 17, 0],
                [26, 19, 0],
                [28, 21, 0],
                [31, 23, 0],
                [33, 25, 0],
                [35, 26, 0],
                [38, 28, 0],
                [40, 30, 0],
                [43, 32, 0],
                [45, 34, 0],
                [47, 35, 0],
                [50, 37, 0],
                [52, 39, 0],
                [54, 41, 0],
                [57, 43, 0],
                [59, 44, 0],
                [62, 46, 0],
                [64, 48, 0],
                [66, 50, 0],
                [69, 51, 0],
                [71, 53, 0],
                [74, 55, 0],
                [76, 57, 0],
                [78, 59, 0],
                [81, 60, 0],
                [83, 62, 0],
                [86, 64, 0],
                [88, 66, 0],
                [90, 68, 0],
                [93, 69, 0],
                [95, 71, 0],
                [98, 73, 0],
                [100, 75, 0],
                [102, 77, 0],
                [105, 78, 0],
                [107, 80, 0],
                [109, 82, 0],
                [112, 84, 0],
                [114, 86, 0],
                [117, 87, 0],
                [119, 89, 0],
                [121, 91, 0],
                [124, 93, 0],
                [126, 95, 0],
                [129, 96, 0],
                [131, 98, 0],
                [133, 100, 0],
                [136, 102, 0],
                [138, 103, 0],
                [141, 105, 0],
                [143, 107, 0],
                [145, 109, 0],
                [148, 111, 0],
                [150, 112, 0],
                [153, 114, 0],
                [155, 116, 0],
                [157, 118, 0],
                [160, 120, 0],
                [162, 121, 0],
                [164, 123, 0],
                [167, 125, 0],
                [169, 127, 0],
                [172, 129, 0],
                [174, 130, 0],
                [176, 132, 0],
                [179, 134, 0],
                [181, 136, 0],
                [184, 138, 0],
                [186, 139, 0],
                [188, 141, 0],
                [191, 143, 0],
                [193, 145, 0],
                [196, 147, 0],
                [198, 148, 0],
                [204, 153, 0],
                [204, 153, 0],
                [204, 154, 0],
                [205, 155, 0],
                [205, 156, 0],
                [206, 157, 0],
                [206, 158, 0],
                [207, 160, 0],
                [208, 161, 0],
                [208, 162, 0],
                [209, 163, 0],
                [209, 164, 0],
                [210, 166, 0],
                [211, 167, 0],
                [211, 168, 0],
                [212, 169, 0],
                [212, 170, 0],
                [213, 172, 0],
                [214, 173, 0],
                [214, 174, 0],
                [215, 175, 0],
                [215, 176, 0],
                [216, 178, 0],
                [217, 179, 0],
                [217, 180, 0],
                [218, 181, 0],
                [218, 182, 0],
                [219, 184, 0],
                [220, 185, 0],
                [220, 186, 0],
                [221, 187, 0],
                [221, 188, 0],
                [222, 190, 0],
                [223, 191, 0],
                [223, 192, 0],
                [224, 193, 0],
                [224, 194, 0],
                [225, 196, 0],
                [226, 197, 0],
                [226, 198, 0],
                [227, 199, 0],
                [227, 200, 0],
                [228, 202, 0],
                [229, 203, 0],
                [229, 204, 0],
                [230, 205, 0],
                [230, 206, 0],
                [231, 207, 0],
                [232, 209, 0],
                [232, 210, 0],
                [233, 211, 0],
                [233, 212, 0],
                [234, 213, 0],
                [235, 215, 0],
                [235, 216, 0],
                [236, 217, 0],
                [236, 218, 0],
                [237, 219, 0],
                [238, 221, 0],
                [238, 222, 0],
                [239, 223, 0],
                [239, 224, 0],
                [240, 225, 0],
                [241, 227, 0],
                [241, 228, 0],
                [242, 229, 0],
                [242, 230, 0],
                [243, 231, 0],
                [244, 233, 0],
                [244, 234, 0],
                [245, 235, 0],
                [245, 236, 0],
                [246, 237, 0],
                [247, 239, 0],
                [247, 240, 0],
                [248, 241, 0],
                [248, 242, 0],
                [249, 243, 0],
                [250, 245, 0],
                [250, 246, 0],
                [251, 247, 0],
                [251, 248, 0],
                [252, 249, 0],
                [253, 251, 0],
                [253, 252, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 2],
                [255, 255, 5],
                [255, 255, 8],
                [255, 255, 11],
                [255, 255, 14],
                [255, 255, 17],
                [255, 255, 20],
                [255, 255, 23],
                [255, 255, 26],
                [255, 255, 29],
                [255, 255, 32],
                [255, 255, 35],
                [255, 255, 38],
                [255, 255, 41],
                [255, 255, 44],
                [255, 255, 47],
                [255, 255, 50],
                [255, 255, 53],
                [255, 255, 56],
                [255, 255, 59],
                [255, 255, 62],
                [255, 255, 65],
                [255, 255, 68],
                [255, 255, 71],
                [255, 255, 74],
                [255, 255, 77],
                [255, 255, 80],
                [255, 255, 83],
                [255, 255, 86],
                [255, 255, 89],
                [255, 255, 92],
                [255, 255, 95],
                [255, 255, 98],
                [255, 255, 101],
                [255, 255, 104],
                [255, 255, 107],
                [255, 255, 110],
                [255, 255, 113],
                [255, 255, 116],
                [255, 255, 119],
                [255, 255, 122],
                [255, 255, 125],
                [255, 255, 128],
                [255, 255, 131],
                [255, 255, 134],
                [255, 255, 137],
                [255, 255, 140],
                [255, 255, 143],
                [255, 255, 146],
                [255, 255, 149],
                [255, 255, 152],
                [255, 255, 155],
                [255, 255, 158],
                [255, 255, 161],
                [255, 255, 164],
                [255, 255, 167],
                [255, 255, 170],
                [255, 255, 173],
                [255, 255, 176],
                [255, 255, 179],
                [255, 255, 182],
                [255, 255, 185],
                [255, 255, 188],
                [255, 255, 191],
                [255, 255, 194],
                [255, 255, 197],
                [255, 255, 200],
                [255, 255, 203],
                [255, 255, 206],
                [255, 255, 209],
                [255, 255, 212],
                [255, 255, 215],
                [255, 255, 218],
                [255, 255, 221],
                [255, 255, 224],
                [255, 255, 227],
                [255, 255, 230],
                [255, 255, 233],
                [255, 255, 236],
                [255, 255, 239],
                [255, 255, 242],
                [255, 255, 245],
                [255, 255, 248],
                [255, 255, 251],
                [255, 255, 255],
            ],
        );

        m.insert(
            "betterBlue",
            [
                [0, 0, 0],
                [0, 1, 2],
                [0, 1, 3],
                [0, 2, 5],
                [0, 3, 6],
                [0, 3, 8],
                [0, 4, 10],
                [0, 5, 11],
                [0, 6, 13],
                [0, 6, 15],
                [0, 7, 16],
                [0, 8, 18],
                [0, 8, 19],
                [0, 9, 21],
                [0, 10, 23],
                [0, 10, 24],
                [0, 11, 26],
                [0, 12, 28],
                [0, 12, 29],
                [0, 13, 31],
                [0, 14, 32],
                [0, 15, 34],
                [0, 15, 36],
                [0, 16, 37],
                [0, 17, 39],
                [0, 17, 40],
                [0, 18, 42],
                [0, 19, 44],
                [0, 19, 45],
                [0, 20, 47],
                [0, 21, 48],
                [0, 21, 50],
                [0, 22, 52],
                [0, 23, 53],
                [0, 24, 55],
                [0, 24, 56],
                [0, 25, 58],
                [0, 26, 59],
                [0, 26, 61],
                [0, 27, 63],
                [0, 28, 64],
                [0, 28, 66],
                [0, 29, 67],
                [0, 30, 69],
                [0, 30, 70],
                [0, 31, 72],
                [0, 32, 73],
                [0, 33, 75],
                [0, 33, 77],
                [0, 34, 78],
                [0, 35, 80],
                [0, 35, 81],
                [0, 36, 83],
                [0, 37, 84],
                [0, 37, 86],
                [0, 38, 87],
                [0, 39, 89],
                [0, 40, 90],
                [0, 40, 92],
                [0, 41, 93],
                [0, 42, 95],
                [0, 42, 96],
                [0, 43, 98],
                [0, 44, 99],
                [0, 44, 101],
                [0, 45, 102],
                [0, 46, 104],
                [0, 47, 105],
                [0, 47, 106],
                [0, 48, 108],
                [0, 49, 109],
                [0, 49, 111],
                [0, 50, 112],
                [0, 51, 114],
                [0, 52, 115],
                [0, 52, 116],
                [0, 53, 118],
                [0, 54, 119],
                [0, 54, 121],
                [0, 55, 122],
                [0, 56, 123],
                [0, 57, 125],
                [0, 57, 126],
                [0, 58, 127],
                [0, 59, 129],
                [0, 59, 130],
                [0, 60, 132],
                [0, 61, 133],
                [0, 62, 134],
                [0, 62, 136],
                [0, 63, 137],
                [0, 64, 138],
                [0, 64, 139],
                [0, 65, 141],
                [0, 66, 142],
                [0, 67, 143],
                [0, 67, 145],
                [0, 68, 146],
                [0, 69, 147],
                [0, 69, 148],
                [0, 70, 150],
                [0, 71, 151],
                [0, 72, 152],
                [0, 72, 153],
                [0, 73, 154],
                [0, 74, 156],
                [0, 75, 157],
                [0, 75, 158],
                [0, 76, 159],
                [0, 77, 160],
                [0, 77, 162],
                [0, 78, 163],
                [0, 79, 164],
                [0, 80, 165],
                [0, 80, 166],
                [0, 81, 167],
                [0, 82, 168],
                [0, 83, 169],
                [0, 83, 171],
                [0, 84, 172],
                [0, 85, 173],
                [0, 86, 174],
                [0, 86, 175],
                [0, 87, 176],
                [0, 88, 177],
                [0, 89, 178],
                [0, 89, 179],
                [0, 89, 180],
                [0, 90, 180],
                [0, 91, 181],
                [0, 91, 182],
                [0, 92, 183],
                [0, 93, 184],
                [0, 94, 185],
                [0, 94, 186],
                [0, 95, 187],
                [0, 96, 188],
                [0, 97, 189],
                [0, 97, 190],
                [0, 98, 190],
                [0, 99, 191],
                [0, 100, 192],
                [0, 101, 193],
                [0, 101, 194],
                [0, 102, 195],
                [0, 103, 196],
                [0, 104, 197],
                [0, 104, 197],
                [0, 105, 198],
                [0, 106, 199],
                [0, 107, 200],
                [0, 107, 201],
                [0, 108, 201],
                [0, 109, 202],
                [0, 110, 203],
                [0, 110, 204],
                [0, 111, 205],
                [0, 112, 205],
                [0, 113, 206],
                [0, 113, 207],
                [0, 114, 208],
                [0, 115, 208],
                [0, 116, 209],
                [0, 117, 210],
                [0, 117, 210],
                [0, 118, 211],
                [0, 119, 212],
                [0, 120, 212],
                [0, 120, 213],
                [0, 121, 214],
                [0, 122, 214],
                [0, 123, 215],
                [0, 124, 216],
                [0, 124, 216],
                [0, 125, 217],
                [0, 126, 218],
                [0, 127, 218],
                [0, 127, 219],
                [0, 128, 220],
                [0, 129, 220],
                [0, 130, 221],
                [0, 131, 221],
                [0, 131, 222],
                [0, 132, 223],
                [0, 133, 223],
                [0, 134, 224],
                [0, 134, 224],
                [0, 135, 225],
                [0, 136, 225],
                [0, 137, 226],
                [0, 138, 226],
                [0, 138, 227],
                [0, 139, 228],
                [0, 140, 228],
                [0, 141, 229],
                [0, 141, 229],
                [0, 142, 230],
                [0, 143, 230],
                [0, 144, 231],
                [0, 145, 231],
                [0, 145, 232],
                [0, 146, 232],
                [0, 147, 233],
                [0, 148, 233],
                [0, 149, 234],
                [0, 149, 234],
                [0, 150, 235],
                [0, 151, 235],
                [0, 152, 235],
                [0, 153, 236],
                [0, 153, 236],
                [0, 154, 237],
                [0, 155, 237],
                [0, 156, 238],
                [0, 157, 238],
                [0, 157, 239],
                [0, 158, 239],
                [0, 159, 240],
                [0, 160, 240],
                [0, 160, 240],
                [0, 161, 241],
                [0, 162, 241],
                [0, 163, 242],
                [0, 164, 242],
                [0, 164, 243],
                [0, 165, 243],
                [0, 166, 243],
                [0, 167, 244],
                [0, 168, 244],
                [0, 168, 245],
                [0, 169, 245],
                [0, 170, 245],
                [0, 171, 246],
                [0, 172, 246],
                [0, 172, 247],
                [0, 173, 247],
                [0, 174, 247],
                [0, 175, 248],
                [0, 176, 248],
                [0, 176, 249],
                [0, 177, 249],
                [0, 178, 249],
                [0, 179, 250],
                [0, 180, 250],
                [0, 180, 250],
                [0, 181, 251],
                [0, 182, 251],
                [0, 183, 252],
                [0, 184, 252],
                [0, 184, 252],
                [0, 185, 253],
                [0, 186, 253],
                [0, 187, 253],
                [0, 188, 254],
                [0, 188, 254],
                [0, 188, 254],
            ],
        );

        m.insert(
            "betterCyan",
            [
                [0, 0, 0],
                [0, 1, 1],
                [1, 2, 2],
                [1, 3, 3],
                [2, 3, 4],
                [2, 4, 5],
                [3, 5, 6],
                [3, 6, 7],
                [4, 7, 8],
                [4, 8, 9],
                [5, 9, 10],
                [5, 9, 11],
                [6, 10, 12],
                [6, 11, 13],
                [7, 12, 14],
                [7, 13, 15],
                [8, 14, 16],
                [8, 15, 17],
                [9, 15, 18],
                [9, 16, 19],
                [10, 17, 20],
                [10, 18, 21],
                [11, 19, 22],
                [11, 20, 23],
                [12, 21, 24],
                [12, 21, 25],
                [13, 22, 26],
                [13, 23, 27],
                [14, 24, 28],
                [14, 25, 29],
                [15, 26, 30],
                [15, 27, 31],
                [16, 28, 32],
                [16, 28, 33],
                [17, 29, 34],
                [17, 30, 35],
                [18, 31, 36],
                [18, 32, 37],
                [19, 33, 38],
                [19, 34, 39],
                [20, 34, 40],
                [20, 35, 41],
                [21, 36, 42],
                [21, 37, 43],
                [21, 38, 44],
                [22, 39, 45],
                [22, 40, 46],
                [23, 40, 47],
                [23, 41, 48],
                [24, 42, 49],
                [24, 43, 50],
                [25, 44, 51],
                [25, 45, 52],
                [26, 46, 53],
                [26, 46, 54],
                [27, 47, 55],
                [27, 48, 56],
                [28, 49, 57],
                [28, 50, 58],
                [29, 51, 59],
                [29, 52, 60],
                [30, 52, 61],
                [30, 53, 62],
                [31, 54, 63],
                [31, 55, 64],
                [32, 56, 65],
                [32, 57, 66],
                [33, 58, 67],
                [33, 58, 68],
                [34, 59, 69],
                [34, 60, 70],
                [35, 61, 71],
                [35, 62, 72],
                [36, 63, 73],
                [36, 64, 74],
                [37, 64, 75],
                [37, 65, 76],
                [38, 66, 77],
                [38, 67, 78],
                [39, 68, 79],
                [39, 69, 80],
                [40, 70, 81],
                [40, 70, 82],
                [41, 71, 83],
                [41, 72, 84],
                [42, 73, 85],
                [42, 74, 86],
                [42, 75, 87],
                [43, 76, 88],
                [43, 76, 89],
                [44, 77, 90],
                [44, 78, 91],
                [45, 79, 92],
                [45, 80, 93],
                [46, 81, 94],
                [46, 82, 95],
                [47, 83, 96],
                [47, 83, 97],
                [48, 84, 98],
                [48, 85, 99],
                [49, 86, 100],
                [49, 87, 101],
                [50, 88, 102],
                [50, 89, 103],
                [51, 89, 104],
                [51, 90, 105],
                [52, 91, 106],
                [52, 92, 107],
                [53, 93, 108],
                [53, 94, 109],
                [54, 95, 110],
                [54, 95, 111],
                [55, 96, 112],
                [55, 97, 113],
                [56, 98, 114],
                [56, 99, 115],
                [57, 100, 116],
                [57, 101, 117],
                [58, 101, 118],
                [58, 102, 119],
                [59, 103, 120],
                [59, 104, 121],
                [60, 105, 122],
                [60, 106, 123],
                [61, 107, 124],
                [61, 107, 125],
                [62, 108, 126],
                [62, 109, 127],
                [63, 110, 128],
                [63, 111, 128],
                [63, 112, 129],
                [64, 113, 130],
                [64, 113, 131],
                [65, 114, 132],
                [65, 115, 133],
                [66, 116, 134],
                [66, 117, 135],
                [67, 118, 136],
                [67, 119, 137],
                [68, 119, 138],
                [68, 120, 139],
                [69, 121, 140],
                [69, 122, 141],
                [70, 123, 142],
                [70, 124, 143],
                [71, 125, 144],
                [71, 125, 145],
                [72, 126, 146],
                [72, 127, 147],
                [73, 128, 148],
                [73, 129, 149],
                [74, 130, 150],
                [74, 131, 151],
                [75, 131, 152],
                [75, 132, 153],
                [76, 133, 154],
                [76, 134, 155],
                [77, 135, 156],
                [77, 136, 157],
                [78, 137, 158],
                [78, 138, 159],
                [79, 138, 160],
                [79, 139, 161],
                [80, 140, 162],
                [80, 141, 163],
                [81, 142, 164],
                [81, 143, 165],
                [82, 144, 166],
                [82, 144, 167],
                [83, 145, 168],
                [83, 146, 169],
                [83, 147, 170],
                [84, 148, 171],
                [84, 149, 172],
                [85, 150, 173],
                [85, 150, 174],
                [86, 151, 175],
                [86, 152, 176],
                [87, 153, 177],
                [87, 154, 178],
                [88, 155, 179],
                [88, 156, 180],
                [89, 156, 181],
                [89, 157, 182],
                [90, 158, 183],
                [90, 159, 184],
                [91, 160, 185],
                [91, 161, 186],
                [92, 162, 187],
                [92, 162, 188],
                [93, 163, 189],
                [93, 164, 190],
                [94, 165, 191],
                [94, 166, 192],
                [95, 167, 193],
                [95, 168, 194],
                [96, 168, 195],
                [96, 169, 196],
                [97, 170, 197],
                [97, 171, 198],
                [98, 172, 199],
                [98, 173, 200],
                [99, 174, 201],
                [99, 174, 202],
                [100, 175, 203],
                [100, 176, 204],
                [101, 177, 205],
                [101, 178, 206],
                [102, 179, 207],
                [102, 180, 208],
                [103, 180, 209],
                [103, 181, 210],
                [104, 182, 211],
                [104, 183, 212],
                [104, 184, 213],
                [105, 185, 214],
                [105, 186, 215],
                [106, 186, 216],
                [106, 187, 217],
                [107, 188, 218],
                [107, 189, 219],
                [108, 190, 220],
                [108, 191, 221],
                [109, 192, 222],
                [109, 193, 223],
                [110, 193, 224],
                [110, 194, 225],
                [111, 195, 226],
                [111, 196, 227],
                [112, 197, 228],
                [112, 198, 229],
                [113, 199, 230],
                [113, 199, 231],
                [114, 200, 232],
                [114, 201, 233],
                [115, 202, 234],
                [115, 203, 235],
                [116, 204, 236],
                [116, 205, 237],
                [117, 205, 238],
                [117, 206, 239],
                [118, 207, 240],
                [118, 208, 241],
                [119, 209, 242],
                [119, 210, 243],
                [120, 211, 244],
                [120, 211, 245],
                [121, 212, 246],
                [121, 213, 247],
                [122, 214, 248],
                [122, 215, 249],
                [123, 216, 250],
                [123, 217, 251],
                [124, 217, 252],
                [124, 218, 253],
                [125, 219, 254],
            ],
        );

        m.insert(
            "betterGreen",
            [
                [0, 0, 0],
                [0, 1, 0],
                [0, 2, 0],
                [0, 3, 0],
                [0, 4, 1],
                [0, 5, 1],
                [0, 6, 1],
                [0, 7, 1],
                [0, 8, 1],
                [0, 9, 1],
                [0, 10, 2],
                [0, 11, 2],
                [0, 12, 2],
                [0, 13, 2],
                [0, 14, 2],
                [0, 15, 3],
                [0, 15, 3],
                [0, 16, 3],
                [0, 17, 3],
                [0, 18, 3],
                [0, 19, 3],
                [0, 20, 4],
                [0, 21, 4],
                [1, 22, 4],
                [1, 23, 4],
                [1, 24, 4],
                [1, 25, 4],
                [1, 26, 5],
                [1, 27, 5],
                [1, 28, 5],
                [1, 29, 5],
                [1, 30, 5],
                [1, 31, 6],
                [1, 32, 6],
                [1, 33, 6],
                [1, 34, 6],
                [1, 35, 6],
                [1, 36, 6],
                [1, 37, 7],
                [1, 38, 7],
                [1, 39, 7],
                [1, 40, 7],
                [1, 41, 7],
                [1, 42, 8],
                [1, 43, 8],
                [1, 44, 8],
                [1, 45, 8],
                [1, 46, 8],
                [1, 46, 9],
                [1, 47, 9],
                [2, 48, 9],
                [2, 49, 9],
                [2, 50, 10],
                [2, 51, 10],
                [2, 52, 10],
                [2, 53, 10],
                [2, 54, 10],
                [2, 55, 11],
                [2, 56, 11],
                [2, 57, 11],
                [2, 58, 11],
                [2, 59, 12],
                [2, 60, 12],
                [2, 61, 12],
                [2, 62, 12],
                [3, 63, 13],
                [3, 64, 13],
                [3, 65, 13],
                [3, 66, 13],
                [3, 67, 14],
                [3, 68, 14],
                [3, 69, 14],
                [3, 70, 14],
                [3, 71, 15],
                [3, 72, 15],
                [3, 73, 15],
                [3, 74, 15],
                [4, 75, 16],
                [4, 76, 16],
                [4, 77, 16],
                [4, 78, 17],
                [4, 79, 17],
                [4, 80, 17],
                [4, 81, 18],
                [4, 82, 18],
                [4, 83, 18],
                [5, 84, 18],
                [5, 85, 19],
                [5, 85, 19],
                [5, 86, 19],
                [5, 87, 20],
                [5, 88, 20],
                [5, 89, 20],
                [5, 90, 21],
                [6, 91, 21],
                [6, 92, 21],
                [6, 93, 22],
                [6, 94, 22],
                [6, 95, 22],
                [6, 96, 23],
                [6, 97, 23],
                [7, 98, 24],
                [7, 99, 24],
                [7, 100, 24],
                [7, 101, 25],
                [7, 102, 25],
                [7, 103, 25],
                [8, 104, 26],
                [8, 105, 26],
                [8, 106, 27],
                [8, 107, 27],
                [8, 108, 27],
                [9, 109, 28],
                [9, 110, 28],
                [9, 111, 29],
                [9, 112, 29],
                [9, 113, 29],
                [10, 114, 30],
                [10, 115, 30],
                [10, 116, 31],
                [10, 117, 31],
                [10, 118, 32],
                [11, 119, 32],
                [11, 120, 33],
                [11, 121, 33],
                [11, 122, 34],
                [12, 123, 34],
                [12, 124, 35],
                [12, 125, 35],
                [12, 126, 35],
                [12, 127, 36],
                [13, 128, 36],
                [13, 129, 37],
                [13, 130, 38],
                [14, 131, 38],
                [14, 132, 39],
                [14, 133, 39],
                [14, 134, 40],
                [15, 135, 40],
                [15, 136, 41],
                [15, 137, 41],
                [15, 138, 42],
                [16, 139, 42],
                [16, 140, 43],
                [16, 141, 43],
                [17, 142, 44],
                [17, 143, 45],
                [17, 144, 45],
                [18, 145, 46],
                [18, 146, 46],
                [18, 147, 47],
                [18, 148, 47],
                [19, 149, 48],
                [19, 150, 49],
                [19, 151, 49],
                [20, 152, 50],
                [20, 153, 51],
                [20, 154, 51],
                [21, 155, 52],
                [21, 156, 52],
                [21, 157, 53],
                [22, 158, 54],
                [22, 159, 54],
                [22, 160, 55],
                [23, 161, 56],
                [23, 162, 56],
                [23, 163, 57],
                [24, 164, 57],
                [24, 165, 58],
                [25, 166, 59],
                [25, 167, 59],
                [25, 168, 60],
                [26, 169, 61],
                [26, 170, 61],
                [26, 171, 62],
                [27, 172, 63],
                [27, 173, 64],
                [28, 174, 64],
                [28, 175, 65],
                [28, 176, 66],
                [29, 177, 66],
                [29, 178, 67],
                [29, 179, 68],
                [30, 180, 68],
                [30, 181, 69],
                [31, 182, 70],
                [31, 183, 71],
                [31, 184, 71],
                [32, 185, 72],
                [32, 186, 73],
                [33, 187, 73],
                [33, 189, 74],
                [33, 190, 75],
                [34, 191, 76],
                [34, 192, 76],
                [35, 193, 77],
                [35, 194, 78],
                [36, 195, 79],
                [36, 196, 79],
                [36, 197, 80],
                [37, 198, 81],
                [37, 199, 82],
                [38, 200, 82],
                [38, 201, 83],
                [38, 202, 84],
                [39, 203, 85],
                [39, 204, 85],
                [40, 205, 86],
                [40, 206, 87],
                [41, 207, 88],
                [41, 208, 88],
                [41, 209, 89],
                [42, 210, 90],
                [42, 211, 91],
                [43, 212, 91],
                [43, 213, 92],
                [44, 214, 93],
                [44, 215, 94],
                [45, 216, 95],
                [45, 217, 95],
                [45, 218, 96],
                [46, 219, 97],
                [46, 220, 98],
                [47, 221, 98],
                [47, 222, 99],
                [48, 223, 100],
                [48, 224, 101],
                [49, 225, 102],
                [49, 226, 102],
                [50, 227, 103],
                [50, 228, 104],
                [50, 229, 105],
                [51, 230, 106],
                [51, 231, 106],
                [52, 232, 107],
                [52, 233, 108],
                [53, 234, 109],
                [53, 236, 110],
                [54, 237, 110],
                [54, 238, 111],
                [55, 239, 112],
                [55, 240, 113],
                [56, 241, 114],
                [56, 242, 114],
                [56, 243, 115],
                [57, 244, 116],
                [57, 245, 117],
                [58, 246, 118],
                [58, 247, 119],
                [59, 248, 119],
                [59, 249, 120],
                [60, 250, 121],
                [60, 251, 122],
                [61, 252, 123],
                [61, 253, 123],
                [62, 254, 124],
            ],
        );

        m.insert(
            "betterOrange",
            [
                [0, 0, 0],
                [1, 1, 0],
                [3, 1, 0],
                [4, 2, 0],
                [5, 2, 0],
                [7, 3, 0],
                [8, 4, 0],
                [10, 4, 0],
                [11, 5, 0],
                [12, 5, 0],
                [14, 6, 0],
                [15, 6, 0],
                [16, 7, 0],
                [18, 8, 0],
                [19, 8, 0],
                [20, 9, 0],
                [22, 9, 0],
                [23, 10, 0],
                [25, 11, 0],
                [26, 11, 0],
                [27, 12, 0],
                [29, 12, 0],
                [30, 13, 0],
                [31, 13, 0],
                [33, 14, 0],
                [34, 15, 0],
                [35, 15, 0],
                [37, 16, 0],
                [38, 16, 0],
                [39, 17, 0],
                [41, 18, 0],
                [42, 18, 0],
                [43, 19, 0],
                [45, 19, 0],
                [46, 20, 0],
                [47, 21, 0],
                [49, 21, 0],
                [50, 22, 0],
                [51, 22, 0],
                [53, 23, 0],
                [54, 23, 0],
                [55, 24, 0],
                [57, 25, 0],
                [58, 25, 0],
                [59, 26, 0],
                [61, 26, 0],
                [62, 27, 0],
                [63, 28, 0],
                [65, 28, 0],
                [66, 29, 0],
                [67, 29, 0],
                [69, 30, 0],
                [70, 30, 0],
                [71, 31, 0],
                [73, 32, 0],
                [74, 32, 0],
                [75, 33, 0],
                [76, 33, 0],
                [78, 34, 0],
                [79, 35, 0],
                [80, 35, 0],
                [82, 36, 0],
                [83, 36, 0],
                [84, 37, 0],
                [85, 38, 0],
                [87, 38, 0],
                [88, 39, 0],
                [89, 39, 0],
                [90, 40, 0],
                [92, 40, 0],
                [93, 41, 0],
                [94, 42, 0],
                [95, 42, 0],
                [97, 43, 0],
                [98, 43, 0],
                [99, 44, 0],
                [100, 45, 0],
                [102, 45, 0],
                [103, 46, 0],
                [104, 46, 0],
                [105, 47, 0],
                [107, 47, 0],
                [108, 48, 0],
                [109, 49, 0],
                [110, 49, 0],
                [111, 50, 0],
                [113, 50, 0],
                [114, 51, 0],
                [115, 52, 0],
                [116, 52, 0],
                [117, 53, 0],
                [119, 53, 0],
                [120, 54, 0],
                [121, 54, 0],
                [122, 55, 0],
                [123, 56, 0],
                [124, 56, 0],
                [126, 57, 0],
                [127, 57, 0],
                [128, 58, 0],
                [129, 59, 0],
                [130, 59, 0],
                [131, 60, 0],
                [132, 60, 0],
                [134, 61, 0],
                [135, 62, 0],
                [136, 62, 0],
                [137, 63, 0],
                [138, 63, 0],
                [139, 64, 0],
                [140, 64, 0],
                [141, 65, 0],
                [142, 66, 0],
                [143, 66, 0],
                [145, 67, 0],
                [146, 67, 0],
                [147, 68, 0],
                [148, 69, 0],
                [149, 69, 0],
                [150, 70, 0],
                [151, 70, 0],
                [152, 71, 0],
                [153, 71, 0],
                [154, 72, 0],
                [155, 73, 0],
                [156, 73, 0],
                [157, 74, 0],
                [158, 74, 0],
                [159, 75, 0],
                [160, 76, 0],
                [161, 76, 0],
                [162, 77, 0],
                [163, 77, 0],
                [164, 78, 0],
                [165, 79, 0],
                [166, 79, 0],
                [167, 80, 0],
                [168, 80, 0],
                [169, 81, 0],
                [170, 81, 0],
                [171, 82, 0],
                [171, 83, 0],
                [172, 83, 0],
                [173, 84, 0],
                [174, 84, 0],
                [175, 85, 0],
                [176, 86, 0],
                [177, 86, 0],
                [178, 87, 0],
                [179, 87, 0],
                [180, 88, 0],
                [180, 88, 0],
                [181, 89, 0],
                [182, 90, 0],
                [183, 90, 0],
                [184, 91, 0],
                [185, 91, 0],
                [186, 92, 0],
                [186, 93, 0],
                [187, 93, 0],
                [188, 94, 0],
                [189, 94, 0],
                [190, 95, 0],
                [191, 96, 0],
                [191, 96, 0],
                [192, 97, 0],
                [193, 97, 0],
                [194, 98, 0],
                [195, 98, 0],
                [196, 99, 0],
                [196, 100, 0],
                [197, 100, 0],
                [198, 101, 0],
                [199, 101, 0],
                [199, 102, 0],
                [200, 103, 0],
                [201, 103, 0],
                [202, 104, 0],
                [203, 104, 0],
                [203, 105, 0],
                [204, 105, 0],
                [205, 106, 0],
                [206, 107, 0],
                [206, 107, 0],
                [207, 108, 0],
                [208, 108, 0],
                [209, 109, 0],
                [209, 110, 0],
                [210, 110, 0],
                [211, 111, 0],
                [211, 111, 0],
                [212, 112, 0],
                [213, 113, 0],
                [214, 113, 0],
                [214, 114, 0],
                [215, 114, 0],
                [216, 115, 0],
                [216, 115, 0],
                [217, 116, 0],
                [218, 117, 0],
                [219, 117, 0],
                [219, 118, 0],
                [220, 118, 0],
                [221, 119, 0],
                [221, 120, 0],
                [222, 120, 0],
                [223, 121, 0],
                [223, 121, 0],
                [224, 122, 0],
                [225, 122, 0],
                [225, 123, 0],
                [226, 124, 0],
                [227, 124, 0],
                [227, 125, 0],
                [228, 125, 0],
                [229, 126, 0],
                [229, 127, 0],
                [230, 127, 0],
                [231, 128, 0],
                [231, 128, 0],
                [232, 129, 0],
                [233, 129, 0],
                [233, 130, 0],
                [234, 131, 0],
                [235, 131, 0],
                [235, 132, 0],
                [236, 132, 0],
                [237, 133, 0],
                [237, 134, 0],
                [238, 134, 0],
                [239, 135, 0],
                [239, 135, 0],
                [240, 136, 0],
                [240, 137, 0],
                [241, 137, 0],
                [242, 138, 0],
                [242, 138, 0],
                [243, 139, 0],
                [244, 139, 0],
                [244, 140, 0],
                [245, 141, 0],
                [246, 141, 0],
                [246, 142, 0],
                [247, 142, 0],
                [247, 143, 0],
                [248, 144, 0],
                [249, 144, 0],
                [249, 145, 0],
                [250, 145, 0],
                [251, 146, 0],
                [251, 146, 0],
                [252, 147, 0],
                [252, 148, 0],
                [253, 148, 0],
                [254, 149, 0],
                [255, 149, 0],
            ],
        );

        m.insert(
            "betterRed",
            [
                [0, 0, 0],
                [0, 0, 0],
                [1, 0, 0],
                [1, 0, 0],
                [2, 1, 0],
                [2, 1, 0],
                [2, 1, 0],
                [3, 1, 0],
                [3, 1, 0],
                [4, 1, 0],
                [4, 2, 0],
                [4, 2, 0],
                [5, 2, 0],
                [5, 2, 1],
                [6, 2, 1],
                [6, 2, 1],
                [6, 3, 1],
                [7, 3, 1],
                [7, 3, 1],
                [8, 3, 1],
                [8, 3, 1],
                [9, 3, 1],
                [9, 4, 1],
                [10, 4, 1],
                [10, 4, 1],
                [10, 4, 1],
                [11, 4, 1],
                [11, 4, 1],
                [12, 4, 1],
                [12, 5, 1],
                [13, 5, 1],
                [13, 5, 1],
                [14, 5, 1],
                [14, 5, 1],
                [15, 5, 1],
                [16, 6, 1],
                [16, 6, 1],
                [17, 6, 1],
                [17, 6, 1],
                [18, 6, 1],
                [18, 6, 1],
                [19, 6, 1],
                [20, 7, 1],
                [20, 7, 1],
                [21, 7, 1],
                [21, 7, 1],
                [22, 7, 1],
                [23, 7, 1],
                [23, 7, 1],
                [24, 8, 1],
                [25, 8, 1],
                [26, 8, 1],
                [26, 8, 1],
                [27, 8, 1],
                [28, 8, 1],
                [29, 8, 1],
                [29, 9, 1],
                [30, 9, 1],
                [31, 9, 1],
                [32, 9, 1],
                [33, 9, 1],
                [33, 9, 1],
                [34, 9, 1],
                [35, 10, 1],
                [36, 10, 1],
                [37, 10, 1],
                [38, 10, 1],
                [39, 10, 1],
                [40, 10, 1],
                [41, 10, 1],
                [42, 10, 1],
                [43, 10, 1],
                [44, 11, 1],
                [45, 11, 1],
                [46, 11, 1],
                [47, 11, 1],
                [48, 11, 1],
                [49, 11, 1],
                [50, 11, 1],
                [52, 11, 0],
                [53, 11, 0],
                [54, 12, 0],
                [55, 12, 0],
                [56, 12, 0],
                [58, 12, 0],
                [59, 12, 0],
                [60, 12, 0],
                [62, 12, 0],
                [63, 12, 0],
                [64, 12, 0],
                [66, 12, 0],
                [67, 13, 0],
                [69, 13, 0],
                [70, 13, 0],
                [71, 13, 0],
                [73, 13, 0],
                [74, 13, 0],
                [76, 13, 0],
                [77, 13, 0],
                [79, 13, 0],
                [81, 13, 0],
                [82, 14, 0],
                [84, 14, 0],
                [85, 14, 0],
                [87, 14, 0],
                [89, 14, 0],
                [90, 14, 0],
                [92, 14, 0],
                [93, 14, 0],
                [95, 14, 0],
                [97, 14, 0],
                [98, 15, 0],
                [100, 15, 0],
                [102, 15, 0],
                [104, 15, 0],
                [105, 15, 0],
                [107, 15, 0],
                [109, 15, 0],
                [110, 16, 0],
                [112, 16, 0],
                [114, 16, 0],
                [116, 16, 0],
                [117, 16, 0],
                [119, 16, 0],
                [121, 17, 0],
                [123, 17, 0],
                [124, 17, 0],
                [126, 17, 0],
                [128, 17, 0],
                [130, 17, 0],
                [131, 18, 0],
                [133, 18, 0],
                [135, 18, 0],
                [137, 18, 0],
                [138, 19, 0],
                [140, 19, 0],
                [142, 19, 0],
                [143, 19, 0],
                [145, 20, 0],
                [147, 20, 0],
                [149, 20, 0],
                [150, 21, 0],
                [152, 21, 0],
                [154, 21, 0],
                [155, 22, 0],
                [157, 22, 0],
                [159, 22, 0],
                [160, 23, 0],
                [162, 23, 0],
                [164, 23, 0],
                [165, 24, 0],
                [167, 24, 0],
                [169, 25, 0],
                [170, 25, 0],
                [172, 25, 0],
                [173, 26, 0],
                [175, 26, 0],
                [176, 27, 0],
                [178, 27, 0],
                [180, 28, 0],
                [181, 28, 0],
                [182, 29, 0],
                [184, 29, 0],
                [185, 30, 0],
                [187, 30, 0],
                [188, 31, 0],
                [190, 32, 0],
                [191, 32, 0],
                [192, 33, 0],
                [194, 33, 1],
                [195, 34, 1],
                [196, 35, 1],
                [198, 35, 2],
                [199, 36, 2],
                [200, 37, 2],
                [201, 37, 3],
                [202, 38, 3],
                [204, 39, 4],
                [205, 40, 4],
                [206, 40, 4],
                [207, 41, 5],
                [208, 42, 5],
                [209, 43, 6],
                [210, 44, 6],
                [211, 44, 7],
                [212, 45, 7],
                [213, 46, 8],
                [214, 47, 8],
                [215, 48, 9],
                [216, 49, 9],
                [217, 50, 10],
                [218, 50, 11],
                [219, 51, 11],
                [220, 52, 12],
                [221, 53, 12],
                [222, 54, 13],
                [222, 55, 14],
                [223, 56, 14],
                [224, 57, 15],
                [225, 58, 15],
                [226, 59, 16],
                [226, 60, 17],
                [227, 61, 17],
                [228, 62, 18],
                [229, 63, 19],
                [229, 64, 19],
                [230, 65, 20],
                [231, 66, 21],
                [232, 67, 21],
                [232, 68, 22],
                [233, 70, 23],
                [233, 71, 24],
                [234, 72, 24],
                [235, 73, 25],
                [235, 74, 26],
                [236, 75, 27],
                [237, 76, 27],
                [237, 77, 28],
                [238, 78, 29],
                [238, 80, 30],
                [239, 81, 30],
                [239, 82, 31],
                [240, 83, 32],
                [240, 84, 33],
                [241, 85, 34],
                [242, 87, 34],
                [242, 88, 35],
                [243, 89, 36],
                [243, 90, 37],
                [244, 91, 38],
                [244, 93, 39],
                [244, 94, 39],
                [245, 95, 40],
                [245, 96, 41],
                [246, 97, 42],
                [246, 99, 43],
                [247, 100, 44],
                [247, 101, 44],
                [248, 102, 45],
                [248, 104, 46],
                [249, 105, 47],
                [249, 106, 48],
                [249, 107, 49],
                [250, 109, 50],
                [250, 110, 50],
                [251, 111, 51],
                [251, 112, 52],
                [251, 114, 53],
                [252, 115, 54],
                [252, 116, 55],
                [253, 117, 56],
                [253, 119, 57],
                [253, 120, 57],
                [254, 121, 58],
                [254, 122, 59],
                [255, 124, 60],
            ],
        );

        m.insert(
            "betterYellow",
            [
                [0, 0, 0],
                [1, 1, 0],
                [2, 2, 0],
                [3, 3, 0],
                [4, 4, 0],
                [5, 4, 0],
                [6, 5, 0],
                [7, 6, 0],
                [8, 7, 0],
                [9, 8, 0],
                [10, 9, 0],
                [11, 10, 0],
                [12, 11, 0],
                [13, 11, 0],
                [14, 12, 0],
                [15, 13, 0],
                [16, 14, 0],
                [17, 15, 0],
                [18, 16, 0],
                [19, 17, 0],
                [20, 18, 0],
                [21, 18, 0],
                [22, 19, 0],
                [23, 20, 0],
                [24, 21, 0],
                [25, 22, 0],
                [26, 23, 0],
                [27, 24, 0],
                [28, 25, 0],
                [29, 25, 0],
                [30, 26, 0],
                [31, 27, 0],
                [32, 28, 0],
                [33, 29, 0],
                [34, 30, 0],
                [35, 31, 0],
                [36, 32, 0],
                [37, 33, 0],
                [38, 33, 0],
                [39, 34, 0],
                [40, 35, 0],
                [41, 36, 0],
                [42, 37, 0],
                [43, 38, 0],
                [44, 39, 0],
                [45, 40, 0],
                [46, 40, 0],
                [47, 41, 0],
                [48, 42, 0],
                [49, 43, 0],
                [50, 44, 0],
                [51, 45, 0],
                [52, 46, 0],
                [53, 47, 0],
                [54, 47, 0],
                [55, 48, 0],
                [56, 49, 0],
                [57, 50, 0],
                [58, 51, 0],
                [59, 52, 0],
                [60, 53, 0],
                [61, 54, 0],
                [62, 54, 0],
                [63, 55, 0],
                [64, 56, 0],
                [65, 57, 0],
                [66, 58, 0],
                [67, 59, 0],
                [68, 60, 0],
                [69, 61, 0],
                [70, 62, 0],
                [71, 62, 0],
                [72, 63, 0],
                [73, 64, 0],
                [74, 65, 0],
                [75, 66, 0],
                [76, 67, 0],
                [77, 68, 0],
                [78, 69, 0],
                [79, 69, 0],
                [80, 70, 0],
                [81, 71, 0],
                [82, 72, 0],
                [83, 73, 0],
                [84, 74, 0],
                [85, 75, 0],
                [86, 76, 0],
                [87, 76, 0],
                [88, 77, 0],
                [89, 78, 0],
                [90, 79, 0],
                [91, 80, 0],
                [92, 81, 0],
                [93, 82, 0],
                [94, 83, 0],
                [95, 83, 0],
                [96, 84, 0],
                [97, 85, 0],
                [98, 86, 0],
                [99, 87, 0],
                [100, 88, 0],
                [101, 89, 0],
                [102, 90, 0],
                [103, 91, 0],
                [104, 91, 0],
                [105, 92, 0],
                [106, 93, 0],
                [107, 94, 0],
                [108, 95, 0],
                [109, 96, 0],
                [110, 97, 0],
                [111, 98, 0],
                [112, 98, 0],
                [113, 99, 0],
                [114, 100, 0],
                [115, 101, 0],
                [116, 102, 0],
                [117, 103, 0],
                [118, 104, 0],
                [119, 105, 0],
                [120, 105, 0],
                [121, 106, 0],
                [122, 107, 0],
                [123, 108, 0],
                [124, 109, 0],
                [125, 110, 0],
                [126, 111, 0],
                [127, 112, 0],
                [128, 113, 0],
                [128, 113, 0],
                [129, 114, 0],
                [130, 115, 0],
                [131, 116, 0],
                [132, 117, 0],
                [133, 118, 0],
                [134, 119, 0],
                [135, 120, 0],
                [136, 120, 0],
                [137, 121, 0],
                [138, 122, 0],
                [139, 123, 0],
                [140, 124, 0],
                [141, 125, 0],
                [142, 126, 0],
                [143, 127, 0],
                [144, 127, 0],
                [145, 128, 0],
                [146, 129, 0],
                [147, 130, 0],
                [148, 131, 0],
                [149, 132, 0],
                [150, 133, 0],
                [151, 134, 0],
                [152, 134, 0],
                [153, 135, 0],
                [154, 136, 0],
                [155, 137, 0],
                [156, 138, 0],
                [157, 139, 0],
                [158, 140, 0],
                [159, 141, 0],
                [160, 142, 0],
                [161, 142, 0],
                [162, 143, 0],
                [163, 144, 0],
                [164, 145, 0],
                [165, 146, 0],
                [166, 147, 0],
                [167, 148, 0],
                [168, 149, 0],
                [169, 149, 0],
                [170, 150, 0],
                [171, 151, 0],
                [172, 152, 0],
                [173, 153, 0],
                [174, 154, 0],
                [175, 155, 0],
                [176, 156, 0],
                [177, 156, 0],
                [178, 157, 0],
                [179, 158, 0],
                [180, 159, 0],
                [181, 160, 0],
                [182, 161, 0],
                [183, 162, 0],
                [184, 163, 0],
                [185, 163, 0],
                [186, 164, 0],
                [187, 165, 0],
                [188, 166, 0],
                [189, 167, 0],
                [190, 168, 0],
                [191, 169, 0],
                [192, 170, 0],
                [193, 171, 0],
                [194, 171, 0],
                [195, 172, 0],
                [196, 173, 0],
                [197, 174, 0],
                [198, 175, 0],
                [199, 176, 0],
                [200, 177, 0],
                [201, 178, 0],
                [202, 178, 0],
                [203, 179, 0],
                [204, 180, 0],
                [205, 181, 0],
                [206, 182, 0],
                [207, 183, 0],
                [208, 184, 0],
                [209, 185, 0],
                [210, 185, 0],
                [211, 186, 0],
                [212, 187, 0],
                [213, 188, 0],
                [214, 189, 0],
                [215, 190, 0],
                [216, 191, 0],
                [217, 192, 0],
                [218, 192, 0],
                [219, 193, 0],
                [220, 194, 0],
                [221, 195, 0],
                [222, 196, 0],
                [223, 197, 0],
                [224, 198, 0],
                [225, 199, 0],
                [226, 200, 0],
                [227, 200, 0],
                [228, 201, 0],
                [229, 202, 0],
                [230, 203, 0],
                [231, 204, 0],
                [232, 205, 0],
                [233, 206, 0],
                [234, 207, 0],
                [235, 207, 0],
                [236, 208, 0],
                [237, 209, 0],
                [238, 210, 0],
                [239, 211, 0],
                [240, 212, 0],
                [241, 213, 0],
                [242, 214, 0],
                [243, 214, 0],
                [244, 215, 0],
                [245, 216, 0],
                [246, 217, 0],
                [247, 218, 0],
                [248, 219, 0],
                [249, 220, 0],
                [250, 221, 0],
                [251, 221, 0],
                [252, 222, 0],
                [253, 223, 0],
                [254, 224, 0],
            ],
        );

        m.insert(
            "blue_orange_icb",
            [
                [1, 2, 1],
                [1, 2, 1],
                [1, 3, 1],
                [1, 4, 1],
                [1, 5, 1],
                [1, 6, 1],
                [1, 7, 1],
                [1, 8, 1],
                [1, 9, 1],
                [1, 10, 1],
                [1, 11, 1],
                [1, 12, 1],
                [1, 13, 1],
                [1, 14, 1],
                [1, 15, 1],
                [1, 16, 1],
                [1, 17, 1],
                [1, 18, 1],
                [1, 19, 1],
                [1, 20, 1],
                [1, 21, 1],
                [1, 22, 1],
                [1, 23, 1],
                [1, 24, 1],
                [1, 25, 1],
                [1, 26, 1],
                [1, 27, 1],
                [1, 28, 1],
                [1, 29, 1],
                [1, 30, 1],
                [1, 31, 1],
                [1, 32, 1],
                [1, 33, 1],
                [1, 34, 1],
                [1, 35, 1],
                [1, 36, 1],
                [1, 37, 1],
                [1, 38, 1],
                [1, 39, 1],
                [1, 40, 1],
                [1, 41, 1],
                [1, 42, 1],
                [1, 43, 1],
                [1, 44, 1],
                [1, 45, 1],
                [1, 46, 1],
                [1, 47, 1],
                [1, 48, 1],
                [1, 49, 1],
                [1, 50, 1],
                [1, 51, 1],
                [1, 52, 1],
                [1, 53, 1],
                [1, 54, 1],
                [1, 55, 1],
                [1, 56, 1],
                [1, 57, 1],
                [1, 58, 1],
                [1, 59, 1],
                [1, 60, 1],
                [1, 61, 1],
                [1, 62, 1],
                [1, 63, 1],
                [1, 64, 1],
                [2, 64, 2],
                [4, 63, 4],
                [6, 62, 6],
                [8, 61, 8],
                [10, 60, 10],
                [12, 59, 12],
                [14, 58, 14],
                [16, 57, 16],
                [18, 56, 18],
                [20, 55, 20],
                [22, 54, 22],
                [24, 53, 24],
                [26, 52, 26],
                [28, 51, 28],
                [30, 50, 30],
                [32, 49, 32],
                [34, 48, 34],
                [36, 47, 36],
                [38, 46, 38],
                [40, 45, 40],
                [42, 44, 42],
                [44, 43, 44],
                [46, 42, 46],
                [48, 41, 48],
                [50, 40, 50],
                [52, 39, 52],
                [54, 38, 54],
                [56, 37, 56],
                [58, 36, 58],
                [60, 35, 60],
                [62, 34, 62],
                [64, 33, 64],
                [65, 32, 65],
                [67, 31, 67],
                [69, 30, 69],
                [71, 29, 71],
                [73, 28, 73],
                [75, 27, 75],
                [77, 26, 77],
                [79, 25, 79],
                [81, 24, 81],
                [83, 23, 83],
                [85, 22, 85],
                [87, 21, 87],
                [89, 20, 89],
                [91, 19, 91],
                [93, 18, 93],
                [95, 17, 95],
                [97, 16, 97],
                [99, 15, 99],
                [101, 14, 101],
                [103, 13, 103],
                [105, 12, 105],
                [107, 11, 107],
                [109, 10, 109],
                [111, 9, 111],
                [113, 8, 113],
                [115, 7, 115],
                [117, 6, 117],
                [119, 5, 119],
                [121, 4, 121],
                [123, 3, 123],
                [125, 2, 125],
                [127, 1, 127],
                [129, 1, 125],
                [131, 3, 123],
                [133, 5, 121],
                [135, 7, 119],
                [137, 9, 117],
                [139, 11, 115],
                [141, 13, 113],
                [143, 15, 111],
                [145, 17, 109],
                [147, 19, 107],
                [149, 21, 105],
                [151, 23, 103],
                [153, 25, 101],
                [155, 27, 99],
                [157, 29, 97],
                [159, 31, 95],
                [161, 33, 93],
                [163, 35, 91],
                [165, 37, 89],
                [167, 39, 87],
                [169, 41, 85],
                [171, 43, 83],
                [173, 45, 81],
                [175, 47, 79],
                [177, 49, 77],
                [179, 51, 75],
                [181, 53, 73],
                [183, 55, 71],
                [185, 57, 69],
                [187, 59, 67],
                [189, 61, 65],
                [191, 63, 64],
                [192, 64, 62],
                [194, 66, 60],
                [196, 68, 58],
                [198, 70, 56],
                [200, 72, 54],
                [202, 74, 52],
                [204, 76, 50],
                [206, 78, 48],
                [208, 80, 46],
                [210, 82, 44],
                [212, 84, 42],
                [214, 86, 40],
                [216, 88, 38],
                [218, 90, 36],
                [220, 92, 34],
                [222, 94, 32],
                [224, 96, 30],
                [226, 98, 28],
                [228, 100, 26],
                [230, 102, 24],
                [232, 104, 22],
                [234, 106, 20],
                [236, 108, 18],
                [238, 110, 16],
                [240, 112, 14],
                [242, 114, 12],
                [244, 116, 10],
                [246, 118, 8],
                [248, 120, 6],
                [250, 122, 4],
                [252, 124, 2],
                [254, 126, 1],
                [254, 128, 4],
                [254, 130, 8],
                [254, 132, 12],
                [254, 134, 16],
                [254, 136, 20],
                [254, 138, 24],
                [254, 140, 28],
                [254, 142, 32],
                [254, 144, 36],
                [254, 146, 40],
                [254, 148, 44],
                [254, 150, 48],
                [254, 152, 52],
                [254, 154, 56],
                [254, 156, 60],
                [254, 158, 64],
                [254, 160, 67],
                [254, 162, 71],
                [254, 164, 75],
                [254, 166, 79],
                [254, 168, 83],
                [254, 170, 87],
                [254, 172, 91],
                [254, 174, 95],
                [254, 176, 99],
                [254, 178, 103],
                [254, 180, 107],
                [254, 182, 111],
                [254, 184, 115],
                [254, 186, 119],
                [254, 188, 123],
                [254, 190, 127],
                [254, 191, 131],
                [254, 193, 135],
                [254, 195, 139],
                [254, 197, 143],
                [254, 199, 147],
                [254, 201, 151],
                [254, 203, 155],
                [254, 205, 159],
                [254, 207, 163],
                [254, 209, 167],
                [254, 211, 171],
                [254, 213, 175],
                [254, 215, 179],
                [254, 217, 183],
                [254, 219, 187],
                [254, 221, 191],
                [254, 223, 194],
                [254, 225, 198],
                [254, 227, 202],
                [254, 229, 206],
                [254, 231, 210],
                [254, 233, 214],
                [254, 235, 218],
                [254, 237, 222],
                [254, 239, 226],
                [254, 241, 230],
                [254, 243, 234],
                [254, 245, 238],
                [254, 247, 242],
                [254, 249, 246],
                [254, 251, 250],
                [254, 251, 250],
            ],
        );

        m.insert(
            "brgbcmyw",
            [
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [0, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [255, 0, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 255, 0],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 0, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [0, 255, 255],
                [248, 0, 255],
                [248, 0, 255],
                [248, 0, 255],
                [248, 0, 255],
                [248, 0, 255],
                [249, 0, 255],
                [249, 0, 255],
                [249, 0, 255],
                [249, 0, 255],
                [249, 0, 255],
                [250, 0, 255],
                [250, 0, 255],
                [250, 0, 255],
                [250, 0, 255],
                [251, 0, 255],
                [251, 0, 255],
                [251, 0, 255],
                [251, 0, 255],
                [251, 0, 255],
                [252, 0, 255],
                [252, 0, 255],
                [252, 0, 255],
                [252, 0, 255],
                [253, 0, 255],
                [253, 0, 255],
                [253, 0, 255],
                [253, 0, 255],
                [253, 0, 255],
                [254, 0, 255],
                [254, 0, 255],
                [254, 0, 255],
                [254, 0, 255],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 0],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
                [255, 255, 255],
            ],
        );

        m.insert(
            "cool",
            [
                [1, 3, 2],
                [1, 3, 2],
                [1, 5, 4],
                [1, 7, 6],
                [1, 9, 8],
                [1, 11, 10],
                [1, 13, 12],
                [1, 15, 14],
                [1, 17, 16],
                [1, 19, 18],
                [1, 21, 20],
                [1, 23, 22],
                [1, 25, 24],
                [1, 27, 26],
                [1, 29, 28],
                [1, 31, 30],
                [1, 33, 32],
                [1, 35, 34],
                [1, 37, 36],
                [1, 39, 38],
                [1, 41, 40],
                [1, 43, 42],
                [1, 45, 44],
                [1, 47, 46],
                [1, 49, 48],
                [1, 51, 50],
                [1, 53, 52],
                [1, 55, 54],
                [1, 57, 56],
                [1, 59, 58],
                [1, 61, 60],
                [1, 63, 62],
                [1, 64, 64],
                [1, 66, 65],
                [1, 68, 67],
                [1, 70, 69],
                [1, 72, 71],
                [1, 74, 73],
                [1, 76, 75],
                [1, 78, 77],
                [1, 80, 79],
                [1, 82, 81],
                [1, 84, 83],
                [1, 86, 85],
                [1, 88, 87],
                [1, 90, 89],
                [1, 92, 91],
                [1, 94, 93],
                [1, 96, 95],
                [1, 98, 97],
                [1, 100, 99],
                [1, 102, 101],
                [1, 104, 103],
                [1, 106, 105],
                [1, 108, 107],
                [1, 110, 109],
                [1, 112, 111],
                [1, 114, 113],
                [1, 116, 115],
                [1, 118, 117],
                [1, 120, 119],
                [1, 122, 121],
                [1, 124, 123],
                [1, 126, 125],
                [1, 128, 127],
                [2, 126, 129],
                [4, 124, 131],
                [6, 122, 133],
                [8, 120, 135],
                [10, 118, 137],
                [12, 116, 139],
                [14, 114, 141],
                [16, 112, 143],
                [18, 110, 145],
                [20, 108, 147],
                [22, 106, 149],
                [24, 104, 151],
                [26, 102, 153],
                [28, 100, 155],
                [30, 98, 157],
                [32, 96, 159],
                [34, 94, 161],
                [36, 92, 163],
                [38, 90, 165],
                [40, 88, 167],
                [42, 86, 169],
                [44, 84, 171],
                [46, 82, 173],
                [48, 80, 175],
                [50, 78, 177],
                [52, 76, 179],
                [54, 74, 181],
                [56, 72, 183],
                [58, 70, 185],
                [60, 68, 187],
                [62, 66, 189],
                [64, 64, 191],
                [65, 63, 192],
                [67, 61, 194],
                [69, 59, 196],
                [71, 57, 198],
                [73, 55, 200],
                [75, 53, 202],
                [77, 51, 204],
                [79, 49, 206],
                [81, 47, 208],
                [83, 45, 210],
                [85, 43, 212],
                [87, 41, 214],
                [89, 39, 216],
                [91, 37, 218],
                [93, 35, 220],
                [95, 33, 222],
                [97, 31, 224],
                [99, 29, 226],
                [101, 27, 228],
                [103, 25, 230],
                [105, 23, 232],
                [107, 21, 234],
                [109, 19, 236],
                [111, 17, 238],
                [113, 15, 240],
                [115, 13, 242],
                [117, 11, 244],
                [119, 9, 246],
                [121, 7, 248],
                [123, 5, 250],
                [125, 3, 252],
                [127, 1, 254],
                [129, 2, 250],
                [131, 4, 246],
                [133, 6, 242],
                [135, 8, 238],
                [137, 10, 234],
                [139, 12, 230],
                [141, 14, 226],
                [143, 16, 222],
                [145, 18, 218],
                [147, 20, 214],
                [149, 22, 210],
                [151, 24, 206],
                [153, 26, 202],
                [155, 28, 198],
                [157, 30, 194],
                [159, 32, 191],
                [161, 34, 187],
                [163, 36, 183],
                [165, 38, 179],
                [167, 40, 175],
                [169, 42, 171],
                [171, 44, 167],
                [173, 46, 163],
                [175, 48, 159],
                [177, 50, 155],
                [179, 52, 151],
                [181, 54, 147],
                [183, 56, 143],
                [185, 58, 139],
                [187, 60, 135],
                [189, 62, 131],
                [191, 64, 127],
                [192, 65, 123],
                [194, 67, 119],
                [196, 69, 115],
                [198, 71, 111],
                [200, 73, 107],
                [202, 75, 103],
                [204, 77, 99],
                [206, 79, 95],
                [208, 81, 91],
                [210, 83, 87],
                [212, 85, 83],
                [214, 87, 79],
                [216, 89, 75],
                [218, 91, 71],
                [220, 93, 67],
                [222, 95, 64],
                [224, 97, 60],
                [226, 99, 56],
                [228, 101, 52],
                [230, 103, 48],
                [232, 105, 44],
                [234, 107, 40],
                [236, 109, 36],
                [238, 111, 32],
                [240, 113, 28],
                [242, 115, 24],
                [244, 117, 20],
                [246, 119, 16],
                [248, 121, 12],
                [250, 123, 8],
                [252, 125, 4],
                [254, 127, 1],
                [254, 129, 4],
                [254, 131, 8],
                [254, 133, 12],
                [254, 135, 16],
                [254, 137, 20],
                [254, 139, 24],
                [254, 141, 28],
                [254, 143, 32],
                [254, 145, 36],
                [254, 147, 40],
                [254, 149, 44],
                [254, 151, 48],
                [254, 153, 52],
                [254, 155, 56],
                [254, 157, 60],
                [254, 159, 64],
                [254, 161, 67],
                [254, 163, 71],
                [254, 165, 75],
                [254, 167, 79],
                [254, 169, 83],
                [254, 171, 87],
                [254, 173, 91],
                [254, 175, 95],
                [254, 177, 99],
                [254, 179, 103],
                [254, 181, 107],
                [254, 183, 111],
                [254, 185, 115],
                [254, 187, 119],
                [254, 189, 123],
                [254, 191, 127],
                [254, 192, 131],
                [254, 194, 135],
                [254, 196, 139],
                [254, 198, 143],
                [254, 200, 147],
                [254, 202, 151],
                [254, 204, 155],
                [254, 206, 159],
                [254, 208, 163],
                [254, 210, 167],
                [254, 212, 171],
                [254, 214, 175],
                [254, 216, 179],
                [254, 218, 183],
                [254, 220, 187],
                [254, 222, 191],
                [254, 224, 194],
                [254, 226, 198],
                [254, 228, 202],
                [254, 230, 206],
                [254, 232, 210],
                [254, 234, 214],
                [254, 236, 218],
                [254, 238, 222],
                [254, 240, 226],
                [254, 242, 230],
                [254, 244, 234],
                [254, 246, 238],
                [254, 248, 242],
                [254, 250, 246],
                [254, 250, 246],
            ],
        );

        m.insert(
            "edges",
            [
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [6, 6, 6],
                [11, 11, 11],
                [16, 16, 16],
                [21, 21, 21],
                [26, 26, 26],
                [31, 31, 31],
                [36, 36, 36],
                [41, 41, 41],
                [46, 46, 46],
                [51, 51, 51],
                [61, 61, 61],
                [90, 90, 90],
                [105, 105, 1],
                [120, 120, 120],
                [135, 135, 135],
                [150, 150, 150],
                [165, 165, 165],
                [180, 180, 180],
                [194, 194, 194],
                [204, 204, 204],
                [224, 224, 224],
                [253, 253, 253],
                [224, 224, 224],
                [204, 204, 204],
                [194, 194, 194],
                [180, 180, 180],
                [165, 165, 165],
                [150, 150, 150],
                [135, 135, 135],
                [120, 120, 120],
                [105, 105, 105],
                [80, 80, 80],
                [70, 70, 70],
                [61, 61, 61],
                [51, 51, 51],
                [46, 46, 46],
                [41, 41, 41],
                [36, 36, 36],
                [31, 31, 31],
                [26, 26, 26],
                [21, 21, 21],
                [16, 16, 16],
                [11, 11, 11],
                [6, 6, 6],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
            ],
        );

        m.insert(
            "gem",
            [
                [1, 2, 2],
                [1, 2, 2],
                [1, 2, 3],
                [1, 3, 4],
                [1, 3, 5],
                [1, 4, 6],
                [1, 4, 7],
                [1, 5, 8],
                [1, 5, 9],
                [1, 6, 10],
                [1, 6, 11],
                [1, 7, 12],
                [1, 7, 13],
                [1, 8, 14],
                [1, 8, 15],
                [1, 9, 16],
                [1, 9, 17],
                [1, 10, 18],
                [1, 10, 19],
                [1, 11, 20],
                [1, 11, 21],
                [1, 12, 22],
                [1, 12, 23],
                [1, 13, 24],
                [1, 13, 25],
                [1, 14, 26],
                [1, 14, 27],
                [1, 15, 28],
                [1, 15, 29],
                [1, 16, 30],
                [1, 16, 31],
                [1, 17, 32],
                [1, 17, 33],
                [1, 18, 34],
                [1, 18, 35],
                [1, 19, 36],
                [1, 19, 37],
                [1, 20, 38],
                [1, 20, 39],
                [1, 21, 40],
                [1, 21, 41],
                [1, 22, 42],
                [1, 22, 43],
                [1, 23, 44],
                [1, 23, 45],
                [1, 24, 46],
                [1, 24, 47],
                [1, 25, 48],
                [1, 25, 49],
                [1, 26, 50],
                [1, 26, 51],
                [1, 27, 52],
                [1, 27, 53],
                [1, 28, 54],
                [1, 28, 55],
                [1, 29, 56],
                [1, 29, 57],
                [1, 30, 58],
                [1, 30, 59],
                [1, 31, 60],
                [1, 31, 61],
                [1, 32, 62],
                [1, 32, 63],
                [1, 33, 64],
                [1, 33, 64],
                [2, 32, 65],
                [4, 32, 66],
                [6, 31, 67],
                [8, 31, 68],
                [10, 30, 69],
                [12, 30, 70],
                [14, 29, 71],
                [16, 29, 72],
                [18, 28, 73],
                [20, 28, 74],
                [22, 27, 75],
                [24, 27, 76],
                [26, 26, 77],
                [28, 26, 78],
                [30, 25, 79],
                [32, 25, 80],
                [34, 24, 81],
                [36, 24, 82],
                [38, 23, 83],
                [40, 23, 84],
                [42, 22, 85],
                [44, 22, 86],
                [46, 21, 87],
                [48, 21, 88],
                [50, 20, 89],
                [52, 20, 90],
                [54, 19, 91],
                [56, 19, 92],
                [58, 18, 93],
                [60, 18, 94],
                [62, 17, 95],
                [64, 17, 96],
                [65, 16, 97],
                [67, 16, 98],
                [69, 15, 99],
                [71, 15, 100],
                [73, 14, 101],
                [75, 14, 102],
                [77, 13, 103],
                [79, 13, 104],
                [81, 12, 105],
                [83, 12, 106],
                [85, 11, 107],
                [87, 11, 108],
                [89, 10, 109],
                [91, 10, 110],
                [93, 9, 111],
                [95, 9, 112],
                [97, 8, 113],
                [99, 8, 114],
                [101, 7, 115],
                [103, 7, 116],
                [105, 6, 117],
                [107, 6, 118],
                [109, 5, 119],
                [111, 5, 120],
                [113, 4, 121],
                [115, 4, 122],
                [117, 3, 123],
                [119, 3, 124],
                [121, 2, 125],
                [123, 2, 126],
                [125, 1, 127],
                [127, 3, 127],
                [129, 4, 125],
                [131, 6, 123],
                [133, 7, 121],
                [135, 9, 119],
                [137, 10, 117],
                [139, 12, 115],
                [141, 13, 113],
                [143, 15, 111],
                [145, 16, 109],
                [147, 18, 107],
                [149, 19, 105],
                [151, 21, 103],
                [153, 22, 101],
                [155, 24, 99],
                [157, 25, 97],
                [159, 27, 95],
                [161, 28, 93],
                [163, 30, 91],
                [165, 31, 89],
                [167, 33, 87],
                [169, 34, 85],
                [171, 36, 83],
                [173, 37, 81],
                [175, 39, 79],
                [177, 40, 77],
                [179, 42, 75],
                [181, 43, 73],
                [183, 45, 71],
                [185, 46, 69],
                [187, 48, 67],
                [189, 49, 65],
                [191, 51, 64],
                [192, 52, 62],
                [194, 54, 60],
                [196, 55, 58],
                [198, 57, 56],
                [200, 58, 54],
                [202, 60, 52],
                [204, 61, 50],
                [206, 63, 48],
                [208, 64, 46],
                [210, 65, 44],
                [212, 66, 42],
                [214, 68, 40],
                [216, 69, 38],
                [218, 71, 36],
                [220, 72, 34],
                [222, 74, 32],
                [224, 75, 30],
                [226, 77, 28],
                [228, 78, 26],
                [230, 80, 24],
                [232, 81, 22],
                [234, 83, 20],
                [236, 84, 18],
                [238, 86, 16],
                [240, 87, 14],
                [242, 89, 12],
                [244, 90, 10],
                [246, 92, 8],
                [248, 93, 6],
                [250, 95, 4],
                [252, 95, 1],
                [254, 98, 4],
                [254, 100, 8],
                [254, 103, 12],
                [254, 105, 16],
                [254, 108, 20],
                [254, 110, 24],
                [254, 113, 28],
                [254, 115, 32],
                [254, 118, 36],
                [254, 120, 40],
                [254, 123, 44],
                [254, 125, 48],
                [254, 128, 52],
                [254, 130, 56],
                [254, 133, 60],
                [254, 135, 64],
                [254, 138, 67],
                [254, 140, 71],
                [254, 143, 75],
                [254, 145, 79],
                [254, 148, 83],
                [254, 150, 87],
                [254, 153, 91],
                [254, 155, 95],
                [254, 158, 99],
                [254, 160, 103],
                [254, 163, 107],
                [254, 165, 111],
                [254, 168, 115],
                [254, 170, 119],
                [254, 173, 123],
                [254, 175, 127],
                [254, 178, 131],
                [254, 180, 135],
                [254, 183, 139],
                [254, 185, 143],
                [254, 188, 147],
                [254, 190, 151],
                [254, 192, 155],
                [254, 194, 159],
                [254, 197, 163],
                [254, 199, 167],
                [254, 202, 171],
                [254, 204, 175],
                [254, 207, 179],
                [254, 209, 183],
                [254, 212, 187],
                [254, 214, 191],
                [254, 217, 194],
                [254, 219, 198],
                [254, 222, 202],
                [254, 224, 206],
                [254, 227, 210],
                [254, 229, 214],
                [254, 232, 218],
                [254, 234, 222],
                [254, 237, 226],
                [254, 239, 230],
                [254, 242, 234],
                [254, 244, 238],
                [254, 247, 242],
                [254, 249, 246],
                [254, 252, 250],
                [254, 252, 250],
            ],
        );

        m.insert(
            "glasbey",
            [
                [255, 255, 255],
                [0, 0, 255],
                [255, 0, 0],
                [0, 255, 0],
                [0, 0, 51],
                [255, 0, 182],
                [0, 83, 0],
                [255, 211, 0],
                [0, 159, 255],
                [154, 77, 66],
                [0, 255, 190],
                [120, 63, 193],
                [31, 150, 152],
                [255, 172, 253],
                [177, 204, 113],
                [241, 8, 92],
                [254, 143, 66],
                [221, 0, 255],
                [32, 26, 1],
                [114, 0, 85],
                [118, 108, 149],
                [2, 173, 36],
                [200, 255, 0],
                [136, 108, 0],
                [255, 183, 159],
                [133, 133, 103],
                [161, 3, 0],
                [20, 249, 255],
                [0, 71, 158],
                [220, 94, 147],
                [147, 212, 255],
                [0, 76, 255],
                [0, 66, 80],
                [57, 167, 106],
                [238, 112, 254],
                [0, 0, 100],
                [171, 245, 204],
                [161, 146, 255],
                [164, 255, 115],
                [255, 206, 113],
                [71, 0, 21],
                [212, 173, 197],
                [251, 118, 111],
                [171, 188, 0],
                [117, 0, 215],
                [166, 0, 154],
                [0, 115, 254],
                [165, 93, 174],
                [98, 132, 2],
                [0, 121, 168],
                [0, 255, 131],
                [86, 53, 0],
                [159, 0, 63],
                [66, 45, 66],
                [255, 242, 187],
                [0, 93, 67],
                [252, 255, 124],
                [159, 191, 186],
                [167, 84, 19],
                [74, 39, 108],
                [0, 16, 166],
                [145, 78, 109],
                [207, 149, 0],
                [195, 187, 255],
                [253, 68, 64],
                [66, 78, 32],
                [106, 1, 0],
                [181, 131, 84],
                [132, 233, 147],
                [96, 217, 0],
                [255, 111, 211],
                [102, 75, 63],
                [254, 100, 0],
                [228, 3, 127],
                [17, 199, 174],
                [210, 129, 139],
                [91, 118, 124],
                [32, 59, 106],
                [180, 84, 255],
                [226, 8, 210],
                [0, 1, 20],
                [93, 132, 68],
                [166, 250, 255],
                [97, 123, 201],
                [98, 0, 122],
                [126, 190, 58],
                [0, 60, 183],
                [255, 253, 0],
                [7, 197, 226],
                [180, 167, 57],
                [148, 186, 138],
                [204, 187, 160],
                [55, 0, 49],
                [0, 40, 1],
                [150, 122, 129],
                [39, 136, 38],
                [206, 130, 180],
                [150, 164, 196],
                [180, 32, 128],
                [110, 86, 180],
                [147, 0, 185],
                [199, 48, 61],
                [115, 102, 255],
                [15, 187, 253],
                [172, 164, 100],
                [182, 117, 250],
                [216, 220, 254],
                [87, 141, 113],
                [216, 85, 34],
                [0, 196, 103],
                [243, 165, 105],
                [216, 255, 182],
                [1, 24, 219],
                [52, 66, 54],
                [255, 154, 0],
                [87, 95, 1],
                [198, 241, 79],
                [255, 95, 133],
                [123, 172, 240],
                [120, 100, 49],
                [162, 133, 204],
                [105, 255, 220],
                [198, 82, 100],
                [121, 26, 64],
                [0, 238, 70],
                [231, 207, 69],
                [217, 128, 233],
                [255, 211, 209],
                [209, 255, 141],
                [36, 0, 3],
                [87, 163, 193],
                [211, 231, 201],
                [203, 111, 79],
                [62, 24, 0],
                [0, 117, 223],
                [112, 176, 88],
                [209, 24, 0],
                [0, 30, 107],
                [105, 200, 197],
                [255, 203, 255],
                [233, 194, 137],
                [191, 129, 46],
                [69, 42, 145],
                [171, 76, 194],
                [14, 117, 61],
                [0, 30, 25],
                [118, 73, 127],
                [255, 169, 200],
                [94, 55, 217],
                [238, 230, 138],
                [159, 54, 33],
                [80, 0, 148],
                [189, 144, 128],
                [0, 109, 126],
                [88, 223, 96],
                [71, 80, 103],
                [1, 93, 159],
                [99, 48, 60],
                [2, 206, 148],
                [139, 83, 37],
                [171, 0, 255],
                [141, 42, 135],
                [85, 83, 148],
                [150, 255, 0],
                [0, 152, 123],
                [255, 138, 203],
                [222, 69, 200],
                [107, 109, 230],
                [30, 0, 68],
                [173, 76, 138],
                [255, 134, 161],
                [0, 35, 60],
                [138, 205, 0],
                [111, 202, 157],
                [225, 75, 253],
                [255, 176, 77],
                [229, 232, 57],
                [114, 16, 255],
                [111, 82, 101],
                [134, 137, 48],
                [99, 38, 80],
                [105, 38, 32],
                [200, 110, 0],
                [209, 164, 255],
                [198, 210, 86],
                [79, 103, 77],
                [174, 165, 166],
                [170, 45, 101],
                [199, 81, 175],
                [255, 89, 172],
                [146, 102, 78],
                [102, 134, 184],
                [111, 152, 255],
                [92, 255, 159],
                [172, 137, 178],
                [210, 34, 98],
                [199, 207, 147],
                [255, 185, 30],
                [250, 148, 141],
                [49, 34, 78],
                [254, 81, 97],
                [254, 141, 100],
                [68, 54, 23],
                [201, 162, 84],
                [199, 232, 240],
                [68, 152, 0],
                [147, 172, 58],
                [22, 75, 28],
                [8, 84, 121],
                [116, 45, 0],
                [104, 60, 255],
                [64, 41, 38],
                [164, 113, 215],
                [207, 0, 155],
                [118, 1, 35],
                [83, 0, 88],
                [0, 82, 232],
                [43, 92, 87],
                [160, 217, 146],
                [176, 26, 229],
                [29, 3, 36],
                [122, 58, 159],
                [214, 209, 207],
                [160, 100, 105],
                [106, 157, 160],
                [153, 219, 113],
                [192, 56, 207],
                [125, 255, 89],
                [149, 0, 34],
                [213, 162, 223],
                [22, 131, 204],
                [166, 249, 69],
                [109, 105, 97],
                [86, 188, 78],
                [255, 109, 81],
                [255, 3, 248],
                [255, 0, 73],
                [202, 0, 35],
                [67, 109, 18],
                [234, 170, 173],
                [191, 165, 0],
                [38, 44, 51],
                [85, 185, 2],
                [121, 182, 158],
                [254, 236, 212],
                [139, 165, 89],
                [141, 254, 193],
                [0, 60, 43],
                [63, 17, 40],
                [255, 221, 246],
                [17, 26, 146],
                [154, 66, 84],
                [149, 157, 238],
                [126, 130, 72],
                [58, 6, 101],
                [189, 117, 101],
            ],
        );

        m.insert(
            "glasbey_inverted",
            [
                [0, 0, 0],
                [0, 48, 136],
                [16, 136, 0],
                [0, 168, 152],
                [88, 0, 0],
                [128, 0, 160],
                [136, 152, 0],
                [184, 168, 152],
                [0, 8, 64],
                [0, 112, 152],
                [0, 120, 88],
                [104, 176, 144],
                [144, 0, 32],
                [120, 120, 152],
                [136, 144, 104],
                [184, 176, 216],
                [0, 48, 0],
                [24, 48, 184],
                [72, 136, 0],
                [0, 184, 184],
                [88, 32, 104],
                [160, 32, 152],
                [144, 192, 0],
                [200, 216, 176],
                [0, 112, 48],
                [0, 112, 184],
                [56, 168, 80],
                [112, 168, 216],
                [160, 0, 96],
                [168, 112, 136],
                [128, 192, 96],
                [192, 232, 208],
                [32, 32, 0],
                [8, 88, 144],
                [56, 192, 48],
                [56, 168, 152],
                [88, 104, 0],
                [104, 0, 248],
                [248, 136, 0],
                [216, 192, 144],
                [0, 0, 128],
                [64, 136, 152],
                [48, 120, 72],
                [128, 224, 184],
                [248, 0, 64],
                [120, 112, 200],
                [248, 128, 80],
                [184, 200, 232],
                [40, 88, 0],
                [24, 16, 192],
                [80, 248, 0],
                [56, 200, 192],
                [96, 64, 64],
                [248, 16, 184],
                [160, 200, 32],
                [200, 248, 200],
                [40, 80, 56],
                [72, 88, 192],
                [80, 176, 112],
                [96, 248, 192],
                [144, 96, 88],
                [240, 136, 192],
                [248, 192, 72],
                [248, 224, 224],
                [0, 16, 40],
                [72, 48, 136],
                [0, 144, 40],
                [8, 240, 160],
                [104, 40, 0],
                [112, 88, 160],
                [152, 128, 48],
                [200, 184, 200],
                [48, 64, 88],
                [0, 144, 168],
                [0, 160, 120],
                [152, 176, 192],
                [144, 48, 56],
                [144, 144, 152],
                [136, 176, 128],
                [184, 208, 216],
                [56, 64, 0],
                [0, 0, 248],
                [88, 136, 40],
                [0, 248, 248],
                [88, 0, 136],
                [192, 88, 144],
                [136, 232, 0],
                [248, 224, 144],
                [0, 72, 96],
                [48, 104, 248],
                [48, 248, 96],
                [144, 216, 216],
                [248, 0, 120],
                [208, 160, 168],
                [168, 248, 104],
                [192, 224, 248],
                [40, 24, 48],
                [48, 88, 168],
                [0, 248, 0],
                [96, 184, 168],
                [104, 96, 16],
                [104, 80, 192],
                [248, 136, 32],
                [216, 208, 200],
                [16, 24, 112],
                [88, 152, 144],
                [88, 160, 80],
                [152, 216, 168],
                [240, 64, 0],
                [112, 144, 248],
                [248, 144, 128],
                [248, 168, 248],
                [0, 80, 48],
                [48, 0, 248],
                [128, 192, 56],
                [48, 248, 216],
                [104, 64, 112],
                [168, 64, 248],
                [248, 248, 0],
                [248, 216, 192],
                [80, 88, 88],
                [64, 88, 248],
                [72, 216, 120],
                [136, 248, 216],
                [232, 56, 80],
                [184, 96, 248],
                [248, 232, 88],
                [216, 248, 248],
                [0, 32, 8],
                [56, 40, 168],
                [24, 176, 0],
                [40, 216, 152],
                [112, 0, 56],
                [128, 64, 192],
                [144, 144, 24],
                [176, 216, 144],
                [32, 0, 72],
                [0, 136, 144],
                [0, 160, 80],
                [144, 168, 152],
                [232, 0, 0],
                [128, 120, 176],
                [160, 136, 128],
                [168, 160, 248],
                [0, 80, 0],
                [0, 64, 224],
                [72, 168, 0],
                [32, 168, 216],
                [120, 16, 104],
                [168, 64, 176],
                [144, 168, 72],
                [192, 248, 152],
                [16, 80, 80],
                [0, 96, 248],
                [0, 248, 72],
                [96, 200, 216],
                [144, 48, 96],
                [176, 152, 176],
                [184, 208, 104],
                [184, 248, 232],
                [56, 16, 8],
                [0, 72, 176],
                [24, 240, 40],
                [96, 176, 184],
                [88, 120, 48],
                [152, 32, 248],
                [248, 168, 16],
                [248, 184, 168],
                [40, 0, 112],
                [72, 120, 168],
                [40, 120, 112],
                [136, 248, 168],
                [248, 56, 24],
                [128, 152, 200],
                [248, 160, 96],
                [232, 176, 224],
                [32, 120, 16],
                [88, 0, 184],
                [72, 224, 24],
                [88, 168, 232],
                [104, 88, 56],
                [248, 0, 248],
                [248, 176, 0],
                [224, 248, 184],
                [80, 112, 72],
                [64, 120, 208],
                [112, 208, 120],
                [104, 248, 216],
                [224, 104, 96],
                [216, 112, 216],
                [248, 184, 96],
                [224, 248, 216],
                [0, 40, 40],
                [56, 8, 176],
                [32, 184, 48],
                [0, 248, 176],
                [128, 80, 8],
                [136, 72, 160],
                [152, 120, 64],
                [184, 208, 184],
                [56, 48, 104],
                [48, 144, 176],
                [32, 160, 104],
                [152, 200, 192],
                [168, 88, 56],
                [160, 120, 184],
                [168, 168, 104],
                [168, 200, 248],
                [40, 40, 48],
                [0, 40, 248],
                [80, 176, 56],
                [40, 224, 248],
                [96, 32, 136],
                [248, 56, 152],
                [136, 248, 40],
                [248, 248, 152],
                [0, 104, 112],
                [0, 152, 248],
                [24, 248, 128],
                [136, 208, 248],
                [248, 48, 104],
                [248, 160, 184],
                [152, 248, 128],
                [216, 224, 248],
                [80, 8, 48],
                [80, 88, 152],
                [32, 248, 0],
                [80, 208, 152],
                [144, 96, 0],
                [112, 48, 248],
                [232, 120, 48],
                [248, 192, 208],
                [16, 56, 112],
                [104, 152, 176],
                [104, 128, 120],
                [168, 248, 160],
                [248, 96, 0],
                [152, 120, 248],
                [240, 168, 128],
                [248, 208, 248],
                [40, 88, 32],
                [80, 64, 248],
                [104, 248, 64],
                [88, 248, 248],
                [128, 72, 96],
                [248, 80, 216],
                [248, 224, 32],
                [248, 248, 200],
                [64, 104, 120],
                [48, 144, 248],
                [88, 248, 96],
                [144, 248, 248],
                [248, 96, 128],
                [184, 144, 232],
                [232, 224, 104],
                [248, 248, 232],
            ],
        );

        m.insert(
            "glasbey_on_dark",
            [
                [0, 0, 0],
                [255, 255, 0],
                [255, 25, 255],
                [0, 147, 147],
                [156, 64, 0],
                [88, 0, 199],
                [241, 235, 255],
                [20, 75, 0],
                [0, 188, 1],
                [255, 159, 98],
                [145, 144, 255],
                [93, 0, 63],
                [0, 255, 214],
                [255, 0, 95],
                [120, 100, 119],
                [0, 73, 96],
                [140, 136, 74],
                [82, 207, 255],
                [207, 152, 186],
                [157, 0, 177],
                [191, 211, 152],
                [0, 107, 210],
                [163, 51, 91],
                [88, 70, 43],
                [107, 255, 102],
                [156, 171, 174],
                [0, 132, 65],
                [92, 16, 0],
                [0, 0, 143],
                [240, 81, 0],
                [205, 170, 0],
                [182, 114, 100],
                [76, 190, 141],
                [148, 60, 255],
                [82, 54, 100],
                [73, 101, 93],
                [110, 132, 165],
                [175, 105, 192],
                [208, 184, 255],
                [255, 211, 190],
                [212, 255, 237],
                [255, 123, 137],
                [96, 98, 0],
                [222, 0, 157],
                [0, 159, 249],
                [197, 120, 1],
                [0, 1, 255],
                [197, 1, 29],
                [190, 163, 136],
                [98, 90, 157],
                [255, 144, 255],
                [160, 205, 0],
                [255, 215, 97],
                [107, 59, 73],
                [101, 144, 0],
                [124, 131, 125],
                [255, 255, 195],
                [149, 215, 214],
                [18, 112, 141],
                [255, 195, 239],
                [195, 102, 146],
                [140, 0, 30],
                [138, 177, 93],
                [135, 98, 59],
                [183, 209, 245],
                [163, 153, 193],
                [16, 189, 193],
                [255, 102, 194],
                [48, 57, 118],
                [77, 82, 99],
                [205, 192, 201],
                [94, 63, 255],
                [197, 135, 255],
                [195, 0, 255],
                [0, 80, 57],
                [139, 3, 110],
                [208, 252, 136],
                [127, 229, 159],
                [151, 78, 136],
                [110, 0, 159],
                [130, 170, 209],
                [100, 150, 109],
                [158, 132, 145],
                [204, 76, 87],
                [66, 0, 124],
                [255, 172, 180],
                [136, 119, 190],
                [144, 86, 89],
                [109, 52, 0],
                [93, 116, 74],
                [0, 246, 255],
                [96, 116, 255],
                [84, 0, 98],
                [0, 169, 83],
                [137, 79, 175],
                [219, 182, 107],
                [197, 213, 203],
                [16, 144, 184],
                [230, 121, 85],
                [65, 85, 45],
                [42, 106, 0],
                [104, 96, 87],
                [255, 165, 4],
                [2, 220, 95],
                [151, 183, 151],
                [147, 109, 0],
                [247, 0, 29],
                [195, 50, 190],
                [2, 85, 148],
                [192, 93, 39],
                [0, 125, 102],
                [156, 149, 0],
                [248, 125, 0],
                [255, 252, 243],
                [105, 165, 154],
                [184, 245, 0],
                [132, 56, 45],
                [214, 144, 141],
                [209, 0, 98],
                [197, 241, 255],
                [222, 214, 3],
                [163, 180, 255],
                [90, 124, 130],
                [105, 26, 42],
                [186, 150, 73],
                [114, 79, 0],
                [0, 216, 189],
                [120, 53, 126],
                [157, 133, 109],
                [215, 124, 206],
                [254, 85, 81],
                [0, 96, 100],
                [238, 85, 137],
                [23, 176, 218],
                [187, 255, 192],
                [126, 0, 220],
                [255, 150, 208],
                [73, 65, 0],
                [216, 90, 255],
                [176, 33, 135],
                [163, 110, 255],
                [64, 71, 177],
                [49, 0, 186],
                [186, 196, 86],
                [14, 103, 55],
                [85, 105, 136],
                [137, 0, 68],
                [0, 158, 125],
                [125, 174, 0],
                [209, 196, 168],
                [140, 143, 156],
                [158, 224, 110],
                [86, 73, 78],
                [154, 255, 245],
                [176, 162, 168],
                [171, 62, 51],
                [103, 153, 169],
                [146, 116, 156],
                [106, 80, 124],
                [77, 131, 204],
                [179, 182, 207],
                [160, 25, 0],
                [143, 154, 123],
                [170, 117, 64],
                [91, 59, 145],
                [91, 227, 0],
                [205, 156, 223],
                [235, 177, 149],
                [0, 140, 1],
                [204, 57, 2],
                [239, 218, 157],
                [175, 176, 117],
                [138, 111, 109],
                [156, 104, 129],
                [97, 42, 85],
                [167, 229, 200],
                [129, 186, 199],
                [254, 219, 232],
                [120, 123, 19],
                [99, 104, 111],
                [101, 94, 51],
                [217, 85, 183],
                [200, 139, 98],
                [115, 97, 214],
                [73, 80, 70],
                [227, 126, 166],
                [222, 203, 238],
                [132, 57, 100],
                [213, 110, 121],
                [158, 3, 224],
                [175, 0, 58],
                [117, 76, 61],
                [89, 127, 109],
                [139, 229, 255],
                [125, 33, 0],
                [123, 117, 89],
                [133, 147, 204],
                [179, 134, 184],
                [116, 164, 254],
                [126, 193, 175],
                [162, 91, 3],
                [26, 70, 255],
                [255, 0, 202],
                [215, 236, 199],
                [255, 248, 115],
                [115, 108, 145],
                [0, 255, 150],
                [114, 201, 120],
                [80, 124, 40],
                [160, 88, 60],
                [68, 81, 128],
                [206, 213, 225],
                [194, 65, 126],
                [57, 80, 83],
                [225, 149, 58],
                [240, 178, 255],
                [176, 158, 238],
                [255, 0, 148],
                [116, 151, 74],
                [214, 171, 175],
                [101, 43, 29],
                [253, 150, 133],
                [0, 215, 232],
                [243, 190, 0],
                [164, 87, 221],
                [9, 120, 123],
                [54, 91, 112],
                [176, 88, 108],
                [102, 114, 176],
                [216, 222, 120],
                [191, 129, 149],
                [176, 178, 166],
                [127, 190, 255],
                [115, 0, 117],
                [0, 60, 158],
                [229, 220, 214],
                [100, 67, 195],
                [113, 200, 65],
                [74, 0, 250],
                [0, 220, 157],
                [235, 249, 254],
                [170, 177, 2],
                [199, 174, 206],
                [131, 74, 29],
                [255, 104, 237],
                [0, 181, 158],
                [116, 77, 103],
                [171, 131, 6],
                [218, 90, 65],
                [173, 197, 203],
                [64, 85, 0],
                [255, 194, 132],
                [220, 27, 68],
                [168, 131, 209],
                [125, 121, 131],
                [17, 101, 82],
            ],
        );

        m.insert(
            "glow",
            [
                [0, 138, 0],
                [1, 0, 0],
                [1, 0, 0],
                [2, 0, 0],
                [2, 0, 0],
                [3, 0, 0],
                [4, 0, 0],
                [6, 0, 0],
                [8, 0, 0],
                [11, 0, 0],
                [13, 0, 0],
                [15, 0, 0],
                [18, 0, 0],
                [21, 1, 1],
                [23, 1, 1],
                [24, 1, 1],
                [27, 1, 1],
                [30, 1, 1],
                [31, 1, 1],
                [33, 1, 1],
                [36, 1, 1],
                [37, 1, 1],
                [40, 2, 1],
                [42, 2, 3],
                [45, 2, 4],
                [46, 2, 4],
                [49, 2, 4],
                [51, 2, 4],
                [53, 2, 4],
                [56, 2, 4],
                [58, 3, 3],
                [60, 3, 3],
                [62, 3, 3],
                [65, 3, 3],
                [68, 4, 4],
                [70, 5, 6],
                [72, 5, 6],
                [74, 5, 6],
                [78, 5, 6],
                [80, 6, 6],
                [82, 6, 6],
                [84, 6, 6],
                [86, 7, 6],
                [89, 7, 6],
                [91, 8, 6],
                [93, 9, 6],
                [96, 9, 6],
                [98, 9, 6],
                [100, 9, 6],
                [102, 10, 6],
                [104, 10, 6],
                [106, 11, 6],
                [108, 12, 6],
                [110, 13, 6],
                [113, 14, 6],
                [115, 14, 6],
                [117, 14, 6],
                [119, 14, 6],
                [122, 15, 6],
                [125, 16, 6],
                [127, 16, 5],
                [129, 17, 5],
                [132, 18, 7],
                [135, 19, 9],
                [135, 19, 10],
                [137, 19, 10],
                [140, 20, 10],
                [141, 21, 10],
                [142, 22, 10],
                [145, 23, 10],
                [148, 24, 10],
                [149, 24, 10],
                [152, 25, 10],
                [154, 27, 10],
                [156, 28, 10],
                [157, 28, 10],
                [158, 28, 10],
                [160, 29, 10],
                [162, 31, 10],
                [164, 32, 10],
                [166, 32, 10],
                [168, 33, 9],
                [170, 35, 9],
                [171, 36, 9],
                [173, 36, 9],
                [174, 37, 9],
                [176, 39, 9],
                [178, 40, 9],
                [179, 40, 9],
                [180, 41, 9],
                [182, 42, 9],
                [183, 43, 9],
                [185, 45, 9],
                [186, 46, 9],
                [189, 47, 9],
                [192, 48, 8],
                [193, 50, 8],
                [193, 51, 8],
                [194, 52, 8],
                [195, 54, 8],
                [195, 55, 8],
                [196, 56, 8],
                [198, 57, 8],
                [199, 59, 8],
                [201, 62, 8],
                [203, 63, 8],
                [204, 65, 8],
                [204, 66, 8],
                [205, 68, 8],
                [206, 70, 8],
                [207, 71, 8],
                [209, 73, 8],
                [211, 74, 7],
                [211, 75, 7],
                [211, 77, 7],
                [211, 79, 7],
                [213, 81, 7],
                [215, 83, 7],
                [216, 85, 7],
                [216, 87, 7],
                [216, 89, 7],
                [216, 92, 7],
                [218, 93, 7],
                [219, 96, 7],
                [219, 98, 7],
                [219, 99, 7],
                [220, 100, 7],
                [222, 103, 6],
                [223, 105, 6],
                [223, 107, 6],
                [223, 109, 6],
                [223, 111, 6],
                [224, 113, 6],
                [224, 116, 6],
                [226, 117, 7],
                [227, 119, 10],
                [227, 121, 12],
                [227, 123, 12],
                [227, 125, 12],
                [228, 126, 12],
                [229, 128, 12],
                [231, 130, 12],
                [231, 132, 13],
                [231, 135, 15],
                [231, 137, 17],
                [231, 139, 18],
                [231, 140, 18],
                [231, 142, 19],
                [232, 144, 20],
                [233, 145, 22],
                [234, 147, 23],
                [234, 148, 23],
                [234, 150, 24],
                [234, 152, 26],
                [234, 154, 27],
                [234, 156, 27],
                [235, 158, 28],
                [237, 160, 30],
                [238, 161, 32],
                [238, 162, 33],
                [238, 164, 34],
                [238, 166, 35],
                [238, 168, 37],
                [238, 171, 39],
                [238, 172, 40],
                [238, 172, 41],
                [239, 174, 43],
                [240, 176, 45],
                [242, 177, 46],
                [242, 179, 48],
                [242, 180, 50],
                [242, 182, 52],
                [242, 183, 54],
                [242, 185, 55],
                [242, 187, 57],
                [242, 188, 58],
                [242, 189, 61],
                [243, 191, 63],
                [245, 192, 65],
                [246, 192, 67],
                [246, 192, 70],
                [246, 196, 72],
                [246, 200, 73],
                [245, 201, 76],
                [245, 201, 79],
                [245, 202, 80],
                [245, 203, 83],
                [245, 204, 86],
                [245, 206, 88],
                [245, 208, 89],
                [247, 210, 92],
                [248, 212, 95],
                [249, 213, 96],
                [249, 213, 99],
                [249, 214, 102],
                [249, 215, 104],
                [249, 217, 107],
                [249, 218, 108],
                [249, 220, 110],
                [249, 221, 113],
                [249, 222, 116],
                [249, 223, 120],
                [249, 224, 121],
                [249, 225, 123],
                [249, 226, 125],
                [249, 226, 127],
                [249, 227, 129],
                [249, 228, 132],
                [249, 229, 135],
                [250, 231, 137],
                [252, 232, 140],
                [253, 233, 143],
                [253, 234, 146],
                [253, 235, 149],
                [253, 236, 150],
                [253, 237, 153],
                [253, 238, 155],
                [253, 239, 158],
                [253, 239, 160],
                [253, 239, 162],
                [253, 239, 165],
                [253, 241, 168],
                [253, 242, 171],
                [253, 243, 173],
                [253, 243, 175],
                [253, 243, 178],
                [253, 244, 180],
                [253, 245, 183],
                [253, 247, 186],
                [253, 247, 188],
                [253, 247, 191],
                [253, 247, 192],
                [253, 247, 195],
                [253, 247, 198],
                [253, 248, 201],
                [253, 249, 203],
                [253, 250, 206],
                [253, 251, 209],
                [253, 251, 210],
                [253, 251, 213],
                [253, 252, 215],
                [253, 252, 218],
                [253, 252, 221],
                [253, 252, 223],
                [253, 252, 225],
                [253, 252, 228],
                [253, 252, 231],
                [253, 252, 233],
                [253, 252, 236],
                [253, 252, 238],
                [253, 252, 241],
                [253, 252, 244],
                [253, 252, 246],
                [253, 253, 250],
                [253, 253, 252],
                [0, 0, 255],
            ],
        );

        m.insert(
            "mpl-inferno",
            [
                [0, 0, 3],
                [0, 0, 4],
                [0, 0, 6],
                [1, 0, 7],
                [1, 1, 9],
                [1, 1, 11],
                [2, 1, 14],
                [2, 2, 16],
                [3, 2, 18],
                [4, 3, 20],
                [4, 3, 22],
                [5, 4, 24],
                [6, 4, 27],
                [7, 5, 29],
                [8, 6, 31],
                [9, 6, 33],
                [10, 7, 35],
                [11, 7, 38],
                [13, 8, 40],
                [14, 8, 42],
                [15, 9, 45],
                [16, 9, 47],
                [18, 10, 50],
                [19, 10, 52],
                [20, 11, 54],
                [22, 11, 57],
                [23, 11, 59],
                [25, 11, 62],
                [26, 11, 64],
                [28, 12, 67],
                [29, 12, 69],
                [31, 12, 71],
                [32, 12, 74],
                [34, 11, 76],
                [36, 11, 78],
                [38, 11, 80],
                [39, 11, 82],
                [41, 11, 84],
                [43, 10, 86],
                [45, 10, 88],
                [46, 10, 90],
                [48, 10, 92],
                [50, 9, 93],
                [52, 9, 95],
                [53, 9, 96],
                [55, 9, 97],
                [57, 9, 98],
                [59, 9, 100],
                [60, 9, 101],
                [62, 9, 102],
                [64, 9, 102],
                [65, 9, 103],
                [67, 10, 104],
                [69, 10, 105],
                [70, 10, 105],
                [72, 11, 106],
                [74, 11, 106],
                [75, 12, 107],
                [77, 12, 107],
                [79, 13, 108],
                [80, 13, 108],
                [82, 14, 108],
                [83, 14, 109],
                [85, 15, 109],
                [87, 15, 109],
                [88, 16, 109],
                [90, 17, 109],
                [91, 17, 110],
                [93, 18, 110],
                [95, 18, 110],
                [96, 19, 110],
                [98, 20, 110],
                [99, 20, 110],
                [101, 21, 110],
                [102, 21, 110],
                [104, 22, 110],
                [106, 23, 110],
                [107, 23, 110],
                [109, 24, 110],
                [110, 24, 110],
                [112, 25, 110],
                [114, 25, 109],
                [115, 26, 109],
                [117, 27, 109],
                [118, 27, 109],
                [120, 28, 109],
                [122, 28, 109],
                [123, 29, 108],
                [125, 29, 108],
                [126, 30, 108],
                [128, 31, 107],
                [129, 31, 107],
                [131, 32, 107],
                [133, 32, 106],
                [134, 33, 106],
                [136, 33, 106],
                [137, 34, 105],
                [139, 34, 105],
                [141, 35, 105],
                [142, 36, 104],
                [144, 36, 104],
                [145, 37, 103],
                [147, 37, 103],
                [149, 38, 102],
                [150, 38, 102],
                [152, 39, 101],
                [153, 40, 100],
                [155, 40, 100],
                [156, 41, 99],
                [158, 41, 99],
                [160, 42, 98],
                [161, 43, 97],
                [163, 43, 97],
                [164, 44, 96],
                [166, 44, 95],
                [167, 45, 95],
                [169, 46, 94],
                [171, 46, 93],
                [172, 47, 92],
                [174, 48, 91],
                [175, 49, 91],
                [177, 49, 90],
                [178, 50, 89],
                [180, 51, 88],
                [181, 51, 87],
                [183, 52, 86],
                [184, 53, 86],
                [186, 54, 85],
                [187, 55, 84],
                [189, 55, 83],
                [190, 56, 82],
                [191, 57, 81],
                [193, 58, 80],
                [194, 59, 79],
                [196, 60, 78],
                [197, 61, 77],
                [199, 62, 76],
                [200, 62, 75],
                [201, 63, 74],
                [203, 64, 73],
                [204, 65, 72],
                [205, 66, 71],
                [207, 68, 70],
                [208, 69, 68],
                [209, 70, 67],
                [210, 71, 66],
                [212, 72, 65],
                [213, 73, 64],
                [214, 74, 63],
                [215, 75, 62],
                [217, 77, 61],
                [218, 78, 59],
                [219, 79, 58],
                [220, 80, 57],
                [221, 82, 56],
                [222, 83, 55],
                [223, 84, 54],
                [224, 86, 52],
                [226, 87, 51],
                [227, 88, 50],
                [228, 90, 49],
                [229, 91, 48],
                [230, 92, 46],
                [230, 94, 45],
                [231, 95, 44],
                [232, 97, 43],
                [233, 98, 42],
                [234, 100, 40],
                [235, 101, 39],
                [236, 103, 38],
                [237, 104, 37],
                [237, 106, 35],
                [238, 108, 34],
                [239, 109, 33],
                [240, 111, 31],
                [240, 112, 30],
                [241, 114, 29],
                [242, 116, 28],
                [242, 117, 26],
                [243, 119, 25],
                [243, 121, 24],
                [244, 122, 22],
                [245, 124, 21],
                [245, 126, 20],
                [246, 128, 18],
                [246, 129, 17],
                [247, 131, 16],
                [247, 133, 14],
                [248, 135, 13],
                [248, 136, 12],
                [248, 138, 11],
                [249, 140, 9],
                [249, 142, 8],
                [249, 144, 8],
                [250, 145, 7],
                [250, 147, 6],
                [250, 149, 6],
                [250, 151, 6],
                [251, 153, 6],
                [251, 155, 6],
                [251, 157, 6],
                [251, 158, 7],
                [251, 160, 7],
                [251, 162, 8],
                [251, 164, 10],
                [251, 166, 11],
                [251, 168, 13],
                [251, 170, 14],
                [251, 172, 16],
                [251, 174, 18],
                [251, 176, 20],
                [251, 177, 22],
                [251, 179, 24],
                [251, 181, 26],
                [251, 183, 28],
                [251, 185, 30],
                [250, 187, 33],
                [250, 189, 35],
                [250, 191, 37],
                [250, 193, 40],
                [249, 195, 42],
                [249, 197, 44],
                [249, 199, 47],
                [248, 201, 49],
                [248, 203, 52],
                [248, 205, 55],
                [247, 207, 58],
                [247, 209, 60],
                [246, 211, 63],
                [246, 213, 66],
                [245, 215, 69],
                [245, 217, 72],
                [244, 219, 75],
                [244, 220, 79],
                [243, 222, 82],
                [243, 224, 86],
                [243, 226, 89],
                [242, 228, 93],
                [242, 230, 96],
                [241, 232, 100],
                [241, 233, 104],
                [241, 235, 108],
                [241, 237, 112],
                [241, 238, 116],
                [241, 240, 121],
                [241, 242, 125],
                [242, 243, 129],
                [242, 244, 133],
                [243, 246, 137],
                [244, 247, 141],
                [245, 248, 145],
                [246, 250, 149],
                [247, 251, 153],
                [249, 252, 157],
                [250, 253, 160],
                [252, 254, 164],
            ],
        );

        m.insert(
            "mpl-magma",
            [
                [0, 0, 3],
                [0, 0, 4],
                [0, 0, 6],
                [1, 0, 7],
                [1, 1, 9],
                [1, 1, 11],
                [2, 2, 13],
                [2, 2, 15],
                [3, 3, 17],
                [4, 3, 19],
                [4, 4, 21],
                [5, 4, 23],
                [6, 5, 25],
                [7, 5, 27],
                [8, 6, 29],
                [9, 7, 31],
                [10, 7, 34],
                [11, 8, 36],
                [12, 9, 38],
                [13, 10, 40],
                [14, 10, 42],
                [15, 11, 44],
                [16, 12, 47],
                [17, 12, 49],
                [18, 13, 51],
                [20, 13, 53],
                [21, 14, 56],
                [22, 14, 58],
                [23, 15, 60],
                [24, 15, 63],
                [26, 16, 65],
                [27, 16, 68],
                [28, 16, 70],
                [30, 16, 73],
                [31, 17, 75],
                [32, 17, 77],
                [34, 17, 80],
                [35, 17, 82],
                [37, 17, 85],
                [38, 17, 87],
                [40, 17, 89],
                [42, 17, 92],
                [43, 17, 94],
                [45, 16, 96],
                [47, 16, 98],
                [48, 16, 101],
                [50, 16, 103],
                [52, 16, 104],
                [53, 15, 106],
                [55, 15, 108],
                [57, 15, 110],
                [59, 15, 111],
                [60, 15, 113],
                [62, 15, 114],
                [64, 15, 115],
                [66, 15, 116],
                [67, 15, 117],
                [69, 15, 118],
                [71, 15, 119],
                [72, 16, 120],
                [74, 16, 121],
                [75, 16, 121],
                [77, 17, 122],
                [79, 17, 123],
                [80, 18, 123],
                [82, 18, 124],
                [83, 19, 124],
                [85, 19, 125],
                [87, 20, 125],
                [88, 21, 126],
                [90, 21, 126],
                [91, 22, 126],
                [93, 23, 126],
                [94, 23, 127],
                [96, 24, 127],
                [97, 24, 127],
                [99, 25, 127],
                [101, 26, 128],
                [102, 26, 128],
                [104, 27, 128],
                [105, 28, 128],
                [107, 28, 128],
                [108, 29, 128],
                [110, 30, 129],
                [111, 30, 129],
                [113, 31, 129],
                [115, 31, 129],
                [116, 32, 129],
                [118, 33, 129],
                [119, 33, 129],
                [121, 34, 129],
                [122, 34, 129],
                [124, 35, 129],
                [126, 36, 129],
                [127, 36, 129],
                [129, 37, 129],
                [130, 37, 129],
                [132, 38, 129],
                [133, 38, 129],
                [135, 39, 129],
                [137, 40, 129],
                [138, 40, 129],
                [140, 41, 128],
                [141, 41, 128],
                [143, 42, 128],
                [145, 42, 128],
                [146, 43, 128],
                [148, 43, 128],
                [149, 44, 128],
                [151, 44, 127],
                [153, 45, 127],
                [154, 45, 127],
                [156, 46, 127],
                [158, 46, 126],
                [159, 47, 126],
                [161, 47, 126],
                [163, 48, 126],
                [164, 48, 125],
                [166, 49, 125],
                [167, 49, 125],
                [169, 50, 124],
                [171, 51, 124],
                [172, 51, 123],
                [174, 52, 123],
                [176, 52, 123],
                [177, 53, 122],
                [179, 53, 122],
                [181, 54, 121],
                [182, 54, 121],
                [184, 55, 120],
                [185, 55, 120],
                [187, 56, 119],
                [189, 57, 119],
                [190, 57, 118],
                [192, 58, 117],
                [194, 58, 117],
                [195, 59, 116],
                [197, 60, 116],
                [198, 60, 115],
                [200, 61, 114],
                [202, 62, 114],
                [203, 62, 113],
                [205, 63, 112],
                [206, 64, 112],
                [208, 65, 111],
                [209, 66, 110],
                [211, 66, 109],
                [212, 67, 109],
                [214, 68, 108],
                [215, 69, 107],
                [217, 70, 106],
                [218, 71, 105],
                [220, 72, 105],
                [221, 73, 104],
                [222, 74, 103],
                [224, 75, 102],
                [225, 76, 102],
                [226, 77, 101],
                [228, 78, 100],
                [229, 80, 99],
                [230, 81, 98],
                [231, 82, 98],
                [232, 84, 97],
                [234, 85, 96],
                [235, 86, 96],
                [236, 88, 95],
                [237, 89, 95],
                [238, 91, 94],
                [238, 93, 93],
                [239, 94, 93],
                [240, 96, 93],
                [241, 97, 92],
                [242, 99, 92],
                [243, 101, 92],
                [243, 103, 91],
                [244, 104, 91],
                [245, 106, 91],
                [245, 108, 91],
                [246, 110, 91],
                [246, 112, 91],
                [247, 113, 91],
                [247, 115, 92],
                [248, 117, 92],
                [248, 119, 92],
                [249, 121, 92],
                [249, 123, 93],
                [249, 125, 93],
                [250, 127, 94],
                [250, 128, 94],
                [250, 130, 95],
                [251, 132, 96],
                [251, 134, 96],
                [251, 136, 97],
                [251, 138, 98],
                [252, 140, 99],
                [252, 142, 99],
                [252, 144, 100],
                [252, 146, 101],
                [252, 147, 102],
                [253, 149, 103],
                [253, 151, 104],
                [253, 153, 105],
                [253, 155, 106],
                [253, 157, 107],
                [253, 159, 108],
                [253, 161, 110],
                [253, 162, 111],
                [253, 164, 112],
                [254, 166, 113],
                [254, 168, 115],
                [254, 170, 116],
                [254, 172, 117],
                [254, 174, 118],
                [254, 175, 120],
                [254, 177, 121],
                [254, 179, 123],
                [254, 181, 124],
                [254, 183, 125],
                [254, 185, 127],
                [254, 187, 128],
                [254, 188, 130],
                [254, 190, 131],
                [254, 192, 133],
                [254, 194, 134],
                [254, 196, 136],
                [254, 198, 137],
                [254, 199, 139],
                [254, 201, 141],
                [254, 203, 142],
                [253, 205, 144],
                [253, 207, 146],
                [253, 209, 147],
                [253, 210, 149],
                [253, 212, 151],
                [253, 214, 152],
                [253, 216, 154],
                [253, 218, 156],
                [253, 220, 157],
                [253, 221, 159],
                [253, 223, 161],
                [253, 225, 163],
                [252, 227, 165],
                [252, 229, 166],
                [252, 230, 168],
                [252, 232, 170],
                [252, 234, 172],
                [252, 236, 174],
                [252, 238, 176],
                [252, 240, 177],
                [252, 241, 179],
                [252, 243, 181],
                [252, 245, 183],
                [251, 247, 185],
                [251, 249, 187],
                [251, 250, 189],
                [251, 252, 191],
            ],
        );

        m.insert(
            "mpl-plasma",
            [
                [12, 7, 134],
                [16, 7, 135],
                [19, 6, 137],
                [21, 6, 138],
                [24, 6, 139],
                [27, 6, 140],
                [29, 6, 141],
                [31, 5, 142],
                [33, 5, 143],
                [35, 5, 144],
                [37, 5, 145],
                [39, 5, 146],
                [41, 5, 147],
                [43, 5, 148],
                [45, 4, 148],
                [47, 4, 149],
                [49, 4, 150],
                [51, 4, 151],
                [52, 4, 152],
                [54, 4, 152],
                [56, 4, 153],
                [58, 4, 154],
                [59, 3, 154],
                [61, 3, 155],
                [63, 3, 156],
                [64, 3, 156],
                [66, 3, 157],
                [68, 3, 158],
                [69, 3, 158],
                [71, 2, 159],
                [73, 2, 159],
                [74, 2, 160],
                [76, 2, 161],
                [78, 2, 161],
                [79, 2, 162],
                [81, 1, 162],
                [82, 1, 163],
                [84, 1, 163],
                [86, 1, 163],
                [87, 1, 164],
                [89, 1, 164],
                [90, 0, 165],
                [92, 0, 165],
                [94, 0, 165],
                [95, 0, 166],
                [97, 0, 166],
                [98, 0, 166],
                [100, 0, 167],
                [101, 0, 167],
                [103, 0, 167],
                [104, 0, 167],
                [106, 0, 167],
                [108, 0, 168],
                [109, 0, 168],
                [111, 0, 168],
                [112, 0, 168],
                [114, 0, 168],
                [115, 0, 168],
                [117, 0, 168],
                [118, 1, 168],
                [120, 1, 168],
                [121, 1, 168],
                [123, 2, 168],
                [124, 2, 167],
                [126, 3, 167],
                [127, 3, 167],
                [129, 4, 167],
                [130, 4, 167],
                [132, 5, 166],
                [133, 6, 166],
                [134, 7, 166],
                [136, 7, 165],
                [137, 8, 165],
                [139, 9, 164],
                [140, 10, 164],
                [142, 12, 164],
                [143, 13, 163],
                [144, 14, 163],
                [146, 15, 162],
                [147, 16, 161],
                [149, 17, 161],
                [150, 18, 160],
                [151, 19, 160],
                [153, 20, 159],
                [154, 21, 158],
                [155, 23, 158],
                [157, 24, 157],
                [158, 25, 156],
                [159, 26, 155],
                [160, 27, 155],
                [162, 28, 154],
                [163, 29, 153],
                [164, 30, 152],
                [165, 31, 151],
                [167, 33, 151],
                [168, 34, 150],
                [169, 35, 149],
                [170, 36, 148],
                [172, 37, 147],
                [173, 38, 146],
                [174, 39, 145],
                [175, 40, 144],
                [176, 42, 143],
                [177, 43, 143],
                [178, 44, 142],
                [180, 45, 141],
                [181, 46, 140],
                [182, 47, 139],
                [183, 48, 138],
                [184, 50, 137],
                [185, 51, 136],
                [186, 52, 135],
                [187, 53, 134],
                [188, 54, 133],
                [189, 55, 132],
                [190, 56, 131],
                [191, 57, 130],
                [192, 59, 129],
                [193, 60, 128],
                [194, 61, 128],
                [195, 62, 127],
                [196, 63, 126],
                [197, 64, 125],
                [198, 65, 124],
                [199, 66, 123],
                [200, 68, 122],
                [201, 69, 121],
                [202, 70, 120],
                [203, 71, 119],
                [204, 72, 118],
                [205, 73, 117],
                [206, 74, 117],
                [207, 75, 116],
                [208, 77, 115],
                [209, 78, 114],
                [209, 79, 113],
                [210, 80, 112],
                [211, 81, 111],
                [212, 82, 110],
                [213, 83, 109],
                [214, 85, 109],
                [215, 86, 108],
                [215, 87, 107],
                [216, 88, 106],
                [217, 89, 105],
                [218, 90, 104],
                [219, 91, 103],
                [220, 93, 102],
                [220, 94, 102],
                [221, 95, 101],
                [222, 96, 100],
                [223, 97, 99],
                [223, 98, 98],
                [224, 100, 97],
                [225, 101, 96],
                [226, 102, 96],
                [227, 103, 95],
                [227, 104, 94],
                [228, 106, 93],
                [229, 107, 92],
                [229, 108, 91],
                [230, 109, 90],
                [231, 110, 90],
                [232, 112, 89],
                [232, 113, 88],
                [233, 114, 87],
                [234, 115, 86],
                [234, 116, 85],
                [235, 118, 84],
                [236, 119, 84],
                [236, 120, 83],
                [237, 121, 82],
                [237, 123, 81],
                [238, 124, 80],
                [239, 125, 79],
                [239, 126, 78],
                [240, 128, 77],
                [240, 129, 77],
                [241, 130, 76],
                [242, 132, 75],
                [242, 133, 74],
                [243, 134, 73],
                [243, 135, 72],
                [244, 137, 71],
                [244, 138, 71],
                [245, 139, 70],
                [245, 141, 69],
                [246, 142, 68],
                [246, 143, 67],
                [246, 145, 66],
                [247, 146, 65],
                [247, 147, 65],
                [248, 149, 64],
                [248, 150, 63],
                [248, 152, 62],
                [249, 153, 61],
                [249, 154, 60],
                [250, 156, 59],
                [250, 157, 58],
                [250, 159, 58],
                [250, 160, 57],
                [251, 162, 56],
                [251, 163, 55],
                [251, 164, 54],
                [252, 166, 53],
                [252, 167, 53],
                [252, 169, 52],
                [252, 170, 51],
                [252, 172, 50],
                [252, 173, 49],
                [253, 175, 49],
                [253, 176, 48],
                [253, 178, 47],
                [253, 179, 46],
                [253, 181, 45],
                [253, 182, 45],
                [253, 184, 44],
                [253, 185, 43],
                [253, 187, 43],
                [253, 188, 42],
                [253, 190, 41],
                [253, 192, 41],
                [253, 193, 40],
                [253, 195, 40],
                [253, 196, 39],
                [253, 198, 38],
                [252, 199, 38],
                [252, 201, 38],
                [252, 203, 37],
                [252, 204, 37],
                [252, 206, 37],
                [251, 208, 36],
                [251, 209, 36],
                [251, 211, 36],
                [250, 213, 36],
                [250, 214, 36],
                [250, 216, 36],
                [249, 217, 36],
                [249, 219, 36],
                [248, 221, 36],
                [248, 223, 36],
                [247, 224, 36],
                [247, 226, 37],
                [246, 228, 37],
                [246, 229, 37],
                [245, 231, 38],
                [245, 233, 38],
                [244, 234, 38],
                [243, 236, 38],
                [243, 238, 38],
                [242, 240, 38],
                [242, 241, 38],
                [241, 243, 38],
                [240, 245, 37],
                [240, 246, 35],
                [239, 248, 33],
            ],
        );

        m.insert(
            "mpl-viridis",
            [
                [68, 1, 84],
                [68, 2, 85],
                [68, 3, 87],
                [69, 5, 88],
                [69, 6, 90],
                [69, 8, 91],
                [70, 9, 92],
                [70, 11, 94],
                [70, 12, 95],
                [70, 14, 97],
                [71, 15, 98],
                [71, 17, 99],
                [71, 18, 101],
                [71, 20, 102],
                [71, 21, 103],
                [71, 22, 105],
                [71, 24, 106],
                [72, 25, 107],
                [72, 26, 108],
                [72, 28, 110],
                [72, 29, 111],
                [72, 30, 112],
                [72, 32, 113],
                [72, 33, 114],
                [72, 34, 115],
                [72, 35, 116],
                [71, 37, 117],
                [71, 38, 118],
                [71, 39, 119],
                [71, 40, 120],
                [71, 42, 121],
                [71, 43, 122],
                [71, 44, 123],
                [70, 45, 124],
                [70, 47, 124],
                [70, 48, 125],
                [70, 49, 126],
                [69, 50, 127],
                [69, 52, 127],
                [69, 53, 128],
                [69, 54, 129],
                [68, 55, 129],
                [68, 57, 130],
                [67, 58, 131],
                [67, 59, 131],
                [67, 60, 132],
                [66, 61, 132],
                [66, 62, 133],
                [66, 64, 133],
                [65, 65, 134],
                [65, 66, 134],
                [64, 67, 135],
                [64, 68, 135],
                [63, 69, 135],
                [63, 71, 136],
                [62, 72, 136],
                [62, 73, 137],
                [61, 74, 137],
                [61, 75, 137],
                [61, 76, 137],
                [60, 77, 138],
                [60, 78, 138],
                [59, 80, 138],
                [59, 81, 138],
                [58, 82, 139],
                [58, 83, 139],
                [57, 84, 139],
                [57, 85, 139],
                [56, 86, 139],
                [56, 87, 140],
                [55, 88, 140],
                [55, 89, 140],
                [54, 90, 140],
                [54, 91, 140],
                [53, 92, 140],
                [53, 93, 140],
                [52, 94, 141],
                [52, 95, 141],
                [51, 96, 141],
                [51, 97, 141],
                [50, 98, 141],
                [50, 99, 141],
                [49, 100, 141],
                [49, 101, 141],
                [49, 102, 141],
                [48, 103, 141],
                [48, 104, 141],
                [47, 105, 141],
                [47, 106, 141],
                [46, 107, 142],
                [46, 108, 142],
                [46, 109, 142],
                [45, 110, 142],
                [45, 111, 142],
                [44, 112, 142],
                [44, 113, 142],
                [44, 114, 142],
                [43, 115, 142],
                [43, 116, 142],
                [42, 117, 142],
                [42, 118, 142],
                [42, 119, 142],
                [41, 120, 142],
                [41, 121, 142],
                [40, 122, 142],
                [40, 122, 142],
                [40, 123, 142],
                [39, 124, 142],
                [39, 125, 142],
                [39, 126, 142],
                [38, 127, 142],
                [38, 128, 142],
                [38, 129, 142],
                [37, 130, 142],
                [37, 131, 141],
                [36, 132, 141],
                [36, 133, 141],
                [36, 134, 141],
                [35, 135, 141],
                [35, 136, 141],
                [35, 137, 141],
                [34, 137, 141],
                [34, 138, 141],
                [34, 139, 141],
                [33, 140, 141],
                [33, 141, 140],
                [33, 142, 140],
                [32, 143, 140],
                [32, 144, 140],
                [32, 145, 140],
                [31, 146, 140],
                [31, 147, 139],
                [31, 148, 139],
                [31, 149, 139],
                [31, 150, 139],
                [30, 151, 138],
                [30, 152, 138],
                [30, 153, 138],
                [30, 153, 138],
                [30, 154, 137],
                [30, 155, 137],
                [30, 156, 137],
                [30, 157, 136],
                [30, 158, 136],
                [30, 159, 136],
                [30, 160, 135],
                [31, 161, 135],
                [31, 162, 134],
                [31, 163, 134],
                [32, 164, 133],
                [32, 165, 133],
                [33, 166, 133],
                [33, 167, 132],
                [34, 167, 132],
                [35, 168, 131],
                [35, 169, 130],
                [36, 170, 130],
                [37, 171, 129],
                [38, 172, 129],
                [39, 173, 128],
                [40, 174, 127],
                [41, 175, 127],
                [42, 176, 126],
                [43, 177, 125],
                [44, 177, 125],
                [46, 178, 124],
                [47, 179, 123],
                [48, 180, 122],
                [50, 181, 122],
                [51, 182, 121],
                [53, 183, 120],
                [54, 184, 119],
                [56, 185, 118],
                [57, 185, 118],
                [59, 186, 117],
                [61, 187, 116],
                [62, 188, 115],
                [64, 189, 114],
                [66, 190, 113],
                [68, 190, 112],
                [69, 191, 111],
                [71, 192, 110],
                [73, 193, 109],
                [75, 194, 108],
                [77, 194, 107],
                [79, 195, 105],
                [81, 196, 104],
                [83, 197, 103],
                [85, 198, 102],
                [87, 198, 101],
                [89, 199, 100],
                [91, 200, 98],
                [94, 201, 97],
                [96, 201, 96],
                [98, 202, 95],
                [100, 203, 93],
                [103, 204, 92],
                [105, 204, 91],
                [107, 205, 89],
                [109, 206, 88],
                [112, 206, 86],
                [114, 207, 85],
                [116, 208, 84],
                [119, 208, 82],
                [121, 209, 81],
                [124, 210, 79],
                [126, 210, 78],
                [129, 211, 76],
                [131, 211, 75],
                [134, 212, 73],
                [136, 213, 71],
                [139, 213, 70],
                [141, 214, 68],
                [144, 214, 67],
                [146, 215, 65],
                [149, 215, 63],
                [151, 216, 62],
                [154, 216, 60],
                [157, 217, 58],
                [159, 217, 56],
                [162, 218, 55],
                [165, 218, 53],
                [167, 219, 51],
                [170, 219, 50],
                [173, 220, 48],
                [175, 220, 46],
                [178, 221, 44],
                [181, 221, 43],
                [183, 221, 41],
                [186, 222, 39],
                [189, 222, 38],
                [191, 223, 36],
                [194, 223, 34],
                [197, 223, 33],
                [199, 224, 31],
                [202, 224, 30],
                [205, 224, 29],
                [207, 225, 28],
                [210, 225, 27],
                [212, 225, 26],
                [215, 226, 25],
                [218, 226, 24],
                [220, 226, 24],
                [223, 227, 24],
                [225, 227, 24],
                [228, 227, 24],
                [231, 228, 25],
                [233, 228, 25],
                [236, 228, 26],
                [238, 229, 27],
                [241, 229, 28],
                [243, 229, 30],
                [246, 230, 31],
                [248, 230, 33],
                [250, 230, 34],
                [253, 231, 36],
            ],
        );

        m.insert(
            "phase",
            [
                [0, 0, 252],
                [0, 0, 252],
                [0, 0, 252],
                [4, 4, 252],
                [4, 4, 252],
                [4, 4, 252],
                [8, 8, 252],
                [8, 8, 252],
                [12, 12, 252],
                [12, 12, 252],
                [12, 12, 248],
                [16, 16, 248],
                [16, 16, 248],
                [20, 20, 248],
                [20, 20, 248],
                [20, 20, 248],
                [24, 24, 248],
                [24, 24, 248],
                [28, 28, 248],
                [28, 28, 248],
                [28, 28, 244],
                [32, 32, 244],
                [32, 32, 244],
                [36, 36, 244],
                [36, 36, 244],
                [36, 36, 244],
                [40, 40, 244],
                [40, 40, 244],
                [44, 44, 244],
                [44, 44, 244],
                [44, 44, 240],
                [48, 48, 240],
                [48, 48, 240],
                [52, 52, 240],
                [52, 52, 240],
                [52, 52, 240],
                [56, 56, 240],
                [56, 56, 240],
                [60, 60, 240],
                [60, 60, 236],
                [60, 60, 236],
                [64, 64, 236],
                [64, 64, 236],
                [68, 68, 236],
                [68, 68, 236],
                [68, 68, 236],
                [72, 72, 236],
                [72, 72, 236],
                [76, 76, 236],
                [76, 76, 232],
                [76, 76, 232],
                [80, 80, 232],
                [80, 80, 232],
                [84, 84, 232],
                [84, 84, 232],
                [84, 84, 232],
                [88, 88, 232],
                [88, 88, 232],
                [92, 92, 232],
                [92, 92, 228],
                [92, 92, 228],
                [96, 96, 228],
                [96, 96, 228],
                [96, 96, 228],
                [100, 100, 228],
                [100, 100, 228],
                [104, 104, 228],
                [104, 104, 228],
                [104, 104, 224],
                [108, 108, 224],
                [108, 108, 224],
                [112, 112, 224],
                [112, 112, 224],
                [112, 112, 224],
                [116, 116, 224],
                [116, 116, 224],
                [120, 120, 224],
                [120, 120, 224],
                [120, 120, 220],
                [124, 124, 220],
                [124, 124, 220],
                [128, 128, 220],
                [128, 128, 220],
                [128, 128, 220],
                [132, 132, 220],
                [132, 132, 220],
                [136, 136, 220],
                [136, 136, 220],
                [136, 136, 216],
                [140, 140, 216],
                [140, 140, 216],
                [144, 144, 216],
                [144, 144, 216],
                [144, 144, 216],
                [148, 148, 216],
                [148, 148, 216],
                [152, 152, 216],
                [152, 152, 212],
                [152, 152, 212],
                [156, 156, 212],
                [156, 156, 212],
                [160, 160, 212],
                [160, 160, 212],
                [160, 160, 212],
                [164, 164, 212],
                [164, 164, 212],
                [168, 168, 212],
                [168, 168, 208],
                [168, 168, 208],
                [172, 172, 208],
                [172, 172, 208],
                [176, 176, 208],
                [176, 176, 208],
                [176, 176, 208],
                [180, 180, 208],
                [180, 180, 208],
                [184, 184, 208],
                [184, 184, 204],
                [184, 184, 204],
                [188, 188, 204],
                [188, 188, 204],
                [192, 192, 204],
                [192, 192, 204],
                [192, 192, 204],
                [196, 196, 204],
                [196, 196, 204],
                [200, 200, 200],
                [200, 200, 200],
                [200, 200, 200],
                [200, 196, 196],
                [200, 196, 196],
                [200, 196, 196],
                [200, 192, 192],
                [200, 192, 192],
                [200, 188, 188],
                [200, 188, 188],
                [204, 188, 188],
                [204, 184, 184],
                [204, 184, 184],
                [204, 180, 180],
                [204, 180, 180],
                [204, 180, 180],
                [204, 176, 176],
                [204, 176, 176],
                [204, 172, 172],
                [204, 172, 172],
                [208, 172, 172],
                [208, 168, 168],
                [208, 168, 168],
                [208, 168, 168],
                [208, 164, 164],
                [208, 164, 164],
                [208, 160, 160],
                [208, 160, 160],
                [208, 160, 160],
                [208, 156, 156],
                [212, 156, 156],
                [212, 152, 152],
                [212, 152, 152],
                [212, 152, 152],
                [212, 148, 148],
                [212, 148, 148],
                [212, 144, 144],
                [212, 144, 144],
                [212, 144, 144],
                [212, 140, 140],
                [216, 140, 140],
                [216, 136, 136],
                [216, 136, 136],
                [216, 136, 136],
                [216, 132, 132],
                [216, 132, 132],
                [216, 132, 132],
                [216, 128, 128],
                [216, 128, 128],
                [216, 124, 124],
                [220, 124, 124],
                [220, 124, 124],
                [220, 120, 120],
                [220, 120, 120],
                [220, 116, 116],
                [220, 116, 116],
                [220, 116, 116],
                [220, 112, 112],
                [220, 112, 112],
                [220, 108, 108],
                [224, 108, 108],
                [224, 108, 108],
                [224, 104, 104],
                [224, 104, 104],
                [224, 100, 100],
                [224, 100, 100],
                [224, 100, 100],
                [224, 96, 96],
                [224, 96, 96],
                [228, 96, 96],
                [228, 92, 92],
                [228, 92, 92],
                [228, 88, 88],
                [228, 88, 88],
                [228, 88, 88],
                [228, 84, 84],
                [228, 84, 84],
                [228, 80, 80],
                [228, 80, 80],
                [232, 80, 80],
                [232, 76, 76],
                [232, 76, 76],
                [232, 72, 72],
                [232, 72, 72],
                [232, 72, 72],
                [232, 68, 68],
                [232, 68, 68],
                [232, 68, 68],
                [232, 64, 64],
                [236, 64, 64],
                [236, 60, 60],
                [236, 60, 60],
                [236, 60, 60],
                [236, 56, 56],
                [236, 56, 56],
                [236, 52, 52],
                [236, 52, 52],
                [236, 52, 52],
                [236, 48, 48],
                [240, 48, 48],
                [240, 44, 44],
                [240, 44, 44],
                [240, 44, 44],
                [240, 40, 40],
                [240, 40, 40],
                [240, 36, 36],
                [240, 36, 36],
                [240, 36, 36],
                [240, 32, 32],
                [244, 32, 32],
                [244, 32, 32],
                [244, 28, 28],
                [244, 28, 28],
                [244, 24, 24],
                [244, 24, 24],
                [244, 24, 24],
                [244, 20, 20],
                [244, 20, 20],
                [244, 16, 16],
                [248, 16, 16],
                [248, 16, 16],
                [248, 12, 12],
                [248, 12, 12],
                [248, 8, 8],
                [248, 8, 8],
                [248, 8, 8],
                [248, 4, 4],
                [248, 4, 4],
                [252, 0, 0],
                [252, 0, 0],
            ],
        );

        m.insert(
            "physics",
            [
                [47, 2, 119],
                [46, 2, 120],
                [45, 2, 122],
                [44, 2, 123],
                [42, 2, 124],
                [41, 2, 125],
                [40, 2, 126],
                [39, 2, 127],
                [37, 2, 128],
                [36, 1, 129],
                [35, 1, 131],
                [33, 1, 132],
                [32, 1, 133],
                [30, 1, 134],
                [29, 1, 135],
                [27, 1, 136],
                [26, 1, 137],
                [24, 1, 138],
                [23, 1, 139],
                [21, 1, 141],
                [19, 1, 142],
                [18, 1, 143],
                [16, 1, 144],
                [14, 1, 145],
                [12, 1, 146],
                [10, 1, 147],
                [9, 0, 148],
                [7, 0, 149],
                [5, 0, 151],
                [3, 0, 152],
                [1, 0, 153],
                [0, 1, 154],
                [0, 3, 155],
                [0, 5, 156],
                [0, 7, 157],
                [0, 9, 158],
                [0, 11, 160],
                [0, 13, 161],
                [0, 15, 162],
                [0, 18, 163],
                [1, 20, 164],
                [2, 23, 165],
                [3, 26, 166],
                [3, 28, 167],
                [4, 31, 168],
                [5, 33, 169],
                [6, 36, 169],
                [7, 39, 170],
                [8, 41, 171],
                [8, 44, 172],
                [9, 47, 173],
                [10, 49, 174],
                [11, 52, 175],
                [12, 55, 176],
                [13, 58, 177],
                [14, 60, 178],
                [15, 63, 179],
                [16, 66, 180],
                [16, 69, 181],
                [17, 71, 182],
                [18, 74, 183],
                [19, 77, 184],
                [20, 80, 185],
                [21, 82, 186],
                [22, 85, 187],
                [23, 88, 188],
                [24, 91, 189],
                [25, 94, 190],
                [26, 96, 191],
                [26, 99, 191],
                [26, 102, 191],
                [26, 105, 191],
                [26, 108, 192],
                [26, 111, 192],
                [26, 114, 192],
                [26, 116, 192],
                [26, 119, 192],
                [26, 122, 193],
                [26, 125, 193],
                [26, 128, 193],
                [26, 131, 193],
                [26, 134, 193],
                [26, 137, 194],
                [26, 140, 194],
                [26, 143, 194],
                [26, 146, 194],
                [26, 149, 194],
                [26, 152, 195],
                [26, 155, 195],
                [25, 158, 195],
                [25, 161, 195],
                [25, 164, 195],
                [25, 167, 196],
                [25, 170, 196],
                [25, 173, 196],
                [25, 176, 196],
                [25, 179, 196],
                [25, 182, 197],
                [25, 185, 197],
                [25, 188, 197],
                [25, 191, 197],
                [25, 194, 197],
                [25, 198, 198],
                [25, 198, 195],
                [25, 198, 192],
                [25, 198, 190],
                [25, 198, 187],
                [25, 199, 184],
                [25, 199, 181],
                [25, 199, 178],
                [25, 199, 176],
                [25, 199, 173],
                [25, 200, 170],
                [24, 200, 167],
                [24, 200, 165],
                [24, 200, 162],
                [24, 200, 159],
                [24, 201, 156],
                [24, 201, 153],
                [24, 201, 150],
                [24, 201, 148],
                [24, 202, 143],
                [24, 202, 138],
                [24, 202, 133],
                [24, 203, 129],
                [24, 203, 124],
                [24, 203, 119],
                [24, 204, 114],
                [24, 204, 109],
                [24, 204, 104],
                [23, 205, 99],
                [23, 205, 94],
                [23, 205, 89],
                [23, 206, 84],
                [23, 206, 79],
                [23, 206, 74],
                [23, 207, 69],
                [23, 207, 64],
                [23, 207, 59],
                [23, 208, 54],
                [23, 208, 49],
                [23, 208, 44],
                [23, 209, 39],
                [22, 209, 33],
                [22, 209, 28],
                [22, 210, 23],
                [27, 210, 22],
                [32, 210, 22],
                [37, 211, 22],
                [42, 211, 22],
                [48, 211, 22],
                [53, 212, 22],
                [58, 212, 22],
                [63, 212, 22],
                [69, 213, 22],
                [74, 213, 21],
                [79, 213, 21],
                [85, 214, 21],
                [90, 214, 21],
                [96, 214, 21],
                [101, 215, 21],
                [107, 215, 21],
                [112, 215, 21],
                [118, 216, 21],
                [123, 216, 21],
                [129, 216, 21],
                [134, 217, 21],
                [140, 217, 20],
                [145, 217, 20],
                [148, 217, 20],
                [151, 217, 20],
                [153, 218, 20],
                [156, 218, 20],
                [159, 218, 20],
                [161, 218, 20],
                [164, 218, 20],
                [166, 218, 20],
                [169, 219, 20],
                [172, 219, 20],
                [174, 219, 20],
                [177, 219, 20],
                [180, 219, 20],
                [182, 219, 20],
                [185, 219, 20],
                [188, 220, 20],
                [190, 220, 20],
                [193, 220, 20],
                [196, 220, 20],
                [198, 220, 19],
                [201, 220, 19],
                [204, 221, 19],
                [206, 221, 19],
                [210, 221, 19],
                [213, 221, 19],
                [216, 221, 19],
                [220, 221, 19],
                [222, 220, 19],
                [222, 217, 19],
                [222, 214, 19],
                [222, 212, 19],
                [222, 209, 19],
                [223, 206, 19],
                [223, 203, 19],
                [223, 200, 19],
                [223, 197, 19],
                [223, 194, 19],
                [223, 191, 19],
                [224, 188, 19],
                [224, 185, 18],
                [224, 182, 18],
                [224, 178, 18],
                [224, 175, 18],
                [225, 172, 18],
                [225, 169, 18],
                [225, 166, 18],
                [225, 163, 18],
                [225, 160, 18],
                [225, 157, 18],
                [226, 154, 18],
                [226, 151, 18],
                [226, 148, 18],
                [226, 145, 18],
                [226, 141, 18],
                [227, 138, 18],
                [227, 135, 18],
                [227, 132, 18],
                [227, 129, 17],
                [227, 126, 17],
                [228, 122, 17],
                [228, 119, 17],
                [228, 116, 17],
                [228, 113, 17],
                [228, 110, 17],
                [228, 106, 17],
                [229, 103, 17],
                [229, 100, 17],
                [229, 97, 17],
                [229, 94, 17],
                [229, 90, 17],
                [230, 87, 17],
                [230, 84, 17],
                [230, 80, 17],
                [230, 77, 17],
                [230, 74, 17],
                [230, 71, 16],
                [231, 67, 16],
                [231, 64, 16],
                [231, 61, 16],
                [231, 57, 16],
                [231, 54, 16],
                [232, 51, 16],
                [232, 47, 16],
                [232, 44, 16],
                [232, 41, 16],
                [232, 37, 16],
                [233, 34, 16],
            ],
        );

        m.insert(
            "royal",
            [
                [1, 1, 7],
                [1, 1, 7],
                [1, 1, 13],
                [1, 1, 18],
                [1, 1, 24],
                [1, 1, 30],
                [1, 1, 36],
                [1, 1, 42],
                [1, 1, 47],
                [1, 1, 53],
                [1, 1, 59],
                [1, 1, 64],
                [1, 1, 70],
                [1, 1, 75],
                [1, 1, 81],
                [1, 1, 85],
                [1, 1, 89],
                [1, 1, 93],
                [1, 1, 98],
                [1, 1, 104],
                [1, 1, 109],
                [1, 1, 115],
                [1, 1, 121],
                [1, 1, 126],
                [1, 1, 132],
                [1, 1, 137],
                [1, 1, 143],
                [1, 1, 149],
                [1, 1, 154],
                [1, 1, 160],
                [1, 1, 165],
                [1, 1, 169],
                [1, 1, 174],
                [1, 7, 177],
                [1, 13, 182],
                [1, 18, 188],
                [1, 24, 192],
                [1, 30, 198],
                [1, 36, 204],
                [1, 42, 209],
                [1, 47, 215],
                [1, 53, 220],
                [1, 59, 226],
                [1, 64, 232],
                [1, 70, 237],
                [1, 75, 243],
                [1, 81, 248],
                [1, 85, 254],
                [1, 89, 254],
                [1, 93, 254],
                [1, 98, 254],
                [1, 104, 254],
                [1, 109, 254],
                [1, 115, 254],
                [1, 121, 254],
                [1, 126, 254],
                [1, 132, 254],
                [1, 137, 254],
                [1, 143, 254],
                [1, 149, 254],
                [1, 154, 254],
                [1, 160, 254],
                [1, 165, 254],
                [1, 169, 254],
                [1, 174, 254],
                [1, 177, 254],
                [1, 182, 254],
                [1, 188, 254],
                [1, 192, 254],
                [1, 198, 254],
                [1, 204, 254],
                [1, 209, 254],
                [1, 215, 254],
                [1, 220, 254],
                [1, 226, 254],
                [1, 232, 254],
                [1, 237, 254],
                [1, 243, 254],
                [1, 248, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 254],
                [1, 254, 238],
                [10, 254, 222],
                [18, 254, 206],
                [27, 254, 191],
                [36, 254, 175],
                [45, 254, 159],
                [53, 254, 143],
                [62, 254, 127],
                [70, 254, 111],
                [79, 254, 95],
                [87, 254, 79],
                [96, 254, 64],
                [105, 254, 48],
                [114, 254, 32],
                [122, 254, 16],
                [128, 254, 1],
                [134, 254, 1],
                [139, 252, 1],
                [148, 250, 1],
                [156, 248, 1],
                [164, 245, 1],
                [172, 243, 1],
                [181, 241, 1],
                [189, 239, 1],
                [196, 237, 1],
                [204, 235, 1],
                [213, 233, 1],
                [221, 231, 1],
                [229, 228, 1],
                [237, 226, 1],
                [246, 224, 1],
                [254, 222, 1],
                [254, 222, 1],
                [254, 219, 1],
                [254, 217, 1],
                [254, 214, 1],
                [254, 211, 1],
                [254, 209, 1],
                [254, 206, 1],
                [254, 203, 1],
                [254, 201, 1],
                [254, 198, 1],
                [254, 195, 1],
                [254, 193, 1],
                [254, 191, 1],
                [254, 188, 1],
                [254, 186, 1],
                [254, 184, 1],
                [254, 182, 1],
                [254, 180, 1],
                [254, 176, 1],
                [254, 173, 1],
                [254, 169, 1],
                [254, 166, 1],
                [254, 162, 1],
                [254, 159, 1],
                [254, 155, 1],
                [254, 152, 1],
                [254, 148, 1],
                [254, 145, 1],
                [254, 141, 1],
                [254, 138, 1],
                [254, 134, 1],
                [254, 129, 1],
                [254, 131, 1],
                [254, 127, 1],
                [254, 122, 1],
                [254, 118, 1],
                [254, 114, 1],
                [254, 110, 1],
                [254, 105, 1],
                [254, 101, 1],
                [254, 97, 1],
                [254, 93, 1],
                [254, 88, 1],
                [254, 84, 1],
                [254, 80, 1],
                [254, 76, 1],
                [254, 71, 1],
                [254, 66, 1],
                [254, 68, 1],
                [254, 64, 1],
                [254, 59, 1],
                [254, 55, 1],
                [254, 50, 1],
                [254, 46, 1],
                [254, 41, 1],
                [254, 37, 1],
                [254, 32, 1],
                [254, 28, 1],
                [254, 23, 1],
                [254, 19, 1],
                [254, 14, 1],
                [254, 10, 1],
                [254, 5, 1],
                [254, 1, 1],
                [254, 1, 1],
                [252, 14, 14],
                [250, 26, 26],
                [248, 39, 39],
                [245, 52, 52],
                [243, 64, 64],
                [241, 76, 76],
                [239, 89, 89],
                [237, 102, 102],
                [235, 115, 115],
                [233, 127, 127],
                [231, 140, 140],
                [228, 153, 153],
                [226, 166, 166],
                [224, 178, 178],
                [222, 183, 183],
                [222, 188, 188],
                [222, 192, 192],
                [222, 194, 194],
                [222, 196, 196],
                [222, 199, 199],
                [222, 201, 201],
                [222, 203, 203],
                [222, 205, 205],
                [222, 207, 207],
                [222, 209, 209],
                [222, 211, 211],
                [222, 213, 213],
                [222, 216, 216],
                [222, 218, 218],
                [222, 220, 220],
                [222, 222, 222],
                [222, 222, 222],
                [224, 224, 224],
                [226, 226, 226],
                [228, 228, 228],
                [231, 231, 231],
                [233, 233, 233],
                [235, 235, 235],
                [237, 237, 237],
                [239, 239, 239],
                [241, 241, 241],
                [243, 243, 243],
                [245, 245, 245],
                [248, 248, 248],
                [250, 250, 250],
                [252, 252, 252],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
            ],
        );

        m.insert(
            "sepia",
            [
                [0, 0, 0],
                [43, 28, 4],
                [57, 35, 5],
                [65, 35, 6],
                [66, 36, 7],
                [67, 37, 8],
                [68, 38, 9],
                [69, 39, 10],
                [70, 40, 11],
                [71, 41, 12],
                [72, 42, 13],
                [73, 43, 14],
                [74, 44, 15],
                [75, 45, 16],
                [76, 46, 17],
                [77, 47, 18],
                [78, 48, 19],
                [79, 49, 20],
                [80, 50, 21],
                [81, 51, 22],
                [82, 52, 23],
                [83, 53, 24],
                [83, 53, 24],
                [84, 54, 25],
                [85, 55, 26],
                [86, 56, 27],
                [87, 57, 28],
                [88, 58, 29],
                [89, 59, 30],
                [90, 60, 31],
                [91, 61, 32],
                [92, 62, 33],
                [93, 63, 34],
                [94, 64, 35],
                [95, 65, 36],
                [96, 66, 37],
                [97, 67, 38],
                [98, 68, 39],
                [99, 69, 40],
                [100, 70, 41],
                [101, 71, 42],
                [102, 72, 43],
                [103, 73, 44],
                [104, 74, 45],
                [105, 75, 46],
                [106, 76, 47],
                [107, 77, 48],
                [107, 77, 48],
                [108, 78, 49],
                [109, 79, 50],
                [110, 80, 51],
                [111, 81, 52],
                [112, 82, 53],
                [113, 83, 54],
                [114, 84, 55],
                [115, 85, 56],
                [116, 86, 57],
                [117, 87, 58],
                [118, 88, 59],
                [119, 89, 60],
                [120, 90, 61],
                [121, 91, 62],
                [122, 92, 63],
                [123, 93, 64],
                [124, 94, 65],
                [125, 95, 66],
                [125, 95, 66],
                [126, 96, 67],
                [127, 97, 68],
                [128, 98, 69],
                [129, 99, 70],
                [130, 100, 71],
                [131, 101, 72],
                [132, 102, 73],
                [133, 103, 74],
                [134, 104, 75],
                [135, 105, 76],
                [136, 106, 77],
                [137, 107, 78],
                [138, 108, 79],
                [139, 109, 80],
                [140, 110, 81],
                [141, 111, 82],
                [142, 112, 83],
                [143, 113, 84],
                [144, 114, 85],
                [145, 115, 86],
                [146, 116, 87],
                [147, 117, 88],
                [148, 118, 89],
                [149, 119, 90],
                [150, 120, 91],
                [151, 121, 92],
                [152, 122, 93],
                [153, 123, 94],
                [154, 124, 95],
                [155, 125, 96],
                [156, 126, 97],
                [157, 127, 98],
                [158, 128, 99],
                [159, 129, 100],
                [160, 130, 101],
                [161, 131, 102],
                [162, 132, 103],
                [163, 133, 104],
                [164, 134, 105],
                [165, 135, 106],
                [166, 136, 107],
                [167, 137, 108],
                [168, 138, 109],
                [169, 139, 110],
                [170, 140, 111],
                [171, 141, 112],
                [172, 142, 113],
                [173, 143, 114],
                [174, 144, 115],
                [175, 145, 116],
                [176, 146, 117],
                [177, 147, 118],
                [178, 148, 119],
                [179, 149, 120],
                [180, 150, 121],
                [181, 151, 122],
                [182, 152, 123],
                [183, 153, 124],
                [184, 154, 125],
                [185, 155, 126],
                [186, 156, 127],
                [187, 157, 128],
                [187, 157, 128],
                [188, 158, 129],
                [189, 159, 130],
                [190, 160, 131],
                [191, 161, 132],
                [192, 162, 133],
                [193, 163, 134],
                [194, 164, 135],
                [195, 165, 136],
                [196, 166, 137],
                [197, 167, 138],
                [198, 168, 139],
                [199, 169, 140],
                [200, 170, 141],
                [201, 171, 142],
                [202, 172, 143],
                [203, 173, 144],
                [204, 174, 145],
                [205, 175, 146],
                [206, 176, 147],
                [207, 177, 148],
                [208, 178, 149],
                [209, 179, 150],
                [210, 180, 151],
                [211, 181, 152],
                [212, 182, 153],
                [213, 183, 154],
                [214, 184, 155],
                [215, 185, 156],
                [216, 186, 157],
                [217, 187, 158],
                [218, 188, 159],
                [219, 189, 160],
                [220, 190, 161],
                [221, 191, 162],
                [222, 192, 163],
                [223, 193, 164],
                [224, 194, 165],
                [225, 195, 166],
                [226, 196, 167],
                [227, 197, 168],
                [228, 198, 169],
                [229, 199, 170],
                [230, 200, 171],
                [231, 201, 172],
                [232, 202, 173],
                [233, 203, 174],
                [234, 204, 175],
                [235, 205, 176],
                [236, 206, 177],
                [237, 207, 178],
                [238, 208, 179],
                [239, 209, 180],
                [240, 210, 181],
                [241, 211, 182],
                [242, 212, 183],
                [243, 213, 184],
                [244, 214, 185],
                [245, 215, 186],
                [246, 216, 187],
                [247, 217, 188],
                [248, 218, 189],
                [249, 219, 190],
                [250, 220, 191],
                [251, 221, 192],
                [252, 222, 193],
                [253, 223, 194],
                [254, 224, 195],
                [255, 225, 196],
                [255, 225, 196],
                [255, 225, 196],
                [255, 225, 196],
                [255, 225, 196],
                [255, 225, 197],
                [255, 225, 197],
                [255, 225, 197],
                [255, 225, 197],
                [255, 226, 198],
                [255, 226, 198],
                [255, 226, 198],
                [255, 226, 198],
                [255, 226, 198],
                [255, 226, 199],
                [255, 226, 199],
                [255, 226, 199],
                [255, 226, 199],
                [255, 226, 199],
                [255, 227, 200],
                [255, 227, 200],
                [255, 227, 200],
                [255, 227, 200],
                [255, 227, 200],
                [255, 227, 201],
                [255, 227, 201],
                [255, 227, 201],
                [255, 227, 201],
                [255, 227, 201],
                [255, 228, 202],
                [255, 228, 202],
                [255, 228, 202],
                [255, 228, 202],
                [255, 228, 202],
                [255, 228, 202],
                [255, 228, 203],
                [255, 228, 203],
                [255, 228, 203],
                [255, 228, 203],
                [255, 228, 203],
                [255, 229, 204],
                [255, 229, 204],
                [255, 229, 204],
                [255, 229, 204],
                [255, 229, 204],
                [255, 229, 204],
                [255, 229, 205],
                [255, 229, 205],
                [255, 229, 205],
                [255, 229, 205],
                [255, 229, 205],
                [255, 230, 205],
                [255, 230, 205],
                [255, 231, 205],
                [255, 231, 209],
                [255, 233, 214],
                [255, 233, 217],
                [255, 242, 233],
                [255, 255, 255],
            ],
        );

        m.insert(
            "smart",
            [
                [2, 2, 2],
                [2, 2, 2],
                [2, 2, 2],
                [3, 3, 3],
                [4, 4, 4],
                [5, 5, 5],
                [5, 5, 5],
                [6, 6, 6],
                [7, 7, 7],
                [8, 8, 8],
                [8, 8, 8],
                [9, 9, 9],
                [10, 10, 10],
                [11, 11, 11],
                [11, 11, 11],
                [12, 12, 12],
                [13, 13, 13],
                [14, 14, 14],
                [14, 14, 14],
                [15, 15, 15],
                [16, 16, 16],
                [16, 16, 16],
                [17, 17, 17],
                [18, 18, 18],
                [19, 19, 19],
                [19, 19, 19],
                [20, 20, 20],
                [21, 21, 21],
                [22, 22, 22],
                [22, 22, 22],
                [23, 23, 23],
                [24, 24, 24],
                [25, 25, 25],
                [25, 25, 25],
                [26, 26, 26],
                [27, 27, 27],
                [27, 27, 27],
                [28, 28, 28],
                [29, 29, 29],
                [30, 30, 30],
                [30, 30, 30],
                [31, 31, 31],
                [32, 32, 32],
                [33, 33, 33],
                [33, 33, 33],
                [34, 34, 34],
                [35, 35, 35],
                [36, 36, 36],
                [36, 36, 36],
                [37, 37, 37],
                [38, 38, 38],
                [39, 39, 39],
                [39, 39, 39],
                [40, 40, 40],
                [41, 41, 41],
                [41, 41, 41],
                [42, 42, 42],
                [43, 43, 43],
                [44, 44, 44],
                [44, 44, 44],
                [45, 45, 45],
                [46, 46, 46],
                [47, 47, 47],
                [47, 47, 47],
                [48, 48, 48],
                [49, 49, 49],
                [50, 50, 50],
                [50, 50, 50],
                [51, 51, 51],
                [52, 52, 52],
                [52, 52, 52],
                [53, 53, 53],
                [54, 54, 54],
                [55, 55, 55],
                [55, 55, 55],
                [56, 56, 56],
                [57, 57, 57],
                [58, 58, 58],
                [58, 58, 58],
                [59, 59, 59],
                [60, 60, 60],
                [61, 61, 61],
                [61, 61, 61],
                [62, 62, 62],
                [63, 63, 63],
                [64, 64, 64],
                [64, 64, 64],
                [64, 64, 64],
                [65, 65, 65],
                [65, 65, 65],
                [66, 66, 66],
                [67, 67, 67],
                [68, 68, 68],
                [68, 68, 68],
                [69, 69, 69],
                [70, 70, 70],
                [71, 71, 71],
                [71, 71, 71],
                [72, 72, 72],
                [73, 73, 73],
                [74, 74, 74],
                [74, 74, 74],
                [75, 75, 75],
                [76, 71, 71],
                [77, 68, 66],
                [77, 64, 62],
                [78, 62, 58],
                [79, 58, 53],
                [80, 55, 48],
                [80, 51, 43],
                [81, 47, 40],
                [82, 45, 38],
                [83, 43, 36],
                [83, 42, 34],
                [84, 40, 32],
                [85, 38, 30],
                [86, 36, 28],
                [86, 34, 26],
                [87, 32, 24],
                [88, 30, 22],
                [89, 29, 21],
                [89, 27, 20],
                [90, 26, 19],
                [91, 26, 19],
                [92, 25, 18],
                [92, 24, 18],
                [93, 24, 17],
                [94, 23, 17],
                [95, 23, 17],
                [95, 22, 16],
                [96, 22, 16],
                [97, 22, 15],
                [98, 21, 14],
                [98, 21, 13],
                [99, 20, 13],
                [100, 20, 13],
                [101, 20, 12],
                [101, 19, 12],
                [102, 19, 11],
                [103, 18, 11],
                [102, 18, 11],
                [105, 18, 10],
                [106, 17, 9],
                [107, 17, 8],
                [109, 17, 7],
                [111, 16, 6],
                [112, 16, 6],
                [113, 16, 5],
                [114, 16, 4],
                [116, 15, 4],
                [117, 15, 4],
                [119, 15, 3],
                [122, 16, 3],
                [125, 16, 2],
                [128, 16, 2],
                [130, 16, 2],
                [133, 16, 1],
                [136, 16, 1],
                [139, 16, 1],
                [142, 16, 1],
                [145, 17, 1],
                [149, 18, 1],
                [152, 20, 1],
                [156, 21, 1],
                [159, 23, 1],
                [163, 24, 1],
                [166, 26, 1],
                [189, 27, 1],
                [173, 29, 1],
                [177, 31, 1],
                [179, 31, 1],
                [182, 31, 1],
                [185, 32, 1],
                [189, 33, 1],
                [191, 34, 1],
                [194, 36, 1],
                [196, 37, 1],
                [199, 39, 1],
                [201, 41, 1],
                [203, 43, 1],
                [205, 47, 1],
                [207, 50, 1],
                [209, 53, 1],
                [210, 55, 1],
                [212, 57, 1],
                [213, 59, 1],
                [215, 62, 1],
                [216, 64, 1],
                [218, 67, 1],
                [220, 71, 1],
                [221, 74, 2],
                [222, 78, 2],
                [224, 83, 2],
                [222, 88, 3],
                [226, 92, 3],
                [227, 97, 4],
                [228, 100, 4],
                [229, 103, 4],
                [229, 107, 5],
                [230, 110, 5],
                [231, 113, 6],
                [233, 121, 6],
                [234, 130, 6],
                [236, 136, 7],
                [238, 144, 7],
                [239, 156, 8],
                [240, 162, 8],
                [240, 167, 8],
                [241, 173, 9],
                [242, 179, 9],
                [242, 185, 10],
                [243, 187, 10],
                [245, 190, 11],
                [246, 192, 11],
                [247, 195, 12],
                [248, 198, 12],
                [248, 201, 13],
                [249, 204, 13],
                [249, 207, 14],
                [250, 210, 14],
                [250, 213, 15],
                [251, 215, 17],
                [252, 216, 18],
                [252, 217, 20],
                [253, 218, 22],
                [253, 219, 24],
                [254, 220, 28],
                [254, 222, 32],
                [254, 222, 36],
                [254, 224, 40],
                [254, 225, 43],
                [254, 226, 47],
                [254, 227, 50],
                [254, 227, 53],
                [254, 228, 56],
                [254, 229, 59],
                [254, 229, 66],
                [254, 230, 74],
                [254, 230, 82],
                [254, 231, 89],
                [254, 231, 101],
                [254, 235, 113],
                [254, 238, 125],
                [254, 240, 136],
                [254, 242, 148],
                [254, 245, 164],
                [254, 245, 179],
                [254, 246, 187],
                [254, 247, 198],
                [254, 248, 209],
                [254, 249, 225],
                [254, 250, 241],
                [254, 251, 245],
                [254, 252, 249],
                [254, 253, 252],
                [254, 253, 252],
            ],
        );

        m.insert(
            "thal",
            [
                [1, 1, 9],
                [1, 1, 9],
                [1, 1, 17],
                [1, 1, 25],
                [1, 1, 33],
                [1, 1, 41],
                [1, 1, 49],
                [1, 1, 57],
                [1, 1, 64],
                [1, 1, 72],
                [1, 1, 80],
                [1, 1, 88],
                [1, 1, 96],
                [1, 1, 104],
                [1, 1, 112],
                [1, 1, 120],
                [1, 1, 128],
                [1, 1, 132],
                [1, 1, 136],
                [1, 1, 140],
                [1, 1, 144],
                [1, 1, 148],
                [1, 1, 152],
                [1, 1, 156],
                [1, 1, 160],
                [1, 1, 164],
                [1, 1, 168],
                [1, 1, 172],
                [1, 1, 176],
                [1, 1, 180],
                [1, 1, 184],
                [1, 1, 188],
                [1, 1, 191],
                [1, 1, 195],
                [1, 1, 199],
                [1, 1, 203],
                [1, 1, 207],
                [1, 1, 211],
                [1, 1, 215],
                [1, 1, 219],
                [1, 1, 223],
                [1, 1, 227],
                [1, 1, 231],
                [1, 1, 235],
                [1, 1, 239],
                [1, 1, 243],
                [1, 1, 247],
                [1, 1, 251],
                [1, 1, 254],
                [1, 5, 239],
                [1, 9, 223],
                [1, 13, 207],
                [1, 17, 191],
                [1, 21, 176],
                [1, 25, 160],
                [1, 29, 144],
                [1, 33, 128],
                [1, 37, 112],
                [1, 41, 96],
                [1, 45, 80],
                [1, 49, 64],
                [1, 53, 49],
                [1, 57, 33],
                [1, 61, 17],
                [1, 64, 1],
                [1, 68, 1],
                [1, 72, 1],
                [1, 76, 1],
                [1, 80, 1],
                [1, 84, 1],
                [1, 88, 1],
                [1, 92, 1],
                [1, 96, 1],
                [1, 100, 1],
                [1, 104, 1],
                [1, 108, 1],
                [1, 112, 1],
                [1, 116, 1],
                [1, 120, 1],
                [1, 124, 1],
                [1, 128, 1],
                [1, 132, 1],
                [1, 136, 1],
                [1, 140, 1],
                [1, 144, 1],
                [1, 148, 1],
                [1, 152, 1],
                [1, 156, 1],
                [1, 160, 1],
                [1, 164, 1],
                [1, 168, 1],
                [1, 172, 1],
                [1, 176, 1],
                [1, 180, 1],
                [1, 184, 1],
                [1, 188, 1],
                [1, 191, 1],
                [1, 195, 1],
                [1, 199, 1],
                [1, 203, 1],
                [1, 207, 1],
                [1, 211, 1],
                [1, 215, 1],
                [1, 219, 1],
                [1, 223, 1],
                [1, 227, 1],
                [1, 231, 1],
                [1, 235, 1],
                [1, 239, 1],
                [1, 243, 1],
                [1, 247, 1],
                [1, 251, 1],
                [1, 254, 1],
                [5, 239, 1],
                [9, 223, 1],
                [13, 207, 1],
                [17, 191, 1],
                [21, 176, 1],
                [25, 160, 1],
                [29, 144, 1],
                [33, 128, 1],
                [37, 112, 1],
                [41, 96, 1],
                [45, 80, 1],
                [49, 64, 1],
                [53, 49, 1],
                [57, 33, 1],
                [61, 17, 1],
                [64, 1, 1],
                [68, 1, 1],
                [72, 1, 1],
                [76, 1, 1],
                [80, 1, 1],
                [84, 1, 1],
                [88, 1, 1],
                [92, 1, 1],
                [96, 1, 1],
                [100, 1, 1],
                [104, 1, 1],
                [108, 1, 1],
                [112, 1, 1],
                [116, 1, 1],
                [120, 1, 1],
                [124, 1, 1],
                [128, 1, 1],
                [132, 1, 1],
                [136, 1, 1],
                [140, 1, 1],
                [144, 1, 1],
                [148, 1, 1],
                [152, 1, 1],
                [156, 1, 1],
                [160, 1, 1],
                [164, 1, 1],
                [168, 1, 1],
                [172, 1, 1],
                [176, 1, 1],
                [180, 1, 1],
                [184, 1, 1],
                [188, 1, 1],
                [191, 1, 1],
                [195, 1, 1],
                [199, 1, 1],
                [203, 1, 1],
                [207, 1, 1],
                [211, 1, 1],
                [215, 1, 1],
                [219, 1, 1],
                [223, 1, 1],
                [227, 1, 1],
                [231, 1, 1],
                [235, 1, 1],
                [239, 1, 1],
                [243, 1, 1],
                [247, 1, 1],
                [251, 1, 1],
                [254, 1, 1],
                [250, 5, 1],
                [247, 9, 1],
                [243, 13, 1],
                [239, 17, 1],
                [236, 21, 1],
                [232, 25, 1],
                [229, 29, 1],
                [225, 33, 1],
                [221, 37, 1],
                [218, 41, 1],
                [214, 45, 1],
                [210, 49, 1],
                [208, 53, 1],
                [205, 57, 1],
                [201, 61, 1],
                [199, 64, 1],
                [199, 68, 1],
                [199, 72, 1],
                [199, 76, 1],
                [199, 80, 1],
                [199, 84, 1],
                [199, 88, 1],
                [199, 92, 1],
                [199, 96, 1],
                [199, 100, 1],
                [199, 104, 1],
                [199, 108, 1],
                [199, 112, 1],
                [199, 116, 1],
                [199, 120, 1],
                [199, 124, 1],
                [199, 128, 1],
                [201, 132, 1],
                [205, 136, 1],
                [208, 140, 1],
                [210, 144, 1],
                [214, 148, 1],
                [218, 152, 1],
                [221, 156, 1],
                [225, 160, 1],
                [229, 164, 1],
                [232, 168, 1],
                [236, 172, 1],
                [239, 176, 1],
                [243, 180, 1],
                [247, 184, 1],
                [250, 188, 1],
                [254, 191, 1],
                [254, 195, 17],
                [254, 199, 33],
                [254, 203, 49],
                [254, 207, 64],
                [254, 211, 80],
                [254, 215, 96],
                [254, 219, 112],
                [254, 223, 128],
                [254, 227, 144],
                [254, 231, 160],
                [254, 235, 176],
                [254, 239, 191],
                [254, 243, 207],
                [254, 247, 223],
                [254, 251, 239],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
                [254, 254, 254],
            ],
        );

        m.insert(
            "thallium",
            [
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 1, 1],
                [1, 2, 1],
                [1, 2, 1],
                [1, 3, 1],
                [1, 4, 1],
                [1, 4, 1],
                [1, 5, 1],
                [1, 6, 1],
                [1, 6, 1],
                [1, 7, 1],
                [1, 7, 1],
                [1, 8, 1],
                [1, 9, 1],
                [1, 9, 1],
                [1, 10, 1],
                [1, 11, 1],
                [1, 12, 1],
                [1, 13, 1],
                [1, 13, 1],
                [1, 14, 1],
                [1, 14, 1],
                [1, 15, 1],
                [1, 16, 1],
                [1, 16, 1],
                [1, 17, 1],
                [1, 18, 1],
                [1, 19, 1],
                [1, 19, 1],
                [1, 19, 1],
                [1, 19, 1],
                [1, 19, 1],
                [1, 20, 1],
                [1, 20, 1],
                [1, 20, 1],
                [1, 20, 1],
                [1, 21, 1],
                [1, 21, 1],
                [1, 21, 1],
                [1, 22, 1],
                [1, 22, 1],
                [1, 22, 1],
                [1, 22, 1],
                [1, 23, 1],
                [1, 23, 1],
                [1, 23, 1],
                [1, 23, 1],
                [1, 24, 1],
                [1, 24, 1],
                [1, 24, 1],
                [1, 24, 1],
                [1, 25, 1],
                [1, 25, 1],
                [1, 25, 1],
                [1, 25, 1],
                [1, 26, 1],
                [1, 26, 1],
                [1, 27, 1],
                [1, 27, 1],
                [1, 28, 1],
                [1, 28, 1],
                [1, 29, 1],
                [1, 29, 1],
                [1, 30, 1],
                [1, 30, 1],
                [1, 31, 1],
                [1, 31, 1],
                [1, 32, 1],
                [1, 32, 1],
                [1, 33, 1],
                [1, 33, 1],
                [1, 34, 1],
                [1, 34, 1],
                [1, 35, 1],
                [1, 35, 1],
                [1, 36, 1],
                [1, 37, 1],
                [1, 37, 1],
                [1, 38, 1],
                [1, 38, 1],
                [1, 39, 1],
                [1, 40, 1],
                [1, 40, 1],
                [1, 41, 1],
                [2, 42, 2],
                [2, 42, 2],
                [3, 43, 3],
                [3, 44, 3],
                [4, 45, 4],
                [4, 45, 4],
                [5, 46, 5],
                [5, 47, 5],
                [6, 48, 6],
                [6, 48, 6],
                [6, 49, 6],
                [7, 51, 7],
                [8, 51, 8],
                [8, 52, 8],
                [9, 53, 9],
                [9, 54, 9],
                [10, 54, 10],
                [10, 55, 10],
                [11, 56, 11],
                [11, 56, 11],
                [11, 57, 11],
                [12, 58, 12],
                [12, 59, 12],
                [13, 59, 13],
                [13, 60, 13],
                [14, 61, 14],
                [14, 61, 14],
                [14, 62, 14],
                [15, 63, 15],
                [15, 64, 15],
                [16, 64, 16],
                [17, 66, 17],
                [17, 67, 17],
                [18, 68, 18],
                [18, 69, 18],
                [19, 70, 19],
                [19, 70, 19],
                [20, 71, 20],
                [20, 72, 20],
                [21, 73, 21],
                [21, 74, 21],
                [22, 75, 22],
                [22, 76, 22],
                [23, 77, 23],
                [23, 78, 23],
                [24, 79, 24],
                [24, 80, 24],
                [25, 81, 25],
                [25, 81, 25],
                [26, 82, 26],
                [26, 83, 26],
                [28, 86, 28],
                [29, 87, 29],
                [30, 88, 30],
                [31, 90, 31],
                [33, 91, 33],
                [34, 93, 34],
                [35, 94, 35],
                [36, 96, 36],
                [38, 97, 38],
                [39, 99, 39],
                [40, 100, 40],
                [41, 102, 41],
                [43, 103, 43],
                [44, 105, 44],
                [45, 106, 45],
                [46, 108, 46],
                [48, 109, 48],
                [49, 111, 49],
                [50, 112, 50],
                [53, 115, 53],
                [54, 117, 54],
                [55, 118, 55],
                [57, 119, 57],
                [58, 121, 58],
                [59, 122, 59],
                [60, 124, 60],
                [62, 125, 62],
                [63, 127, 63],
                [64, 128, 64],
                [65, 130, 65],
                [67, 132, 67],
                [70, 134, 70],
                [72, 136, 72],
                [75, 139, 75],
                [77, 141, 77],
                [80, 143, 80],
                [82, 145, 82],
                [85, 147, 85],
                [87, 150, 87],
                [92, 154, 92],
                [95, 156, 95],
                [97, 159, 97],
                [100, 161, 100],
                [102, 163, 102],
                [105, 165, 105],
                [107, 167, 107],
                [110, 170, 110],
                [112, 172, 112],
                [115, 174, 115],
                [117, 176, 117],
                [120, 178, 120],
                [122, 181, 122],
                [125, 183, 125],
                [127, 185, 127],
                [130, 187, 130],
                [134, 191, 134],
                [138, 192, 138],
                [142, 194, 142],
                [147, 196, 147],
                [156, 201, 156],
                [160, 203, 160],
                [164, 206, 164],
                [169, 208, 169],
                [173, 210, 173],
                [178, 213, 178],
                [182, 215, 182],
                [186, 217, 186],
                [191, 220, 191],
                [194, 222, 194],
                [199, 224, 199],
                [203, 227, 203],
                [207, 229, 207],
                [212, 231, 212],
                [216, 234, 216],
                [221, 236, 221],
                [225, 238, 225],
                [229, 241, 229],
                [234, 243, 234],
                [251, 242, 244],
                [252, 247, 251],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
                [253, 253, 253],
            ],
        );

        m.insert(
            "unionjack",
            [
                [0, 0, 0],
                [0, 0, 2],
                [0, 0, 5],
                [0, 0, 8],
                [0, 0, 11],
                [0, 0, 14],
                [0, 0, 17],
                [0, 0, 20],
                [0, 0, 23],
                [0, 0, 26],
                [0, 0, 29],
                [0, 0, 32],
                [0, 0, 35],
                [0, 0, 38],
                [0, 0, 41],
                [0, 0, 44],
                [0, 0, 47],
                [0, 0, 50],
                [0, 0, 53],
                [0, 0, 56],
                [0, 0, 59],
                [0, 0, 62],
                [0, 0, 65],
                [0, 0, 68],
                [0, 0, 71],
                [0, 0, 74],
                [0, 0, 77],
                [0, 0, 80],
                [0, 0, 83],
                [0, 0, 86],
                [0, 0, 89],
                [0, 0, 92],
                [0, 0, 95],
                [0, 0, 97],
                [0, 0, 100],
                [0, 0, 103],
                [0, 0, 106],
                [0, 0, 109],
                [0, 0, 112],
                [0, 0, 115],
                [0, 0, 118],
                [0, 0, 121],
                [0, 0, 124],
                [0, 0, 127],
                [0, 0, 130],
                [0, 0, 133],
                [0, 0, 136],
                [0, 0, 139],
                [0, 0, 142],
                [0, 0, 145],
                [0, 0, 148],
                [0, 0, 151],
                [0, 0, 154],
                [0, 0, 157],
                [0, 0, 160],
                [0, 0, 163],
                [0, 0, 166],
                [0, 0, 169],
                [0, 0, 172],
                [0, 0, 175],
                [0, 0, 178],
                [0, 0, 181],
                [0, 0, 184],
                [0, 0, 190],
                [0, 0, 190],
                [3, 3, 191],
                [7, 7, 192],
                [11, 11, 193],
                [15, 15, 194],
                [19, 19, 195],
                [23, 23, 196],
                [27, 27, 197],
                [31, 31, 198],
                [35, 35, 199],
                [39, 39, 200],
                [43, 43, 201],
                [47, 47, 202],
                [51, 51, 203],
                [55, 55, 204],
                [59, 59, 205],
                [63, 63, 206],
                [67, 67, 207],
                [71, 71, 208],
                [75, 75, 209],
                [79, 79, 210],
                [83, 83, 211],
                [87, 87, 212],
                [91, 91, 213],
                [95, 95, 214],
                [99, 99, 215],
                [103, 103, 216],
                [107, 107, 217],
                [111, 111, 218],
                [115, 115, 219],
                [119, 119, 220],
                [123, 123, 221],
                [127, 127, 222],
                [131, 131, 223],
                [135, 135, 224],
                [139, 139, 225],
                [143, 143, 226],
                [147, 147, 227],
                [151, 151, 228],
                [155, 155, 229],
                [159, 159, 230],
                [163, 163, 231],
                [167, 167, 232],
                [171, 171, 233],
                [175, 175, 234],
                [179, 179, 235],
                [183, 183, 236],
                [187, 187, 237],
                [191, 191, 238],
                [195, 195, 239],
                [199, 199, 240],
                [203, 203, 241],
                [207, 207, 242],
                [211, 211, 243],
                [215, 215, 244],
                [219, 219, 245],
                [223, 223, 246],
                [227, 227, 247],
                [231, 231, 248],
                [235, 235, 249],
                [239, 239, 250],
                [243, 243, 251],
                [247, 247, 252],
                [255, 255, 255],
                [255, 255, 255],
                [253, 251, 251],
                [252, 247, 247],
                [251, 243, 243],
                [250, 239, 239],
                [249, 235, 235],
                [248, 231, 231],
                [247, 227, 227],
                [246, 223, 223],
                [245, 219, 219],
                [244, 215, 215],
                [243, 211, 211],
                [242, 207, 207],
                [241, 203, 203],
                [240, 199, 199],
                [239, 195, 195],
                [238, 191, 191],
                [237, 187, 187],
                [236, 183, 183],
                [235, 179, 179],
                [234, 175, 175],
                [233, 171, 171],
                [232, 167, 167],
                [231, 163, 163],
                [230, 159, 159],
                [229, 155, 155],
                [228, 151, 151],
                [227, 147, 147],
                [226, 143, 143],
                [225, 139, 139],
                [224, 135, 135],
                [223, 131, 131],
                [222, 127, 127],
                [221, 123, 123],
                [220, 119, 119],
                [219, 115, 115],
                [218, 111, 111],
                [217, 107, 107],
                [216, 103, 103],
                [215, 99, 99],
                [214, 95, 95],
                [213, 91, 91],
                [212, 87, 87],
                [211, 83, 83],
                [210, 79, 79],
                [209, 75, 75],
                [208, 71, 71],
                [207, 67, 67],
                [206, 63, 63],
                [205, 59, 59],
                [204, 55, 55],
                [203, 51, 51],
                [202, 47, 47],
                [201, 43, 43],
                [200, 39, 39],
                [199, 35, 35],
                [198, 31, 31],
                [197, 27, 27],
                [196, 23, 23],
                [195, 19, 19],
                [194, 15, 15],
                [193, 11, 11],
                [192, 7, 7],
                [190, 0, 0],
                [190, 0, 0],
                [191, 3, 3],
                [192, 7, 7],
                [193, 11, 11],
                [194, 15, 15],
                [195, 19, 19],
                [196, 23, 23],
                [197, 27, 27],
                [198, 31, 31],
                [199, 35, 35],
                [200, 39, 39],
                [201, 43, 43],
                [202, 47, 47],
                [203, 51, 51],
                [204, 55, 55],
                [205, 59, 59],
                [206, 63, 63],
                [207, 67, 67],
                [208, 71, 71],
                [209, 75, 75],
                [210, 79, 79],
                [211, 83, 83],
                [212, 87, 87],
                [213, 91, 91],
                [214, 95, 95],
                [215, 99, 99],
                [216, 103, 103],
                [217, 107, 107],
                [218, 111, 111],
                [219, 115, 115],
                [220, 119, 119],
                [221, 123, 123],
                [222, 127, 127],
                [223, 131, 131],
                [224, 135, 135],
                [225, 139, 139],
                [226, 143, 143],
                [227, 147, 147],
                [228, 151, 151],
                [229, 155, 155],
                [230, 159, 159],
                [231, 163, 163],
                [232, 167, 167],
                [233, 171, 171],
                [234, 175, 175],
                [235, 179, 179],
                [236, 183, 183],
                [237, 187, 187],
                [238, 191, 191],
                [239, 195, 195],
                [240, 199, 199],
                [241, 203, 203],
                [242, 207, 207],
                [243, 211, 211],
                [244, 215, 215],
                [245, 219, 219],
                [246, 223, 223],
                [247, 227, 227],
                [248, 231, 231],
                [249, 235, 235],
                [250, 239, 239],
                [251, 243, 243],
                [252, 247, 247],
                [255, 255, 255],
            ],
        );

        m
    };
}
